.onAttach <-
function (lib, pkg) {
    pkg.info <- drop(read.dcf(file=system.file("DESCRIPTION", package="CatDyn"),
                              fields=c("Title","Version","Date")))

   packageStartupMessage(paste("--------------------------------------------------------------\n",
			       pkg.info["Title"]),"\n",
    paste(" CatDyn version ", pkg.info["Version"],
              " (built on ", pkg.info["Date"], ") is now loaded\n", sep=""),
			 "--------------------------------------------------------------\n"
    )
}
.psi.nb2 <-
function(psi,predcat1,obscat1) {sum(2*psi*log((psi+predcat1)/(psi+obscat1)) +
                                                     psi/(psi+obscat1) -
                                                     obscat1*(2*psi+obscat1)/(6*psi*(psi+obscat1)^2)) - psi}
.CatDynLik <-
function(obscat1,predcat1,distr,npar)
  {
                  Likel        <- vector("list",4);
                  names(Likel) <- c("Dispersion","Deviance","Likelihood","DevianceResidual");
                  sealen       <- length(obscat1);
                  if(distr=='poisson')
                    {
                     psi1        <- 1;
                     dev1        <- ifelse(obscat1==0 | predcat1==0,0,2*(obscat1*log(obscat1)-obscat1*log(predcat1)-(obscat1-predcat1)));
                     likcontr1   <- ifelse(predcat1==0,0,obscat1*log(predcat1) - predcat1 - lfactorial(obscat1));
                     res1        <- sign(obscat1-predcat1)*sqrt(dev1);
                    }
                  else if(distr=='negbin')
                    {
                     psi1        <- uniroot(f=.psi.nb2, interval=c(0.1,10), extendInt="upX", predcat1, obscat1)$root;
                     dev1        <- ifelse(obscat1==0,2*psi1*log(1+predcat1/psi1),
                                                      2*(obscat1*log(obscat1/predcat1)-(obscat1+psi1)*log((1+obscat1/psi1)/(1+predcat1/psi1))));
                     likcontr1   <- ifelse(predcat1==0,0,
                                           obscat1*log(1/psi1) +
                                           obscat1*log(predcat1) -
                                           (obscat1 + psi1)*log(1 + predcat1/psi1) +
                                           lgamma(obscat1 + psi1) -
                                           lgamma(obscat1 + 1) -
                                           lgamma(psi1));
                     res1        <- sign(obscat1-predcat1)*sqrt(dev1);
                    }
                  else if(distr=='normal')
                    {
                     psi1        <- sum((obscat1-predcat1)^2)/sealen;
                     dev1        <- ((obscat1-predcat1)^2)/sealen;
                     likcontr1   <- -(sealen/2)*log(2*pi*psi1)-(1/(2*psi1))*(obscat1-predcat1)^2;
                     res1        <- sign(obscat1-predcat1)*sqrt(dev1);
                    }
                  else if(distr=='apnormal')
                    {
                     psi1        <- NA;
                     res1        <- obscat1-predcat1;
                     likcontr1   <- res1^2;
                     dev1        <- res1;
                    }
                  else if(distr=='lognormal')
                    {
                     psi1        <- sum(ifelse(obscat1==0 | predcat1==0,0,(log(obscat1)-log(predcat1))^2))/sealen;
                     dev1        <- ifelse(obscat1==0 | predcat1==0,0,(log(obscat1)-log(predcat1))^2)/sealen;
                     likcontr1   <- ifelse(obscat1==0 | predcat1==0,0,-(sealen/2)*log(2*obscat1^2*pi*psi1)-(1/(2*psi1))*(log(obscat1)-log(predcat1))^2);
                     res1        <- sign(obscat1-predcat1)*sqrt(dev1);
                    }
                  else if(distr=='aplnormal')
                    {
                     psi1        <- NA;
                     res1        <- ifelse(obscat1==0 | predcat1==0,0,log(obscat1)-log(predcat1));
                     likcontr1   <- res1^2;
                     dev1        <- res1;
                    }
                  else if(distr=='gamma')
                    {
                     x <- vector("numeric",sealen)
                     for(i in 1:sealen)
                       {
                        x[i] <- ifelse(predcat1[i] == 0,0,(obscat1[i]-predcat1[i])^2/predcat1[i])
                       }
                     psi1        <- sum(x)/(sealen-(npar+1));
                     rm(x);
                     dev1        <- ifelse(obscat1==0 | predcat1==0,0,-(2/psi1)*(log(obscat1/predcat1)-(obscat1-predcat1)/predcat1));
                     likcontr1   <- ifelse(obscat1==0 | predcat1==0,0,(1/psi1)*(log(obscat1)-log(psi1*predcat1))-log(obscat1)-sealen*lgamma(1/psi1)-obscat1/(psi1*predcat1));
                     res1        <- sign(obscat1-predcat1)*sqrt(dev1);
                    }
                  Likel[[1]] <- psi1
                  Likel[[2]] <- dev1
                  Likel[[3]] <- likcontr1
                  Likel[[4]] <- res1
                  return(Likel);
  }
.CatDynExp1F.Res <-
function(properties,nstep,obsmbm1,ppp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
  {
                  if(properties$Units[2] == "ind")
                    {
                     biom <- NA
                    }
                  else
                    {
                     biom <- if(properties$Units[4] == "bill" && properties$Units[3] == "g")
                               {
                                obsmbm1*1e-6*nstep*1e9;
                               }
                             else if(properties$Units[4] == "bill" && properties$Units[3] == "kg")
                               {
                                obsmbm1*1e-3*nstep*1e9;
                               }
                             else if(properties$Units[4] == "mill" && properties$Units[3] == "g")
                               {
                                obsmbm1*1e-6*nstep*1e6;
                               }
                             else if(properties$Units[4] == "mill" && properties$Units[3] == "kg")
                               {
                               obsmbm1*1e-3*nstep*1e6;
                               }
                             else if(properties$Units[4] == "thou" && properties$Units[3] == "g")
                               {
                               obsmbm1*1e-6*nstep*1e3;
                               }
                             else if(properties$Units[4] == "thou" && properties$Units[3] == "kg")
                               {
                               obsmbm1*1e-3*nstep*1e3;
                               }
                             else if(properties$Units[4] == "hund" && properties$Units[3] == "g")
                               {
                               obsmbm1*1e-6*nstep*1e2;
                               }
                             else
                               {
                               obsmbm1*1e-3*nstep*1e2;
                               }
                    }
                  catdynexp                         <- vector("list",2);
                  names(catdynexp)                  <- c("Properties","Model");
                  catdynexp$Properties              <- properties;
                  catdynexp$Model                   <- vector("list",5);
                  names(catdynexp$Model)            <- c("Type","Dates","Distribution","Parameters","Results");
                  catdynexp$Model$Type              <- ppp;
                  catdynexp$Model$Dates             <- dates;
                  catdynexp$Model$Distribution      <- distr;
                  catdynexp$Model$Parameters        <- c(exp(par),Likel[[1]],dates);
                  if(ppp==0)
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0","k","alpha","beta","psi","ts.start","ts.end")
                    }
                  else if(ppp>0)
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0",paste("P",1:ppp,sep=""),"k","alpha","beta","psi","ts.start",paste("ts.P",1:ppp,sep=""),"ts.end")
                    }                                                   
                  else
                    {
                     ppp                               <- abs(ppp);
                     names(catdynexp$Model$Parameters) <- c("M","N0",paste("P",1:ppp,sep=""),"k","alpha","beta","psi","ts.start",paste(c("ts.P","ts.N"),sort(rep(1:ppp,2)),sep=""),"ts.end")
                    }                                                   
                  catdynexp$Model$Results           <- data.frame(period=ts.start:ts.end,
                                                                  obseff1=obseff1,
                                                                  obscat1=obscat1,
                                                                  modcat=predcat1,
                                                                  deviance=Likel[[2]],
                                                                  likcontr=Likel[[3]],
                                                                  devresid=Likel[[4]],
                                                                  npred=nstep,
                                                                  biompred=biom);
                  names(catdynexp$Model$Results)    <- c(paste("Period (",properties$Units[1],")",sep=""),
                                                         paste("Effort ",properties$Fleets[1,1]," Fleet (",properties$Fleets[1,2],")",sep=""),
                                                         paste("Obs. Catch ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                         paste("Pred. Catch ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                         paste("Deviance ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                         paste("Likelihood ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                         paste("Deviance Residuals ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                         paste("Pred. Abundance (",properties$Units[4],")",sep=""),
                                                         "Pred. Biomass (tonnes)")
                  return(catdynexp);
  }
.CatDynExp2F.Res <-
function(properties,nstep,obsmbm1,obsmbm2,ppp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
  {
                  if(properties$Units[2] == "ind")
                    {
                     biom <- NA
                    }
                  else
                    {
                     biom <- if(properties$Units[4] == "bill" && properties$Units[3] == "g")
                               {
                                (obsmbm1+obsmbm2)*0.5*1e-6*nstep*1e9;
                               }
                             else if(properties$Units[4] == "bill" && properties$Units[3] == "kg")
                               {
                                (obsmbm1+obsmbm2)*0.5*1e-3*nstep*1e9;
                               }
                             else if(properties$Units[4] == "mill" && properties$Units[3] == "g")
                               {
                                (obsmbm1+obsmbm2)*0.5*1e-6*nstep*1e6;
                               }
                             else if(properties$Units[4] == "mill" && properties$Units[3] == "kg")
                               {
                               (obsmbm1+obsmbm2)*0.5*1e-3*nstep*1e6;
                               }
                             else if(properties$Units[4] == "thou" && properties$Units[3] == "g")
                               {
                               (obsmbm1+obsmbm2)*0.5*1e-6*nstep*1e3;
                               }
                             else if(properties$Units[4] == "thou" && properties$Units[3] == "kg")
                               {
                               (obsmbm1+obsmbm2)*0.5*1e-3*nstep*1e3;
                               }
                             else if(properties$Units[4] == "hund" && properties$Units[3] == "g")
                               {
                               (obsmbm1+obsmbm2)*0.5*1e-6*nstep*1e2;
                               }
                             else
                               {
                               (obsmbm1+obsmbm2)*0.5*1e-3*nstep*1e2;
                               }
                    }
                  catdynexp                         <- vector("list",2);
                  names(catdynexp)                  <- c("Properties","Model");
                  catdynexp$Properties              <- properties;
                  catdynexp$Model                   <- vector("list",5);
                  names(catdynexp$Model)            <- c("Type","Dates","Distribution","Parameters","Results");
                  catdynexp$Model$Type              <- ppp;
                  catdynexp$Model$Dates             <- dates;
                  catdynexp$Model$Distribution      <- distr;
                  catdynexp$Model$Parameters        <- c(exp(par[c(1:((ppp[1]+5)))]),Likel1[[1]],exp(par[c((ppp[1]+6):length(par))]),Likel2[[1]],round(dates));
                  if(ppp == c(0,0))
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0","k1","alpha1","beta1","psi1","k2","alpha2","beta2","psi2","ts.start","ts.end")
                    }
                  else if(ppp == c(0,1))
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0","k1","alpha1","beta1","psi1","P1F2","k2","alpha2","beta2","psi2","ts.start","ts.P1F2","ts.end")
                    }
                  else if(ppp == c(0,2))
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0","k1","alpha1","beta1","psi1","P1F2","P2F2","k2","alpha2","beta2","psi2","ts.start","ts.P1F2","ts.P2F2","ts.end")
                    }
                  else if(ppp == c(0,3))
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0","k1","alpha1","beta1","psi1","P1F2","P2F2","P3F2","k2","alpha2","beta2","psi2","ts.start","ts.P1F2","ts.P2F2","ts.P3F2","ts.end")
                    }
                  else if(ppp == c(0,4))
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0","k1","alpha1","beta1","psi1","P1F2","P2F2","P3F2","P4F2","k2","alpha2","beta2","psi2","ts.start","ts.P1F2","ts.P2F2","ts.P3F2","ts.P4F2","ts.end")
                    }
                  else if(ppp == c(0,5))
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0","k1","alpha1","beta1","psi1","P1F2","P2F2","P3F2","P4F2","P5F2","k2","alpha2","beta2","psi2","ts.start","ts.P1F2","ts.P2F2","ts.P3F2","ts.P4F2","ts.P5F2","ts.end")
                    }
                  else
                    {
                     names(catdynexp$Model$Parameters) <- c("M","N0",paste("P",1:ppp[1],"F1",sep=""),"k1","alpha1","beta1","psi1",paste("P",1:ppp[2],"F2",sep=""),"k2","alpha2","beta2","psi2","ts.start",paste("ts.P",1:ppp[1],"F1",sep=""),paste("ts.P",1:ppp[2],"F1",sep=""),"ts.end")
                    }
                  catdynexp$Model$Results           <- data.frame(period=ts.start:ts.end,
                                                                  obseff1=obseff1,
                                                                  obscat1=obscat1,
                                                                  modcat1=predcat1,
                                                                  deviance1=Likel1[[2]],
                                                                  likcontr1=Likel1[[3]],
                                                                  devresid1=Likel1[[4]],
                                                                  obseff2=obseff2,
                                                                  obscat2=obscat2,
                                                                  modcat2=predcat2,
                                                                  deviance2=Likel2[[2]],
                                                                  likcontr2=Likel2[[3]],
                                                                  devresid2=Likel2[[4]],
                                                                  npred=nstep,
                                                                  biompred=biom);
                  names(catdynexp$Model$Results) <- c(paste("Period (",properties$Units[1],")",sep=""),
                                                      paste("Effort ",properties$Fleets[1,1]," Fleet (",properties$Fleets[1,2],")",sep=""),
                                                      paste("Obs. Catch ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Pred. Catch ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Deviance ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Likelihood ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Deviance Residuals ",properties$Fleets[1,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Effort ",properties$Fleets[2,1]," Fleet (",properties$Fleets[2,2],")",sep=""),
                                                      paste("Obs. Catch ",properties$Fleets[2,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Pred. Catch ",properties$Fleets[2,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Deviance ",properties$Fleets[2,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Likelihood ",properties$Fleets[2,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Deviance Residuals ",properties$Fleets[2,1]," Fleet (",properties$Units[4],")",sep=""),
                                                      paste("Pred. Abundance (",properties$Units[4],")",sep=""),
                                                      "Pred. Biomass (tonnes)")
                  return(catdynexp);
  }
.CDMN0P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=0)
  {
                  ts.start  <- head(dates,1);
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logscale  <- par[3];
                  logalpha  <- par[4];
                  logbeta   <- par[5];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                    mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                    nstep[i] <- exp(logN0)*exp(-exp(logM)*i) - mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN1P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=1)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logscale  <- par[4];
                  logalpha  <- par[5];
                  logbeta   <- par[6];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                    mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                    nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) -
                                mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN2P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=2)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logscale  <- par[5];
                  logalpha  <- par[6];
                  logbeta   <- par[7];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                    mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                    nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) -
                                mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN3P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=3)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                   ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logscale  <- par[6];
                  logalpha  <- par[7];
                  logbeta   <- par[8];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen){
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN4P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=4)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logscale  <- par[7];
                  logalpha  <- par[8];
                  logbeta   <- par[9];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN5P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=5)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logscale  <- par[8];
                  logalpha  <- par[9];
                  logbeta   <- par[10];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN6P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=6)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logscale  <- par[9];
                  logalpha  <- par[10];
                  logbeta   <- par[11];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN7P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=7)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logscale  <- par[10];
                  logalpha  <- par[11];
                  logbeta   <- par[12];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN8P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=8)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logscale  <- par[11];
                  logalpha  <- par[12];
                  logbeta   <- par[13];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN9P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=9)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logscale  <- par[12];
                  logalpha  <- par[13];
                  logbeta   <- par[14];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN10P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=10)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logscale  <- par[13];
                  logalpha  <- par[14];
                  logbeta   <- par[15];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN11P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=11)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logscale  <- par[14];
                  logalpha  <- par[15];
                  logbeta   <- par[16];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN12P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=12)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logscale  <- par[15];
                  logalpha  <- par[16];
                  logbeta   <- par[17];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN13P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=13)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logscale  <- par[16];
                  logalpha  <- par[17];
                  logbeta   <- par[18];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN14P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=14)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logscale  <- par[17];
                  logalpha  <- par[18];
                  logbeta   <- par[19];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN15P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=15)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logscale  <- par[18];
                  logalpha  <- par[19];
                  logbeta   <- par[20];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN16P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=16)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logscale  <- par[19];
                  logalpha  <- par[20];
                  logbeta   <- par[21];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN17P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=17)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logscale  <- par[20];
                  logalpha  <- par[21];
                  logbeta   <- par[22];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN18P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=18)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logscale  <- par[21];
                  logalpha  <- par[22];
                  logbeta   <- par[23];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN19P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=19)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logscale  <- par[22];
                  logalpha  <- par[23];
                  logbeta   <- par[24];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN20P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=20)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logscale  <- par[23];
                  logalpha  <- par[24];
                  logbeta   <- par[25];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha));
                  effn1     <- nstep^(exp(logbeta));
                  predcat1  <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel     <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN21P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=21)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logscale  <- par[24];
                  logalpha  <- par[25];
                  logbeta   <- par[26];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN22P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=22)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logscale  <- par[25];
                  logalpha  <- par[26];
                  logbeta   <- par[27];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN23P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=23)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logscale  <- par[26];
                  logalpha  <- par[27];
                  logbeta   <- par[28];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN24P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=24)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logscale  <- par[27];
                  logalpha  <- par[28];
                  logbeta   <- par[29];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN25P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=25)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logscale  <- par[28];
                  logalpha  <- par[29];
                  logbeta   <- par[30];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN26P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=26)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logscale  <- par[29];
                  logalpha  <- par[30];
                  logbeta   <- par[31];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN27P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=27)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logscale  <- par[30];
                  logalpha  <- par[31];
                  logbeta   <- par[32];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN28P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=28)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logscale  <- par[31];
                  logalpha  <- par[32];
                  logbeta   <- par[33];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN29P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=29)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logscale  <- par[32];
                  logalpha  <- par[33];
                  logbeta   <- par[34];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN30P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=30)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logscale  <- par[33];
                  logalpha  <- par[34];
                  logbeta   <- par[35];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN31P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=31)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logscale  <- par[34];
                  logalpha  <- par[35];
                  logbeta   <- par[36];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN32P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=32)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logscale  <- par[35];
                  logalpha  <- par[36];
                  logbeta   <- par[37];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN33P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=33)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logscale  <- par[36];
                  logalpha  <- par[37];
                  logbeta   <- par[38];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN34P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=34)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logscale  <- par[37];
                  logalpha  <- par[38];
                  logbeta   <- par[39];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN35P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=35)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logscale  <- par[38];
                  logalpha  <- par[39];
                  logbeta   <- par[40];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN36P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=36)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logscale  <- par[39];
                  logalpha  <- par[40];
                  logbeta   <- par[41];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN37P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=37)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logscale  <- par[40];
                  logalpha  <- par[41];
                  logbeta   <- par[42];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN38P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=38)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logscale  <- par[41];
                  logalpha  <- par[42];
                  logbeta   <- par[43];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN39P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=39)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logscale  <- par[42];
                  logalpha  <- par[43];
                  logbeta   <- par[44];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN40P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=40)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logscale  <- par[43];
                  logalpha  <- par[44];
                  logbeta   <- par[45];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN41P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=41)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logscale  <- par[44];
                  logalpha  <- par[45];
                  logbeta   <- par[46];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN42P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=42)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logscale  <- par[45];
                  logalpha  <- par[46];
                  logbeta   <- par[47];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN43P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=43)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logscale  <- par[46];
                  logalpha  <- par[47];
                  logbeta   <- par[48];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN44P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=44)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logscale  <- par[47];
                  logalpha  <- par[48];
                  logbeta   <- par[49];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN45P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=45)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logscale  <- par[48];
                  logalpha  <- par[49];
                  logbeta   <- par[50];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN46P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=46)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logscale  <- par[49];
                  logalpha  <- par[50];
                  logbeta   <- par[51];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN47P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=47)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logscale  <- par[50];
                  logalpha  <- par[51];
                  logbeta   <- par[52];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN48P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=48)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logscale  <- par[51];
                  logalpha  <- par[52];
                  logbeta   <- par[53];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN49P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=49)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logscale  <- par[52];
                  logalpha  <- par[53];
                  logbeta   <- par[54];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN50P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=50)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logscale  <- par[53];
                  logalpha  <- par[54];
                  logbeta   <- par[55];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN51P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=51)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logscale  <- par[54];
                  logalpha  <- par[55];
                  logbeta   <- par[56];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN52P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=52)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logscale  <- par[55];
                  logalpha  <- par[56];
                  logbeta   <- par[57];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN53P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=53)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logscale  <- par[56];
                  logalpha  <- par[57];
                  logbeta   <- par[58];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN54P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=54)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logscale  <- par[57];
                  logalpha  <- par[58];
                  logbeta   <- par[59];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN55P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=55)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logscale  <- par[58];
                  logalpha  <- par[59];
                  logbeta   <- par[60];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN56P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=56)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logscale  <- par[59];
                  logalpha  <- par[60];
                  logbeta   <- par[61];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN57P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=57)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logscale  <- par[60];
                  logalpha  <- par[61];
                  logbeta   <- par[62];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN58P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=58)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logscale  <- par[61];
                  logalpha  <- par[62];
                  logbeta   <- par[63];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN59P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=59)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logscale  <- par[62];
                  logalpha  <- par[63];
                  logbeta   <- par[64];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN60P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=60)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logscale  <- par[63];
                  logalpha  <- par[64];
                  logbeta   <- par[65];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN61P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=61)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logscale  <- par[64];
                  logalpha  <- par[65];
                  logbeta   <- par[66];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN62P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=62)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logscale  <- par[65];
                  logalpha  <- par[66];
                  logbeta   <- par[67];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN63P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=63)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logscale  <- par[66];
                  logalpha  <- par[67];
                  logbeta   <- par[68];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN64P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=64)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logscale  <- par[67];
                  logalpha  <- par[68];
                  logbeta   <- par[69];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN65P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=65)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logscale  <- par[68];
                  logalpha  <- par[69];
                  logbeta   <- par[70];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN66P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=66)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logscale  <- par[69];
                  logalpha  <- par[70];
                  logbeta   <- par[71];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN67P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=67)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logscale  <- par[70];
                  logalpha  <- par[71];
                  logbeta   <- par[72];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN68P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=68)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logscale  <- par[71];
                  logalpha  <- par[72];
                  logbeta   <- par[73];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN69P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=69)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logscale  <- par[72];
                  logalpha  <- par[73];
                  logbeta   <- par[74];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN70P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=70)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logscale  <- par[73];
                  logalpha  <- par[74];
                  logbeta   <- par[75];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN71P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=71)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logscale  <- par[74];
                  logalpha  <- par[75];
                  logbeta   <- par[76];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN72P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=72)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logscale  <- par[75];
                  logalpha  <- par[76];
                  logbeta   <- par[77];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN73P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=73)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logscale  <- par[76];
                  logalpha  <- par[77];
                  logbeta   <- par[78];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN74P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=74)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logscale  <- par[77];
                  logalpha  <- par[78];
                  logbeta   <- par[79];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN75P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=75)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logscale  <- par[78];
                  logalpha  <- par[79];
                  logbeta   <- par[80];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN76P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=76)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logscale  <- par[79];
                  logalpha  <- par[80];
                  logbeta   <- par[81];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN77P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=77)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logscale  <- par[80];
                  logalpha  <- par[81];
                  logbeta   <- par[82];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN78P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=78)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logscale  <- par[81];
                  logalpha  <- par[82];
                  logbeta   <- par[83];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN79P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=79)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logscale  <- par[82];
                  logalpha  <- par[83];
                  logbeta   <- par[84];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN80P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=80)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logscale  <- par[83];
                  logalpha  <- par[84];
                  logbeta   <- par[85];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN81P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=81)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logscale  <- par[84];
                  logalpha  <- par[85];
                  logbeta   <- par[86];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN82P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=82)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logscale  <- par[85];
                  logalpha  <- par[86];
                  logbeta   <- par[87];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN83P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=83)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logscale  <- par[86];
                  logalpha  <- par[87];
                  logbeta   <- par[88];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN84P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=84)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logscale  <- par[87];
                  logalpha  <- par[88];
                  logbeta   <- par[89];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN85P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=85)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logscale  <- par[88];
                  logalpha  <- par[89];
                  logbeta   <- par[90];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN86P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=86)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logscale  <- par[89];
                  logalpha  <- par[90];
                  logbeta   <- par[91];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN87P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=87)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logscale  <- par[90];
                  logalpha  <- par[91];
                  logbeta   <- par[92];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN88P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=88)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logscale  <- par[91];
                  logalpha  <- par[92];
                  logbeta   <- par[93];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN89P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=89)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logscale  <- par[92];
                  logalpha  <- par[93];
                  logbeta   <- par[94];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN90P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=90)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logscale  <- par[93];
                  logalpha  <- par[94];
                  logbeta   <- par[95];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN91P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=91)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logscale  <- par[94];
                  logalpha  <- par[95];
                  logbeta   <- par[96];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN92P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=92)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logscale  <- par[95];
                  logalpha  <- par[96];
                  logbeta   <- par[97];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN93P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=93)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logscale  <- par[96];
                  logalpha  <- par[97];
                  logbeta   <- par[98];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN94P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=94)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.P94    <- dates[95];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  ind.P94   <- ifelse(1:sealen < (ts.P94-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logP94    <- par[96];
                  logscale  <- par[97];
                  logalpha  <- par[98];
                  logbeta   <- par[99];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) +
                                 ind.P94[i]*exp(logP94)*exp(-exp(logM)*(i-(ts.P94-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN95P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=95)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.P94    <- dates[95];
                  ts.P95    <- dates[96];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  ind.P94   <- ifelse(1:sealen < (ts.P94-ts.start), 0, 1);
                  ind.P95   <- ifelse(1:sealen < (ts.P95-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logP94    <- par[96];
                  logP95    <- par[97];
                  logscale  <- par[98];
                  logalpha  <- par[99];
                  logbeta   <- par[100];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) +
                                 ind.P94[i]*exp(logP94)*exp(-exp(logM)*(i-(ts.P94-ts.start)+1)) +
                                 ind.P95[i]*exp(logP95)*exp(-exp(logM)*(i-(ts.P95-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN96P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=96)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.P94    <- dates[95];
                  ts.P95    <- dates[96];
                  ts.P96    <- dates[97];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  ind.P94   <- ifelse(1:sealen < (ts.P94-ts.start), 0, 1);
                  ind.P95   <- ifelse(1:sealen < (ts.P95-ts.start), 0, 1);
                  ind.P96   <- ifelse(1:sealen < (ts.P96-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logP94    <- par[96];
                  logP95    <- par[97];
                  logP96    <- par[98];
                  logscale  <- par[99];
                  logalpha  <- par[100];
                  logbeta   <- par[101];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) +
                                 ind.P94[i]*exp(logP94)*exp(-exp(logM)*(i-(ts.P94-ts.start)+1)) +
                                 ind.P95[i]*exp(logP95)*exp(-exp(logM)*(i-(ts.P95-ts.start)+1)) +
                                 ind.P96[i]*exp(logP96)*exp(-exp(logM)*(i-(ts.P96-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN97P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=97)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.P94    <- dates[95];
                  ts.P95    <- dates[96];
                  ts.P96    <- dates[97];
                  ts.P97    <- dates[98];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  ind.P94   <- ifelse(1:sealen < (ts.P94-ts.start), 0, 1);
                  ind.P95   <- ifelse(1:sealen < (ts.P95-ts.start), 0, 1);
                  ind.P96   <- ifelse(1:sealen < (ts.P96-ts.start), 0, 1);
                  ind.P97   <- ifelse(1:sealen < (ts.P97-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logP94    <- par[96];
                  logP95    <- par[97];
                  logP96    <- par[98];
                  logP97    <- par[99];
                  logscale  <- par[100];
                  logalpha  <- par[101];
                  logbeta   <- par[102];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) +
                                 ind.P94[i]*exp(logP94)*exp(-exp(logM)*(i-(ts.P94-ts.start)+1)) +
                                 ind.P95[i]*exp(logP95)*exp(-exp(logM)*(i-(ts.P95-ts.start)+1)) +
                                 ind.P96[i]*exp(logP96)*exp(-exp(logM)*(i-(ts.P96-ts.start)+1)) +
                                 ind.P97[i]*exp(logP97)*exp(-exp(logM)*(i-(ts.P97-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN98P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=98)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.P94    <- dates[95];
                  ts.P95    <- dates[96];
                  ts.P96    <- dates[97];
                  ts.P97    <- dates[98];
                  ts.P98    <- dates[99];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  ind.P94   <- ifelse(1:sealen < (ts.P94-ts.start), 0, 1);
                  ind.P95   <- ifelse(1:sealen < (ts.P95-ts.start), 0, 1);
                  ind.P96   <- ifelse(1:sealen < (ts.P96-ts.start), 0, 1);
                  ind.P97   <- ifelse(1:sealen < (ts.P97-ts.start), 0, 1);
                  ind.P98   <- ifelse(1:sealen < (ts.P98-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logP94    <- par[96];
                  logP95    <- par[97];
                  logP96    <- par[98];
                  logP97    <- par[99];
                  logP98    <- par[100];
                  logscale  <- par[101];
                  logalpha  <- par[102];
                  logbeta   <- par[103];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) +
                                 ind.P94[i]*exp(logP94)*exp(-exp(logM)*(i-(ts.P94-ts.start)+1)) +
                                 ind.P95[i]*exp(logP95)*exp(-exp(logM)*(i-(ts.P95-ts.start)+1)) +
                                 ind.P96[i]*exp(logP96)*exp(-exp(logM)*(i-(ts.P96-ts.start)+1)) +
                                 ind.P97[i]*exp(logP97)*exp(-exp(logM)*(i-(ts.P97-ts.start)+1)) +
                                 ind.P98[i]*exp(logP98)*exp(-exp(logM)*(i-(ts.P98-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN99P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=99)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.P94    <- dates[95];
                  ts.P95    <- dates[96];
                  ts.P96    <- dates[97];
                  ts.P97    <- dates[98];
                  ts.P98    <- dates[99];
                  ts.P99    <- dates[100];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  ind.P94   <- ifelse(1:sealen < (ts.P94-ts.start), 0, 1);
                  ind.P95   <- ifelse(1:sealen < (ts.P95-ts.start), 0, 1);
                  ind.P96   <- ifelse(1:sealen < (ts.P96-ts.start), 0, 1);
                  ind.P97   <- ifelse(1:sealen < (ts.P97-ts.start), 0, 1);
                  ind.P98   <- ifelse(1:sealen < (ts.P98-ts.start), 0, 1);
                  ind.P99   <- ifelse(1:sealen < (ts.P99-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logP94    <- par[96];
                  logP95    <- par[97];
                  logP96    <- par[98];
                  logP97    <- par[99];
                  logP98    <- par[100];
                  logP99    <- par[101];
                  logscale  <- par[102];
                  logalpha  <- par[103];
                  logbeta   <- par[104];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) +
                                 ind.P94[i]*exp(logP94)*exp(-exp(logM)*(i-(ts.P94-ts.start)+1)) +
                                 ind.P95[i]*exp(logP95)*exp(-exp(logM)*(i-(ts.P95-ts.start)+1)) +
                                 ind.P96[i]*exp(logP96)*exp(-exp(logM)*(i-(ts.P96-ts.start)+1)) +
                                 ind.P97[i]*exp(logP97)*exp(-exp(logM)*(i-(ts.P97-ts.start)+1)) +
                                 ind.P98[i]*exp(logP98)*exp(-exp(logM)*(i-(ts.P98-ts.start)+1)) +
                                 ind.P99[i]*exp(logP99)*exp(-exp(logM)*(i-(ts.P99-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN100P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=100)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.P2     <- dates[3];
                  ts.P3     <- dates[4];
                  ts.P4     <- dates[5];
                  ts.P5     <- dates[6];
                  ts.P6     <- dates[7];
                  ts.P7     <- dates[8];
                  ts.P8     <- dates[9];
                  ts.P9     <- dates[10];
                  ts.P10    <- dates[11];
                  ts.P11    <- dates[12];
                  ts.P12    <- dates[13];
                  ts.P13    <- dates[14];
                  ts.P14    <- dates[15];
                  ts.P15    <- dates[16];
                  ts.P16    <- dates[17];
                  ts.P17    <- dates[18];
                  ts.P18    <- dates[19];
                  ts.P19    <- dates[20];
                  ts.P20    <- dates[21];
                  ts.P21    <- dates[22];
                  ts.P22    <- dates[23];
                  ts.P23    <- dates[24];
                  ts.P24    <- dates[25];
                  ts.P25    <- dates[26];
                  ts.P26    <- dates[27];
                  ts.P27    <- dates[28];
                  ts.P28    <- dates[29];
                  ts.P29    <- dates[30];
                  ts.P30    <- dates[31];
                  ts.P31    <- dates[32];
                  ts.P32    <- dates[33];
                  ts.P33    <- dates[34];
                  ts.P34    <- dates[35];
                  ts.P35    <- dates[36];
                  ts.P36    <- dates[37];
                  ts.P37    <- dates[38];
                  ts.P38    <- dates[39];
                  ts.P39    <- dates[40];
                  ts.P40    <- dates[41];
                  ts.P41    <- dates[42];
                  ts.P42    <- dates[43];
                  ts.P43    <- dates[44];
                  ts.P44    <- dates[45];
                  ts.P45    <- dates[46];
                  ts.P46    <- dates[47];
                  ts.P47    <- dates[48];
                  ts.P48    <- dates[49];
                  ts.P49    <- dates[50];
                  ts.P49    <- dates[50];
                  ts.P50    <- dates[51];
                  ts.P51    <- dates[52];
                  ts.P52    <- dates[53];
                  ts.P53    <- dates[54];
                  ts.P54    <- dates[55];
                  ts.P55    <- dates[56];
                  ts.P56    <- dates[57];
                  ts.P57    <- dates[58];
                  ts.P58    <- dates[59];
                  ts.P59    <- dates[60];
                  ts.P60    <- dates[61];
                  ts.P61    <- dates[62];
                  ts.P62    <- dates[63];
                  ts.P63    <- dates[64];
                  ts.P64    <- dates[65];
                  ts.P65    <- dates[66];
                  ts.P66    <- dates[67];
                  ts.P67    <- dates[68];
                  ts.P68    <- dates[69];
                  ts.P69    <- dates[70];
                  ts.P70    <- dates[71];
                  ts.P71    <- dates[72];
                  ts.P72    <- dates[73];
                  ts.P73    <- dates[74];
                  ts.P74    <- dates[75];
                  ts.P75    <- dates[76];
                  ts.P76    <- dates[77];
                  ts.P77    <- dates[78];
                  ts.P78    <- dates[79];
                  ts.P79    <- dates[80];
                  ts.P80    <- dates[81];
                  ts.P81    <- dates[82];
                  ts.P82    <- dates[83];
                  ts.P83    <- dates[84];
                  ts.P84    <- dates[85];
                  ts.P85    <- dates[86];
                  ts.P86    <- dates[87];
                  ts.P87    <- dates[88];
                  ts.P88    <- dates[89];
                  ts.P89    <- dates[90];
                  ts.P90    <- dates[91];
                  ts.P91    <- dates[92];
                  ts.P92    <- dates[93];
                  ts.P93    <- dates[94];
                  ts.P94    <- dates[95];
                  ts.P95    <- dates[96];
                  ts.P96    <- dates[97];
                  ts.P97    <- dates[98];
                  ts.P98    <- dates[99];
                  ts.P99    <- dates[100];
                  ts.P100   <- dates[101];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start), 0, 1);
                  ind.P21   <- ifelse(1:sealen < (ts.P21-ts.start), 0, 1);
                  ind.P22   <- ifelse(1:sealen < (ts.P22-ts.start), 0, 1);
                  ind.P23   <- ifelse(1:sealen < (ts.P23-ts.start), 0, 1);
                  ind.P24   <- ifelse(1:sealen < (ts.P24-ts.start), 0, 1);
                  ind.P25   <- ifelse(1:sealen < (ts.P25-ts.start), 0, 1);
                  ind.P26   <- ifelse(1:sealen < (ts.P26-ts.start), 0, 1);
                  ind.P27   <- ifelse(1:sealen < (ts.P27-ts.start), 0, 1);
                  ind.P28   <- ifelse(1:sealen < (ts.P28-ts.start), 0, 1);
                  ind.P29   <- ifelse(1:sealen < (ts.P29-ts.start), 0, 1);
                  ind.P30   <- ifelse(1:sealen < (ts.P30-ts.start), 0, 1);
                  ind.P31   <- ifelse(1:sealen < (ts.P31-ts.start), 0, 1);
                  ind.P32   <- ifelse(1:sealen < (ts.P32-ts.start), 0, 1);
                  ind.P33   <- ifelse(1:sealen < (ts.P33-ts.start), 0, 1);
                  ind.P34   <- ifelse(1:sealen < (ts.P34-ts.start), 0, 1);
                  ind.P35   <- ifelse(1:sealen < (ts.P35-ts.start), 0, 1);
                  ind.P36   <- ifelse(1:sealen < (ts.P36-ts.start), 0, 1);
                  ind.P37   <- ifelse(1:sealen < (ts.P37-ts.start), 0, 1);
                  ind.P38   <- ifelse(1:sealen < (ts.P38-ts.start), 0, 1);
                  ind.P39   <- ifelse(1:sealen < (ts.P39-ts.start), 0, 1);
                  ind.P40   <- ifelse(1:sealen < (ts.P40-ts.start), 0, 1);
                  ind.P41   <- ifelse(1:sealen < (ts.P41-ts.start), 0, 1);
                  ind.P42   <- ifelse(1:sealen < (ts.P42-ts.start), 0, 1);
                  ind.P43   <- ifelse(1:sealen < (ts.P43-ts.start), 0, 1);
                  ind.P44   <- ifelse(1:sealen < (ts.P44-ts.start), 0, 1);
                  ind.P45   <- ifelse(1:sealen < (ts.P45-ts.start), 0, 1);
                  ind.P46   <- ifelse(1:sealen < (ts.P46-ts.start), 0, 1);
                  ind.P47   <- ifelse(1:sealen < (ts.P47-ts.start), 0, 1);
                  ind.P48   <- ifelse(1:sealen < (ts.P48-ts.start), 0, 1);
                  ind.P49   <- ifelse(1:sealen < (ts.P49-ts.start), 0, 1);
                  ind.P50   <- ifelse(1:sealen < (ts.P50-ts.start), 0, 1);
                  ind.P51   <- ifelse(1:sealen < (ts.P51-ts.start), 0, 1);
                  ind.P52   <- ifelse(1:sealen < (ts.P52-ts.start), 0, 1);
                  ind.P53   <- ifelse(1:sealen < (ts.P53-ts.start), 0, 1);
                  ind.P54   <- ifelse(1:sealen < (ts.P54-ts.start), 0, 1);
                  ind.P55   <- ifelse(1:sealen < (ts.P55-ts.start), 0, 1);
                  ind.P56   <- ifelse(1:sealen < (ts.P56-ts.start), 0, 1);
                  ind.P57   <- ifelse(1:sealen < (ts.P57-ts.start), 0, 1);
                  ind.P58   <- ifelse(1:sealen < (ts.P58-ts.start), 0, 1);
                  ind.P59   <- ifelse(1:sealen < (ts.P59-ts.start), 0, 1);
                  ind.P60   <- ifelse(1:sealen < (ts.P60-ts.start), 0, 1);
                  ind.P61   <- ifelse(1:sealen < (ts.P61-ts.start), 0, 1);
                  ind.P62   <- ifelse(1:sealen < (ts.P62-ts.start), 0, 1);
                  ind.P63   <- ifelse(1:sealen < (ts.P63-ts.start), 0, 1);
                  ind.P64   <- ifelse(1:sealen < (ts.P64-ts.start), 0, 1);
                  ind.P65   <- ifelse(1:sealen < (ts.P65-ts.start), 0, 1);
                  ind.P66   <- ifelse(1:sealen < (ts.P66-ts.start), 0, 1);
                  ind.P67   <- ifelse(1:sealen < (ts.P67-ts.start), 0, 1);
                  ind.P68   <- ifelse(1:sealen < (ts.P68-ts.start), 0, 1);
                  ind.P69   <- ifelse(1:sealen < (ts.P69-ts.start), 0, 1);
                  ind.P70   <- ifelse(1:sealen < (ts.P70-ts.start), 0, 1);
                  ind.P71   <- ifelse(1:sealen < (ts.P71-ts.start), 0, 1);
                  ind.P72   <- ifelse(1:sealen < (ts.P72-ts.start), 0, 1);
                  ind.P73   <- ifelse(1:sealen < (ts.P73-ts.start), 0, 1);
                  ind.P74   <- ifelse(1:sealen < (ts.P74-ts.start), 0, 1);
                  ind.P75   <- ifelse(1:sealen < (ts.P75-ts.start), 0, 1);
                  ind.P76   <- ifelse(1:sealen < (ts.P76-ts.start), 0, 1);
                  ind.P77   <- ifelse(1:sealen < (ts.P77-ts.start), 0, 1);
                  ind.P78   <- ifelse(1:sealen < (ts.P78-ts.start), 0, 1);
                  ind.P79   <- ifelse(1:sealen < (ts.P79-ts.start), 0, 1);
                  ind.P80   <- ifelse(1:sealen < (ts.P80-ts.start), 0, 1);
                  ind.P81   <- ifelse(1:sealen < (ts.P81-ts.start), 0, 1);
                  ind.P82   <- ifelse(1:sealen < (ts.P82-ts.start), 0, 1);
                  ind.P83   <- ifelse(1:sealen < (ts.P83-ts.start), 0, 1);
                  ind.P84   <- ifelse(1:sealen < (ts.P84-ts.start), 0, 1);
                  ind.P85   <- ifelse(1:sealen < (ts.P85-ts.start), 0, 1);
                  ind.P86   <- ifelse(1:sealen < (ts.P86-ts.start), 0, 1);
                  ind.P87   <- ifelse(1:sealen < (ts.P87-ts.start), 0, 1);
                  ind.P88   <- ifelse(1:sealen < (ts.P88-ts.start), 0, 1);
                  ind.P89   <- ifelse(1:sealen < (ts.P89-ts.start), 0, 1);
                  ind.P90   <- ifelse(1:sealen < (ts.P90-ts.start), 0, 1);
                  ind.P91   <- ifelse(1:sealen < (ts.P91-ts.start), 0, 1);
                  ind.P92   <- ifelse(1:sealen < (ts.P92-ts.start), 0, 1);
                  ind.P93   <- ifelse(1:sealen < (ts.P93-ts.start), 0, 1);
                  ind.P94   <- ifelse(1:sealen < (ts.P94-ts.start), 0, 1);
                  ind.P95   <- ifelse(1:sealen < (ts.P95-ts.start), 0, 1);
                  ind.P96   <- ifelse(1:sealen < (ts.P96-ts.start), 0, 1);
                  ind.P97   <- ifelse(1:sealen < (ts.P97-ts.start), 0, 1);
                  ind.P98   <- ifelse(1:sealen < (ts.P98-ts.start), 0, 1);
                  ind.P99   <- ifelse(1:sealen < (ts.P99-ts.start), 0, 1);
                  ind.P100  <- ifelse(1:sealen < (ts.P100-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logP21    <- par[23];
                  logP22    <- par[24];
                  logP23    <- par[25];
                  logP24    <- par[26];
                  logP25    <- par[27];
                  logP26    <- par[28];
                  logP27    <- par[29];
                  logP28    <- par[30];
                  logP29    <- par[31];
                  logP30    <- par[32];
                  logP31    <- par[33];
                  logP32    <- par[34];
                  logP33    <- par[35];
                  logP34    <- par[36];
                  logP35    <- par[37];
                  logP36    <- par[38];
                  logP37    <- par[39];
                  logP38    <- par[40];
                  logP39    <- par[41];
                  logP40    <- par[42];
                  logP41    <- par[43];
                  logP42    <- par[44];
                  logP43    <- par[45];
                  logP44    <- par[46];
                  logP45    <- par[47];
                  logP46    <- par[48];
                  logP47    <- par[49];
                  logP48    <- par[50];
                  logP49    <- par[51];
                  logP50    <- par[52];
                  logP51    <- par[53];
                  logP52    <- par[54];
                  logP53    <- par[55];
                  logP54    <- par[56];
                  logP55    <- par[57];
                  logP56    <- par[58];
                  logP57    <- par[59];
                  logP58    <- par[60];
                  logP59    <- par[61];
                  logP60    <- par[62];
                  logP61    <- par[63];
                  logP62    <- par[64];
                  logP63    <- par[65];
                  logP64    <- par[66];
                  logP65    <- par[67];
                  logP66    <- par[68];
                  logP67    <- par[69];
                  logP68    <- par[70];
                  logP69    <- par[71];
                  logP70    <- par[72];
                  logP71    <- par[73];
                  logP72    <- par[74];
                  logP73    <- par[75];
                  logP74    <- par[76];
                  logP75    <- par[77];
                  logP76    <- par[78];
                  logP77    <- par[79];
                  logP78    <- par[80];
                  logP79    <- par[81];
                  logP80    <- par[82];
                  logP81    <- par[83];
                  logP82    <- par[84];
                  logP83    <- par[85];
                  logP84    <- par[86];
                  logP85    <- par[87];
                  logP86    <- par[88];
                  logP87    <- par[89];
                  logP88    <- par[90];
                  logP89    <- par[91];
                  logP90    <- par[92];
                  logP91    <- par[93];
                  logP92    <- par[94];
                  logP93    <- par[95];
                  logP94    <- par[96];
                  logP95    <- par[97];
                  logP96    <- par[98];
                  logP97    <- par[99];
                  logP98    <- par[100];
                  logP99    <- par[101];
                  logP100   <- par[102];
                  logscale  <- par[103];
                  logalpha  <- par[104];
                  logbeta   <- par[105];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start)+1)) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start)+1)) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start)+1)) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start)+1)) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start)+1)) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start)+1)) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start)+1)) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start)+1)) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start)+1)) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start)+1)) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start)+1)) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start)+1)) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start)+1)) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start)+1)) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start)+1)) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start)+1)) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start)+1)) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start)+1)) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start)+1)) +
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start)+1)) +
                                 ind.P21[i]*exp(logP21)*exp(-exp(logM)*(i-(ts.P21-ts.start)+1)) +
                                 ind.P22[i]*exp(logP22)*exp(-exp(logM)*(i-(ts.P22-ts.start)+1)) +
                                 ind.P23[i]*exp(logP23)*exp(-exp(logM)*(i-(ts.P23-ts.start)+1)) +
                                 ind.P24[i]*exp(logP24)*exp(-exp(logM)*(i-(ts.P24-ts.start)+1)) +
                                 ind.P25[i]*exp(logP25)*exp(-exp(logM)*(i-(ts.P25-ts.start)+1)) +
                                 ind.P26[i]*exp(logP26)*exp(-exp(logM)*(i-(ts.P26-ts.start)+1)) +
                                 ind.P27[i]*exp(logP27)*exp(-exp(logM)*(i-(ts.P27-ts.start)+1)) +
                                 ind.P28[i]*exp(logP28)*exp(-exp(logM)*(i-(ts.P28-ts.start)+1)) +
                                 ind.P29[i]*exp(logP29)*exp(-exp(logM)*(i-(ts.P29-ts.start)+1)) +
                                 ind.P30[i]*exp(logP30)*exp(-exp(logM)*(i-(ts.P30-ts.start)+1)) +
                                 ind.P31[i]*exp(logP31)*exp(-exp(logM)*(i-(ts.P31-ts.start)+1)) +
                                 ind.P32[i]*exp(logP32)*exp(-exp(logM)*(i-(ts.P32-ts.start)+1)) +
                                 ind.P33[i]*exp(logP33)*exp(-exp(logM)*(i-(ts.P33-ts.start)+1)) +
                                 ind.P34[i]*exp(logP34)*exp(-exp(logM)*(i-(ts.P34-ts.start)+1)) +
                                 ind.P35[i]*exp(logP35)*exp(-exp(logM)*(i-(ts.P35-ts.start)+1)) +
                                 ind.P36[i]*exp(logP36)*exp(-exp(logM)*(i-(ts.P36-ts.start)+1)) +
                                 ind.P37[i]*exp(logP37)*exp(-exp(logM)*(i-(ts.P37-ts.start)+1)) +
                                 ind.P38[i]*exp(logP38)*exp(-exp(logM)*(i-(ts.P38-ts.start)+1)) +
                                 ind.P39[i]*exp(logP39)*exp(-exp(logM)*(i-(ts.P39-ts.start)+1)) +
                                 ind.P40[i]*exp(logP40)*exp(-exp(logM)*(i-(ts.P40-ts.start)+1)) +
                                 ind.P41[i]*exp(logP41)*exp(-exp(logM)*(i-(ts.P41-ts.start)+1)) +
                                 ind.P42[i]*exp(logP42)*exp(-exp(logM)*(i-(ts.P42-ts.start)+1)) +
                                 ind.P43[i]*exp(logP43)*exp(-exp(logM)*(i-(ts.P43-ts.start)+1)) +
                                 ind.P44[i]*exp(logP44)*exp(-exp(logM)*(i-(ts.P44-ts.start)+1)) +
                                 ind.P45[i]*exp(logP45)*exp(-exp(logM)*(i-(ts.P45-ts.start)+1)) +
                                 ind.P46[i]*exp(logP46)*exp(-exp(logM)*(i-(ts.P46-ts.start)+1)) +
                                 ind.P47[i]*exp(logP47)*exp(-exp(logM)*(i-(ts.P47-ts.start)+1)) +
                                 ind.P48[i]*exp(logP48)*exp(-exp(logM)*(i-(ts.P48-ts.start)+1)) +
                                 ind.P49[i]*exp(logP49)*exp(-exp(logM)*(i-(ts.P49-ts.start)+1)) +
                                 ind.P50[i]*exp(logP50)*exp(-exp(logM)*(i-(ts.P50-ts.start)+1)) +
                                 ind.P51[i]*exp(logP51)*exp(-exp(logM)*(i-(ts.P51-ts.start)+1)) +
                                 ind.P52[i]*exp(logP52)*exp(-exp(logM)*(i-(ts.P52-ts.start)+1)) +
                                 ind.P53[i]*exp(logP53)*exp(-exp(logM)*(i-(ts.P53-ts.start)+1)) +
                                 ind.P54[i]*exp(logP54)*exp(-exp(logM)*(i-(ts.P54-ts.start)+1)) +
                                 ind.P55[i]*exp(logP55)*exp(-exp(logM)*(i-(ts.P55-ts.start)+1)) +
                                 ind.P56[i]*exp(logP56)*exp(-exp(logM)*(i-(ts.P56-ts.start)+1)) +
                                 ind.P57[i]*exp(logP57)*exp(-exp(logM)*(i-(ts.P57-ts.start)+1)) +
                                 ind.P58[i]*exp(logP58)*exp(-exp(logM)*(i-(ts.P58-ts.start)+1)) +
                                 ind.P59[i]*exp(logP59)*exp(-exp(logM)*(i-(ts.P59-ts.start)+1)) +
                                 ind.P60[i]*exp(logP60)*exp(-exp(logM)*(i-(ts.P60-ts.start)+1)) +
                                 ind.P61[i]*exp(logP61)*exp(-exp(logM)*(i-(ts.P61-ts.start)+1)) +
                                 ind.P62[i]*exp(logP62)*exp(-exp(logM)*(i-(ts.P62-ts.start)+1)) +
                                 ind.P63[i]*exp(logP63)*exp(-exp(logM)*(i-(ts.P63-ts.start)+1)) +
                                 ind.P64[i]*exp(logP64)*exp(-exp(logM)*(i-(ts.P64-ts.start)+1)) +
                                 ind.P65[i]*exp(logP65)*exp(-exp(logM)*(i-(ts.P65-ts.start)+1)) +
                                 ind.P66[i]*exp(logP66)*exp(-exp(logM)*(i-(ts.P66-ts.start)+1)) +
                                 ind.P67[i]*exp(logP67)*exp(-exp(logM)*(i-(ts.P67-ts.start)+1)) +
                                 ind.P68[i]*exp(logP68)*exp(-exp(logM)*(i-(ts.P68-ts.start)+1)) +
                                 ind.P69[i]*exp(logP69)*exp(-exp(logM)*(i-(ts.P69-ts.start)+1)) +
                                 ind.P70[i]*exp(logP70)*exp(-exp(logM)*(i-(ts.P70-ts.start)+1)) +
                                 ind.P71[i]*exp(logP71)*exp(-exp(logM)*(i-(ts.P71-ts.start)+1)) +
                                 ind.P72[i]*exp(logP72)*exp(-exp(logM)*(i-(ts.P72-ts.start)+1)) +
                                 ind.P73[i]*exp(logP73)*exp(-exp(logM)*(i-(ts.P73-ts.start)+1)) +
                                 ind.P74[i]*exp(logP74)*exp(-exp(logM)*(i-(ts.P74-ts.start)+1)) +
                                 ind.P75[i]*exp(logP75)*exp(-exp(logM)*(i-(ts.P75-ts.start)+1)) +
                                 ind.P76[i]*exp(logP76)*exp(-exp(logM)*(i-(ts.P76-ts.start)+1)) +
                                 ind.P77[i]*exp(logP77)*exp(-exp(logM)*(i-(ts.P77-ts.start)+1)) +
                                 ind.P78[i]*exp(logP78)*exp(-exp(logM)*(i-(ts.P78-ts.start)+1)) +
                                 ind.P79[i]*exp(logP79)*exp(-exp(logM)*(i-(ts.P79-ts.start)+1)) +
                                 ind.P80[i]*exp(logP80)*exp(-exp(logM)*(i-(ts.P80-ts.start)+1)) +
                                 ind.P81[i]*exp(logP81)*exp(-exp(logM)*(i-(ts.P81-ts.start)+1)) +
                                 ind.P82[i]*exp(logP82)*exp(-exp(logM)*(i-(ts.P82-ts.start)+1)) +
                                 ind.P83[i]*exp(logP83)*exp(-exp(logM)*(i-(ts.P83-ts.start)+1)) +
                                 ind.P84[i]*exp(logP84)*exp(-exp(logM)*(i-(ts.P84-ts.start)+1)) +
                                 ind.P85[i]*exp(logP85)*exp(-exp(logM)*(i-(ts.P85-ts.start)+1)) +
                                 ind.P86[i]*exp(logP86)*exp(-exp(logM)*(i-(ts.P86-ts.start)+1)) +
                                 ind.P87[i]*exp(logP87)*exp(-exp(logM)*(i-(ts.P87-ts.start)+1)) +
                                 ind.P88[i]*exp(logP88)*exp(-exp(logM)*(i-(ts.P88-ts.start)+1)) +
                                 ind.P89[i]*exp(logP89)*exp(-exp(logM)*(i-(ts.P89-ts.start)+1)) +
                                 ind.P90[i]*exp(logP90)*exp(-exp(logM)*(i-(ts.P90-ts.start)+1)) +
                                 ind.P91[i]*exp(logP91)*exp(-exp(logM)*(i-(ts.P91-ts.start)+1)) +
                                 ind.P92[i]*exp(logP92)*exp(-exp(logM)*(i-(ts.P92-ts.start)+1)) +
                                 ind.P93[i]*exp(logP93)*exp(-exp(logM)*(i-(ts.P93-ts.start)+1)) +
                                 ind.P94[i]*exp(logP94)*exp(-exp(logM)*(i-(ts.P94-ts.start)+1)) +
                                 ind.P95[i]*exp(logP95)*exp(-exp(logM)*(i-(ts.P95-ts.start)+1)) +
                                 ind.P96[i]*exp(logP96)*exp(-exp(logM)*(i-(ts.P96-ts.start)+1)) +
                                 ind.P97[i]*exp(logP97)*exp(-exp(logM)*(i-(ts.P97-ts.start)+1)) +
                                 ind.P98[i]*exp(logP98)*exp(-exp(logM)*(i-(ts.P98-ts.start)+1)) +
                                 ind.P99[i]*exp(logP99)*exp(-exp(logM)*(i-(ts.P99-ts.start)+1)) +
                                 ind.P100[i]*exp(logP100)*exp(-exp(logM)*(i-(ts.P100-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha));
                  effn1       <- nstep^(exp(logbeta));
                  predcat1    <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel       <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT1P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-1)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logscale  <- par[4];
                  logalpha  <- par[5];
                  logbeta   <- par[6];
                  logtetha  <- par[7];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i]    <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT2P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-2)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logscale  <- par[5];
                  logalpha  <- par[6];
                  logbeta   <- par[7];
                  logtetha  <- par[8];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT3P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-3)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logscale  <- par[6];
                  logalpha  <- par[7];
                  logbeta   <- par[8];
                  logtetha  <- par[9];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT4P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-4)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logscale  <- par[7];
                  logalpha  <- par[8];
                  logbeta   <- par[9];
                  logtetha  <- par[10];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT5P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-5)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logscale  <- par[8];
                  logalpha  <- par[9];
                  logbeta   <- par[10];
                  logtetha  <- par[11];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT6P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-6)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logscale  <- par[9];
                  logalpha  <- par[10];
                  logbeta   <- par[11];
                  logtetha  <- par[12];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT7P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-7)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logscale  <- par[10];
                  logalpha  <- par[11];
                  logbeta   <- par[12];
                  logtetha  <- par[13];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT8P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-8)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logscale  <- par[11];
                  logalpha  <- par[12];
                  logbeta   <- par[13];
                  logtetha  <- par[14];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT9P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-9)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logscale  <- par[12];
                  logalpha  <- par[13];
                  logbeta   <- par[14];
                  logtetha  <- par[15];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT10P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-10)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logscale  <- par[13];
                  logalpha  <- par[14];
                  logbeta   <- par[15];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT11P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-11)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logscale  <- par[14];
                  logalpha  <- par[15];
                  logbeta   <- par[16];
                  logtetha  <- par[17];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT12P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-12)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logscale  <- par[15];
                  logalpha  <- par[16];
                  logbeta   <- par[17];
                  logtetha  <- par[18];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT13P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-13)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logscale  <- par[16];
                  logalpha  <- par[17];
                  logbeta   <- par[18];
                  logtetha  <- par[19];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT14P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-14)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.P14    <- dates[28];
                  ts.N14    <- dates[29];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start+1), 0, 1);
                  ind.N14   <- ifelse(1:sealen < (ts.N14-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logscale  <- par[17];
                  logalpha  <- par[18];
                  logbeta   <- par[19];
                  logtetha  <- par[20];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)))
                                          - ind.N14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT15P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-15)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.P14    <- dates[28];
                  ts.N14    <- dates[29];
                  ts.P15    <- dates[30];
                  ts.N15    <- dates[31];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start+1), 0, 1);
                  ind.N14   <- ifelse(1:sealen < (ts.N14-ts.start+1), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start+1), 0, 1);
                  ind.N15   <- ifelse(1:sealen < (ts.N15-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logscale  <- par[18];
                  logalpha  <- par[19];
                  logbeta   <- par[20];
                  logtetha  <- par[21];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1))) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)))
                                          - ind.N14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1)))
                                          - ind.N15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT16P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-16)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.P14    <- dates[28];
                  ts.N14    <- dates[29];
                  ts.P15    <- dates[30];
                  ts.N15    <- dates[31];
                  ts.P16    <- dates[32];
                  ts.N16    <- dates[33];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start+1), 0, 1);
                  ind.N14   <- ifelse(1:sealen < (ts.N14-ts.start+1), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start+1), 0, 1);
                  ind.N15   <- ifelse(1:sealen < (ts.N15-ts.start+1), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start+1), 0, 1);
                  ind.N16   <- ifelse(1:sealen < (ts.N16-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logscale  <- par[19];
                  logalpha  <- par[20];
                  logbeta   <- par[21];
                  logtetha  <- par[22];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1))) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1))) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1))) -
                                mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)))
                                          - ind.N14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1)))
                                          - ind.N15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1)))
                                          - ind.N16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT17P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-17)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.P14    <- dates[28];
                  ts.N14    <- dates[29];
                  ts.P15    <- dates[30];
                  ts.N15    <- dates[31];
                  ts.P16    <- dates[32];
                  ts.N16    <- dates[33];
                  ts.P17    <- dates[34];
                  ts.N17    <- dates[35];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start+1), 0, 1);
                  ind.N14   <- ifelse(1:sealen < (ts.N14-ts.start+1), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start+1), 0, 1);
                  ind.N15   <- ifelse(1:sealen < (ts.N15-ts.start+1), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start+1), 0, 1);
                  ind.N16   <- ifelse(1:sealen < (ts.N16-ts.start+1), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start+1), 0, 1);
                  ind.N17   <- ifelse(1:sealen < (ts.N17-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logscale  <- par[20];
                  logalpha  <- par[21];
                  logbeta   <- par[22];
                  logtetha  <- par[23];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1))) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1))) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1))) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)))
                                          - ind.N14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1)))
                                          - ind.N15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1)))
                                          - ind.N16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1)))
                                          - ind.N17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT18P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-18)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.P14    <- dates[28];
                  ts.N14    <- dates[29];
                  ts.P15    <- dates[30];
                  ts.N15    <- dates[31];
                  ts.P16    <- dates[32];
                  ts.N16    <- dates[33];
                  ts.P17    <- dates[34];
                  ts.N17    <- dates[35];
                  ts.P18    <- dates[36];
                  ts.N18    <- dates[37];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start+1), 0, 1);
                  ind.N14   <- ifelse(1:sealen < (ts.N14-ts.start+1), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start+1), 0, 1);
                  ind.N15   <- ifelse(1:sealen < (ts.N15-ts.start+1), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start+1), 0, 1);
                  ind.N16   <- ifelse(1:sealen < (ts.N16-ts.start+1), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start+1), 0, 1);
                  ind.N17   <- ifelse(1:sealen < (ts.N17-ts.start+1), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start+1), 0, 1);
                  ind.N18   <- ifelse(1:sealen < (ts.N18-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logscale  <- par[21];
                  logalpha  <- par[22];
                  logbeta   <- par[23];
                  logtetha  <- par[24];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1))) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1))) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1))) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1))) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)))
                                          - ind.N14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1)))
                                          - ind.N15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1)))
                                          - ind.N16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1)))
                                          - ind.N17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1)))
                                          - ind.N18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT19P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-19)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.P14    <- dates[28];
                  ts.N14    <- dates[29];
                  ts.P15    <- dates[30];
                  ts.N15    <- dates[31];
                  ts.P16    <- dates[32];
                  ts.N16    <- dates[33];
                  ts.P17    <- dates[34];
                  ts.N17    <- dates[35];
                  ts.P18    <- dates[36];
                  ts.N18    <- dates[37];
                  ts.P19    <- dates[38];
                  ts.N19    <- dates[39];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start+1), 0, 1);
                  ind.N14   <- ifelse(1:sealen < (ts.N14-ts.start+1), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start+1), 0, 1);
                  ind.N15   <- ifelse(1:sealen < (ts.N15-ts.start+1), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start+1), 0, 1);
                  ind.N16   <- ifelse(1:sealen < (ts.N16-ts.start+1), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start+1), 0, 1);
                  ind.N17   <- ifelse(1:sealen < (ts.N17-ts.start+1), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start+1), 0, 1);
                  ind.N18   <- ifelse(1:sealen < (ts.N18-ts.start+1), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start+1), 0, 1);
                  ind.N19   <- ifelse(1:sealen < (ts.N19-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logscale  <- par[22];
                  logalpha  <- par[23];
                  logbeta   <- par[24];
                  logtetha  <- par[25];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1))) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1))) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1))) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1))) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start+1))) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)))
                                          - ind.N14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1)))
                                          - ind.N15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1)))
                                          - ind.N16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1)))
                                          - ind.N17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1)))
                                          - ind.N18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start+1)))
                                          - ind.N19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMNT20P <-
function(par,dates,obscat1,obseff1,obsmbm1,distr,properties,output,pp=-20)
  {
                  ts.start  <- head(dates,1);
                  ts.P1     <- dates[2];
                  ts.N1     <- dates[3];
                  ts.P2     <- dates[4];
                  ts.N2     <- dates[5];
                  ts.P3     <- dates[6];
                  ts.N3     <- dates[7];
                  ts.P4     <- dates[8];
                  ts.N4     <- dates[9];
                  ts.P5     <- dates[10];
                  ts.N5     <- dates[11];
                  ts.P6     <- dates[12];
                  ts.N6     <- dates[13];
                  ts.P7     <- dates[14];
                  ts.N7     <- dates[15];
                  ts.P8     <- dates[16];
                  ts.N8     <- dates[17];
                  ts.P9     <- dates[18];
                  ts.N9     <- dates[19];
                  ts.P10    <- dates[20];
                  ts.N10    <- dates[21];
                  ts.P11    <- dates[22];
                  ts.N11    <- dates[23];
                  ts.P12    <- dates[24];
                  ts.N12    <- dates[25];
                  ts.P13    <- dates[26];
                  ts.N13    <- dates[27];
                  ts.P14    <- dates[28];
                  ts.N14    <- dates[29];
                  ts.P15    <- dates[30];
                  ts.N15    <- dates[31];
                  ts.P16    <- dates[32];
                  ts.N16    <- dates[33];
                  ts.P17    <- dates[34];
                  ts.N17    <- dates[35];
                  ts.P18    <- dates[36];
                  ts.N18    <- dates[37];
                  ts.P19    <- dates[38];
                  ts.N19    <- dates[39];
                  ts.P20    <- dates[40];
                  ts.N20    <- dates[41];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  resn1     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind.P1    <- ifelse(1:sealen < (ts.P1-ts.start+1), 0, 1);
                  ind.N1    <- ifelse(1:sealen < (ts.N1-ts.start+1), 0, 1);
                  ind.P2    <- ifelse(1:sealen < (ts.P2-ts.start+1), 0, 1);
                  ind.N2    <- ifelse(1:sealen < (ts.N2-ts.start+1), 0, 1);
                  ind.P3    <- ifelse(1:sealen < (ts.P3-ts.start+1), 0, 1);
                  ind.N3    <- ifelse(1:sealen < (ts.N3-ts.start+1), 0, 1);
                  ind.P4    <- ifelse(1:sealen < (ts.P4-ts.start+1), 0, 1);
                  ind.N4    <- ifelse(1:sealen < (ts.N4-ts.start+1), 0, 1);
                  ind.P5    <- ifelse(1:sealen < (ts.P5-ts.start+1), 0, 1);
                  ind.N5    <- ifelse(1:sealen < (ts.N5-ts.start+1), 0, 1);
                  ind.P6    <- ifelse(1:sealen < (ts.P6-ts.start+1), 0, 1);
                  ind.N6    <- ifelse(1:sealen < (ts.N6-ts.start+1), 0, 1);
                  ind.P7    <- ifelse(1:sealen < (ts.P7-ts.start+1), 0, 1);
                  ind.N7    <- ifelse(1:sealen < (ts.N7-ts.start+1), 0, 1);
                  ind.P8    <- ifelse(1:sealen < (ts.P8-ts.start+1), 0, 1);
                  ind.N8    <- ifelse(1:sealen < (ts.N8-ts.start+1), 0, 1);
                  ind.P9    <- ifelse(1:sealen < (ts.P9-ts.start+1), 0, 1);
                  ind.N9    <- ifelse(1:sealen < (ts.N9-ts.start+1), 0, 1);
                  ind.P10   <- ifelse(1:sealen < (ts.P10-ts.start+1), 0, 1);
                  ind.N10   <- ifelse(1:sealen < (ts.N10-ts.start+1), 0, 1);
                  ind.P11   <- ifelse(1:sealen < (ts.P11-ts.start+1), 0, 1);
                  ind.N11   <- ifelse(1:sealen < (ts.N11-ts.start+1), 0, 1);
                  ind.P12   <- ifelse(1:sealen < (ts.P12-ts.start+1), 0, 1);
                  ind.N12   <- ifelse(1:sealen < (ts.N12-ts.start+1), 0, 1);
                  ind.P13   <- ifelse(1:sealen < (ts.P13-ts.start+1), 0, 1);
                  ind.N13   <- ifelse(1:sealen < (ts.N13-ts.start+1), 0, 1);
                  ind.P14   <- ifelse(1:sealen < (ts.P14-ts.start+1), 0, 1);
                  ind.N14   <- ifelse(1:sealen < (ts.N14-ts.start+1), 0, 1);
                  ind.P15   <- ifelse(1:sealen < (ts.P15-ts.start+1), 0, 1);
                  ind.N15   <- ifelse(1:sealen < (ts.N15-ts.start+1), 0, 1);
                  ind.P16   <- ifelse(1:sealen < (ts.P16-ts.start+1), 0, 1);
                  ind.N16   <- ifelse(1:sealen < (ts.N16-ts.start+1), 0, 1);
                  ind.P17   <- ifelse(1:sealen < (ts.P17-ts.start+1), 0, 1);
                  ind.N17   <- ifelse(1:sealen < (ts.N17-ts.start+1), 0, 1);
                  ind.P18   <- ifelse(1:sealen < (ts.P18-ts.start+1), 0, 1);
                  ind.N18   <- ifelse(1:sealen < (ts.N18-ts.start+1), 0, 1);
                  ind.P19   <- ifelse(1:sealen < (ts.P19-ts.start+1), 0, 1);
                  ind.N19   <- ifelse(1:sealen < (ts.N19-ts.start+1), 0, 1);
                  ind.P20   <- ifelse(1:sealen < (ts.P20-ts.start+1), 0, 1);
                  ind.N20   <- ifelse(1:sealen < (ts.N20-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1     <- par[3];
                  logP2     <- par[4];
                  logP3     <- par[5];
                  logP4     <- par[6];
                  logP5     <- par[7];
                  logP6     <- par[8];
                  logP7     <- par[9];
                  logP8     <- par[10];
                  logP9     <- par[11];
                  logP10    <- par[12];
                  logP11    <- par[13];
                  logP12    <- par[14];
                  logP13    <- par[15];
                  logP14    <- par[16];
                  logP15    <- par[17];
                  logP16    <- par[18];
                  logP17    <- par[19];
                  logP18    <- par[20];
                  logP19    <- par[21];
                  logP20    <- par[22];
                  logscale  <- par[23];
                  logalpha  <- par[24];
                  logbeta   <- par[25];
                  logtetha  <- par[26];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  resn1[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind.P1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1))) +
                                 ind.P2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1))) +
                                 ind.P3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1))) +
                                 ind.P4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1))) +
                                 ind.P5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1))) +
                                 ind.P6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1))) +
                                 ind.P7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1))) +
                                 ind.P8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1))) +
                                 ind.P9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1))) +
                                 ind.P10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1))) +
                                 ind.P11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1))) +
                                 ind.P12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1))) +
                                 ind.P13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1))) +
                                 ind.P14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1))) +
                                 ind.P15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1))) +
                                 ind.P16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1))) +
                                 ind.P17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1))) +
                                 ind.P18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start+1))) +
                                 ind.P19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start+1))) -
                                 ind.P20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                     resn1[i] <- nstep[i] - ind.N1[i]*exp(logP1)*exp(-exp(logM)*(i-(ts.P1-ts.start+1)))
                                          - ind.N2[i]*exp(logP2)*exp(-exp(logM)*(i-(ts.P2-ts.start+1)))
                                          - ind.N3[i]*exp(logP3)*exp(-exp(logM)*(i-(ts.P3-ts.start+1)))
                                          - ind.N4[i]*exp(logP4)*exp(-exp(logM)*(i-(ts.P4-ts.start+1)))
                                          - ind.N5[i]*exp(logP5)*exp(-exp(logM)*(i-(ts.P5-ts.start+1)))
                                          - ind.N6[i]*exp(logP6)*exp(-exp(logM)*(i-(ts.P6-ts.start+1)))
                                          - ind.N7[i]*exp(logP7)*exp(-exp(logM)*(i-(ts.P7-ts.start+1)))
                                          - ind.N8[i]*exp(logP8)*exp(-exp(logM)*(i-(ts.P8-ts.start+1)))
                                          - ind.N9[i]*exp(logP9)*exp(-exp(logM)*(i-(ts.P9-ts.start+1)))
                                          - ind.N10[i]*exp(logP10)*exp(-exp(logM)*(i-(ts.P10-ts.start+1)))
                                          - ind.N11[i]*exp(logP11)*exp(-exp(logM)*(i-(ts.P11-ts.start+1)))
                                          - ind.N12[i]*exp(logP12)*exp(-exp(logM)*(i-(ts.P12-ts.start+1)))
                                          - ind.N13[i]*exp(logP13)*exp(-exp(logM)*(i-(ts.P13-ts.start+1)))
                                          - ind.N14[i]*exp(logP14)*exp(-exp(logM)*(i-(ts.P14-ts.start+1)))
                                          - ind.N15[i]*exp(logP15)*exp(-exp(logM)*(i-(ts.P15-ts.start+1)))
                                          - ind.N16[i]*exp(logP16)*exp(-exp(logM)*(i-(ts.P16-ts.start+1)))
                                          - ind.N17[i]*exp(logP17)*exp(-exp(logM)*(i-(ts.P17-ts.start+1)))
                                          - ind.N18[i]*exp(logP18)*exp(-exp(logM)*(i-(ts.P18-ts.start+1)))
                                          - ind.N19[i]*exp(logP19)*exp(-exp(logM)*(i-(ts.P19-ts.start+1)))
                                          - ind.N20[i]*exp(logP20)*exp(-exp(logM)*(i-(ts.P20-ts.start+1)));
                    }
                  effeff1  <- obseff1^(exp(logalpha));
                  effn1    <- resn1^(exp(logbeta));
                  predcat1 <- exp(logscale)*(effeff1*effn1)*exp(-exp(logM)/2);
                  Likel    <- .CatDynLik(obscat1,predcat1,distr,npar=length(par))
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp1F.Res(properties,nstep,obsmbm1,pp,dates,distr,par,Likel,ts.start,ts.end,obseff1,obscat1,predcat1)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN0P0P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(0,0))
  {

                  ts.start  <- head(dates,1);
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effeff2   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logscale1 <- par[3];
                  logalpha1 <- par[4];
                  logbeta1  <- par[5];
                  logscale2 <- par[6];
                  logalpha2 <- par[7];
                  logbeta2  <- par[8];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] +mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) - mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat1,predcat1,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN0P1P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(0,1))
  {
                  ts.start  <- head(dates,1);
                  ts2.P1    <- dates[2];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logscale1 <- par[3];
                  logalpha1 <- par[4];
                  logbeta1  <- par[5];
                  logP1F2   <- par[6];
                  logscale2 <- par[7];
                  logalpha2 <- par[8];
                  logbeta2  <- par[9];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN0P2P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(0,2))
  {
                  ts.start  <- head(dates,1);
                  ts2.P1    <- dates[2];
                  ts2.P2    <- dates[3];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logscale1 <- par[3];
                  logalpha1 <- par[4];
                  logbeta1  <- par[5];
                  logP1F2   <- par[6];
                  logP2F2   <- par[7];
                  logscale2 <- par[8];
                  logalpha2 <- par[9];
                  logbeta2  <- par[10];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN0P3P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(0,3))
  {
                  ts.start  <- head(dates,1);
                  ts2.P1    <- dates[2];
                  ts2.P2    <- dates[3];
                  ts2.P3    <- dates[4];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logscale1 <- par[3];
                  logalpha1 <- par[4];
                  logbeta1  <- par[5];
                  logP1F2   <- par[6];
                  logP2F2   <- par[7];
                  logP3F2   <- par[8];
                  logscale2 <- par[9];
                  logalpha2 <- par[10];
                  logbeta2  <- par[11];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN0P4P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(0,4))
  {
                  ts.start  <- head(dates,1);
                  ts2.P1    <- dates[2];
                  ts2.P2    <- dates[3];
                  ts2.P3    <- dates[4];
                  ts2.P4    <- dates[5];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logscale1 <- par[3];
                  logalpha1 <- par[4];
                  logbeta1  <- par[5];
                  logP1F2   <- par[6];
                  logP2F2   <- par[7];
                  logP3F2   <- par[8];
                  logP4F2   <- par[9];
                  logscale2 <- par[10];
                  logalpha2 <- par[11];
                  logbeta2  <- par[12];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN0P5P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(0,5))
  {
                  ts.start  <- head(dates,1);
                  ts2.P1    <- dates[2];
                  ts2.P2    <- dates[3];
                  ts2.P3    <- dates[4];
                  ts2.P4    <- dates[5];
                  ts2.P5    <- dates[6];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logscale1 <- par[3];
                  logalpha1 <- par[4];
                  logbeta1  <- par[5];
                  logP1F2   <- par[6];
                  logP2F2   <- par[7];
                  logP3F2   <- par[8];
                  logP4F2   <- par[9];
                  logP5F2   <- par[10];
                  logscale2 <- par[11];
                  logalpha2 <- par[12];
                  logbeta2  <- par[13];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                  ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN1P1P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(1,1))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts2.P1    <- dates[3];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start+1), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start+1), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logscale1 <- par[4];
                  logalpha1 <- par[5];
                  logbeta1  <- par[6];
                  logP1F2   <- par[7];
                  logscale2 <- par[8];
                  logalpha2 <- par[9];
                  logbeta2  <- par[10];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start+1))) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start+1))) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN1P2P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(1,2))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts2.P1    <- dates[3];
                  ts2.P2    <- dates[4];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logscale1 <- par[4];
                  logalpha1 <- par[5];
                  logbeta1  <- par[6];
                  logP1F2   <- par[7];
                  logP2F2   <- par[8];
                  logscale2 <- par[9];
                  logalpha2 <- par[10];
                  logbeta2  <- par[11];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN1P3P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(1,3))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts2.P1    <- dates[3];
                  ts2.P2    <- dates[4];
                  ts2.P3    <- dates[5];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logscale1 <- par[4];
                  logalpha1 <- par[5];
                  logbeta1  <- par[6];
                  logP1F2   <- par[7];
                  logP2F2   <- par[8];
                  logP3F2   <- par[9];
                  logscale2 <- par[10];
                  logalpha2 <- par[11];
                  logbeta2  <- par[12];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN1P4P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(1,4))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts2.P1    <- dates[3];
                  ts2.P2    <- dates[4];
                  ts2.P3    <- dates[5];
                  ts2.P4    <- dates[6];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logscale1 <- par[4];
                  logalpha1 <- par[5];
                  logbeta1  <- par[6];
                  logP1F2   <- par[7];
                  logP2F2   <- par[8];
                  logP3F2   <- par[9];
                  logP4F2   <- par[10];
                  logscale2 <- par[11];
                  logalpha2 <- par[12];
                  logbeta2  <- par[13];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN1P5P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(1,5))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts2.P1    <- dates[3];
                  ts2.P2    <- dates[4];
                  ts2.P3    <- dates[5];
                  ts2.P4    <- dates[6];
                  ts2.P5    <- dates[7];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logscale1 <- par[4];
                  logalpha1 <- par[5];
                  logbeta1  <- par[6];
                  logP1F2   <- par[7];
                  logP2F2   <- par[8];
                  logP3F2   <- par[9];
                  logP4F2   <- par[10];
                  logP5F2   <- par[11];
                  logscale2 <- par[12];
                  logalpha2 <- par[13];
                  logbeta2  <- par[14];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                  ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN2P2P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(2,2))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts2.P1    <- dates[4];
                  ts2.P2    <- dates[5];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logscale1 <- par[5];
                  logalpha1 <- par[6];
                  logbeta1  <- par[7];
                  logP1F2   <- par[8];
                  logP2F2   <- par[9];
                  logscale2 <- par[10];
                  logalpha2 <- par[11];
                  logbeta2  <- par[12];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN2P3P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(2,3))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts2.P1    <- dates[4];
                  ts2.P2    <- dates[5];
                  ts2.P3    <- dates[6];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logscale1 <- par[5];
                  logalpha1 <- par[6];
                  logbeta1  <- par[7];
                  logP1F2   <- par[8];
                  logP2F2   <- par[9];
                  logP3F2   <- par[10];
                  logscale2 <- par[11];
                  logalpha2 <- par[12];
                  logbeta2  <- par[13];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN2P4P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(2,4))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts2.P1    <- dates[4];
                  ts2.P2    <- dates[5];
                  ts2.P3    <- dates[6];
                  ts2.P4    <- dates[7];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logscale1 <- par[5];
                  logalpha1 <- par[6];
                  logbeta1  <- par[7];
                  logP1F2   <- par[8];
                  logP2F2   <- par[9];
                  logP3F2   <- par[10];
                  logP4F2   <- par[11];
                  logscale2 <- par[12];
                  logalpha2 <- par[13];
                  logbeta2  <- par[14];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN2P5P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(2,5))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts2.P1    <- dates[4];
                  ts2.P2    <- dates[5];
                  ts2.P3    <- dates[6];
                  ts2.P4    <- dates[7];
                  ts2.P5    <- dates[8];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logscale1 <- par[5];
                  logalpha1 <- par[6];
                  logbeta1  <- par[7];
                  logP1F2   <- par[8];
                  logP2F2   <- par[9];
                  logP3F2   <- par[10];
                  logP4F2   <- par[11];
                  logP5F2   <- par[12];
                  logscale2 <- par[13];
                  logalpha2 <- par[14];
                  logbeta2  <- par[15];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                  ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN3P3P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(3,3))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts2.P1    <- dates[5];
                  ts2.P2    <- dates[6];
                  ts2.P3    <- dates[7];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logscale1 <- par[6];
                  logalpha1 <- par[7];
                  logbeta1  <- par[8];
                  logP1F2   <- par[9];
                  logP2F2   <- par[10];
                  logP3F2   <- par[11];
                  logscale2 <- par[12];
                  logalpha2 <- par[13];
                  logbeta2  <- par[14];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                    {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                    }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN3P4P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(3,4))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts2.P1    <- dates[5];
                  ts2.P2    <- dates[6];
                  ts2.P3    <- dates[7];
                  ts2.P4    <- dates[8];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logscale1 <- par[6];
                  logalpha1 <- par[7];
                  logbeta1  <- par[8];
                  logP1F2   <- par[9];
                  logP2F2   <- par[10];
                  logP3F2   <- par[11];
                  logP4F2   <- par[12];
                  logscale2 <- par[13];
                  logalpha2 <- par[14];
                  logbeta2  <- par[15];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN3P5P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(3,5))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts2.P1    <- dates[5];
                  ts2.P2    <- dates[6];
                  ts2.P3    <- dates[7];
                  ts2.P4    <- dates[8];
                  ts2.P5    <- dates[9];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logscale1 <- par[6];
                  logalpha1 <- par[7];
                  logbeta1  <- par[8];
                  logP1F2   <- par[9];
                  logP2F2   <- par[10];
                  logP3F2   <- par[11];
                  logP4F2   <- par[12];
                  logP5F2   <- par[13];
                  logscale2 <- par[14];
                  logalpha2 <- par[15];
                  logbeta2  <- par[16];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                  ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN4P4P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(4,4))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts2.P1    <- dates[6];
                  ts2.P2    <- dates[7];
                  ts2.P3    <- dates[8];
                  ts2.P4    <- dates[9];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logscale1 <- par[7];
                  logalpha1 <- par[8];
                  logbeta1  <- par[9];
                  logP1F2   <- par[10];
                  logP2F2   <- par[11];
                  logP3F2   <- par[12];
                  logP4F2   <- par[13];
                  logscale2 <- par[14];
                  logalpha2 <- par[15];
                  logbeta2  <- par[16];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                  ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN4P5P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(4,5))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts2.P1    <- dates[6];
                  ts2.P2    <- dates[7];
                  ts2.P3    <- dates[8];
                  ts2.P4    <- dates[9];
                  ts2.P5    <- dates[10];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logscale1 <- par[7];
                  logalpha1 <- par[8];
                  logbeta1  <- par[9];
                  logP1F2   <- par[10];
                  logP2F2   <- par[11];
                  logP3F2   <- par[12];
                  logP4F2   <- par[13];
                  logP5F2   <- par[14];
                  logscale2 <- par[15];
                  logalpha2 <- par[16];
                  logbeta2  <- par[17];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                  ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                  ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN5P5P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(5,5))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts2.P1    <- dates[7];
                  ts2.P2    <- dates[8];
                  ts2.P3    <- dates[9];
                  ts2.P4    <- dates[10];
                  ts2.P5    <- dates[11];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logscale1 <- par[8];
                  logalpha1 <- par[9];
                  logbeta1  <- par[10];
                  logP1F2   <- par[11];
                  logP2F2   <- par[12];
                  logP3F2   <- par[13];
                  logP4F2   <- par[14];
                  logP5F2   <- par[15];
                  logscale2 <- par[16];
                  logalpha2 <- par[17];
                  logbeta2  <- par[18];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                  ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                  ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                  ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN6P6P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(6,6))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts2.P1    <- dates[8];
                  ts2.P2    <- dates[9];
                  ts2.P3    <- dates[10];
                  ts2.P4    <- dates[11];
                  ts2.P5    <- dates[12];
                  ts2.P6    <- dates[13];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logscale1 <- par[9];
                  logalpha1 <- par[10];
                  logbeta1  <- par[11];
                  logP1F2   <- par[12];
                  logP2F2   <- par[13];
                  logP3F2   <- par[14];
                  logP4F2   <- par[15];
                  logP5F2   <- par[16];
                  logP6F2   <- par[17];
                  logscale2 <- par[18];
                  logalpha2 <- par[19];
                  logbeta2  <- par[20];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                      mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                      nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                  ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                  ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                  ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                  ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                  ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                  ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                  ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                  ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                  ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                  ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                  ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                  ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) -
                                  mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN7P7P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(7,7))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts2.P1    <- dates[9];
                  ts2.P2    <- dates[10];
                  ts2.P3    <- dates[11];
                  ts2.P4    <- dates[12];
                  ts2.P5    <- dates[13];
                  ts2.P6    <- dates[14];
                  ts2.P7    <- dates[15];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logscale1 <- par[10];
                  logalpha1 <- par[11];
                  logbeta1  <- par[12];
                  logP1F2   <- par[13];
                  logP2F2   <- par[14];
                  logP3F2   <- par[15];
                  logP4F2   <- par[16];
                  logP5F2   <- par[17];
                  logP6F2   <- par[18];
                  logP7F2   <- par[19];
                  logscale2 <- par[20];
                  logalpha2 <- par[21];
                  logbeta2  <- par[22];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN8P8P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(8,8))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts2.P1    <- dates[10];
                  ts2.P2    <- dates[11];
                  ts2.P3    <- dates[12];
                  ts2.P4    <- dates[13];
                  ts2.P5    <- dates[14];
                  ts2.P6    <- dates[15];
                  ts2.P7    <- dates[16];
                  ts2.P8    <- dates[17];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logscale1 <- par[11];
                  logalpha1 <- par[12];
                  logbeta1  <- par[13];
                  logP1F2   <- par[14];
                  logP2F2   <- par[15];
                  logP3F2   <- par[16];
                  logP4F2   <- par[17];
                  logP5F2   <- par[18];
                  logP6F2   <- par[19];
                  logP7F2   <- par[20];
                  logP8F2   <- par[21];
                  logscale2 <- par[22];
                  logalpha2 <- par[23];
                  logbeta2  <- par[24];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN9P9P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(9,9))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts2.P1    <- dates[11];
                  ts2.P2    <- dates[12];
                  ts2.P3    <- dates[13];
                  ts2.P4    <- dates[14];
                  ts2.P5    <- dates[15];
                  ts2.P6    <- dates[16];
                  ts2.P7    <- dates[17];
                  ts2.P8    <- dates[18];
                  ts2.P9    <- dates[19];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logscale1 <- par[12];
                  logalpha1 <- par[13];
                  logbeta1  <- par[14];
                  logP1F2   <- par[15];
                  logP2F2   <- par[16];
                  logP3F2   <- par[17];
                  logP4F2   <- par[18];
                  logP5F2   <- par[19];
                  logP6F2   <- par[20];
                  logP7F2   <- par[21];
                  logP8F2   <- par[22];
                  logP9F2   <- par[23];
                  logscale2 <- par[24];
                  logalpha2 <- par[25];
                  logbeta2  <- par[26];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN10P10P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(10,10))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts2.P1    <- dates[12];
                  ts2.P2    <- dates[13];
                  ts2.P3    <- dates[14];
                  ts2.P4    <- dates[15];
                  ts2.P5    <- dates[16];
                  ts2.P6    <- dates[17];
                  ts2.P7    <- dates[18];
                  ts2.P8    <- dates[19];
                  ts2.P9    <- dates[20];
                  ts2.P10   <- dates[21];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                   ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logscale1 <- par[13];
                  logalpha1 <- par[14];
                  logbeta1  <- par[15];
                  logP1F2   <- par[16];
                  logP2F2   <- par[17];
                  logP3F2   <- par[18];
                  logP4F2   <- par[19];
                  logP5F2   <- par[20];
                  logP6F2   <- par[21];
                  logP7F2   <- par[22];
                  logP8F2   <- par[23];
                  logP9F2   <- par[24];
                  logP10F2  <- par[25];
                  logscale2 <- par[26];
                  logalpha2 <- par[27];
                  logbeta2  <- par[28];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN11P11P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(11,11))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts2.P1    <- dates[13];
                  ts2.P2    <- dates[14];
                  ts2.P3    <- dates[15];
                  ts2.P4    <- dates[16];
                  ts2.P5    <- dates[17];
                  ts2.P6    <- dates[18];
                  ts2.P7    <- dates[19];
                  ts2.P8    <- dates[20];
                  ts2.P9    <- dates[21];
                  ts2.P10   <- dates[22];
                  ts2.P11   <- dates[23];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logscale1 <- par[14];
                  logalpha1 <- par[15];
                  logbeta1  <- par[16];
                  logP1F2   <- par[17];
                  logP2F2   <- par[18];
                  logP3F2   <- par[19];
                  logP4F2   <- par[20];
                  logP5F2   <- par[21];
                  logP6F2   <- par[22];
                  logP7F2   <- par[23];
                  logP8F2   <- par[24];
                  logP9F2   <- par[25];
                  logP10F2  <- par[26];
                  logP11F2  <- par[27];
                  logscale2 <- par[28];
                  logalpha2 <- par[29];
                  logbeta2  <- par[30];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN12P12P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(12,12))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts2.P1    <- dates[14];
                  ts2.P2    <- dates[15];
                  ts2.P3    <- dates[16];
                  ts2.P4    <- dates[17];
                  ts2.P5    <- dates[18];
                  ts2.P6    <- dates[19];
                  ts2.P7    <- dates[20];
                  ts2.P8    <- dates[21];
                  ts2.P9    <- dates[22];
                  ts2.P10   <- dates[23];
                  ts2.P11   <- dates[24];
                  ts2.P12   <- dates[25];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logscale1 <- par[15];
                  logalpha1 <- par[16];
                  logbeta1  <- par[17];
                  logP1F2   <- par[18];
                  logP2F2   <- par[19];
                  logP3F2   <- par[20];
                  logP4F2   <- par[21];
                  logP5F2   <- par[22];
                  logP6F2   <- par[23];
                  logP7F2   <- par[24];
                  logP8F2   <- par[25];
                  logP9F2   <- par[26];
                  logP10F2  <- par[27];
                  logP11F2  <- par[28];
                  logP12F2  <- par[29];
                  logscale2 <- par[30];
                  logalpha2 <- par[31];
                  logbeta2  <- par[32];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN13P13P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(13,13))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts2.P1    <- dates[15];
                  ts2.P2    <- dates[16];
                  ts2.P3    <- dates[17];
                  ts2.P4    <- dates[18];
                  ts2.P5    <- dates[19];
                  ts2.P6    <- dates[20];
                  ts2.P7    <- dates[21];
                  ts2.P8    <- dates[22];
                  ts2.P9    <- dates[23];
                  ts2.P10   <- dates[24];
                  ts2.P11   <- dates[25];
                  ts2.P12   <- dates[26];
                  ts2.P13   <- dates[27];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logscale1 <- par[16];
                  logalpha1 <- par[17];
                  logbeta1  <- par[18];
                  logP1F2   <- par[19];
                  logP2F2   <- par[20];
                  logP3F2   <- par[21];
                  logP4F2   <- par[22];
                  logP5F2   <- par[23];
                  logP6F2   <- par[24];
                  logP7F2   <- par[25];
                  logP8F2   <- par[26];
                  logP9F2   <- par[27];
                  logP10F2  <- par[28];
                  logP11F2  <- par[29];
                  logP12F2  <- par[30];
                  logP13F2  <- par[31];
                  logscale2 <- par[32];
                  logalpha2 <- par[33];
                  logbeta2  <- par[34];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN14P14P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(14,14))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts2.P1    <- dates[16];
                  ts2.P2    <- dates[17];
                  ts2.P3    <- dates[18];
                  ts2.P4    <- dates[19];
                  ts2.P5    <- dates[20];
                  ts2.P6    <- dates[21];
                  ts2.P7    <- dates[22];
                  ts2.P8    <- dates[23];
                  ts2.P9    <- dates[24];
                  ts2.P10   <- dates[25];
                  ts2.P11   <- dates[26];
                  ts2.P12   <- dates[27];
                  ts2.P13   <- dates[28];
                  ts2.P14   <- dates[29];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logscale1 <- par[17];
                  logalpha1 <- par[18];
                  logbeta1  <- par[19];
                  logP1F2   <- par[20];
                  logP2F2   <- par[21];
                  logP3F2   <- par[22];
                  logP4F2   <- par[23];
                  logP5F2   <- par[24];
                  logP6F2   <- par[25];
                  logP7F2   <- par[26];
                  logP8F2   <- par[27];
                  logP9F2   <- par[28];
                  logP10F2  <- par[29];
                  logP11F2  <- par[30];
                  logP12F2  <- par[31];
                  logP13F2  <- par[32];
                  logP14F2  <- par[33];
                  logscale2 <- par[34];
                  logalpha2 <- par[35];
                  logbeta2  <- par[36];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN15P15P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(15,15))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts2.P1    <- dates[17];
                  ts2.P2    <- dates[18];
                  ts2.P3    <- dates[19];
                  ts2.P4    <- dates[20];
                  ts2.P5    <- dates[21];
                  ts2.P6    <- dates[22];
                  ts2.P7    <- dates[23];
                  ts2.P8    <- dates[24];
                  ts2.P9    <- dates[25];
                  ts2.P10   <- dates[26];
                  ts2.P11   <- dates[27];
                  ts2.P12   <- dates[28];
                  ts2.P13   <- dates[29];
                  ts2.P14   <- dates[30];
                  ts2.P15   <- dates[31];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logscale1 <- par[18];
                  logalpha1 <- par[19];
                  logbeta1  <- par[20];
                  logP1F2   <- par[21];
                  logP2F2   <- par[22];
                  logP3F2   <- par[23];
                  logP4F2   <- par[24];
                  logP5F2   <- par[25];
                  logP6F2   <- par[26];
                  logP7F2   <- par[27];
                  logP8F2   <- par[28];
                  logP9F2   <- par[29];
                  logP10F2  <- par[30];
                  logP11F2  <- par[31];
                  logP12F2  <- par[32];
                  logP13F2  <- par[33];
                  logP14F2  <- par[34];
                  logP15F2  <- par[35];
                  logscale2 <- par[36];
                  logalpha2 <- par[37];
                  logbeta2  <- par[38];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN16P16P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(16,16))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts2.P1    <- dates[18];
                  ts2.P2    <- dates[19];
                  ts2.P3    <- dates[20];
                  ts2.P4    <- dates[21];
                  ts2.P5    <- dates[22];
                  ts2.P6    <- dates[23];
                  ts2.P7    <- dates[24];
                  ts2.P8    <- dates[25];
                  ts2.P9    <- dates[26];
                  ts2.P10   <- dates[27];
                  ts2.P11   <- dates[28];
                  ts2.P12   <- dates[29];
                  ts2.P13   <- dates[30];
                  ts2.P14   <- dates[31];
                  ts2.P15   <- dates[32];
                  ts2.P16   <- dates[33];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logscale1 <- par[19];
                  logalpha1 <- par[20];
                  logbeta1  <- par[21];
                  logP1F2   <- par[22];
                  logP2F2   <- par[23];
                  logP3F2   <- par[24];
                  logP4F2   <- par[25];
                  logP5F2   <- par[26];
                  logP6F2   <- par[27];
                  logP7F2   <- par[28];
                  logP8F2   <- par[29];
                  logP9F2   <- par[30];
                  logP10F2  <- par[31];
                  logP11F2  <- par[32];
                  logP12F2  <- par[33];
                  logP13F2  <- par[34];
                  logP14F2  <- par[35];
                  logP15F2  <- par[36];
                  logP16F2  <- par[37];
                  logscale2 <- par[38];
                  logalpha2 <- par[39];
                  logbeta2  <- par[40];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN17P17P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(17,17))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts2.P1    <- dates[19];
                  ts2.P2    <- dates[20];
                  ts2.P3    <- dates[21];
                  ts2.P4    <- dates[22];
                  ts2.P5    <- dates[23];
                  ts2.P6    <- dates[24];
                  ts2.P7    <- dates[25];
                  ts2.P8    <- dates[26];
                  ts2.P9    <- dates[27];
                  ts2.P10   <- dates[28];
                  ts2.P11   <- dates[29];
                  ts2.P12   <- dates[30];
                  ts2.P13   <- dates[31];
                  ts2.P14   <- dates[32];
                  ts2.P15   <- dates[33];
                  ts2.P16   <- dates[34];
                  ts2.P17   <- dates[35];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logscale1 <- par[20];
                  logalpha1 <- par[21];
                  logbeta1  <- par[22];
                  logP1F2   <- par[23];
                  logP2F2   <- par[24];
                  logP3F2   <- par[25];
                  logP4F2   <- par[26];
                  logP5F2   <- par[27];
                  logP6F2   <- par[28];
                  logP7F2   <- par[29];
                  logP8F2   <- par[30];
                  logP9F2   <- par[31];
                  logP10F2  <- par[32];
                  logP11F2  <- par[33];
                  logP12F2  <- par[34];
                  logP13F2  <- par[35];
                  logP14F2  <- par[36];
                  logP15F2  <- par[37];
                  logP16F2  <- par[38];
                  logP17F2  <- par[39];
                  logscale2 <- par[40];
                  logalpha2 <- par[41];
                  logbeta2  <- par[42];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN18P18P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(18,18))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts2.P1    <- dates[20];
                  ts2.P2    <- dates[21];
                  ts2.P3    <- dates[22];
                  ts2.P4    <- dates[23];
                  ts2.P5    <- dates[24];
                  ts2.P6    <- dates[25];
                  ts2.P7    <- dates[26];
                  ts2.P8    <- dates[27];
                  ts2.P9    <- dates[28];
                  ts2.P10   <- dates[29];
                  ts2.P11   <- dates[30];
                  ts2.P12   <- dates[31];
                  ts2.P13   <- dates[32];
                  ts2.P14   <- dates[33];
                  ts2.P15   <- dates[34];
                  ts2.P16   <- dates[35];
                  ts2.P17   <- dates[36];
                  ts2.P18   <- dates[37];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logscale1 <- par[21];
                  logalpha1 <- par[22];
                  logbeta1  <- par[23];
                  logP1F2   <- par[24];
                  logP2F2   <- par[25];
                  logP3F2   <- par[26];
                  logP4F2   <- par[27];
                  logP5F2   <- par[28];
                  logP6F2   <- par[29];
                  logP7F2   <- par[30];
                  logP8F2   <- par[31];
                  logP9F2   <- par[32];
                  logP10F2  <- par[33];
                  logP11F2  <- par[34];
                  logP12F2  <- par[35];
                  logP13F2  <- par[36];
                  logP14F2  <- par[37];
                  logP15F2  <- par[38];
                  logP16F2  <- par[39];
                  logP17F2  <- par[40];
                  logP18F2  <- par[41];
                  logscale2 <- par[42];
                  logalpha2 <- par[43];
                  logbeta2  <- par[44];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN19P19P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(19,19))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts2.P1    <- dates[21];
                  ts2.P2    <- dates[22];
                  ts2.P3    <- dates[23];
                  ts2.P4    <- dates[24];
                  ts2.P5    <- dates[25];
                  ts2.P6    <- dates[26];
                  ts2.P7    <- dates[27];
                  ts2.P8    <- dates[28];
                  ts2.P9    <- dates[29];
                  ts2.P10   <- dates[30];
                  ts2.P11   <- dates[31];
                  ts2.P12   <- dates[32];
                  ts2.P13   <- dates[33];
                  ts2.P14   <- dates[34];
                  ts2.P15   <- dates[35];
                  ts2.P16   <- dates[36];
                  ts2.P17   <- dates[37];
                  ts2.P18   <- dates[38];
                  ts2.P19   <- dates[39];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logscale1 <- par[22];
                  logalpha1 <- par[23];
                  logbeta1  <- par[24];
                  logP1F2   <- par[25];
                  logP2F2   <- par[26];
                  logP3F2   <- par[27];
                  logP4F2   <- par[28];
                  logP5F2   <- par[29];
                  logP6F2   <- par[30];
                  logP7F2   <- par[31];
                  logP8F2   <- par[32];
                  logP9F2   <- par[33];
                  logP10F2  <- par[34];
                  logP11F2  <- par[35];
                  logP12F2  <- par[36];
                  logP13F2  <- par[37];
                  logP14F2  <- par[38];
                  logP15F2  <- par[39];
                  logP16F2  <- par[40];
                  logP17F2  <- par[41];
                  logP18F2  <- par[42];
                  logP19F2  <- par[43];
                  logscale2 <- par[44];
                  logalpha2 <- par[45];
                  logbeta2  <- par[46];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN20P20P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(20,20))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts2.P1    <- dates[22];
                  ts2.P2    <- dates[23];
                  ts2.P3    <- dates[24];
                  ts2.P4    <- dates[25];
                  ts2.P5    <- dates[26];
                  ts2.P6    <- dates[27];
                  ts2.P7    <- dates[28];
                  ts2.P8    <- dates[29];
                  ts2.P9    <- dates[30];
                  ts2.P10   <- dates[31];
                  ts2.P11   <- dates[32];
                  ts2.P12   <- dates[33];
                  ts2.P13   <- dates[34];
                  ts2.P14   <- dates[35];
                  ts2.P15   <- dates[36];
                  ts2.P16   <- dates[37];
                  ts2.P17   <- dates[38];
                  ts2.P18   <- dates[39];
                  ts2.P19   <- dates[40];
                  ts2.P20   <- dates[41];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logscale1 <- par[23];
                  logalpha1 <- par[24];
                  logbeta1  <- par[25];
                  logP1F2   <- par[26];
                  logP2F2   <- par[27];
                  logP3F2   <- par[28];
                  logP4F2   <- par[29];
                  logP5F2   <- par[30];
                  logP6F2   <- par[31];
                  logP7F2   <- par[32];
                  logP8F2   <- par[33];
                  logP9F2   <- par[34];
                  logP10F2  <- par[35];
                  logP11F2  <- par[36];
                  logP12F2  <- par[37];
                  logP13F2  <- par[38];
                  logP14F2  <- par[39];
                  logP15F2  <- par[40];
                  logP16F2  <- par[41];
                  logP17F2  <- par[42];
                  logP18F2  <- par[43];
                  logP19F2  <- par[44];
                  logP20F2  <- par[45];
                  logscale2 <- par[46];
                  logalpha2 <- par[47];
                  logbeta2  <- par[48];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN21P21P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(21,21))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts2.P1    <- dates[23];
                  ts2.P2    <- dates[24];
                  ts2.P3    <- dates[25];
                  ts2.P4    <- dates[26];
                  ts2.P5    <- dates[27];
                  ts2.P6    <- dates[28];
                  ts2.P7    <- dates[29];
                  ts2.P8    <- dates[30];
                  ts2.P9    <- dates[31];
                  ts2.P10   <- dates[32];
                  ts2.P11   <- dates[33];
                  ts2.P12   <- dates[34];
                  ts2.P13   <- dates[35];
                  ts2.P14   <- dates[36];
                  ts2.P15   <- dates[37];
                  ts2.P16   <- dates[38];
                  ts2.P17   <- dates[39];
                  ts2.P18   <- dates[40];
                  ts2.P19   <- dates[41];
                  ts2.P20   <- dates[42];
                  ts2.P21   <- dates[43];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logscale1 <- par[24];
                  logalpha1 <- par[25];
                  logbeta1  <- par[26];
                  logP1F2   <- par[27];
                  logP2F2   <- par[28];
                  logP3F2   <- par[29];
                  logP4F2   <- par[30];
                  logP5F2   <- par[31];
                  logP6F2   <- par[32];
                  logP7F2   <- par[33];
                  logP8F2   <- par[34];
                  logP9F2   <- par[35];
                  logP10F2  <- par[36];
                  logP11F2  <- par[37];
                  logP12F2  <- par[38];
                  logP13F2  <- par[39];
                  logP14F2  <- par[40];
                  logP15F2  <- par[41];
                  logP16F2  <- par[42];
                  logP17F2  <- par[43];
                  logP18F2  <- par[44];
                  logP19F2  <- par[45];
                  logP20F2  <- par[46];
                  logP21F2  <- par[47];
                  logscale2 <- par[48];
                  logalpha2 <- par[49];
                  logbeta2  <- par[50];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN22P22P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(22,22))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts2.P1    <- dates[24];
                  ts2.P2    <- dates[25];
                  ts2.P3    <- dates[26];
                  ts2.P4    <- dates[27];
                  ts2.P5    <- dates[28];
                  ts2.P6    <- dates[29];
                  ts2.P7    <- dates[30];
                  ts2.P8    <- dates[31];
                  ts2.P9    <- dates[32];
                  ts2.P10   <- dates[33];
                  ts2.P11   <- dates[34];
                  ts2.P12   <- dates[35];
                  ts2.P13   <- dates[36];
                  ts2.P14   <- dates[37];
                  ts2.P15   <- dates[38];
                  ts2.P16   <- dates[39];
                  ts2.P17   <- dates[40];
                  ts2.P18   <- dates[41];
                  ts2.P19   <- dates[42];
                  ts2.P20   <- dates[43];
                  ts2.P21   <- dates[44];
                  ts2.P22   <- dates[45];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logscale1 <- par[25];
                  logalpha1 <- par[26];
                  logbeta1  <- par[27];
                  logP1F2   <- par[28];
                  logP2F2   <- par[29];
                  logP3F2   <- par[30];
                  logP4F2   <- par[31];
                  logP5F2   <- par[32];
                  logP6F2   <- par[33];
                  logP7F2   <- par[34];
                  logP8F2   <- par[35];
                  logP9F2   <- par[36];
                  logP10F2  <- par[37];
                  logP11F2  <- par[38];
                  logP12F2  <- par[39];
                  logP13F2  <- par[40];
                  logP14F2  <- par[41];
                  logP15F2  <- par[42];
                  logP16F2  <- par[43];
                  logP17F2  <- par[44];
                  logP18F2  <- par[45];
                  logP19F2  <- par[46];
                  logP20F2  <- par[47];
                  logP21F2  <- par[48];
                  logP22F2  <- par[49];
                  logscale2 <- par[50];
                  logalpha2 <- par[51];
                  logbeta2  <- par[52];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN23P23P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(23,23))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts2.P1    <- dates[25];
                  ts2.P2    <- dates[26];
                  ts2.P3    <- dates[27];
                  ts2.P4    <- dates[28];
                  ts2.P5    <- dates[29];
                  ts2.P6    <- dates[30];
                  ts2.P7    <- dates[31];
                  ts2.P8    <- dates[32];
                  ts2.P9    <- dates[33];
                  ts2.P10   <- dates[34];
                  ts2.P11   <- dates[35];
                  ts2.P12   <- dates[36];
                  ts2.P13   <- dates[37];
                  ts2.P14   <- dates[38];
                  ts2.P15   <- dates[39];
                  ts2.P16   <- dates[40];
                  ts2.P17   <- dates[41];
                  ts2.P18   <- dates[42];
                  ts2.P19   <- dates[43];
                  ts2.P20   <- dates[44];
                  ts2.P21   <- dates[45];
                  ts2.P22   <- dates[46];
                  ts2.P23   <- dates[47];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logscale1 <- par[26];
                  logalpha1 <- par[27];
                  logbeta1  <- par[28];
                  logP1F2   <- par[29];
                  logP2F2   <- par[30];
                  logP3F2   <- par[31];
                  logP4F2   <- par[32];
                  logP5F2   <- par[33];
                  logP6F2   <- par[34];
                  logP7F2   <- par[35];
                  logP8F2   <- par[36];
                  logP9F2   <- par[37];
                  logP10F2  <- par[38];
                  logP11F2  <- par[39];
                  logP12F2  <- par[40];
                  logP13F2  <- par[41];
                  logP14F2  <- par[42];
                  logP15F2  <- par[43];
                  logP16F2  <- par[44];
                  logP17F2  <- par[45];
                  logP18F2  <- par[46];
                  logP19F2  <- par[47];
                  logP20F2  <- par[48];
                  logP21F2  <- par[49];
                  logP22F2  <- par[50];
                  logP23F2  <- par[51];
                  logscale2 <- par[52];
                  logalpha2 <- par[53];
                  logbeta2  <- par[54];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN24P24P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(24,24))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts2.P1    <- dates[26];
                  ts2.P2    <- dates[27];
                  ts2.P3    <- dates[28];
                  ts2.P4    <- dates[29];
                  ts2.P5    <- dates[30];
                  ts2.P6    <- dates[31];
                  ts2.P7    <- dates[32];
                  ts2.P8    <- dates[33];
                  ts2.P9    <- dates[34];
                  ts2.P10   <- dates[35];
                  ts2.P11   <- dates[36];
                  ts2.P12   <- dates[37];
                  ts2.P13   <- dates[38];
                  ts2.P14   <- dates[39];
                  ts2.P15   <- dates[40];
                  ts2.P16   <- dates[41];
                  ts2.P17   <- dates[42];
                  ts2.P18   <- dates[43];
                  ts2.P19   <- dates[44];
                  ts2.P20   <- dates[45];
                  ts2.P21   <- dates[46];
                  ts2.P22   <- dates[47];
                  ts2.P23   <- dates[48];
                  ts2.P24   <- dates[49];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logscale1 <- par[27];
                  logalpha1 <- par[28];
                  logbeta1  <- par[29];
                  logP1F2   <- par[30];
                  logP2F2   <- par[31];
                  logP3F2   <- par[32];
                  logP4F2   <- par[33];
                  logP5F2   <- par[34];
                  logP6F2   <- par[35];
                  logP7F2   <- par[36];
                  logP8F2   <- par[37];
                  logP9F2   <- par[38];
                  logP10F2  <- par[39];
                  logP11F2  <- par[40];
                  logP12F2  <- par[41];
                  logP13F2  <- par[42];
                  logP14F2  <- par[43];
                  logP15F2  <- par[44];
                  logP16F2  <- par[45];
                  logP17F2  <- par[46];
                  logP18F2  <- par[47];
                  logP19F2  <- par[48];
                  logP20F2  <- par[49];
                  logP21F2  <- par[50];
                  logP22F2  <- par[51];
                  logP23F2  <- par[52];
                  logP24F2  <- par[53];
                  logscale2 <- par[54];
                  logalpha2 <- par[55];
                  logbeta2  <- par[56];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN25P25P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(25,25))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts2.P1    <- dates[27];
                  ts2.P2    <- dates[28];
                  ts2.P3    <- dates[29];
                  ts2.P4    <- dates[30];
                  ts2.P5    <- dates[31];
                  ts2.P6    <- dates[32];
                  ts2.P7    <- dates[33];
                  ts2.P8    <- dates[34];
                  ts2.P9    <- dates[35];
                  ts2.P10   <- dates[36];
                  ts2.P11   <- dates[37];
                  ts2.P12   <- dates[38];
                  ts2.P13   <- dates[39];
                  ts2.P14   <- dates[40];
                  ts2.P15   <- dates[41];
                  ts2.P16   <- dates[42];
                  ts2.P17   <- dates[43];
                  ts2.P18   <- dates[44];
                  ts2.P19   <- dates[45];
                  ts2.P20   <- dates[46];
                  ts2.P21   <- dates[47];
                  ts2.P22   <- dates[48];
                  ts2.P23   <- dates[49];
                  ts2.P24   <- dates[50];
                  ts2.P25   <- dates[51];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logscale1 <- par[28];
                  logalpha1 <- par[29];
                  logbeta1  <- par[30];
                  logP1F2   <- par[31];
                  logP2F2   <- par[32];
                  logP3F2   <- par[33];
                  logP4F2   <- par[34];
                  logP5F2   <- par[35];
                  logP6F2   <- par[36];
                  logP7F2   <- par[37];
                  logP8F2   <- par[38];
                  logP9F2   <- par[39];
                  logP10F2  <- par[40];
                  logP11F2  <- par[41];
                  logP12F2  <- par[42];
                  logP13F2  <- par[43];
                  logP14F2  <- par[44];
                  logP15F2  <- par[45];
                  logP16F2  <- par[46];
                  logP17F2  <- par[47];
                  logP18F2  <- par[48];
                  logP19F2  <- par[49];
                  logP20F2  <- par[50];
                  logP21F2  <- par[51];
                  logP22F2  <- par[52];
                  logP23F2  <- par[53];
                  logP24F2  <- par[54];
                  logP25F2  <- par[55];
                  logscale2 <- par[56];
                  logalpha2 <- par[57];
                  logbeta2  <- par[58];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN26P26P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(26,26))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts2.P1    <- dates[28];
                  ts2.P2    <- dates[29];
                  ts2.P3    <- dates[30];
                  ts2.P4    <- dates[31];
                  ts2.P5    <- dates[32];
                  ts2.P6    <- dates[33];
                  ts2.P7    <- dates[34];
                  ts2.P8    <- dates[35];
                  ts2.P9    <- dates[36];
                  ts2.P10   <- dates[37];
                  ts2.P11   <- dates[38];
                  ts2.P12   <- dates[39];
                  ts2.P13   <- dates[40];
                  ts2.P14   <- dates[41];
                  ts2.P15   <- dates[42];
                  ts2.P16   <- dates[43];
                  ts2.P17   <- dates[44];
                  ts2.P18   <- dates[45];
                  ts2.P19   <- dates[46];
                  ts2.P20   <- dates[47];
                  ts2.P21   <- dates[48];
                  ts2.P22   <- dates[49];
                  ts2.P23   <- dates[50];
                  ts2.P24   <- dates[51];
                  ts2.P25   <- dates[52];
                  ts2.P26   <- dates[53];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logscale1 <- par[29];
                  logalpha1 <- par[30];
                  logbeta1  <- par[31];
                  logP1F2   <- par[32];
                  logP2F2   <- par[33];
                  logP3F2   <- par[34];
                  logP4F2   <- par[35];
                  logP5F2   <- par[36];
                  logP6F2   <- par[37];
                  logP7F2   <- par[38];
                  logP8F2   <- par[39];
                  logP9F2   <- par[40];
                  logP10F2  <- par[41];
                  logP11F2  <- par[42];
                  logP12F2  <- par[43];
                  logP13F2  <- par[44];
                  logP14F2  <- par[45];
                  logP15F2  <- par[46];
                  logP16F2  <- par[47];
                  logP17F2  <- par[48];
                  logP18F2  <- par[49];
                  logP19F2  <- par[50];
                  logP20F2  <- par[51];
                  logP21F2  <- par[52];
                  logP22F2  <- par[53];
                  logP23F2  <- par[54];
                  logP24F2  <- par[55];
                  logP25F2  <- par[56];
                  logP26F2  <- par[57];
                  logscale2 <- par[58];
                  logalpha2 <- par[59];
                  logbeta2  <- par[60];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN27P27P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(27,27))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts2.P1    <- dates[29];
                  ts2.P2    <- dates[30];
                  ts2.P3    <- dates[31];
                  ts2.P4    <- dates[32];
                  ts2.P5    <- dates[33];
                  ts2.P6    <- dates[34];
                  ts2.P7    <- dates[35];
                  ts2.P8    <- dates[36];
                  ts2.P9    <- dates[37];
                  ts2.P10   <- dates[38];
                  ts2.P11   <- dates[39];
                  ts2.P12   <- dates[40];
                  ts2.P13   <- dates[41];
                  ts2.P14   <- dates[42];
                  ts2.P15   <- dates[43];
                  ts2.P16   <- dates[44];
                  ts2.P17   <- dates[45];
                  ts2.P18   <- dates[46];
                  ts2.P19   <- dates[47];
                  ts2.P20   <- dates[48];
                  ts2.P21   <- dates[49];
                  ts2.P22   <- dates[50];
                  ts2.P23   <- dates[51];
                  ts2.P24   <- dates[52];
                  ts2.P25   <- dates[53];
                  ts2.P26   <- dates[54];
                  ts2.P27   <- dates[55];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logscale1 <- par[30];
                  logalpha1 <- par[31];
                  logbeta1  <- par[32];
                  logP1F2   <- par[33];
                  logP2F2   <- par[34];
                  logP3F2   <- par[35];
                  logP4F2   <- par[36];
                  logP5F2   <- par[37];
                  logP6F2   <- par[38];
                  logP7F2   <- par[39];
                  logP8F2   <- par[40];
                  logP9F2   <- par[41];
                  logP10F2  <- par[42];
                  logP11F2  <- par[43];
                  logP12F2  <- par[44];
                  logP13F2  <- par[45];
                  logP14F2  <- par[46];
                  logP15F2  <- par[47];
                  logP16F2  <- par[48];
                  logP17F2  <- par[49];
                  logP18F2  <- par[50];
                  logP19F2  <- par[51];
                  logP20F2  <- par[52];
                  logP21F2  <- par[53];
                  logP22F2  <- par[54];
                  logP23F2  <- par[55];
                  logP24F2  <- par[56];
                  logP25F2  <- par[57];
                  logP26F2  <- par[58];
                  logP27F2  <- par[59];
                  logscale2 <- par[60];
                  logalpha2 <- par[61];
                  logbeta2  <- par[62];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN28P28P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(28,28))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts2.P1    <- dates[30];
                  ts2.P2    <- dates[31];
                  ts2.P3    <- dates[32];
                  ts2.P4    <- dates[33];
                  ts2.P5    <- dates[34];
                  ts2.P6    <- dates[35];
                  ts2.P7    <- dates[36];
                  ts2.P8    <- dates[37];
                  ts2.P9    <- dates[38];
                  ts2.P10   <- dates[39];
                  ts2.P11   <- dates[40];
                  ts2.P12   <- dates[41];
                  ts2.P13   <- dates[42];
                  ts2.P14   <- dates[43];
                  ts2.P15   <- dates[44];
                  ts2.P16   <- dates[45];
                  ts2.P17   <- dates[46];
                  ts2.P18   <- dates[47];
                  ts2.P19   <- dates[48];
                  ts2.P20   <- dates[49];
                  ts2.P21   <- dates[50];
                  ts2.P22   <- dates[51];
                  ts2.P23   <- dates[52];
                  ts2.P24   <- dates[53];
                  ts2.P25   <- dates[54];
                  ts2.P26   <- dates[55];
                  ts2.P27   <- dates[56];
                  ts2.P28   <- dates[57];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logscale1 <- par[31];
                  logalpha1 <- par[32];
                  logbeta1  <- par[33];
                  logP1F2   <- par[34];
                  logP2F2   <- par[35];
                  logP3F2   <- par[36];
                  logP4F2   <- par[37];
                  logP5F2   <- par[38];
                  logP6F2   <- par[39];
                  logP7F2   <- par[40];
                  logP8F2   <- par[41];
                  logP9F2   <- par[42];
                  logP10F2  <- par[43];
                  logP11F2  <- par[44];
                  logP12F2  <- par[45];
                  logP13F2  <- par[46];
                  logP14F2  <- par[47];
                  logP15F2  <- par[48];
                  logP16F2  <- par[49];
                  logP17F2  <- par[50];
                  logP18F2  <- par[51];
                  logP19F2  <- par[52];
                  logP20F2  <- par[53];
                  logP21F2  <- par[54];
                  logP22F2  <- par[55];
                  logP23F2  <- par[56];
                  logP24F2  <- par[57];
                  logP25F2  <- par[58];
                  logP26F2  <- par[59];
                  logP27F2  <- par[60];
                  logP28F2  <- par[61];
                  logscale2 <- par[62];
                  logalpha2 <- par[63];
                  logbeta2  <- par[64];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN29P29P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(29,29))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts2.P1    <- dates[31];
                  ts2.P2    <- dates[32];
                  ts2.P3    <- dates[33];
                  ts2.P4    <- dates[34];
                  ts2.P5    <- dates[35];
                  ts2.P6    <- dates[36];
                  ts2.P7    <- dates[37];
                  ts2.P8    <- dates[38];
                  ts2.P9    <- dates[39];
                  ts2.P10   <- dates[40];
                  ts2.P11   <- dates[41];
                  ts2.P12   <- dates[42];
                  ts2.P13   <- dates[43];
                  ts2.P14   <- dates[44];
                  ts2.P15   <- dates[45];
                  ts2.P16   <- dates[46];
                  ts2.P17   <- dates[47];
                  ts2.P18   <- dates[48];
                  ts2.P19   <- dates[49];
                  ts2.P20   <- dates[50];
                  ts2.P21   <- dates[51];
                  ts2.P22   <- dates[52];
                  ts2.P23   <- dates[53];
                  ts2.P24   <- dates[54];
                  ts2.P25   <- dates[55];
                  ts2.P26   <- dates[56];
                  ts2.P27   <- dates[57];
                  ts2.P28   <- dates[58];
                  ts2.P29   <- dates[59];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logscale1 <- par[32];
                  logalpha1 <- par[33];
                  logbeta1  <- par[34];
                  logP1F2   <- par[35];
                  logP2F2   <- par[36];
                  logP3F2   <- par[37];
                  logP4F2   <- par[38];
                  logP5F2   <- par[39];
                  logP6F2   <- par[40];
                  logP7F2   <- par[41];
                  logP8F2   <- par[42];
                  logP9F2   <- par[43];
                  logP10F2  <- par[44];
                  logP11F2  <- par[45];
                  logP12F2  <- par[46];
                  logP13F2  <- par[47];
                  logP14F2  <- par[48];
                  logP15F2  <- par[49];
                  logP16F2  <- par[50];
                  logP17F2  <- par[51];
                  logP18F2  <- par[52];
                  logP19F2  <- par[53];
                  logP20F2  <- par[54];
                  logP21F2  <- par[55];
                  logP22F2  <- par[56];
                  logP23F2  <- par[57];
                  logP24F2  <- par[58];
                  logP25F2  <- par[59];
                  logP26F2  <- par[60];
                  logP27F2  <- par[61];
                  logP28F2  <- par[62];
                  logP29F2  <- par[63];
                  logscale2 <- par[64];
                  logalpha2 <- par[65];
                  logbeta2  <- par[66];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN30P30P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(30,30))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts2.P1    <- dates[32];
                  ts2.P2    <- dates[33];
                  ts2.P3    <- dates[34];
                  ts2.P4    <- dates[35];
                  ts2.P5    <- dates[36];
                  ts2.P6    <- dates[37];
                  ts2.P7    <- dates[38];
                  ts2.P8    <- dates[39];
                  ts2.P9    <- dates[40];
                  ts2.P10   <- dates[41];
                  ts2.P11   <- dates[42];
                  ts2.P12   <- dates[43];
                  ts2.P13   <- dates[44];
                  ts2.P14   <- dates[45];
                  ts2.P15   <- dates[46];
                  ts2.P16   <- dates[47];
                  ts2.P17   <- dates[48];
                  ts2.P18   <- dates[49];
                  ts2.P19   <- dates[50];
                  ts2.P20   <- dates[51];
                  ts2.P21   <- dates[52];
                  ts2.P22   <- dates[53];
                  ts2.P23   <- dates[54];
                  ts2.P24   <- dates[55];
                  ts2.P25   <- dates[56];
                  ts2.P26   <- dates[57];
                  ts2.P27   <- dates[58];
                  ts2.P28   <- dates[59];
                  ts2.P29   <- dates[60];
                  ts2.P30   <- dates[61];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logscale1 <- par[33];
                  logalpha1 <- par[34];
                  logbeta1  <- par[35];
                  logP1F2   <- par[36];
                  logP2F2   <- par[37];
                  logP3F2   <- par[38];
                  logP4F2   <- par[39];
                  logP5F2   <- par[40];
                  logP6F2   <- par[41];
                  logP7F2   <- par[42];
                  logP8F2   <- par[43];
                  logP9F2   <- par[44];
                  logP10F2  <- par[45];
                  logP11F2  <- par[46];
                  logP12F2  <- par[47];
                  logP13F2  <- par[48];
                  logP14F2  <- par[49];
                  logP15F2  <- par[50];
                  logP16F2  <- par[51];
                  logP17F2  <- par[52];
                  logP18F2  <- par[53];
                  logP19F2  <- par[54];
                  logP20F2  <- par[55];
                  logP21F2  <- par[56];
                  logP22F2  <- par[57];
                  logP23F2  <- par[58];
                  logP24F2  <- par[59];
                  logP25F2  <- par[60];
                  logP26F2  <- par[61];
                  logP27F2  <- par[62];
                  logP28F2  <- par[63];
                  logP29F2  <- par[64];
                  logP30F2  <- par[65];
                  logscale2 <- par[66];
                  logalpha2 <- par[67];
                  logbeta2  <- par[68];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN31P31P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(31,31))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts2.P1    <- dates[33];
                  ts2.P2    <- dates[34];
                  ts2.P3    <- dates[35];
                  ts2.P4    <- dates[36];
                  ts2.P5    <- dates[37];
                  ts2.P6    <- dates[38];
                  ts2.P7    <- dates[39];
                  ts2.P8    <- dates[40];
                  ts2.P9    <- dates[41];
                  ts2.P10   <- dates[42];
                  ts2.P11   <- dates[43];
                  ts2.P12   <- dates[44];
                  ts2.P13   <- dates[45];
                  ts2.P14   <- dates[46];
                  ts2.P15   <- dates[47];
                  ts2.P16   <- dates[48];
                  ts2.P17   <- dates[49];
                  ts2.P18   <- dates[50];
                  ts2.P19   <- dates[51];
                  ts2.P20   <- dates[52];
                  ts2.P21   <- dates[53];
                  ts2.P22   <- dates[54];
                  ts2.P23   <- dates[55];
                  ts2.P24   <- dates[56];
                  ts2.P25   <- dates[57];
                  ts2.P26   <- dates[58];
                  ts2.P27   <- dates[59];
                  ts2.P28   <- dates[60];
                  ts2.P29   <- dates[61];
                  ts2.P30   <- dates[62];
                  ts2.P31   <- dates[63];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logscale1 <- par[34];
                  logalpha1 <- par[35];
                  logbeta1  <- par[36];
                  logP1F2   <- par[37];
                  logP2F2   <- par[38];
                  logP3F2   <- par[39];
                  logP4F2   <- par[40];
                  logP5F2   <- par[41];
                  logP6F2   <- par[42];
                  logP7F2   <- par[43];
                  logP8F2   <- par[44];
                  logP9F2   <- par[45];
                  logP10F2  <- par[46];
                  logP11F2  <- par[47];
                  logP12F2  <- par[48];
                  logP13F2  <- par[49];
                  logP14F2  <- par[50];
                  logP15F2  <- par[51];
                  logP16F2  <- par[52];
                  logP17F2  <- par[53];
                  logP18F2  <- par[54];
                  logP19F2  <- par[55];
                  logP20F2  <- par[56];
                  logP21F2  <- par[57];
                  logP22F2  <- par[58];
                  logP23F2  <- par[59];
                  logP24F2  <- par[60];
                  logP25F2  <- par[61];
                  logP26F2  <- par[62];
                  logP27F2  <- par[63];
                  logP28F2  <- par[64];
                  logP29F2  <- par[65];
                  logP30F2  <- par[66];
                  logP31F2  <- par[67];
                  logscale2 <- par[68];
                  logalpha2 <- par[69];
                  logbeta2  <- par[70];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN32P32P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(32,32))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts2.P1    <- dates[34];
                  ts2.P2    <- dates[35];
                  ts2.P3    <- dates[36];
                  ts2.P4    <- dates[37];
                  ts2.P5    <- dates[38];
                  ts2.P6    <- dates[39];
                  ts2.P7    <- dates[40];
                  ts2.P8    <- dates[41];
                  ts2.P9    <- dates[42];
                  ts2.P10   <- dates[43];
                  ts2.P11   <- dates[44];
                  ts2.P12   <- dates[45];
                  ts2.P13   <- dates[46];
                  ts2.P14   <- dates[47];
                  ts2.P15   <- dates[48];
                  ts2.P16   <- dates[49];
                  ts2.P17   <- dates[50];
                  ts2.P18   <- dates[51];
                  ts2.P19   <- dates[52];
                  ts2.P20   <- dates[53];
                  ts2.P21   <- dates[54];
                  ts2.P22   <- dates[55];
                  ts2.P23   <- dates[56];
                  ts2.P24   <- dates[57];
                  ts2.P25   <- dates[58];
                  ts2.P26   <- dates[59];
                  ts2.P27   <- dates[60];
                  ts2.P28   <- dates[61];
                  ts2.P29   <- dates[62];
                  ts2.P30   <- dates[63];
                  ts2.P31   <- dates[64];
                  ts2.P32   <- dates[65];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logscale1 <- par[35];
                  logalpha1 <- par[36];
                  logbeta1  <- par[37];
                  logP1F2   <- par[38];
                  logP2F2   <- par[39];
                  logP3F2   <- par[40];
                  logP4F2   <- par[41];
                  logP5F2   <- par[42];
                  logP6F2   <- par[43];
                  logP7F2   <- par[44];
                  logP8F2   <- par[45];
                  logP9F2   <- par[46];
                  logP10F2  <- par[47];
                  logP11F2  <- par[48];
                  logP12F2  <- par[49];
                  logP13F2  <- par[50];
                  logP14F2  <- par[51];
                  logP15F2  <- par[52];
                  logP16F2  <- par[53];
                  logP17F2  <- par[54];
                  logP18F2  <- par[55];
                  logP19F2  <- par[56];
                  logP20F2  <- par[57];
                  logP21F2  <- par[58];
                  logP22F2  <- par[59];
                  logP23F2  <- par[60];
                  logP24F2  <- par[61];
                  logP25F2  <- par[62];
                  logP26F2  <- par[63];
                  logP27F2  <- par[64];
                  logP28F2  <- par[65];
                  logP29F2  <- par[66];
                  logP30F2  <- par[67];
                  logP31F2  <- par[68];
                  logP32F2  <- par[69];
                  logscale2 <- par[70];
                  logalpha2 <- par[71];
                  logbeta2  <- par[72];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN33P33P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(33,33))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts2.P1    <- dates[35];
                  ts2.P2    <- dates[36];
                  ts2.P3    <- dates[37];
                  ts2.P4    <- dates[38];
                  ts2.P5    <- dates[39];
                  ts2.P6    <- dates[40];
                  ts2.P7    <- dates[41];
                  ts2.P8    <- dates[42];
                  ts2.P9    <- dates[43];
                  ts2.P10   <- dates[44];
                  ts2.P11   <- dates[45];
                  ts2.P12   <- dates[46];
                  ts2.P13   <- dates[47];
                  ts2.P14   <- dates[48];
                  ts2.P15   <- dates[49];
                  ts2.P16   <- dates[50];
                  ts2.P17   <- dates[51];
                  ts2.P18   <- dates[52];
                  ts2.P19   <- dates[53];
                  ts2.P20   <- dates[54];
                  ts2.P21   <- dates[55];
                  ts2.P22   <- dates[56];
                  ts2.P23   <- dates[57];
                  ts2.P24   <- dates[58];
                  ts2.P25   <- dates[59];
                  ts2.P26   <- dates[60];
                  ts2.P27   <- dates[61];
                  ts2.P28   <- dates[62];
                  ts2.P29   <- dates[63];
                  ts2.P30   <- dates[64];
                  ts2.P31   <- dates[65];
                  ts2.P32   <- dates[66];
                  ts2.P33   <- dates[67];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logscale1 <- par[36];
                  logalpha1 <- par[37];
                  logbeta1  <- par[38];
                  logP1F2   <- par[39];
                  logP2F2   <- par[40];
                  logP3F2   <- par[41];
                  logP4F2   <- par[42];
                  logP5F2   <- par[43];
                  logP6F2   <- par[44];
                  logP7F2   <- par[45];
                  logP8F2   <- par[46];
                  logP9F2   <- par[47];
                  logP10F2  <- par[48];
                  logP11F2  <- par[49];
                  logP12F2  <- par[50];
                  logP13F2  <- par[51];
                  logP14F2  <- par[52];
                  logP15F2  <- par[53];
                  logP16F2  <- par[54];
                  logP17F2  <- par[55];
                  logP18F2  <- par[56];
                  logP19F2  <- par[57];
                  logP20F2  <- par[58];
                  logP21F2  <- par[59];
                  logP22F2  <- par[60];
                  logP23F2  <- par[61];
                  logP24F2  <- par[62];
                  logP25F2  <- par[63];
                  logP26F2  <- par[64];
                  logP27F2  <- par[65];
                  logP28F2  <- par[66];
                  logP29F2  <- par[67];
                  logP30F2  <- par[68];
                  logP31F2  <- par[69];
                  logP32F2  <- par[70];
                  logP33F2  <- par[71];
                  logscale2 <- par[72];
                  logalpha2 <- par[73];
                  logbeta2  <- par[74];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN34P34P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(34,34))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts2.P1    <- dates[36];
                  ts2.P2    <- dates[37];
                  ts2.P3    <- dates[38];
                  ts2.P4    <- dates[39];
                  ts2.P5    <- dates[40];
                  ts2.P6    <- dates[41];
                  ts2.P7    <- dates[42];
                  ts2.P8    <- dates[43];
                  ts2.P9    <- dates[44];
                  ts2.P10   <- dates[45];
                  ts2.P11   <- dates[46];
                  ts2.P12   <- dates[47];
                  ts2.P13   <- dates[48];
                  ts2.P14   <- dates[49];
                  ts2.P15   <- dates[50];
                  ts2.P16   <- dates[51];
                  ts2.P17   <- dates[52];
                  ts2.P18   <- dates[53];
                  ts2.P19   <- dates[54];
                  ts2.P20   <- dates[55];
                  ts2.P21   <- dates[56];
                  ts2.P22   <- dates[57];
                  ts2.P23   <- dates[58];
                  ts2.P24   <- dates[59];
                  ts2.P25   <- dates[60];
                  ts2.P26   <- dates[61];
                  ts2.P27   <- dates[62];
                  ts2.P28   <- dates[63];
                  ts2.P29   <- dates[64];
                  ts2.P30   <- dates[65];
                  ts2.P31   <- dates[66];
                  ts2.P32   <- dates[67];
                  ts2.P33   <- dates[68];
                  ts2.P34   <- dates[69];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logscale1 <- par[37];
                  logalpha1 <- par[38];
                  logbeta1  <- par[39];
                  logP1F2   <- par[40];
                  logP2F2   <- par[41];
                  logP3F2   <- par[42];
                  logP4F2   <- par[43];
                  logP5F2   <- par[44];
                  logP6F2   <- par[45];
                  logP7F2   <- par[46];
                  logP8F2   <- par[47];
                  logP9F2   <- par[48];
                  logP10F2  <- par[49];
                  logP11F2  <- par[50];
                  logP12F2  <- par[51];
                  logP13F2  <- par[52];
                  logP14F2  <- par[53];
                  logP15F2  <- par[54];
                  logP16F2  <- par[55];
                  logP17F2  <- par[56];
                  logP18F2  <- par[57];
                  logP19F2  <- par[58];
                  logP20F2  <- par[59];
                  logP21F2  <- par[60];
                  logP22F2  <- par[61];
                  logP23F2  <- par[62];
                  logP24F2  <- par[63];
                  logP25F2  <- par[64];
                  logP26F2  <- par[65];
                  logP27F2  <- par[66];
                  logP28F2  <- par[67];
                  logP29F2  <- par[68];
                  logP30F2  <- par[69];
                  logP31F2  <- par[70];
                  logP32F2  <- par[71];
                  logP33F2  <- par[72];
                  logP34F2  <- par[73];
                  logscale2 <- par[74];
                  logalpha2 <- par[75];
                  logbeta2  <- par[76];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN35P35P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(35,35))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts2.P1    <- dates[37];
                  ts2.P2    <- dates[38];
                  ts2.P3    <- dates[39];
                  ts2.P4    <- dates[40];
                  ts2.P5    <- dates[41];
                  ts2.P6    <- dates[42];
                  ts2.P7    <- dates[43];
                  ts2.P8    <- dates[44];
                  ts2.P9    <- dates[45];
                  ts2.P10   <- dates[46];
                  ts2.P11   <- dates[47];
                  ts2.P12   <- dates[48];
                  ts2.P13   <- dates[49];
                  ts2.P14   <- dates[50];
                  ts2.P15   <- dates[51];
                  ts2.P16   <- dates[52];
                  ts2.P17   <- dates[53];
                  ts2.P18   <- dates[54];
                  ts2.P19   <- dates[55];
                  ts2.P20   <- dates[56];
                  ts2.P21   <- dates[57];
                  ts2.P22   <- dates[58];
                  ts2.P23   <- dates[59];
                  ts2.P24   <- dates[60];
                  ts2.P25   <- dates[61];
                  ts2.P26   <- dates[62];
                  ts2.P27   <- dates[63];
                  ts2.P28   <- dates[64];
                  ts2.P29   <- dates[65];
                  ts2.P30   <- dates[66];
                  ts2.P31   <- dates[67];
                  ts2.P32   <- dates[68];
                  ts2.P33   <- dates[69];
                  ts2.P34   <- dates[70];
                  ts2.P35   <- dates[71];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logscale1 <- par[38];
                  logalpha1 <- par[39];
                  logbeta1  <- par[40];
                  logP1F2   <- par[41];
                  logP2F2   <- par[42];
                  logP3F2   <- par[43];
                  logP4F2   <- par[44];
                  logP5F2   <- par[45];
                  logP6F2   <- par[46];
                  logP7F2   <- par[47];
                  logP8F2   <- par[48];
                  logP9F2   <- par[49];
                  logP10F2  <- par[50];
                  logP11F2  <- par[51];
                  logP12F2  <- par[52];
                  logP13F2  <- par[53];
                  logP14F2  <- par[54];
                  logP15F2  <- par[55];
                  logP16F2  <- par[56];
                  logP17F2  <- par[57];
                  logP18F2  <- par[58];
                  logP19F2  <- par[59];
                  logP20F2  <- par[60];
                  logP21F2  <- par[61];
                  logP22F2  <- par[62];
                  logP23F2  <- par[63];
                  logP24F2  <- par[64];
                  logP25F2  <- par[65];
                  logP26F2  <- par[66];
                  logP27F2  <- par[67];
                  logP28F2  <- par[68];
                  logP29F2  <- par[69];
                  logP30F2  <- par[70];
                  logP31F2  <- par[71];
                  logP32F2  <- par[72];
                  logP33F2  <- par[73];
                  logP34F2  <- par[74];
                  logP35F2  <- par[75];
                  logscale2 <- par[76];
                  logalpha2 <- par[77];
                  logbeta2  <- par[78];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN36P36P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(36,36))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts2.P1    <- dates[38];
                  ts2.P2    <- dates[39];
                  ts2.P3    <- dates[40];
                  ts2.P4    <- dates[41];
                  ts2.P5    <- dates[42];
                  ts2.P6    <- dates[43];
                  ts2.P7    <- dates[44];
                  ts2.P8    <- dates[45];
                  ts2.P9    <- dates[46];
                  ts2.P10   <- dates[47];
                  ts2.P11   <- dates[48];
                  ts2.P12   <- dates[49];
                  ts2.P13   <- dates[50];
                  ts2.P14   <- dates[51];
                  ts2.P15   <- dates[52];
                  ts2.P16   <- dates[53];
                  ts2.P17   <- dates[54];
                  ts2.P18   <- dates[55];
                  ts2.P19   <- dates[56];
                  ts2.P20   <- dates[57];
                  ts2.P21   <- dates[58];
                  ts2.P22   <- dates[59];
                  ts2.P23   <- dates[60];
                  ts2.P24   <- dates[61];
                  ts2.P25   <- dates[62];
                  ts2.P26   <- dates[63];
                  ts2.P27   <- dates[64];
                  ts2.P28   <- dates[65];
                  ts2.P29   <- dates[66];
                  ts2.P30   <- dates[67];
                  ts2.P31   <- dates[68];
                  ts2.P32   <- dates[69];
                  ts2.P33   <- dates[70];
                  ts2.P34   <- dates[71];
                  ts2.P35   <- dates[72];
                  ts2.P36   <- dates[73];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logscale1 <- par[39];
                  logalpha1 <- par[40];
                  logbeta1  <- par[41];
                  logP1F2   <- par[42];
                  logP2F2   <- par[43];
                  logP3F2   <- par[44];
                  logP4F2   <- par[45];
                  logP5F2   <- par[46];
                  logP6F2   <- par[47];
                  logP7F2   <- par[48];
                  logP8F2   <- par[49];
                  logP9F2   <- par[50];
                  logP10F2  <- par[51];
                  logP11F2  <- par[52];
                  logP12F2  <- par[53];
                  logP13F2  <- par[54];
                  logP14F2  <- par[55];
                  logP15F2  <- par[56];
                  logP16F2  <- par[57];
                  logP17F2  <- par[58];
                  logP18F2  <- par[59];
                  logP19F2  <- par[60];
                  logP20F2  <- par[61];
                  logP21F2  <- par[62];
                  logP22F2  <- par[63];
                  logP23F2  <- par[64];
                  logP24F2  <- par[65];
                  logP25F2  <- par[66];
                  logP26F2  <- par[67];
                  logP27F2  <- par[68];
                  logP28F2  <- par[69];
                  logP29F2  <- par[70];
                  logP30F2  <- par[71];
                  logP31F2  <- par[72];
                  logP32F2  <- par[73];
                  logP33F2  <- par[74];
                  logP34F2  <- par[75];
                  logP35F2  <- par[76];
                  logP36F2  <- par[77];
                  logscale2 <- par[78];
                  logalpha2 <- par[79];
                  logbeta2  <- par[80];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN37P37P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(37,37))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts2.P1    <- dates[39];
                  ts2.P2    <- dates[40];
                  ts2.P3    <- dates[41];
                  ts2.P4    <- dates[42];
                  ts2.P5    <- dates[43];
                  ts2.P6    <- dates[44];
                  ts2.P7    <- dates[45];
                  ts2.P8    <- dates[46];
                  ts2.P9    <- dates[47];
                  ts2.P10   <- dates[48];
                  ts2.P11   <- dates[49];
                  ts2.P12   <- dates[50];
                  ts2.P13   <- dates[51];
                  ts2.P14   <- dates[52];
                  ts2.P15   <- dates[53];
                  ts2.P16   <- dates[54];
                  ts2.P17   <- dates[55];
                  ts2.P18   <- dates[56];
                  ts2.P19   <- dates[57];
                  ts2.P20   <- dates[58];
                  ts2.P21   <- dates[59];
                  ts2.P22   <- dates[60];
                  ts2.P23   <- dates[61];
                  ts2.P24   <- dates[62];
                  ts2.P25   <- dates[63];
                  ts2.P26   <- dates[64];
                  ts2.P27   <- dates[65];
                  ts2.P28   <- dates[66];
                  ts2.P29   <- dates[67];
                  ts2.P30   <- dates[68];
                  ts2.P31   <- dates[69];
                  ts2.P32   <- dates[70];
                  ts2.P33   <- dates[71];
                  ts2.P34   <- dates[72];
                  ts2.P35   <- dates[73];
                  ts2.P36   <- dates[74];
                  ts2.P37   <- dates[75];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logscale1 <- par[40];
                  logalpha1 <- par[41];
                  logbeta1  <- par[42];
                  logP1F2   <- par[43];
                  logP2F2   <- par[44];
                  logP3F2   <- par[45];
                  logP4F2   <- par[46];
                  logP5F2   <- par[47];
                  logP6F2   <- par[48];
                  logP7F2   <- par[49];
                  logP8F2   <- par[50];
                  logP9F2   <- par[51];
                  logP10F2  <- par[52];
                  logP11F2  <- par[53];
                  logP12F2  <- par[54];
                  logP13F2  <- par[55];
                  logP14F2  <- par[56];
                  logP15F2  <- par[57];
                  logP16F2  <- par[58];
                  logP17F2  <- par[59];
                  logP18F2  <- par[60];
                  logP19F2  <- par[61];
                  logP20F2  <- par[62];
                  logP21F2  <- par[63];
                  logP22F2  <- par[64];
                  logP23F2  <- par[65];
                  logP24F2  <- par[66];
                  logP25F2  <- par[67];
                  logP26F2  <- par[68];
                  logP27F2  <- par[69];
                  logP28F2  <- par[70];
                  logP29F2  <- par[71];
                  logP30F2  <- par[72];
                  logP31F2  <- par[73];
                  logP32F2  <- par[74];
                  logP33F2  <- par[75];
                  logP34F2  <- par[76];
                  logP35F2  <- par[77];
                  logP36F2  <- par[78];
                  logP37F2  <- par[79];
                  logscale2 <- par[80];
                  logalpha2 <- par[81];
                  logbeta2  <- par[82];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN38P38P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(38,38))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts2.P1    <- dates[40];
                  ts2.P2    <- dates[41];
                  ts2.P3    <- dates[42];
                  ts2.P4    <- dates[43];
                  ts2.P5    <- dates[44];
                  ts2.P6    <- dates[45];
                  ts2.P7    <- dates[46];
                  ts2.P8    <- dates[47];
                  ts2.P9    <- dates[48];
                  ts2.P10   <- dates[49];
                  ts2.P11   <- dates[50];
                  ts2.P12   <- dates[51];
                  ts2.P13   <- dates[52];
                  ts2.P14   <- dates[53];
                  ts2.P15   <- dates[54];
                  ts2.P16   <- dates[55];
                  ts2.P17   <- dates[56];
                  ts2.P18   <- dates[57];
                  ts2.P19   <- dates[58];
                  ts2.P20   <- dates[59];
                  ts2.P21   <- dates[60];
                  ts2.P22   <- dates[61];
                  ts2.P23   <- dates[62];
                  ts2.P24   <- dates[63];
                  ts2.P25   <- dates[64];
                  ts2.P26   <- dates[65];
                  ts2.P27   <- dates[66];
                  ts2.P28   <- dates[67];
                  ts2.P29   <- dates[68];
                  ts2.P30   <- dates[69];
                  ts2.P31   <- dates[70];
                  ts2.P32   <- dates[71];
                  ts2.P33   <- dates[72];
                  ts2.P34   <- dates[73];
                  ts2.P35   <- dates[74];
                  ts2.P36   <- dates[75];
                  ts2.P37   <- dates[76];
                  ts2.P38   <- dates[77];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logscale1 <- par[41];
                  logalpha1 <- par[42];
                  logbeta1  <- par[43];
                  logP1F2   <- par[44];
                  logP2F2   <- par[45];
                  logP3F2   <- par[46];
                  logP4F2   <- par[47];
                  logP5F2   <- par[48];
                  logP6F2   <- par[49];
                  logP7F2   <- par[50];
                  logP8F2   <- par[51];
                  logP9F2   <- par[52];
                  logP10F2  <- par[53];
                  logP11F2  <- par[54];
                  logP12F2  <- par[55];
                  logP13F2  <- par[56];
                  logP14F2  <- par[57];
                  logP15F2  <- par[58];
                  logP16F2  <- par[59];
                  logP17F2  <- par[60];
                  logP18F2  <- par[61];
                  logP19F2  <- par[62];
                  logP20F2  <- par[63];
                  logP21F2  <- par[64];
                  logP22F2  <- par[65];
                  logP23F2  <- par[66];
                  logP24F2  <- par[67];
                  logP25F2  <- par[68];
                  logP26F2  <- par[69];
                  logP27F2  <- par[70];
                  logP28F2  <- par[71];
                  logP29F2  <- par[72];
                  logP30F2  <- par[73];
                  logP31F2  <- par[74];
                  logP32F2  <- par[75];
                  logP33F2  <- par[76];
                  logP34F2  <- par[77];
                  logP35F2  <- par[78];
                  logP36F2  <- par[79];
                  logP37F2  <- par[80];
                  logP38F2  <- par[81];
                  logscale2 <- par[82];
                  logalpha2 <- par[83];
                  logbeta2  <- par[84];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN39P39P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(39,39))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts2.P1    <- dates[41];
                  ts2.P2    <- dates[42];
                  ts2.P3    <- dates[43];
                  ts2.P4    <- dates[44];
                  ts2.P5    <- dates[45];
                  ts2.P6    <- dates[46];
                  ts2.P7    <- dates[47];
                  ts2.P8    <- dates[48];
                  ts2.P9    <- dates[49];
                  ts2.P10   <- dates[50];
                  ts2.P11   <- dates[51];
                  ts2.P12   <- dates[52];
                  ts2.P13   <- dates[53];
                  ts2.P14   <- dates[54];
                  ts2.P15   <- dates[55];
                  ts2.P16   <- dates[56];
                  ts2.P17   <- dates[57];
                  ts2.P18   <- dates[58];
                  ts2.P19   <- dates[59];
                  ts2.P20   <- dates[60];
                  ts2.P21   <- dates[61];
                  ts2.P22   <- dates[62];
                  ts2.P23   <- dates[63];
                  ts2.P24   <- dates[64];
                  ts2.P25   <- dates[65];
                  ts2.P26   <- dates[66];
                  ts2.P27   <- dates[67];
                  ts2.P28   <- dates[68];
                  ts2.P29   <- dates[69];
                  ts2.P30   <- dates[70];
                  ts2.P31   <- dates[71];
                  ts2.P32   <- dates[72];
                  ts2.P33   <- dates[73];
                  ts2.P34   <- dates[74];
                  ts2.P35   <- dates[75];
                  ts2.P36   <- dates[76];
                  ts2.P37   <- dates[77];
                  ts2.P38   <- dates[78];
                  ts2.P39   <- dates[79];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logscale1 <- par[42];
                  logalpha1 <- par[43];
                  logbeta1  <- par[44];
                  logP1F2   <- par[45];
                  logP2F2   <- par[46];
                  logP3F2   <- par[47];
                  logP4F2   <- par[48];
                  logP5F2   <- par[49];
                  logP6F2   <- par[50];
                  logP7F2   <- par[51];
                  logP8F2   <- par[52];
                  logP9F2   <- par[53];
                  logP10F2  <- par[54];
                  logP11F2  <- par[55];
                  logP12F2  <- par[56];
                  logP13F2  <- par[57];
                  logP14F2  <- par[58];
                  logP15F2  <- par[59];
                  logP16F2  <- par[60];
                  logP17F2  <- par[61];
                  logP18F2  <- par[62];
                  logP19F2  <- par[63];
                  logP20F2  <- par[64];
                  logP21F2  <- par[65];
                  logP22F2  <- par[66];
                  logP23F2  <- par[67];
                  logP24F2  <- par[68];
                  logP25F2  <- par[69];
                  logP26F2  <- par[70];
                  logP27F2  <- par[71];
                  logP28F2  <- par[72];
                  logP29F2  <- par[73];
                  logP30F2  <- par[74];
                  logP31F2  <- par[75];
                  logP32F2  <- par[76];
                  logP33F2  <- par[77];
                  logP34F2  <- par[78];
                  logP35F2  <- par[79];
                  logP36F2  <- par[80];
                  logP37F2  <- par[81];
                  logP38F2  <- par[82];
                  logP39F2  <- par[83];
                  logscale2 <- par[84];
                  logalpha2 <- par[85];
                  logbeta2  <- par[86];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN40P40P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(40,40))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts2.P1    <- dates[42];
                  ts2.P2    <- dates[43];
                  ts2.P3    <- dates[44];
                  ts2.P4    <- dates[45];
                  ts2.P5    <- dates[46];
                  ts2.P6    <- dates[47];
                  ts2.P7    <- dates[48];
                  ts2.P8    <- dates[49];
                  ts2.P9    <- dates[50];
                  ts2.P10   <- dates[51];
                  ts2.P11   <- dates[52];
                  ts2.P12   <- dates[53];
                  ts2.P13   <- dates[54];
                  ts2.P14   <- dates[55];
                  ts2.P15   <- dates[56];
                  ts2.P16   <- dates[57];
                  ts2.P17   <- dates[58];
                  ts2.P18   <- dates[59];
                  ts2.P19   <- dates[60];
                  ts2.P20   <- dates[61];
                  ts2.P21   <- dates[62];
                  ts2.P22   <- dates[63];
                  ts2.P23   <- dates[64];
                  ts2.P24   <- dates[65];
                  ts2.P25   <- dates[66];
                  ts2.P26   <- dates[67];
                  ts2.P27   <- dates[68];
                  ts2.P28   <- dates[69];
                  ts2.P29   <- dates[70];
                  ts2.P30   <- dates[71];
                  ts2.P31   <- dates[72];
                  ts2.P32   <- dates[73];
                  ts2.P33   <- dates[74];
                  ts2.P34   <- dates[75];
                  ts2.P35   <- dates[76];
                  ts2.P36   <- dates[77];
                  ts2.P37   <- dates[78];
                  ts2.P38   <- dates[79];
                  ts2.P39   <- dates[80];
                  ts2.P40   <- dates[81];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logscale1 <- par[43];
                  logalpha1 <- par[44];
                  logbeta1  <- par[45];
                  logP1F2   <- par[46];
                  logP2F2   <- par[47];
                  logP3F2   <- par[48];
                  logP4F2   <- par[49];
                  logP5F2   <- par[50];
                  logP6F2   <- par[51];
                  logP7F2   <- par[52];
                  logP8F2   <- par[53];
                  logP9F2   <- par[54];
                  logP10F2  <- par[55];
                  logP11F2  <- par[56];
                  logP12F2  <- par[57];
                  logP13F2  <- par[58];
                  logP14F2  <- par[59];
                  logP15F2  <- par[60];
                  logP16F2  <- par[61];
                  logP17F2  <- par[62];
                  logP18F2  <- par[63];
                  logP19F2  <- par[64];
                  logP20F2  <- par[65];
                  logP21F2  <- par[66];
                  logP22F2  <- par[67];
                  logP23F2  <- par[68];
                  logP24F2  <- par[69];
                  logP25F2  <- par[70];
                  logP26F2  <- par[71];
                  logP27F2  <- par[72];
                  logP28F2  <- par[73];
                  logP29F2  <- par[74];
                  logP30F2  <- par[75];
                  logP31F2  <- par[76];
                  logP32F2  <- par[77];
                  logP33F2  <- par[78];
                  logP34F2  <- par[79];
                  logP35F2  <- par[80];
                  logP36F2  <- par[81];
                  logP37F2  <- par[82];
                  logP38F2  <- par[83];
                  logP39F2  <- par[84];
                  logP40F2  <- par[85];
                  logscale2 <- par[86];
                  logalpha2 <- par[87];
                  logbeta2  <- par[88];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN41P41P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(41,41))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts2.P1    <- dates[43];
                  ts2.P2    <- dates[44];
                  ts2.P3    <- dates[45];
                  ts2.P4    <- dates[46];
                  ts2.P5    <- dates[47];
                  ts2.P6    <- dates[48];
                  ts2.P7    <- dates[49];
                  ts2.P8    <- dates[50];
                  ts2.P9    <- dates[51];
                  ts2.P10   <- dates[52];
                  ts2.P11   <- dates[53];
                  ts2.P12   <- dates[54];
                  ts2.P13   <- dates[55];
                  ts2.P14   <- dates[56];
                  ts2.P15   <- dates[57];
                  ts2.P16   <- dates[58];
                  ts2.P17   <- dates[59];
                  ts2.P18   <- dates[60];
                  ts2.P19   <- dates[61];
                  ts2.P20   <- dates[62];
                  ts2.P21   <- dates[63];
                  ts2.P22   <- dates[64];
                  ts2.P23   <- dates[65];
                  ts2.P24   <- dates[66];
                  ts2.P25   <- dates[67];
                  ts2.P26   <- dates[68];
                  ts2.P27   <- dates[69];
                  ts2.P28   <- dates[70];
                  ts2.P29   <- dates[71];
                  ts2.P30   <- dates[72];
                  ts2.P31   <- dates[73];
                  ts2.P32   <- dates[74];
                  ts2.P33   <- dates[75];
                  ts2.P34   <- dates[76];
                  ts2.P35   <- dates[77];
                  ts2.P36   <- dates[78];
                  ts2.P37   <- dates[79];
                  ts2.P38   <- dates[80];
                  ts2.P39   <- dates[81];
                  ts2.P40   <- dates[82];
                  ts2.P41   <- dates[83];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logscale1 <- par[44];
                  logalpha1 <- par[45];
                  logbeta1  <- par[46];
                  logP1F2   <- par[47];
                  logP2F2   <- par[48];
                  logP3F2   <- par[49];
                  logP4F2   <- par[50];
                  logP5F2   <- par[51];
                  logP6F2   <- par[52];
                  logP7F2   <- par[53];
                  logP8F2   <- par[54];
                  logP9F2   <- par[55];
                  logP10F2  <- par[56];
                  logP11F2  <- par[57];
                  logP12F2  <- par[58];
                  logP13F2  <- par[59];
                  logP14F2  <- par[60];
                  logP15F2  <- par[61];
                  logP16F2  <- par[62];
                  logP17F2  <- par[63];
                  logP18F2  <- par[64];
                  logP19F2  <- par[65];
                  logP20F2  <- par[66];
                  logP21F2  <- par[67];
                  logP22F2  <- par[68];
                  logP23F2  <- par[69];
                  logP24F2  <- par[70];
                  logP25F2  <- par[71];
                  logP26F2  <- par[72];
                  logP27F2  <- par[73];
                  logP28F2  <- par[74];
                  logP29F2  <- par[75];
                  logP30F2  <- par[76];
                  logP31F2  <- par[77];
                  logP32F2  <- par[78];
                  logP33F2  <- par[79];
                  logP34F2  <- par[80];
                  logP35F2  <- par[81];
                  logP36F2  <- par[82];
                  logP37F2  <- par[83];
                  logP38F2  <- par[84];
                  logP39F2  <- par[85];
                  logP40F2  <- par[86];
                  logP41F2  <- par[87];
                  logscale2 <- par[88];
                  logalpha2 <- par[89];
                  logbeta2  <- par[90];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN42P42P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(42,42))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts2.P1    <- dates[44];
                  ts2.P2    <- dates[45];
                  ts2.P3    <- dates[46];
                  ts2.P4    <- dates[47];
                  ts2.P5    <- dates[48];
                  ts2.P6    <- dates[49];
                  ts2.P7    <- dates[50];
                  ts2.P8    <- dates[51];
                  ts2.P9    <- dates[52];
                  ts2.P10   <- dates[53];
                  ts2.P11   <- dates[54];
                  ts2.P12   <- dates[55];
                  ts2.P13   <- dates[56];
                  ts2.P14   <- dates[57];
                  ts2.P15   <- dates[58];
                  ts2.P16   <- dates[59];
                  ts2.P17   <- dates[60];
                  ts2.P18   <- dates[61];
                  ts2.P19   <- dates[62];
                  ts2.P20   <- dates[63];
                  ts2.P21   <- dates[64];
                  ts2.P22   <- dates[65];
                  ts2.P23   <- dates[66];
                  ts2.P24   <- dates[67];
                  ts2.P25   <- dates[68];
                  ts2.P26   <- dates[69];
                  ts2.P27   <- dates[70];
                  ts2.P28   <- dates[71];
                  ts2.P29   <- dates[72];
                  ts2.P30   <- dates[73];
                  ts2.P31   <- dates[74];
                  ts2.P32   <- dates[75];
                  ts2.P33   <- dates[76];
                  ts2.P34   <- dates[77];
                  ts2.P35   <- dates[78];
                  ts2.P36   <- dates[79];
                  ts2.P37   <- dates[80];
                  ts2.P38   <- dates[81];
                  ts2.P39   <- dates[82];
                  ts2.P40   <- dates[83];
                  ts2.P41   <- dates[84];
                  ts2.P42   <- dates[85];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logscale1 <- par[45];
                  logalpha1 <- par[46];
                  logbeta1  <- par[47];
                  logP1F2   <- par[48];
                  logP2F2   <- par[49];
                  logP3F2   <- par[50];
                  logP4F2   <- par[51];
                  logP5F2   <- par[52];
                  logP6F2   <- par[53];
                  logP7F2   <- par[54];
                  logP8F2   <- par[55];
                  logP9F2   <- par[56];
                  logP10F2  <- par[57];
                  logP11F2  <- par[58];
                  logP12F2  <- par[59];
                  logP13F2  <- par[60];
                  logP14F2  <- par[61];
                  logP15F2  <- par[62];
                  logP16F2  <- par[63];
                  logP17F2  <- par[64];
                  logP18F2  <- par[65];
                  logP19F2  <- par[66];
                  logP20F2  <- par[67];
                  logP21F2  <- par[68];
                  logP22F2  <- par[69];
                  logP23F2  <- par[70];
                  logP24F2  <- par[71];
                  logP25F2  <- par[72];
                  logP26F2  <- par[73];
                  logP27F2  <- par[74];
                  logP28F2  <- par[75];
                  logP29F2  <- par[76];
                  logP30F2  <- par[77];
                  logP31F2  <- par[78];
                  logP32F2  <- par[79];
                  logP33F2  <- par[80];
                  logP34F2  <- par[81];
                  logP35F2  <- par[82];
                  logP36F2  <- par[83];
                  logP37F2  <- par[84];
                  logP38F2  <- par[85];
                  logP39F2  <- par[86];
                  logP40F2  <- par[87];
                  logP41F2  <- par[88];
                  logP42F2  <- par[89];
                  logscale2 <- par[90];
                  logalpha2 <- par[91];
                  logbeta2  <- par[92];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN43P43P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(43,43))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts2.P1    <- dates[45];
                  ts2.P2    <- dates[46];
                  ts2.P3    <- dates[47];
                  ts2.P4    <- dates[48];
                  ts2.P5    <- dates[49];
                  ts2.P6    <- dates[50];
                  ts2.P7    <- dates[51];
                  ts2.P8    <- dates[52];
                  ts2.P9    <- dates[53];
                  ts2.P10   <- dates[54];
                  ts2.P11   <- dates[55];
                  ts2.P12   <- dates[56];
                  ts2.P13   <- dates[57];
                  ts2.P14   <- dates[58];
                  ts2.P15   <- dates[59];
                  ts2.P16   <- dates[60];
                  ts2.P17   <- dates[61];
                  ts2.P18   <- dates[62];
                  ts2.P19   <- dates[63];
                  ts2.P20   <- dates[64];
                  ts2.P21   <- dates[65];
                  ts2.P22   <- dates[66];
                  ts2.P23   <- dates[67];
                  ts2.P24   <- dates[68];
                  ts2.P25   <- dates[69];
                  ts2.P26   <- dates[70];
                  ts2.P27   <- dates[71];
                  ts2.P28   <- dates[72];
                  ts2.P29   <- dates[73];
                  ts2.P30   <- dates[74];
                  ts2.P31   <- dates[75];
                  ts2.P32   <- dates[76];
                  ts2.P33   <- dates[77];
                  ts2.P34   <- dates[78];
                  ts2.P35   <- dates[79];
                  ts2.P36   <- dates[80];
                  ts2.P37   <- dates[81];
                  ts2.P38   <- dates[82];
                  ts2.P39   <- dates[83];
                  ts2.P40   <- dates[84];
                  ts2.P41   <- dates[85];
                  ts2.P42   <- dates[86];
                  ts2.P43   <- dates[87];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logscale1 <- par[46];
                  logalpha1 <- par[47];
                  logbeta1  <- par[48];
                  logP1F2   <- par[49];
                  logP2F2   <- par[50];
                  logP3F2   <- par[51];
                  logP4F2   <- par[52];
                  logP5F2   <- par[53];
                  logP6F2   <- par[54];
                  logP7F2   <- par[55];
                  logP8F2   <- par[56];
                  logP9F2   <- par[57];
                  logP10F2  <- par[58];
                  logP11F2  <- par[59];
                  logP12F2  <- par[60];
                  logP13F2  <- par[61];
                  logP14F2  <- par[62];
                  logP15F2  <- par[63];
                  logP16F2  <- par[64];
                  logP17F2  <- par[65];
                  logP18F2  <- par[66];
                  logP19F2  <- par[67];
                  logP20F2  <- par[68];
                  logP21F2  <- par[69];
                  logP22F2  <- par[70];
                  logP23F2  <- par[71];
                  logP24F2  <- par[72];
                  logP25F2  <- par[73];
                  logP26F2  <- par[74];
                  logP27F2  <- par[75];
                  logP28F2  <- par[76];
                  logP29F2  <- par[77];
                  logP30F2  <- par[78];
                  logP31F2  <- par[79];
                  logP32F2  <- par[80];
                  logP33F2  <- par[81];
                  logP34F2  <- par[82];
                  logP35F2  <- par[83];
                  logP36F2  <- par[84];
                  logP37F2  <- par[85];
                  logP38F2  <- par[86];
                  logP39F2  <- par[87];
                  logP40F2  <- par[88];
                  logP41F2  <- par[89];
                  logP42F2  <- par[90];
                  logP43F2  <- par[91];
                  logscale2 <- par[92];
                  logalpha2 <- par[93];
                  logbeta2  <- par[94];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN44P44P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(44,44))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts2.P1    <- dates[46];
                  ts2.P2    <- dates[47];
                  ts2.P3    <- dates[48];
                  ts2.P4    <- dates[49];
                  ts2.P5    <- dates[50];
                  ts2.P6    <- dates[51];
                  ts2.P7    <- dates[52];
                  ts2.P8    <- dates[53];
                  ts2.P9    <- dates[54];
                  ts2.P10   <- dates[55];
                  ts2.P11   <- dates[56];
                  ts2.P12   <- dates[57];
                  ts2.P13   <- dates[58];
                  ts2.P14   <- dates[59];
                  ts2.P15   <- dates[60];
                  ts2.P16   <- dates[61];
                  ts2.P17   <- dates[62];
                  ts2.P18   <- dates[63];
                  ts2.P19   <- dates[64];
                  ts2.P20   <- dates[65];
                  ts2.P21   <- dates[66];
                  ts2.P22   <- dates[67];
                  ts2.P23   <- dates[68];
                  ts2.P24   <- dates[69];
                  ts2.P25   <- dates[70];
                  ts2.P26   <- dates[71];
                  ts2.P27   <- dates[72];
                  ts2.P28   <- dates[73];
                  ts2.P29   <- dates[74];
                  ts2.P30   <- dates[75];
                  ts2.P31   <- dates[76];
                  ts2.P32   <- dates[77];
                  ts2.P33   <- dates[78];
                  ts2.P34   <- dates[79];
                  ts2.P35   <- dates[80];
                  ts2.P36   <- dates[81];
                  ts2.P37   <- dates[82];
                  ts2.P38   <- dates[83];
                  ts2.P39   <- dates[84];
                  ts2.P40   <- dates[85];
                  ts2.P41   <- dates[86];
                  ts2.P42   <- dates[87];
                  ts2.P43   <- dates[88];
                  ts2.P44   <- dates[89];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logscale1 <- par[47];
                  logalpha1 <- par[48];
                  logbeta1  <- par[49];
                  logP1F2   <- par[50];
                  logP2F2   <- par[51];
                  logP3F2   <- par[52];
                  logP4F2   <- par[53];
                  logP5F2   <- par[54];
                  logP6F2   <- par[55];
                  logP7F2   <- par[56];
                  logP8F2   <- par[57];
                  logP9F2   <- par[58];
                  logP10F2  <- par[59];
                  logP11F2  <- par[60];
                  logP12F2  <- par[61];
                  logP13F2  <- par[62];
                  logP14F2  <- par[63];
                  logP15F2  <- par[64];
                  logP16F2  <- par[65];
                  logP17F2  <- par[66];
                  logP18F2  <- par[67];
                  logP19F2  <- par[68];
                  logP20F2  <- par[69];
                  logP21F2  <- par[70];
                  logP22F2  <- par[71];
                  logP23F2  <- par[72];
                  logP24F2  <- par[73];
                  logP25F2  <- par[74];
                  logP26F2  <- par[75];
                  logP27F2  <- par[76];
                  logP28F2  <- par[77];
                  logP29F2  <- par[78];
                  logP30F2  <- par[79];
                  logP31F2  <- par[80];
                  logP32F2  <- par[81];
                  logP33F2  <- par[82];
                  logP34F2  <- par[83];
                  logP35F2  <- par[84];
                  logP36F2  <- par[85];
                  logP37F2  <- par[86];
                  logP38F2  <- par[87];
                  logP39F2  <- par[88];
                  logP40F2  <- par[89];
                  logP41F2  <- par[90];
                  logP42F2  <- par[91];
                  logP43F2  <- par[92];
                  logP44F2  <- par[93];
                  logscale2 <- par[94];
                  logalpha2 <- par[95];
                  logbeta2  <- par[96];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN45P45P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(45,45))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts2.P1    <- dates[47];
                  ts2.P2    <- dates[48];
                  ts2.P3    <- dates[49];
                  ts2.P4    <- dates[50];
                  ts2.P5    <- dates[51];
                  ts2.P6    <- dates[52];
                  ts2.P7    <- dates[53];
                  ts2.P8    <- dates[54];
                  ts2.P9    <- dates[55];
                  ts2.P10   <- dates[56];
                  ts2.P11   <- dates[57];
                  ts2.P12   <- dates[58];
                  ts2.P13   <- dates[59];
                  ts2.P14   <- dates[60];
                  ts2.P15   <- dates[61];
                  ts2.P16   <- dates[62];
                  ts2.P17   <- dates[63];
                  ts2.P18   <- dates[64];
                  ts2.P19   <- dates[65];
                  ts2.P20   <- dates[66];
                  ts2.P21   <- dates[67];
                  ts2.P22   <- dates[68];
                  ts2.P23   <- dates[69];
                  ts2.P24   <- dates[70];
                  ts2.P25   <- dates[71];
                  ts2.P26   <- dates[72];
                  ts2.P27   <- dates[73];
                  ts2.P28   <- dates[74];
                  ts2.P29   <- dates[75];
                  ts2.P30   <- dates[76];
                  ts2.P31   <- dates[77];
                  ts2.P32   <- dates[78];
                  ts2.P33   <- dates[79];
                  ts2.P34   <- dates[80];
                  ts2.P35   <- dates[81];
                  ts2.P36   <- dates[82];
                  ts2.P37   <- dates[83];
                  ts2.P38   <- dates[84];
                  ts2.P39   <- dates[85];
                  ts2.P40   <- dates[86];
                  ts2.P41   <- dates[87];
                  ts2.P42   <- dates[88];
                  ts2.P43   <- dates[89];
                  ts2.P44   <- dates[90];
                  ts2.P45   <- dates[91];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logscale1 <- par[48];
                  logalpha1 <- par[49];
                  logbeta1  <- par[50];
                  logP1F2   <- par[51];
                  logP2F2   <- par[52];
                  logP3F2   <- par[53];
                  logP4F2   <- par[54];
                  logP5F2   <- par[55];
                  logP6F2   <- par[56];
                  logP7F2   <- par[57];
                  logP8F2   <- par[58];
                  logP9F2   <- par[59];
                  logP10F2  <- par[60];
                  logP11F2  <- par[61];
                  logP12F2  <- par[62];
                  logP13F2  <- par[63];
                  logP14F2  <- par[64];
                  logP15F2  <- par[65];
                  logP16F2  <- par[66];
                  logP17F2  <- par[67];
                  logP18F2  <- par[68];
                  logP19F2  <- par[69];
                  logP20F2  <- par[70];
                  logP21F2  <- par[71];
                  logP22F2  <- par[72];
                  logP23F2  <- par[73];
                  logP24F2  <- par[74];
                  logP25F2  <- par[75];
                  logP26F2  <- par[76];
                  logP27F2  <- par[77];
                  logP28F2  <- par[78];
                  logP29F2  <- par[79];
                  logP30F2  <- par[80];
                  logP31F2  <- par[81];
                  logP32F2  <- par[82];
                  logP33F2  <- par[83];
                  logP34F2  <- par[84];
                  logP35F2  <- par[85];
                  logP36F2  <- par[86];
                  logP37F2  <- par[87];
                  logP38F2  <- par[88];
                  logP39F2  <- par[89];
                  logP40F2  <- par[90];
                  logP41F2  <- par[91];
                  logP42F2  <- par[92];
                  logP43F2  <- par[93];
                  logP44F2  <- par[94];
                  logP45F2  <- par[95];
                  logscale2 <- par[96];
                  logalpha2 <- par[97];
                  logbeta2  <- par[98];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN46P46P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(46,46))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts2.P1    <- dates[48];
                  ts2.P2    <- dates[49];
                  ts2.P3    <- dates[50];
                  ts2.P4    <- dates[51];
                  ts2.P5    <- dates[52];
                  ts2.P6    <- dates[53];
                  ts2.P7    <- dates[54];
                  ts2.P8    <- dates[55];
                  ts2.P9    <- dates[56];
                  ts2.P10   <- dates[57];
                  ts2.P11   <- dates[58];
                  ts2.P12   <- dates[59];
                  ts2.P13   <- dates[60];
                  ts2.P14   <- dates[61];
                  ts2.P15   <- dates[62];
                  ts2.P16   <- dates[63];
                  ts2.P17   <- dates[64];
                  ts2.P18   <- dates[65];
                  ts2.P19   <- dates[66];
                  ts2.P20   <- dates[67];
                  ts2.P21   <- dates[68];
                  ts2.P22   <- dates[69];
                  ts2.P23   <- dates[70];
                  ts2.P24   <- dates[71];
                  ts2.P25   <- dates[72];
                  ts2.P26   <- dates[73];
                  ts2.P27   <- dates[74];
                  ts2.P28   <- dates[75];
                  ts2.P29   <- dates[76];
                  ts2.P30   <- dates[77];
                  ts2.P31   <- dates[78];
                  ts2.P32   <- dates[79];
                  ts2.P33   <- dates[80];
                  ts2.P34   <- dates[81];
                  ts2.P35   <- dates[82];
                  ts2.P36   <- dates[83];
                  ts2.P37   <- dates[84];
                  ts2.P38   <- dates[85];
                  ts2.P39   <- dates[86];
                  ts2.P40   <- dates[87];
                  ts2.P41   <- dates[88];
                  ts2.P42   <- dates[89];
                  ts2.P43   <- dates[90];
                  ts2.P44   <- dates[91];
                  ts2.P45   <- dates[92];
                  ts2.P46   <- dates[93];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logscale1 <- par[49];
                  logalpha1 <- par[50];
                  logbeta1  <- par[51];
                  logP1F2   <- par[52];
                  logP2F2   <- par[53];
                  logP3F2   <- par[54];
                  logP4F2   <- par[55];
                  logP5F2   <- par[56];
                  logP6F2   <- par[57];
                  logP7F2   <- par[58];
                  logP8F2   <- par[59];
                  logP9F2   <- par[60];
                  logP10F2  <- par[61];
                  logP11F2  <- par[62];
                  logP12F2  <- par[63];
                  logP13F2  <- par[64];
                  logP14F2  <- par[65];
                  logP15F2  <- par[66];
                  logP16F2  <- par[67];
                  logP17F2  <- par[68];
                  logP18F2  <- par[69];
                  logP19F2  <- par[70];
                  logP20F2  <- par[71];
                  logP21F2  <- par[72];
                  logP22F2  <- par[73];
                  logP23F2  <- par[74];
                  logP24F2  <- par[75];
                  logP25F2  <- par[76];
                  logP26F2  <- par[77];
                  logP27F2  <- par[78];
                  logP28F2  <- par[79];
                  logP29F2  <- par[80];
                  logP30F2  <- par[81];
                  logP31F2  <- par[82];
                  logP32F2  <- par[83];
                  logP33F2  <- par[84];
                  logP34F2  <- par[85];
                  logP35F2  <- par[86];
                  logP36F2  <- par[87];
                  logP37F2  <- par[88];
                  logP38F2  <- par[89];
                  logP39F2  <- par[90];
                  logP40F2  <- par[91];
                  logP41F2  <- par[92];
                  logP42F2  <- par[93];
                  logP43F2  <- par[94];
                  logP44F2  <- par[95];
                  logP45F2  <- par[96];
                  logP46F2  <- par[97];
                  logscale2 <- par[98];
                  logalpha2 <- par[99];
                  logbeta2  <- par[100];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN47P47P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(47,47))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts2.P1    <- dates[49];
                  ts2.P2    <- dates[50];
                  ts2.P3    <- dates[51];
                  ts2.P4    <- dates[52];
                  ts2.P5    <- dates[53];
                  ts2.P6    <- dates[54];
                  ts2.P7    <- dates[55];
                  ts2.P8    <- dates[56];
                  ts2.P9    <- dates[57];
                  ts2.P10   <- dates[58];
                  ts2.P11   <- dates[59];
                  ts2.P12   <- dates[60];
                  ts2.P13   <- dates[61];
                  ts2.P14   <- dates[62];
                  ts2.P15   <- dates[63];
                  ts2.P16   <- dates[64];
                  ts2.P17   <- dates[65];
                  ts2.P18   <- dates[66];
                  ts2.P19   <- dates[67];
                  ts2.P20   <- dates[68];
                  ts2.P21   <- dates[69];
                  ts2.P22   <- dates[70];
                  ts2.P23   <- dates[71];
                  ts2.P24   <- dates[72];
                  ts2.P25   <- dates[73];
                  ts2.P26   <- dates[74];
                  ts2.P27   <- dates[75];
                  ts2.P28   <- dates[76];
                  ts2.P29   <- dates[77];
                  ts2.P30   <- dates[78];
                  ts2.P31   <- dates[79];
                  ts2.P32   <- dates[80];
                  ts2.P33   <- dates[81];
                  ts2.P34   <- dates[82];
                  ts2.P35   <- dates[83];
                  ts2.P36   <- dates[84];
                  ts2.P37   <- dates[85];
                  ts2.P38   <- dates[86];
                  ts2.P39   <- dates[87];
                  ts2.P40   <- dates[88];
                  ts2.P41   <- dates[89];
                  ts2.P42   <- dates[90];
                  ts2.P43   <- dates[91];
                  ts2.P44   <- dates[92];
                  ts2.P45   <- dates[93];
                  ts2.P46   <- dates[94];
                  ts2.P47   <- dates[95];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logscale1 <- par[50];
                  logalpha1 <- par[51];
                  logbeta1  <- par[52];
                  logP1F2   <- par[53];
                  logP2F2   <- par[54];
                  logP3F2   <- par[55];
                  logP4F2   <- par[56];
                  logP5F2   <- par[57];
                  logP6F2   <- par[58];
                  logP7F2   <- par[59];
                  logP8F2   <- par[60];
                  logP9F2   <- par[61];
                  logP10F2  <- par[62];
                  logP11F2  <- par[63];
                  logP12F2  <- par[64];
                  logP13F2  <- par[65];
                  logP14F2  <- par[66];
                  logP15F2  <- par[67];
                  logP16F2  <- par[68];
                  logP17F2  <- par[69];
                  logP18F2  <- par[70];
                  logP19F2  <- par[71];
                  logP20F2  <- par[72];
                  logP21F2  <- par[73];
                  logP22F2  <- par[74];
                  logP23F2  <- par[75];
                  logP24F2  <- par[76];
                  logP25F2  <- par[77];
                  logP26F2  <- par[78];
                  logP27F2  <- par[79];
                  logP28F2  <- par[80];
                  logP29F2  <- par[81];
                  logP30F2  <- par[82];
                  logP31F2  <- par[83];
                  logP32F2  <- par[84];
                  logP33F2  <- par[85];
                  logP34F2  <- par[86];
                  logP35F2  <- par[87];
                  logP36F2  <- par[88];
                  logP37F2  <- par[89];
                  logP38F2  <- par[90];
                  logP39F2  <- par[91];
                  logP40F2  <- par[92];
                  logP41F2  <- par[93];
                  logP42F2  <- par[94];
                  logP43F2  <- par[95];
                  logP44F2  <- par[96];
                  logP45F2  <- par[97];
                  logP46F2  <- par[98];
                  logP47F2  <- par[99];
                  logscale2 <- par[100];
                  logalpha2 <- par[101];
                  logbeta2  <- par[102];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN48P48P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(48,48))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts2.P1    <- dates[50];
                  ts2.P2    <- dates[51];
                  ts2.P3    <- dates[52];
                  ts2.P4    <- dates[53];
                  ts2.P5    <- dates[54];
                  ts2.P6    <- dates[55];
                  ts2.P7    <- dates[56];
                  ts2.P8    <- dates[57];
                  ts2.P9    <- dates[58];
                  ts2.P10   <- dates[59];
                  ts2.P11   <- dates[60];
                  ts2.P12   <- dates[61];
                  ts2.P13   <- dates[62];
                  ts2.P14   <- dates[63];
                  ts2.P15   <- dates[64];
                  ts2.P16   <- dates[65];
                  ts2.P17   <- dates[66];
                  ts2.P18   <- dates[67];
                  ts2.P19   <- dates[68];
                  ts2.P20   <- dates[69];
                  ts2.P21   <- dates[70];
                  ts2.P22   <- dates[71];
                  ts2.P23   <- dates[72];
                  ts2.P24   <- dates[73];
                  ts2.P25   <- dates[74];
                  ts2.P26   <- dates[75];
                  ts2.P27   <- dates[76];
                  ts2.P28   <- dates[77];
                  ts2.P29   <- dates[78];
                  ts2.P30   <- dates[79];
                  ts2.P31   <- dates[80];
                  ts2.P32   <- dates[81];
                  ts2.P33   <- dates[82];
                  ts2.P34   <- dates[83];
                  ts2.P35   <- dates[84];
                  ts2.P36   <- dates[85];
                  ts2.P37   <- dates[86];
                  ts2.P38   <- dates[87];
                  ts2.P39   <- dates[88];
                  ts2.P40   <- dates[89];
                  ts2.P41   <- dates[90];
                  ts2.P42   <- dates[91];
                  ts2.P43   <- dates[92];
                  ts2.P44   <- dates[93];
                  ts2.P45   <- dates[94];
                  ts2.P46   <- dates[95];
                  ts2.P47   <- dates[96];
                  ts2.P48   <- dates[97];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logscale1 <- par[51];
                  logalpha1 <- par[52];
                  logbeta1  <- par[53];
                  logP1F2   <- par[54];
                  logP2F2   <- par[55];
                  logP3F2   <- par[56];
                  logP4F2   <- par[57];
                  logP5F2   <- par[58];
                  logP6F2   <- par[59];
                  logP7F2   <- par[60];
                  logP8F2   <- par[61];
                  logP9F2   <- par[62];
                  logP10F2  <- par[63];
                  logP11F2  <- par[64];
                  logP12F2  <- par[65];
                  logP13F2  <- par[66];
                  logP14F2  <- par[67];
                  logP15F2  <- par[68];
                  logP16F2  <- par[69];
                  logP17F2  <- par[70];
                  logP18F2  <- par[71];
                  logP19F2  <- par[72];
                  logP20F2  <- par[73];
                  logP21F2  <- par[74];
                  logP22F2  <- par[75];
                  logP23F2  <- par[76];
                  logP24F2  <- par[77];
                  logP25F2  <- par[78];
                  logP26F2  <- par[79];
                  logP27F2  <- par[80];
                  logP28F2  <- par[81];
                  logP29F2  <- par[82];
                  logP30F2  <- par[83];
                  logP31F2  <- par[84];
                  logP32F2  <- par[85];
                  logP33F2  <- par[86];
                  logP34F2  <- par[87];
                  logP35F2  <- par[88];
                  logP36F2  <- par[89];
                  logP37F2  <- par[90];
                  logP38F2  <- par[91];
                  logP39F2  <- par[92];
                  logP40F2  <- par[93];
                  logP41F2  <- par[94];
                  logP42F2  <- par[95];
                  logP43F2  <- par[96];
                  logP44F2  <- par[97];
                  logP45F2  <- par[98];
                  logP46F2  <- par[99];
                  logP47F2  <- par[100];
                  logP48F2  <- par[101];
                  logscale2 <- par[102];
                  logalpha2 <- par[103];
                  logbeta2  <- par[104];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN49P49P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(49,49))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts2.P1    <- dates[51];
                  ts2.P2    <- dates[52];
                  ts2.P3    <- dates[53];
                  ts2.P4    <- dates[54];
                  ts2.P5    <- dates[55];
                  ts2.P6    <- dates[56];
                  ts2.P7    <- dates[57];
                  ts2.P8    <- dates[58];
                  ts2.P9    <- dates[59];
                  ts2.P10   <- dates[60];
                  ts2.P11   <- dates[61];
                  ts2.P12   <- dates[62];
                  ts2.P13   <- dates[63];
                  ts2.P14   <- dates[64];
                  ts2.P15   <- dates[65];
                  ts2.P16   <- dates[66];
                  ts2.P17   <- dates[67];
                  ts2.P18   <- dates[68];
                  ts2.P19   <- dates[69];
                  ts2.P20   <- dates[70];
                  ts2.P21   <- dates[71];
                  ts2.P22   <- dates[72];
                  ts2.P23   <- dates[73];
                  ts2.P24   <- dates[74];
                  ts2.P25   <- dates[75];
                  ts2.P26   <- dates[76];
                  ts2.P27   <- dates[77];
                  ts2.P28   <- dates[78];
                  ts2.P29   <- dates[79];
                  ts2.P30   <- dates[80];
                  ts2.P31   <- dates[81];
                  ts2.P32   <- dates[82];
                  ts2.P33   <- dates[83];
                  ts2.P34   <- dates[84];
                  ts2.P35   <- dates[85];
                  ts2.P36   <- dates[86];
                  ts2.P37   <- dates[87];
                  ts2.P38   <- dates[88];
                  ts2.P39   <- dates[89];
                  ts2.P40   <- dates[90];
                  ts2.P41   <- dates[91];
                  ts2.P42   <- dates[92];
                  ts2.P43   <- dates[93];
                  ts2.P44   <- dates[94];
                  ts2.P45   <- dates[95];
                  ts2.P46   <- dates[96];
                  ts2.P47   <- dates[97];
                  ts2.P48   <- dates[98];
                  ts2.P49   <- dates[99];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logscale1 <- par[52];
                  logalpha1 <- par[53];
                  logbeta1  <- par[54];
                  logP1F2   <- par[55];
                  logP2F2   <- par[56];
                  logP3F2   <- par[57];
                  logP4F2   <- par[58];
                  logP5F2   <- par[59];
                  logP6F2   <- par[60];
                  logP7F2   <- par[61];
                  logP8F2   <- par[62];
                  logP9F2   <- par[63];
                  logP10F2  <- par[64];
                  logP11F2  <- par[65];
                  logP12F2  <- par[66];
                  logP13F2  <- par[67];
                  logP14F2  <- par[68];
                  logP15F2  <- par[69];
                  logP16F2  <- par[70];
                  logP17F2  <- par[71];
                  logP18F2  <- par[72];
                  logP19F2  <- par[73];
                  logP20F2  <- par[74];
                  logP21F2  <- par[75];
                  logP22F2  <- par[76];
                  logP23F2  <- par[77];
                  logP24F2  <- par[78];
                  logP25F2  <- par[79];
                  logP26F2  <- par[80];
                  logP27F2  <- par[81];
                  logP28F2  <- par[82];
                  logP29F2  <- par[83];
                  logP30F2  <- par[84];
                  logP31F2  <- par[85];
                  logP32F2  <- par[86];
                  logP33F2  <- par[87];
                  logP34F2  <- par[88];
                  logP35F2  <- par[89];
                  logP36F2  <- par[90];
                  logP37F2  <- par[91];
                  logP38F2  <- par[92];
                  logP39F2  <- par[93];
                  logP40F2  <- par[94];
                  logP41F2  <- par[95];
                  logP42F2  <- par[96];
                  logP43F2  <- par[97];
                  logP44F2  <- par[98];
                  logP45F2  <- par[99];
                  logP46F2  <- par[100];
                  logP47F2  <- par[101];
                  logP48F2  <- par[102];
                  logP49F2  <- par[103];
                  logscale2 <- par[104];
                  logalpha2 <- par[105];
                  logbeta2  <- par[106];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN50P50P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(50,50))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts2.P1    <- dates[52];
                  ts2.P2    <- dates[53];
                  ts2.P3    <- dates[54];
                  ts2.P4    <- dates[55];
                  ts2.P5    <- dates[56];
                  ts2.P6    <- dates[57];
                  ts2.P7    <- dates[58];
                  ts2.P8    <- dates[59];
                  ts2.P9    <- dates[60];
                  ts2.P10   <- dates[61];
                  ts2.P11   <- dates[62];
                  ts2.P12   <- dates[63];
                  ts2.P13   <- dates[64];
                  ts2.P14   <- dates[65];
                  ts2.P15   <- dates[66];
                  ts2.P16   <- dates[67];
                  ts2.P17   <- dates[68];
                  ts2.P18   <- dates[69];
                  ts2.P19   <- dates[70];
                  ts2.P20   <- dates[71];
                  ts2.P21   <- dates[72];
                  ts2.P22   <- dates[73];
                  ts2.P23   <- dates[74];
                  ts2.P24   <- dates[75];
                  ts2.P25   <- dates[76];
                  ts2.P26   <- dates[77];
                  ts2.P27   <- dates[78];
                  ts2.P28   <- dates[79];
                  ts2.P29   <- dates[80];
                  ts2.P30   <- dates[81];
                  ts2.P31   <- dates[82];
                  ts2.P32   <- dates[83];
                  ts2.P33   <- dates[84];
                  ts2.P34   <- dates[85];
                  ts2.P35   <- dates[86];
                  ts2.P36   <- dates[87];
                  ts2.P37   <- dates[88];
                  ts2.P38   <- dates[89];
                  ts2.P39   <- dates[90];
                  ts2.P40   <- dates[91];
                  ts2.P41   <- dates[92];
                  ts2.P42   <- dates[93];
                  ts2.P43   <- dates[94];
                  ts2.P44   <- dates[95];
                  ts2.P45   <- dates[96];
                  ts2.P46   <- dates[97];
                  ts2.P47   <- dates[98];
                  ts2.P48   <- dates[99];
                  ts2.P49   <- dates[100];
                  ts2.P50   <- dates[101];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logscale1 <- par[53];
                  logalpha1 <- par[54];
                  logbeta1  <- par[55];
                  logP1F2   <- par[56];
                  logP2F2   <- par[57];
                  logP3F2   <- par[58];
                  logP4F2   <- par[59];
                  logP5F2   <- par[60];
                  logP6F2   <- par[61];
                  logP7F2   <- par[62];
                  logP8F2   <- par[63];
                  logP9F2   <- par[64];
                  logP10F2  <- par[65];
                  logP11F2  <- par[66];
                  logP12F2  <- par[67];
                  logP13F2  <- par[68];
                  logP14F2  <- par[69];
                  logP15F2  <- par[70];
                  logP16F2  <- par[71];
                  logP17F2  <- par[72];
                  logP18F2  <- par[73];
                  logP19F2  <- par[74];
                  logP20F2  <- par[75];
                  logP21F2  <- par[76];
                  logP22F2  <- par[77];
                  logP23F2  <- par[78];
                  logP24F2  <- par[79];
                  logP25F2  <- par[80];
                  logP26F2  <- par[81];
                  logP27F2  <- par[82];
                  logP28F2  <- par[83];
                  logP29F2  <- par[84];
                  logP30F2  <- par[85];
                  logP31F2  <- par[86];
                  logP32F2  <- par[87];
                  logP33F2  <- par[88];
                  logP34F2  <- par[89];
                  logP35F2  <- par[90];
                  logP36F2  <- par[91];
                  logP37F2  <- par[92];
                  logP38F2  <- par[93];
                  logP39F2  <- par[94];
                  logP40F2  <- par[95];
                  logP41F2  <- par[96];
                  logP42F2  <- par[97];
                  logP43F2  <- par[98];
                  logP44F2  <- par[99];
                  logP45F2  <- par[100];
                  logP46F2  <- par[101];
                  logP47F2  <- par[102];
                  logP48F2  <- par[103];
                  logP49F2  <- par[104];
                  logP50F2  <- par[105];
                  logscale2 <- par[106];
                  logalpha2 <- par[107];
                  logbeta2  <- par[108];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN51P51P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(51,51))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts2.P1    <- dates[53];
                  ts2.P2    <- dates[54];
                  ts2.P3    <- dates[55];
                  ts2.P4    <- dates[56];
                  ts2.P5    <- dates[57];
                  ts2.P6    <- dates[58];
                  ts2.P7    <- dates[59];
                  ts2.P8    <- dates[60];
                  ts2.P9    <- dates[61];
                  ts2.P10   <- dates[62];
                  ts2.P11   <- dates[63];
                  ts2.P12   <- dates[64];
                  ts2.P13   <- dates[65];
                  ts2.P14   <- dates[66];
                  ts2.P15   <- dates[67];
                  ts2.P16   <- dates[68];
                  ts2.P17   <- dates[69];
                  ts2.P18   <- dates[70];
                  ts2.P19   <- dates[71];
                  ts2.P20   <- dates[72];
                  ts2.P21   <- dates[73];
                  ts2.P22   <- dates[74];
                  ts2.P23   <- dates[75];
                  ts2.P24   <- dates[76];
                  ts2.P25   <- dates[77];
                  ts2.P26   <- dates[78];
                  ts2.P27   <- dates[79];
                  ts2.P28   <- dates[80];
                  ts2.P29   <- dates[81];
                  ts2.P30   <- dates[82];
                  ts2.P31   <- dates[83];
                  ts2.P32   <- dates[84];
                  ts2.P33   <- dates[85];
                  ts2.P34   <- dates[86];
                  ts2.P35   <- dates[87];
                  ts2.P36   <- dates[88];
                  ts2.P37   <- dates[89];
                  ts2.P38   <- dates[90];
                  ts2.P39   <- dates[91];
                  ts2.P40   <- dates[92];
                  ts2.P41   <- dates[93];
                  ts2.P42   <- dates[94];
                  ts2.P43   <- dates[95];
                  ts2.P44   <- dates[96];
                  ts2.P45   <- dates[97];
                  ts2.P46   <- dates[98];
                  ts2.P47   <- dates[99];
                  ts2.P48   <- dates[100];
                  ts2.P49   <- dates[101];
                  ts2.P50   <- dates[102];
                  ts2.P51   <- dates[103];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logscale1 <- par[54];
                  logalpha1 <- par[55];
                  logbeta1  <- par[56];
                  logP1F2   <- par[57];
                  logP2F2   <- par[58];
                  logP3F2   <- par[59];
                  logP4F2   <- par[60];
                  logP5F2   <- par[61];
                  logP6F2   <- par[62];
                  logP7F2   <- par[63];
                  logP8F2   <- par[64];
                  logP9F2   <- par[65];
                  logP10F2  <- par[66];
                  logP11F2  <- par[67];
                  logP12F2  <- par[68];
                  logP13F2  <- par[69];
                  logP14F2  <- par[70];
                  logP15F2  <- par[71];
                  logP16F2  <- par[72];
                  logP17F2  <- par[73];
                  logP18F2  <- par[74];
                  logP19F2  <- par[75];
                  logP20F2  <- par[76];
                  logP21F2  <- par[77];
                  logP22F2  <- par[78];
                  logP23F2  <- par[79];
                  logP24F2  <- par[80];
                  logP25F2  <- par[81];
                  logP26F2  <- par[82];
                  logP27F2  <- par[83];
                  logP28F2  <- par[84];
                  logP29F2  <- par[85];
                  logP30F2  <- par[86];
                  logP31F2  <- par[87];
                  logP32F2  <- par[88];
                  logP33F2  <- par[89];
                  logP34F2  <- par[90];
                  logP35F2  <- par[91];
                  logP36F2  <- par[92];
                  logP37F2  <- par[93];
                  logP38F2  <- par[94];
                  logP39F2  <- par[95];
                  logP40F2  <- par[96];
                  logP41F2  <- par[97];
                  logP42F2  <- par[98];
                  logP43F2  <- par[99];
                  logP44F2  <- par[100];
                  logP45F2  <- par[101];
                  logP46F2  <- par[102];
                  logP47F2  <- par[103];
                  logP48F2  <- par[104];
                  logP49F2  <- par[105];
                  logP50F2  <- par[106];
                  logP51F2  <- par[107];
                  logscale2 <- par[108];
                  logalpha2 <- par[109];
                  logbeta2  <- par[110];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN52P52P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(52,52))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts2.P1    <- dates[54];
                  ts2.P2    <- dates[55];
                  ts2.P3    <- dates[56];
                  ts2.P4    <- dates[57];
                  ts2.P5    <- dates[58];
                  ts2.P6    <- dates[59];
                  ts2.P7    <- dates[60];
                  ts2.P8    <- dates[61];
                  ts2.P9    <- dates[62];
                  ts2.P10   <- dates[63];
                  ts2.P11   <- dates[64];
                  ts2.P12   <- dates[65];
                  ts2.P13   <- dates[66];
                  ts2.P14   <- dates[67];
                  ts2.P15   <- dates[68];
                  ts2.P16   <- dates[69];
                  ts2.P17   <- dates[70];
                  ts2.P18   <- dates[71];
                  ts2.P19   <- dates[72];
                  ts2.P20   <- dates[73];
                  ts2.P21   <- dates[74];
                  ts2.P22   <- dates[75];
                  ts2.P23   <- dates[76];
                  ts2.P24   <- dates[77];
                  ts2.P25   <- dates[78];
                  ts2.P26   <- dates[79];
                  ts2.P27   <- dates[80];
                  ts2.P28   <- dates[81];
                  ts2.P29   <- dates[82];
                  ts2.P30   <- dates[83];
                  ts2.P31   <- dates[84];
                  ts2.P32   <- dates[85];
                  ts2.P33   <- dates[86];
                  ts2.P34   <- dates[87];
                  ts2.P35   <- dates[88];
                  ts2.P36   <- dates[89];
                  ts2.P37   <- dates[90];
                  ts2.P38   <- dates[91];
                  ts2.P39   <- dates[92];
                  ts2.P40   <- dates[93];
                  ts2.P41   <- dates[94];
                  ts2.P42   <- dates[95];
                  ts2.P43   <- dates[96];
                  ts2.P44   <- dates[97];
                  ts2.P45   <- dates[98];
                  ts2.P46   <- dates[99];
                  ts2.P47   <- dates[100];
                  ts2.P48   <- dates[101];
                  ts2.P49   <- dates[102];
                  ts2.P50   <- dates[103];
                  ts2.P51   <- dates[104];
                  ts2.P52   <- dates[105];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logscale1 <- par[55];
                  logalpha1 <- par[56];
                  logbeta1  <- par[57];
                  logP1F2   <- par[58];
                  logP2F2   <- par[59];
                  logP3F2   <- par[60];
                  logP4F2   <- par[61];
                  logP5F2   <- par[62];
                  logP6F2   <- par[63];
                  logP7F2   <- par[64];
                  logP8F2   <- par[65];
                  logP9F2   <- par[66];
                  logP10F2  <- par[67];
                  logP11F2  <- par[68];
                  logP12F2  <- par[69];
                  logP13F2  <- par[70];
                  logP14F2  <- par[71];
                  logP15F2  <- par[72];
                  logP16F2  <- par[73];
                  logP17F2  <- par[74];
                  logP18F2  <- par[75];
                  logP19F2  <- par[76];
                  logP20F2  <- par[77];
                  logP21F2  <- par[78];
                  logP22F2  <- par[79];
                  logP23F2  <- par[80];
                  logP24F2  <- par[81];
                  logP25F2  <- par[82];
                  logP26F2  <- par[83];
                  logP27F2  <- par[84];
                  logP28F2  <- par[85];
                  logP29F2  <- par[86];
                  logP30F2  <- par[87];
                  logP31F2  <- par[88];
                  logP32F2  <- par[89];
                  logP33F2  <- par[90];
                  logP34F2  <- par[91];
                  logP35F2  <- par[92];
                  logP36F2  <- par[93];
                  logP37F2  <- par[94];
                  logP38F2  <- par[95];
                  logP39F2  <- par[96];
                  logP40F2  <- par[97];
                  logP41F2  <- par[98];
                  logP42F2  <- par[99];
                  logP43F2  <- par[100];
                  logP44F2  <- par[101];
                  logP45F2  <- par[102];
                  logP46F2  <- par[103];
                  logP47F2  <- par[104];
                  logP48F2  <- par[105];
                  logP49F2  <- par[106];
                  logP50F2  <- par[107];
                  logP51F2  <- par[108];
                  logP52F2  <- par[109];
                  logscale2 <- par[110];
                  logalpha2 <- par[111];
                  logbeta2  <- par[112];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN53P53P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(53,53))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts2.P1    <- dates[55];
                  ts2.P2    <- dates[56];
                  ts2.P3    <- dates[57];
                  ts2.P4    <- dates[58];
                  ts2.P5    <- dates[59];
                  ts2.P6    <- dates[60];
                  ts2.P7    <- dates[61];
                  ts2.P8    <- dates[62];
                  ts2.P9    <- dates[63];
                  ts2.P10   <- dates[64];
                  ts2.P11   <- dates[65];
                  ts2.P12   <- dates[66];
                  ts2.P13   <- dates[67];
                  ts2.P14   <- dates[68];
                  ts2.P15   <- dates[69];
                  ts2.P16   <- dates[70];
                  ts2.P17   <- dates[71];
                  ts2.P18   <- dates[72];
                  ts2.P19   <- dates[73];
                  ts2.P20   <- dates[74];
                  ts2.P21   <- dates[75];
                  ts2.P22   <- dates[76];
                  ts2.P23   <- dates[77];
                  ts2.P24   <- dates[78];
                  ts2.P25   <- dates[79];
                  ts2.P26   <- dates[80];
                  ts2.P27   <- dates[81];
                  ts2.P28   <- dates[82];
                  ts2.P29   <- dates[83];
                  ts2.P30   <- dates[84];
                  ts2.P31   <- dates[85];
                  ts2.P32   <- dates[86];
                  ts2.P33   <- dates[87];
                  ts2.P34   <- dates[88];
                  ts2.P35   <- dates[89];
                  ts2.P36   <- dates[90];
                  ts2.P37   <- dates[91];
                  ts2.P38   <- dates[92];
                  ts2.P39   <- dates[93];
                  ts2.P40   <- dates[94];
                  ts2.P41   <- dates[95];
                  ts2.P42   <- dates[96];
                  ts2.P43   <- dates[97];
                  ts2.P44   <- dates[98];
                  ts2.P45   <- dates[99];
                  ts2.P46   <- dates[100];
                  ts2.P47   <- dates[101];
                  ts2.P48   <- dates[102];
                  ts2.P49   <- dates[103];
                  ts2.P50   <- dates[104];
                  ts2.P51   <- dates[105];
                  ts2.P52   <- dates[106];
                  ts2.P53   <- dates[107];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logscale1 <- par[56];
                  logalpha1 <- par[57];
                  logbeta1  <- par[58];
                  logP1F2   <- par[59];
                  logP2F2   <- par[60];
                  logP3F2   <- par[61];
                  logP4F2   <- par[62];
                  logP5F2   <- par[63];
                  logP6F2   <- par[64];
                  logP7F2   <- par[65];
                  logP8F2   <- par[66];
                  logP9F2   <- par[67];
                  logP10F2  <- par[68];
                  logP11F2  <- par[69];
                  logP12F2  <- par[70];
                  logP13F2  <- par[71];
                  logP14F2  <- par[72];
                  logP15F2  <- par[73];
                  logP16F2  <- par[74];
                  logP17F2  <- par[75];
                  logP18F2  <- par[76];
                  logP19F2  <- par[77];
                  logP20F2  <- par[78];
                  logP21F2  <- par[79];
                  logP22F2  <- par[80];
                  logP23F2  <- par[81];
                  logP24F2  <- par[82];
                  logP25F2  <- par[83];
                  logP26F2  <- par[84];
                  logP27F2  <- par[85];
                  logP28F2  <- par[86];
                  logP29F2  <- par[87];
                  logP30F2  <- par[88];
                  logP31F2  <- par[89];
                  logP32F2  <- par[90];
                  logP33F2  <- par[91];
                  logP34F2  <- par[92];
                  logP35F2  <- par[93];
                  logP36F2  <- par[94];
                  logP37F2  <- par[95];
                  logP38F2  <- par[96];
                  logP39F2  <- par[97];
                  logP40F2  <- par[98];
                  logP41F2  <- par[99];
                  logP42F2  <- par[100];
                  logP43F2  <- par[101];
                  logP44F2  <- par[102];
                  logP45F2  <- par[103];
                  logP46F2  <- par[104];
                  logP47F2  <- par[105];
                  logP48F2  <- par[106];
                  logP49F2  <- par[107];
                  logP50F2  <- par[108];
                  logP51F2  <- par[109];
                  logP52F2  <- par[110];
                  logP53F2  <- par[111];
                  logscale2 <- par[112];
                  logalpha2 <- par[113];
                  logbeta2  <- par[114];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN54P54P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(54,54))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts2.P1    <- dates[56];
                  ts2.P2    <- dates[57];
                  ts2.P3    <- dates[58];
                  ts2.P4    <- dates[59];
                  ts2.P5    <- dates[60];
                  ts2.P6    <- dates[61];
                  ts2.P7    <- dates[62];
                  ts2.P8    <- dates[63];
                  ts2.P9    <- dates[64];
                  ts2.P10   <- dates[65];
                  ts2.P11   <- dates[66];
                  ts2.P12   <- dates[67];
                  ts2.P13   <- dates[68];
                  ts2.P14   <- dates[69];
                  ts2.P15   <- dates[70];
                  ts2.P16   <- dates[71];
                  ts2.P17   <- dates[72];
                  ts2.P18   <- dates[73];
                  ts2.P19   <- dates[74];
                  ts2.P20   <- dates[75];
                  ts2.P21   <- dates[76];
                  ts2.P22   <- dates[77];
                  ts2.P23   <- dates[78];
                  ts2.P24   <- dates[79];
                  ts2.P25   <- dates[80];
                  ts2.P26   <- dates[81];
                  ts2.P27   <- dates[82];
                  ts2.P28   <- dates[83];
                  ts2.P29   <- dates[84];
                  ts2.P30   <- dates[85];
                  ts2.P31   <- dates[86];
                  ts2.P32   <- dates[87];
                  ts2.P33   <- dates[88];
                  ts2.P34   <- dates[89];
                  ts2.P35   <- dates[90];
                  ts2.P36   <- dates[91];
                  ts2.P37   <- dates[92];
                  ts2.P38   <- dates[93];
                  ts2.P39   <- dates[94];
                  ts2.P40   <- dates[95];
                  ts2.P41   <- dates[96];
                  ts2.P42   <- dates[97];
                  ts2.P43   <- dates[98];
                  ts2.P44   <- dates[99];
                  ts2.P45   <- dates[100];
                  ts2.P46   <- dates[101];
                  ts2.P47   <- dates[102];
                  ts2.P48   <- dates[103];
                  ts2.P49   <- dates[104];
                  ts2.P50   <- dates[105];
                  ts2.P51   <- dates[106];
                  ts2.P52   <- dates[107];
                  ts2.P53   <- dates[108];
                  ts2.P54   <- dates[109];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logscale1 <- par[57];
                  logalpha1 <- par[58];
                  logbeta1  <- par[59];
                  logP1F2   <- par[60];
                  logP2F2   <- par[61];
                  logP3F2   <- par[62];
                  logP4F2   <- par[63];
                  logP5F2   <- par[64];
                  logP6F2   <- par[65];
                  logP7F2   <- par[66];
                  logP8F2   <- par[67];
                  logP9F2   <- par[68];
                  logP10F2  <- par[69];
                  logP11F2  <- par[70];
                  logP12F2  <- par[71];
                  logP13F2  <- par[72];
                  logP14F2  <- par[73];
                  logP15F2  <- par[74];
                  logP16F2  <- par[75];
                  logP17F2  <- par[76];
                  logP18F2  <- par[77];
                  logP19F2  <- par[78];
                  logP20F2  <- par[79];
                  logP21F2  <- par[80];
                  logP22F2  <- par[81];
                  logP23F2  <- par[82];
                  logP24F2  <- par[83];
                  logP25F2  <- par[84];
                  logP26F2  <- par[85];
                  logP27F2  <- par[86];
                  logP28F2  <- par[87];
                  logP29F2  <- par[88];
                  logP30F2  <- par[89];
                  logP31F2  <- par[90];
                  logP32F2  <- par[91];
                  logP33F2  <- par[92];
                  logP34F2  <- par[93];
                  logP35F2  <- par[94];
                  logP36F2  <- par[95];
                  logP37F2  <- par[96];
                  logP38F2  <- par[97];
                  logP39F2  <- par[98];
                  logP40F2  <- par[99];
                  logP41F2  <- par[100];
                  logP42F2  <- par[101];
                  logP43F2  <- par[102];
                  logP44F2  <- par[103];
                  logP45F2  <- par[104];
                  logP46F2  <- par[105];
                  logP47F2  <- par[106];
                  logP48F2  <- par[107];
                  logP49F2  <- par[108];
                  logP50F2  <- par[109];
                  logP51F2  <- par[110];
                  logP52F2  <- par[111];
                  logP53F2  <- par[112];
                  logP54F2  <- par[113];
                  logscale2 <- par[114];
                  logalpha2 <- par[115];
                  logbeta2  <- par[116];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN55P55P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(55,55))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts2.P1    <- dates[57];
                  ts2.P2    <- dates[58];
                  ts2.P3    <- dates[59];
                  ts2.P4    <- dates[60];
                  ts2.P5    <- dates[61];
                  ts2.P6    <- dates[62];
                  ts2.P7    <- dates[63];
                  ts2.P8    <- dates[64];
                  ts2.P9    <- dates[65];
                  ts2.P10   <- dates[66];
                  ts2.P11   <- dates[67];
                  ts2.P12   <- dates[68];
                  ts2.P13   <- dates[69];
                  ts2.P14   <- dates[70];
                  ts2.P15   <- dates[71];
                  ts2.P16   <- dates[72];
                  ts2.P17   <- dates[73];
                  ts2.P18   <- dates[74];
                  ts2.P19   <- dates[75];
                  ts2.P20   <- dates[76];
                  ts2.P21   <- dates[77];
                  ts2.P22   <- dates[78];
                  ts2.P23   <- dates[79];
                  ts2.P24   <- dates[80];
                  ts2.P25   <- dates[81];
                  ts2.P26   <- dates[82];
                  ts2.P27   <- dates[83];
                  ts2.P28   <- dates[84];
                  ts2.P29   <- dates[85];
                  ts2.P30   <- dates[86];
                  ts2.P31   <- dates[87];
                  ts2.P32   <- dates[88];
                  ts2.P33   <- dates[89];
                  ts2.P34   <- dates[90];
                  ts2.P35   <- dates[91];
                  ts2.P36   <- dates[92];
                  ts2.P37   <- dates[93];
                  ts2.P38   <- dates[94];
                  ts2.P39   <- dates[95];
                  ts2.P40   <- dates[96];
                  ts2.P41   <- dates[97];
                  ts2.P42   <- dates[98];
                  ts2.P43   <- dates[99];
                  ts2.P44   <- dates[100];
                  ts2.P45   <- dates[101];
                  ts2.P46   <- dates[102];
                  ts2.P47   <- dates[103];
                  ts2.P48   <- dates[104];
                  ts2.P49   <- dates[105];
                  ts2.P50   <- dates[106];
                  ts2.P51   <- dates[107];
                  ts2.P52   <- dates[108];
                  ts2.P53   <- dates[109];
                  ts2.P54   <- dates[110];
                  ts2.P55   <- dates[111];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logscale1 <- par[58];
                  logalpha1 <- par[59];
                  logbeta1  <- par[60];
                  logP1F2   <- par[61];
                  logP2F2   <- par[62];
                  logP3F2   <- par[63];
                  logP4F2   <- par[64];
                  logP5F2   <- par[65];
                  logP6F2   <- par[66];
                  logP7F2   <- par[67];
                  logP8F2   <- par[68];
                  logP9F2   <- par[69];
                  logP10F2  <- par[70];
                  logP11F2  <- par[71];
                  logP12F2  <- par[72];
                  logP13F2  <- par[73];
                  logP14F2  <- par[74];
                  logP15F2  <- par[75];
                  logP16F2  <- par[76];
                  logP17F2  <- par[77];
                  logP18F2  <- par[78];
                  logP19F2  <- par[79];
                  logP20F2  <- par[80];
                  logP21F2  <- par[81];
                  logP22F2  <- par[82];
                  logP23F2  <- par[83];
                  logP24F2  <- par[84];
                  logP25F2  <- par[85];
                  logP26F2  <- par[86];
                  logP27F2  <- par[87];
                  logP28F2  <- par[88];
                  logP29F2  <- par[89];
                  logP30F2  <- par[90];
                  logP31F2  <- par[91];
                  logP32F2  <- par[92];
                  logP33F2  <- par[93];
                  logP34F2  <- par[94];
                  logP35F2  <- par[95];
                  logP36F2  <- par[96];
                  logP37F2  <- par[97];
                  logP38F2  <- par[98];
                  logP39F2  <- par[99];
                  logP40F2  <- par[100];
                  logP41F2  <- par[101];
                  logP42F2  <- par[102];
                  logP43F2  <- par[103];
                  logP44F2  <- par[104];
                  logP45F2  <- par[105];
                  logP46F2  <- par[106];
                  logP47F2  <- par[107];
                  logP48F2  <- par[108];
                  logP49F2  <- par[109];
                  logP50F2  <- par[110];
                  logP51F2  <- par[111];
                  logP52F2  <- par[112];
                  logP53F2  <- par[113];
                  logP54F2  <- par[114];
                  logP55F2  <- par[115];
                  logscale2 <- par[116];
                  logalpha2 <- par[117];
                  logbeta2  <- par[118];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN56P56P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(56,56))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts2.P1    <- dates[58];
                  ts2.P2    <- dates[59];
                  ts2.P3    <- dates[60];
                  ts2.P4    <- dates[61];
                  ts2.P5    <- dates[62];
                  ts2.P6    <- dates[63];
                  ts2.P7    <- dates[64];
                  ts2.P8    <- dates[65];
                  ts2.P9    <- dates[66];
                  ts2.P10   <- dates[67];
                  ts2.P11   <- dates[68];
                  ts2.P12   <- dates[69];
                  ts2.P13   <- dates[70];
                  ts2.P14   <- dates[71];
                  ts2.P15   <- dates[72];
                  ts2.P16   <- dates[73];
                  ts2.P17   <- dates[74];
                  ts2.P18   <- dates[75];
                  ts2.P19   <- dates[76];
                  ts2.P20   <- dates[77];
                  ts2.P21   <- dates[78];
                  ts2.P22   <- dates[79];
                  ts2.P23   <- dates[80];
                  ts2.P24   <- dates[81];
                  ts2.P25   <- dates[82];
                  ts2.P26   <- dates[83];
                  ts2.P27   <- dates[84];
                  ts2.P28   <- dates[85];
                  ts2.P29   <- dates[86];
                  ts2.P30   <- dates[87];
                  ts2.P31   <- dates[88];
                  ts2.P32   <- dates[89];
                  ts2.P33   <- dates[90];
                  ts2.P34   <- dates[91];
                  ts2.P35   <- dates[92];
                  ts2.P36   <- dates[93];
                  ts2.P37   <- dates[94];
                  ts2.P38   <- dates[95];
                  ts2.P39   <- dates[96];
                  ts2.P40   <- dates[97];
                  ts2.P41   <- dates[98];
                  ts2.P42   <- dates[99];
                  ts2.P43   <- dates[100];
                  ts2.P44   <- dates[101];
                  ts2.P45   <- dates[102];
                  ts2.P46   <- dates[103];
                  ts2.P47   <- dates[104];
                  ts2.P48   <- dates[105];
                  ts2.P49   <- dates[106];
                  ts2.P50   <- dates[107];
                  ts2.P51   <- dates[108];
                  ts2.P52   <- dates[109];
                  ts2.P53   <- dates[110];
                  ts2.P54   <- dates[111];
                  ts2.P55   <- dates[112];
                  ts2.P56   <- dates[113];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logscale1 <- par[59];
                  logalpha1 <- par[60];
                  logbeta1  <- par[61];
                  logP1F2   <- par[62];
                  logP2F2   <- par[63];
                  logP3F2   <- par[64];
                  logP4F2   <- par[65];
                  logP5F2   <- par[66];
                  logP6F2   <- par[67];
                  logP7F2   <- par[68];
                  logP8F2   <- par[69];
                  logP9F2   <- par[70];
                  logP10F2  <- par[71];
                  logP11F2  <- par[72];
                  logP12F2  <- par[73];
                  logP13F2  <- par[74];
                  logP14F2  <- par[75];
                  logP15F2  <- par[76];
                  logP16F2  <- par[77];
                  logP17F2  <- par[78];
                  logP18F2  <- par[79];
                  logP19F2  <- par[80];
                  logP20F2  <- par[81];
                  logP21F2  <- par[82];
                  logP22F2  <- par[83];
                  logP23F2  <- par[84];
                  logP24F2  <- par[85];
                  logP25F2  <- par[86];
                  logP26F2  <- par[87];
                  logP27F2  <- par[88];
                  logP28F2  <- par[89];
                  logP29F2  <- par[90];
                  logP30F2  <- par[91];
                  logP31F2  <- par[92];
                  logP32F2  <- par[93];
                  logP33F2  <- par[94];
                  logP34F2  <- par[95];
                  logP35F2  <- par[96];
                  logP36F2  <- par[97];
                  logP37F2  <- par[98];
                  logP38F2  <- par[99];
                  logP39F2  <- par[100];
                  logP40F2  <- par[101];
                  logP41F2  <- par[102];
                  logP42F2  <- par[103];
                  logP43F2  <- par[104];
                  logP44F2  <- par[105];
                  logP45F2  <- par[106];
                  logP46F2  <- par[107];
                  logP47F2  <- par[108];
                  logP48F2  <- par[109];
                  logP49F2  <- par[110];
                  logP50F2  <- par[111];
                  logP51F2  <- par[112];
                  logP52F2  <- par[113];
                  logP53F2  <- par[114];
                  logP54F2  <- par[115];
                  logP55F2  <- par[116];
                  logP56F2  <- par[117];
                  logscale2 <- par[118];
                  logalpha2 <- par[119];
                  logbeta2  <- par[120];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN57P57P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(57,57))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts2.P1    <- dates[59];
                  ts2.P2    <- dates[60];
                  ts2.P3    <- dates[61];
                  ts2.P4    <- dates[62];
                  ts2.P5    <- dates[63];
                  ts2.P6    <- dates[64];
                  ts2.P7    <- dates[65];
                  ts2.P8    <- dates[66];
                  ts2.P9    <- dates[67];
                  ts2.P10   <- dates[68];
                  ts2.P11   <- dates[69];
                  ts2.P12   <- dates[70];
                  ts2.P13   <- dates[71];
                  ts2.P14   <- dates[72];
                  ts2.P15   <- dates[73];
                  ts2.P16   <- dates[74];
                  ts2.P17   <- dates[75];
                  ts2.P18   <- dates[76];
                  ts2.P19   <- dates[77];
                  ts2.P20   <- dates[78];
                  ts2.P21   <- dates[79];
                  ts2.P22   <- dates[80];
                  ts2.P23   <- dates[81];
                  ts2.P24   <- dates[82];
                  ts2.P25   <- dates[83];
                  ts2.P26   <- dates[84];
                  ts2.P27   <- dates[85];
                  ts2.P28   <- dates[86];
                  ts2.P29   <- dates[87];
                  ts2.P30   <- dates[88];
                  ts2.P31   <- dates[89];
                  ts2.P32   <- dates[90];
                  ts2.P33   <- dates[91];
                  ts2.P34   <- dates[92];
                  ts2.P35   <- dates[93];
                  ts2.P36   <- dates[94];
                  ts2.P37   <- dates[95];
                  ts2.P38   <- dates[96];
                  ts2.P39   <- dates[97];
                  ts2.P40   <- dates[98];
                  ts2.P41   <- dates[99];
                  ts2.P42   <- dates[100];
                  ts2.P43   <- dates[101];
                  ts2.P44   <- dates[102];
                  ts2.P45   <- dates[103];
                  ts2.P46   <- dates[104];
                  ts2.P47   <- dates[105];
                  ts2.P48   <- dates[106];
                  ts2.P49   <- dates[107];
                  ts2.P50   <- dates[108];
                  ts2.P51   <- dates[109];
                  ts2.P52   <- dates[110];
                  ts2.P53   <- dates[111];
                  ts2.P54   <- dates[112];
                  ts2.P55   <- dates[113];
                  ts2.P56   <- dates[114];
                  ts2.P57   <- dates[115];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logscale1 <- par[60];
                  logalpha1 <- par[61];
                  logbeta1  <- par[62];
                  logP1F2   <- par[63];
                  logP2F2   <- par[64];
                  logP3F2   <- par[65];
                  logP4F2   <- par[66];
                  logP5F2   <- par[67];
                  logP6F2   <- par[68];
                  logP7F2   <- par[69];
                  logP8F2   <- par[70];
                  logP9F2   <- par[71];
                  logP10F2  <- par[72];
                  logP11F2  <- par[73];
                  logP12F2  <- par[74];
                  logP13F2  <- par[75];
                  logP14F2  <- par[76];
                  logP15F2  <- par[77];
                  logP16F2  <- par[78];
                  logP17F2  <- par[79];
                  logP18F2  <- par[80];
                  logP19F2  <- par[81];
                  logP20F2  <- par[82];
                  logP21F2  <- par[83];
                  logP22F2  <- par[84];
                  logP23F2  <- par[85];
                  logP24F2  <- par[86];
                  logP25F2  <- par[87];
                  logP26F2  <- par[88];
                  logP27F2  <- par[89];
                  logP28F2  <- par[90];
                  logP29F2  <- par[91];
                  logP30F2  <- par[92];
                  logP31F2  <- par[93];
                  logP32F2  <- par[94];
                  logP33F2  <- par[95];
                  logP34F2  <- par[96];
                  logP35F2  <- par[97];
                  logP36F2  <- par[98];
                  logP37F2  <- par[99];
                  logP38F2  <- par[100];
                  logP39F2  <- par[101];
                  logP40F2  <- par[102];
                  logP41F2  <- par[103];
                  logP42F2  <- par[104];
                  logP43F2  <- par[105];
                  logP44F2  <- par[106];
                  logP45F2  <- par[107];
                  logP46F2  <- par[108];
                  logP47F2  <- par[109];
                  logP48F2  <- par[110];
                  logP49F2  <- par[111];
                  logP50F2  <- par[112];
                  logP51F2  <- par[113];
                  logP52F2  <- par[114];
                  logP53F2  <- par[115];
                  logP54F2  <- par[116];
                  logP55F2  <- par[117];
                  logP56F2  <- par[118];
                  logP57F2  <- par[119];
                  logscale2 <- par[120];
                  logalpha2 <- par[121];
                  logbeta2  <- par[122];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN58P58P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(58,58))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts2.P1    <- dates[60];
                  ts2.P2    <- dates[61];
                  ts2.P3    <- dates[62];
                  ts2.P4    <- dates[63];
                  ts2.P5    <- dates[64];
                  ts2.P6    <- dates[65];
                  ts2.P7    <- dates[66];
                  ts2.P8    <- dates[67];
                  ts2.P9    <- dates[68];
                  ts2.P10   <- dates[69];
                  ts2.P11   <- dates[70];
                  ts2.P12   <- dates[71];
                  ts2.P13   <- dates[72];
                  ts2.P14   <- dates[73];
                  ts2.P15   <- dates[74];
                  ts2.P16   <- dates[75];
                  ts2.P17   <- dates[76];
                  ts2.P18   <- dates[77];
                  ts2.P19   <- dates[78];
                  ts2.P20   <- dates[79];
                  ts2.P21   <- dates[80];
                  ts2.P22   <- dates[81];
                  ts2.P23   <- dates[82];
                  ts2.P24   <- dates[83];
                  ts2.P25   <- dates[84];
                  ts2.P26   <- dates[85];
                  ts2.P27   <- dates[86];
                  ts2.P28   <- dates[87];
                  ts2.P29   <- dates[88];
                  ts2.P30   <- dates[89];
                  ts2.P31   <- dates[90];
                  ts2.P32   <- dates[91];
                  ts2.P33   <- dates[92];
                  ts2.P34   <- dates[93];
                  ts2.P35   <- dates[94];
                  ts2.P36   <- dates[95];
                  ts2.P37   <- dates[96];
                  ts2.P38   <- dates[97];
                  ts2.P39   <- dates[98];
                  ts2.P40   <- dates[99];
                  ts2.P41   <- dates[100];
                  ts2.P42   <- dates[101];
                  ts2.P43   <- dates[102];
                  ts2.P44   <- dates[103];
                  ts2.P45   <- dates[104];
                  ts2.P46   <- dates[105];
                  ts2.P47   <- dates[106];
                  ts2.P48   <- dates[107];
                  ts2.P49   <- dates[108];
                  ts2.P50   <- dates[109];
                  ts2.P51   <- dates[110];
                  ts2.P52   <- dates[111];
                  ts2.P53   <- dates[112];
                  ts2.P54   <- dates[113];
                  ts2.P55   <- dates[114];
                  ts2.P56   <- dates[115];
                  ts2.P57   <- dates[116];
                  ts2.P58   <- dates[117];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logscale1 <- par[61];
                  logalpha1 <- par[62];
                  logbeta1  <- par[63];
                  logP1F2   <- par[64];
                  logP2F2   <- par[65];
                  logP3F2   <- par[66];
                  logP4F2   <- par[67];
                  logP5F2   <- par[68];
                  logP6F2   <- par[69];
                  logP7F2   <- par[70];
                  logP8F2   <- par[71];
                  logP9F2   <- par[72];
                  logP10F2  <- par[73];
                  logP11F2  <- par[74];
                  logP12F2  <- par[75];
                  logP13F2  <- par[76];
                  logP14F2  <- par[77];
                  logP15F2  <- par[78];
                  logP16F2  <- par[79];
                  logP17F2  <- par[80];
                  logP18F2  <- par[81];
                  logP19F2  <- par[82];
                  logP20F2  <- par[83];
                  logP21F2  <- par[84];
                  logP22F2  <- par[85];
                  logP23F2  <- par[86];
                  logP24F2  <- par[87];
                  logP25F2  <- par[88];
                  logP26F2  <- par[89];
                  logP27F2  <- par[90];
                  logP28F2  <- par[91];
                  logP29F2  <- par[92];
                  logP30F2  <- par[93];
                  logP31F2  <- par[94];
                  logP32F2  <- par[95];
                  logP33F2  <- par[96];
                  logP34F2  <- par[97];
                  logP35F2  <- par[98];
                  logP36F2  <- par[99];
                  logP37F2  <- par[100];
                  logP38F2  <- par[101];
                  logP39F2  <- par[102];
                  logP40F2  <- par[103];
                  logP41F2  <- par[104];
                  logP42F2  <- par[105];
                  logP43F2  <- par[106];
                  logP44F2  <- par[107];
                  logP45F2  <- par[108];
                  logP46F2  <- par[109];
                  logP47F2  <- par[110];
                  logP48F2  <- par[111];
                  logP49F2  <- par[112];
                  logP50F2  <- par[113];
                  logP51F2  <- par[114];
                  logP52F2  <- par[115];
                  logP53F2  <- par[116];
                  logP54F2  <- par[117];
                  logP55F2  <- par[118];
                  logP56F2  <- par[119];
                  logP57F2  <- par[120];
                  logP58F2  <- par[121];
                  logscale2 <- par[122];
                  logalpha2 <- par[123];
                  logbeta2  <- par[124];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN59P59P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(59,59))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts2.P1    <- dates[61];
                  ts2.P2    <- dates[62];
                  ts2.P3    <- dates[63];
                  ts2.P4    <- dates[64];
                  ts2.P5    <- dates[65];
                  ts2.P6    <- dates[66];
                  ts2.P7    <- dates[67];
                  ts2.P8    <- dates[68];
                  ts2.P9    <- dates[69];
                  ts2.P10   <- dates[70];
                  ts2.P11   <- dates[71];
                  ts2.P12   <- dates[72];
                  ts2.P13   <- dates[73];
                  ts2.P14   <- dates[74];
                  ts2.P15   <- dates[75];
                  ts2.P16   <- dates[76];
                  ts2.P17   <- dates[77];
                  ts2.P18   <- dates[78];
                  ts2.P19   <- dates[79];
                  ts2.P20   <- dates[80];
                  ts2.P21   <- dates[81];
                  ts2.P22   <- dates[82];
                  ts2.P23   <- dates[83];
                  ts2.P24   <- dates[84];
                  ts2.P25   <- dates[85];
                  ts2.P26   <- dates[86];
                  ts2.P27   <- dates[87];
                  ts2.P28   <- dates[88];
                  ts2.P29   <- dates[89];
                  ts2.P30   <- dates[90];
                  ts2.P31   <- dates[91];
                  ts2.P32   <- dates[92];
                  ts2.P33   <- dates[93];
                  ts2.P34   <- dates[94];
                  ts2.P35   <- dates[95];
                  ts2.P36   <- dates[96];
                  ts2.P37   <- dates[97];
                  ts2.P38   <- dates[98];
                  ts2.P39   <- dates[99];
                  ts2.P40   <- dates[100];
                  ts2.P41   <- dates[101];
                  ts2.P42   <- dates[102];
                  ts2.P43   <- dates[103];
                  ts2.P44   <- dates[104];
                  ts2.P45   <- dates[105];
                  ts2.P46   <- dates[106];
                  ts2.P47   <- dates[107];
                  ts2.P48   <- dates[108];
                  ts2.P49   <- dates[109];
                  ts2.P50   <- dates[110];
                  ts2.P51   <- dates[111];
                  ts2.P52   <- dates[112];
                  ts2.P53   <- dates[113];
                  ts2.P54   <- dates[114];
                  ts2.P55   <- dates[115];
                  ts2.P56   <- dates[116];
                  ts2.P57   <- dates[117];
                  ts2.P58   <- dates[118];
                  ts2.P59   <- dates[119];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logscale1 <- par[62];
                  logalpha1 <- par[63];
                  logbeta1  <- par[64];
                  logP1F2   <- par[65];
                  logP2F2   <- par[66];
                  logP3F2   <- par[67];
                  logP4F2   <- par[68];
                  logP5F2   <- par[69];
                  logP6F2   <- par[70];
                  logP7F2   <- par[71];
                  logP8F2   <- par[72];
                  logP9F2   <- par[73];
                  logP10F2  <- par[74];
                  logP11F2  <- par[75];
                  logP12F2  <- par[76];
                  logP13F2  <- par[77];
                  logP14F2  <- par[78];
                  logP15F2  <- par[79];
                  logP16F2  <- par[80];
                  logP17F2  <- par[81];
                  logP18F2  <- par[82];
                  logP19F2  <- par[83];
                  logP20F2  <- par[84];
                  logP21F2  <- par[85];
                  logP22F2  <- par[86];
                  logP23F2  <- par[87];
                  logP24F2  <- par[88];
                  logP25F2  <- par[89];
                  logP26F2  <- par[90];
                  logP27F2  <- par[91];
                  logP28F2  <- par[92];
                  logP29F2  <- par[93];
                  logP30F2  <- par[94];
                  logP31F2  <- par[95];
                  logP32F2  <- par[96];
                  logP33F2  <- par[97];
                  logP34F2  <- par[98];
                  logP35F2  <- par[99];
                  logP36F2  <- par[100];
                  logP37F2  <- par[101];
                  logP38F2  <- par[102];
                  logP39F2  <- par[103];
                  logP40F2  <- par[104];
                  logP41F2  <- par[105];
                  logP42F2  <- par[106];
                  logP43F2  <- par[107];
                  logP44F2  <- par[108];
                  logP45F2  <- par[109];
                  logP46F2  <- par[110];
                  logP47F2  <- par[111];
                  logP48F2  <- par[112];
                  logP49F2  <- par[113];
                  logP50F2  <- par[114];
                  logP51F2  <- par[115];
                  logP52F2  <- par[116];
                  logP53F2  <- par[117];
                  logP54F2  <- par[118];
                  logP55F2  <- par[119];
                  logP56F2  <- par[120];
                  logP57F2  <- par[121];
                  logP58F2  <- par[122];
                  logP59F2  <- par[123];
                  logscale2 <- par[124];
                  logalpha2 <- par[125];
                  logbeta2  <- par[126];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN60P60P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(60,60))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts2.P1    <- dates[62];
                  ts2.P2    <- dates[63];
                  ts2.P3    <- dates[64];
                  ts2.P4    <- dates[65];
                  ts2.P5    <- dates[66];
                  ts2.P6    <- dates[67];
                  ts2.P7    <- dates[68];
                  ts2.P8    <- dates[69];
                  ts2.P9    <- dates[70];
                  ts2.P10   <- dates[71];
                  ts2.P11   <- dates[72];
                  ts2.P12   <- dates[73];
                  ts2.P13   <- dates[74];
                  ts2.P14   <- dates[75];
                  ts2.P15   <- dates[76];
                  ts2.P16   <- dates[77];
                  ts2.P17   <- dates[78];
                  ts2.P18   <- dates[79];
                  ts2.P19   <- dates[80];
                  ts2.P20   <- dates[81];
                  ts2.P21   <- dates[82];
                  ts2.P22   <- dates[83];
                  ts2.P23   <- dates[84];
                  ts2.P24   <- dates[85];
                  ts2.P25   <- dates[86];
                  ts2.P26   <- dates[87];
                  ts2.P27   <- dates[88];
                  ts2.P28   <- dates[89];
                  ts2.P29   <- dates[90];
                  ts2.P30   <- dates[91];
                  ts2.P31   <- dates[92];
                  ts2.P32   <- dates[93];
                  ts2.P33   <- dates[94];
                  ts2.P34   <- dates[95];
                  ts2.P35   <- dates[96];
                  ts2.P36   <- dates[97];
                  ts2.P37   <- dates[98];
                  ts2.P38   <- dates[99];
                  ts2.P39   <- dates[100];
                  ts2.P40   <- dates[101];
                  ts2.P41   <- dates[102];
                  ts2.P42   <- dates[103];
                  ts2.P43   <- dates[104];
                  ts2.P44   <- dates[105];
                  ts2.P45   <- dates[106];
                  ts2.P46   <- dates[107];
                  ts2.P47   <- dates[108];
                  ts2.P48   <- dates[109];
                  ts2.P49   <- dates[110];
                  ts2.P50   <- dates[111];
                  ts2.P51   <- dates[112];
                  ts2.P52   <- dates[113];
                  ts2.P53   <- dates[114];
                  ts2.P54   <- dates[115];
                  ts2.P55   <- dates[116];
                  ts2.P56   <- dates[117];
                  ts2.P57   <- dates[118];
                  ts2.P58   <- dates[119];
                  ts2.P59   <- dates[120];
                  ts2.P60   <- dates[121];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logscale1 <- par[63];
                  logalpha1 <- par[64];
                  logbeta1  <- par[65];
                  logP1F2   <- par[66];
                  logP2F2   <- par[67];
                  logP3F2   <- par[68];
                  logP4F2   <- par[69];
                  logP5F2   <- par[70];
                  logP6F2   <- par[71];
                  logP7F2   <- par[72];
                  logP8F2   <- par[73];
                  logP9F2   <- par[74];
                  logP10F2  <- par[75];
                  logP11F2  <- par[76];
                  logP12F2  <- par[77];
                  logP13F2  <- par[78];
                  logP14F2  <- par[79];
                  logP15F2  <- par[80];
                  logP16F2  <- par[81];
                  logP17F2  <- par[82];
                  logP18F2  <- par[83];
                  logP19F2  <- par[84];
                  logP20F2  <- par[85];
                  logP21F2  <- par[86];
                  logP22F2  <- par[87];
                  logP23F2  <- par[88];
                  logP24F2  <- par[89];
                  logP25F2  <- par[90];
                  logP26F2  <- par[91];
                  logP27F2  <- par[92];
                  logP28F2  <- par[93];
                  logP29F2  <- par[94];
                  logP30F2  <- par[95];
                  logP31F2  <- par[96];
                  logP32F2  <- par[97];
                  logP33F2  <- par[98];
                  logP34F2  <- par[99];
                  logP35F2  <- par[100];
                  logP36F2  <- par[101];
                  logP37F2  <- par[102];
                  logP38F2  <- par[103];
                  logP39F2  <- par[104];
                  logP40F2  <- par[105];
                  logP41F2  <- par[106];
                  logP42F2  <- par[107];
                  logP43F2  <- par[108];
                  logP44F2  <- par[109];
                  logP45F2  <- par[110];
                  logP46F2  <- par[111];
                  logP47F2  <- par[112];
                  logP48F2  <- par[113];
                  logP49F2  <- par[114];
                  logP50F2  <- par[115];
                  logP51F2  <- par[116];
                  logP52F2  <- par[117];
                  logP53F2  <- par[118];
                  logP54F2  <- par[119];
                  logP55F2  <- par[120];
                  logP56F2  <- par[121];
                  logP57F2  <- par[122];
                  logP58F2  <- par[123];
                  logP59F2  <- par[124];
                  logP60F2  <- par[125];
                  logscale2 <- par[126];
                  logalpha2 <- par[127];
                  logbeta2  <- par[128];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN61P61P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(61,61))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts2.P1    <- dates[63];
                  ts2.P2    <- dates[64];
                  ts2.P3    <- dates[65];
                  ts2.P4    <- dates[66];
                  ts2.P5    <- dates[67];
                  ts2.P6    <- dates[68];
                  ts2.P7    <- dates[69];
                  ts2.P8    <- dates[70];
                  ts2.P9    <- dates[71];
                  ts2.P10   <- dates[72];
                  ts2.P11   <- dates[73];
                  ts2.P12   <- dates[74];
                  ts2.P13   <- dates[75];
                  ts2.P14   <- dates[76];
                  ts2.P15   <- dates[77];
                  ts2.P16   <- dates[78];
                  ts2.P17   <- dates[79];
                  ts2.P18   <- dates[80];
                  ts2.P19   <- dates[81];
                  ts2.P20   <- dates[82];
                  ts2.P21   <- dates[83];
                  ts2.P22   <- dates[84];
                  ts2.P23   <- dates[85];
                  ts2.P24   <- dates[86];
                  ts2.P25   <- dates[87];
                  ts2.P26   <- dates[88];
                  ts2.P27   <- dates[89];
                  ts2.P28   <- dates[90];
                  ts2.P29   <- dates[91];
                  ts2.P30   <- dates[92];
                  ts2.P31   <- dates[93];
                  ts2.P32   <- dates[94];
                  ts2.P33   <- dates[95];
                  ts2.P34   <- dates[96];
                  ts2.P35   <- dates[97];
                  ts2.P36   <- dates[98];
                  ts2.P37   <- dates[99];
                  ts2.P38   <- dates[100];
                  ts2.P39   <- dates[101];
                  ts2.P40   <- dates[102];
                  ts2.P41   <- dates[103];
                  ts2.P42   <- dates[104];
                  ts2.P43   <- dates[105];
                  ts2.P44   <- dates[106];
                  ts2.P45   <- dates[107];
                  ts2.P46   <- dates[108];
                  ts2.P47   <- dates[109];
                  ts2.P48   <- dates[110];
                  ts2.P49   <- dates[111];
                  ts2.P50   <- dates[112];
                  ts2.P51   <- dates[113];
                  ts2.P52   <- dates[114];
                  ts2.P53   <- dates[115];
                  ts2.P54   <- dates[116];
                  ts2.P55   <- dates[117];
                  ts2.P56   <- dates[118];
                  ts2.P57   <- dates[119];
                  ts2.P58   <- dates[120];
                  ts2.P59   <- dates[121];
                  ts2.P60   <- dates[122];
                  ts2.P61   <- dates[123];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logscale1 <- par[64];
                  logalpha1 <- par[65];
                  logbeta1  <- par[66];
                  logP1F2   <- par[67];
                  logP2F2   <- par[68];
                  logP3F2   <- par[69];
                  logP4F2   <- par[70];
                  logP5F2   <- par[71];
                  logP6F2   <- par[72];
                  logP7F2   <- par[73];
                  logP8F2   <- par[74];
                  logP9F2   <- par[75];
                  logP10F2  <- par[76];
                  logP11F2  <- par[77];
                  logP12F2  <- par[78];
                  logP13F2  <- par[79];
                  logP14F2  <- par[80];
                  logP15F2  <- par[81];
                  logP16F2  <- par[82];
                  logP17F2  <- par[83];
                  logP18F2  <- par[84];
                  logP19F2  <- par[85];
                  logP20F2  <- par[86];
                  logP21F2  <- par[87];
                  logP22F2  <- par[88];
                  logP23F2  <- par[89];
                  logP24F2  <- par[90];
                  logP25F2  <- par[91];
                  logP26F2  <- par[92];
                  logP27F2  <- par[93];
                  logP28F2  <- par[94];
                  logP29F2  <- par[95];
                  logP30F2  <- par[96];
                  logP31F2  <- par[97];
                  logP32F2  <- par[98];
                  logP33F2  <- par[99];
                  logP34F2  <- par[100];
                  logP35F2  <- par[101];
                  logP36F2  <- par[102];
                  logP37F2  <- par[103];
                  logP38F2  <- par[104];
                  logP39F2  <- par[105];
                  logP40F2  <- par[106];
                  logP41F2  <- par[107];
                  logP42F2  <- par[108];
                  logP43F2  <- par[109];
                  logP44F2  <- par[110];
                  logP45F2  <- par[111];
                  logP46F2  <- par[112];
                  logP47F2  <- par[113];
                  logP48F2  <- par[114];
                  logP49F2  <- par[115];
                  logP50F2  <- par[116];
                  logP51F2  <- par[117];
                  logP52F2  <- par[118];
                  logP53F2  <- par[119];
                  logP54F2  <- par[120];
                  logP55F2  <- par[121];
                  logP56F2  <- par[122];
                  logP57F2  <- par[123];
                  logP58F2  <- par[124];
                  logP59F2  <- par[125];
                  logP60F2  <- par[126];
                  logP61F2  <- par[127];
                  logscale2 <- par[128];
                  logalpha2 <- par[129];
                  logbeta2  <- par[130];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN62P62P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(62,63))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts2.P1    <- dates[64];
                  ts2.P2    <- dates[65];
                  ts2.P3    <- dates[66];
                  ts2.P4    <- dates[67];
                  ts2.P5    <- dates[68];
                  ts2.P6    <- dates[69];
                  ts2.P7    <- dates[70];
                  ts2.P8    <- dates[71];
                  ts2.P9    <- dates[72];
                  ts2.P10   <- dates[73];
                  ts2.P11   <- dates[74];
                  ts2.P12   <- dates[75];
                  ts2.P13   <- dates[76];
                  ts2.P14   <- dates[77];
                  ts2.P15   <- dates[78];
                  ts2.P16   <- dates[79];
                  ts2.P17   <- dates[80];
                  ts2.P18   <- dates[81];
                  ts2.P19   <- dates[82];
                  ts2.P20   <- dates[83];
                  ts2.P21   <- dates[84];
                  ts2.P22   <- dates[85];
                  ts2.P23   <- dates[86];
                  ts2.P24   <- dates[87];
                  ts2.P25   <- dates[88];
                  ts2.P26   <- dates[89];
                  ts2.P27   <- dates[90];
                  ts2.P28   <- dates[91];
                  ts2.P29   <- dates[92];
                  ts2.P30   <- dates[93];
                  ts2.P31   <- dates[94];
                  ts2.P32   <- dates[95];
                  ts2.P33   <- dates[96];
                  ts2.P34   <- dates[97];
                  ts2.P35   <- dates[98];
                  ts2.P36   <- dates[99];
                  ts2.P37   <- dates[100];
                  ts2.P38   <- dates[101];
                  ts2.P39   <- dates[102];
                  ts2.P40   <- dates[103];
                  ts2.P41   <- dates[104];
                  ts2.P42   <- dates[105];
                  ts2.P43   <- dates[106];
                  ts2.P44   <- dates[107];
                  ts2.P45   <- dates[108];
                  ts2.P46   <- dates[109];
                  ts2.P47   <- dates[110];
                  ts2.P48   <- dates[111];
                  ts2.P49   <- dates[112];
                  ts2.P50   <- dates[113];
                  ts2.P51   <- dates[114];
                  ts2.P52   <- dates[115];
                  ts2.P53   <- dates[116];
                  ts2.P54   <- dates[117];
                  ts2.P55   <- dates[118];
                  ts2.P56   <- dates[119];
                  ts2.P57   <- dates[120];
                  ts2.P58   <- dates[121];
                  ts2.P59   <- dates[122];
                  ts2.P60   <- dates[123];
                  ts2.P61   <- dates[124];
                  ts2.P62   <- dates[125];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logscale1 <- par[65];
                  logalpha1 <- par[66];
                  logbeta1  <- par[67];
                  logP1F2   <- par[68];
                  logP2F2   <- par[69];
                  logP3F2   <- par[70];
                  logP4F2   <- par[71];
                  logP5F2   <- par[72];
                  logP6F2   <- par[73];
                  logP7F2   <- par[74];
                  logP8F2   <- par[75];
                  logP9F2   <- par[76];
                  logP10F2  <- par[77];
                  logP11F2  <- par[78];
                  logP12F2  <- par[79];
                  logP13F2  <- par[80];
                  logP14F2  <- par[81];
                  logP15F2  <- par[82];
                  logP16F2  <- par[83];
                  logP17F2  <- par[84];
                  logP18F2  <- par[85];
                  logP19F2  <- par[86];
                  logP20F2  <- par[87];
                  logP21F2  <- par[88];
                  logP22F2  <- par[89];
                  logP23F2  <- par[90];
                  logP24F2  <- par[91];
                  logP25F2  <- par[92];
                  logP26F2  <- par[93];
                  logP27F2  <- par[94];
                  logP28F2  <- par[95];
                  logP29F2  <- par[96];
                  logP30F2  <- par[97];
                  logP31F2  <- par[98];
                  logP32F2  <- par[99];
                  logP33F2  <- par[100];
                  logP34F2  <- par[101];
                  logP35F2  <- par[102];
                  logP36F2  <- par[103];
                  logP37F2  <- par[104];
                  logP38F2  <- par[105];
                  logP39F2  <- par[106];
                  logP40F2  <- par[107];
                  logP41F2  <- par[108];
                  logP42F2  <- par[109];
                  logP43F2  <- par[110];
                  logP44F2  <- par[111];
                  logP45F2  <- par[112];
                  logP46F2  <- par[113];
                  logP47F2  <- par[114];
                  logP48F2  <- par[115];
                  logP49F2  <- par[116];
                  logP50F2  <- par[117];
                  logP51F2  <- par[118];
                  logP52F2  <- par[119];
                  logP53F2  <- par[120];
                  logP54F2  <- par[121];
                  logP55F2  <- par[122];
                  logP56F2  <- par[123];
                  logP57F2  <- par[124];
                  logP58F2  <- par[125];
                  logP59F2  <- par[126];
                  logP60F2  <- par[127];
                  logP61F2  <- par[128];
                  logP62F2  <- par[129];
                  logscale2 <- par[130];
                  logalpha2 <- par[131];
                  logbeta2  <- par[132];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN63P63P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(63,63))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts2.P1    <- dates[65];
                  ts2.P2    <- dates[66];
                  ts2.P3    <- dates[67];
                  ts2.P4    <- dates[68];
                  ts2.P5    <- dates[69];
                  ts2.P6    <- dates[70];
                  ts2.P7    <- dates[71];
                  ts2.P8    <- dates[72];
                  ts2.P9    <- dates[73];
                  ts2.P10   <- dates[74];
                  ts2.P11   <- dates[75];
                  ts2.P12   <- dates[76];
                  ts2.P13   <- dates[77];
                  ts2.P14   <- dates[78];
                  ts2.P15   <- dates[79];
                  ts2.P16   <- dates[80];
                  ts2.P17   <- dates[81];
                  ts2.P18   <- dates[82];
                  ts2.P19   <- dates[83];
                  ts2.P20   <- dates[84];
                  ts2.P21   <- dates[85];
                  ts2.P22   <- dates[86];
                  ts2.P23   <- dates[87];
                  ts2.P24   <- dates[88];
                  ts2.P25   <- dates[89];
                  ts2.P26   <- dates[90];
                  ts2.P27   <- dates[91];
                  ts2.P28   <- dates[92];
                  ts2.P29   <- dates[93];
                  ts2.P30   <- dates[94];
                  ts2.P31   <- dates[95];
                  ts2.P32   <- dates[96];
                  ts2.P33   <- dates[97];
                  ts2.P34   <- dates[98];
                  ts2.P35   <- dates[99];
                  ts2.P36   <- dates[100];
                  ts2.P37   <- dates[101];
                  ts2.P38   <- dates[102];
                  ts2.P39   <- dates[103];
                  ts2.P40   <- dates[104];
                  ts2.P41   <- dates[105];
                  ts2.P42   <- dates[106];
                  ts2.P43   <- dates[107];
                  ts2.P44   <- dates[108];
                  ts2.P45   <- dates[109];
                  ts2.P46   <- dates[110];
                  ts2.P47   <- dates[111];
                  ts2.P48   <- dates[112];
                  ts2.P49   <- dates[113];
                  ts2.P50   <- dates[114];
                  ts2.P51   <- dates[115];
                  ts2.P52   <- dates[116];
                  ts2.P53   <- dates[117];
                  ts2.P54   <- dates[118];
                  ts2.P55   <- dates[119];
                  ts2.P56   <- dates[120];
                  ts2.P57   <- dates[121];
                  ts2.P58   <- dates[122];
                  ts2.P59   <- dates[123];
                  ts2.P60   <- dates[124];
                  ts2.P61   <- dates[125];
                  ts2.P62   <- dates[126];
                  ts2.P63   <- dates[127];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logscale1 <- par[66];
                  logalpha1 <- par[67];
                  logbeta1  <- par[68];
                  logP1F2   <- par[69];
                  logP2F2   <- par[70];
                  logP3F2   <- par[71];
                  logP4F2   <- par[72];
                  logP5F2   <- par[73];
                  logP6F2   <- par[74];
                  logP7F2   <- par[75];
                  logP8F2   <- par[76];
                  logP9F2   <- par[77];
                  logP10F2  <- par[78];
                  logP11F2  <- par[79];
                  logP12F2  <- par[80];
                  logP13F2  <- par[81];
                  logP14F2  <- par[82];
                  logP15F2  <- par[83];
                  logP16F2  <- par[84];
                  logP17F2  <- par[85];
                  logP18F2  <- par[86];
                  logP19F2  <- par[87];
                  logP20F2  <- par[88];
                  logP21F2  <- par[89];
                  logP22F2  <- par[90];
                  logP23F2  <- par[91];
                  logP24F2  <- par[92];
                  logP25F2  <- par[93];
                  logP26F2  <- par[94];
                  logP27F2  <- par[95];
                  logP28F2  <- par[96];
                  logP29F2  <- par[97];
                  logP30F2  <- par[98];
                  logP31F2  <- par[99];
                  logP32F2  <- par[100];
                  logP33F2  <- par[101];
                  logP34F2  <- par[102];
                  logP35F2  <- par[103];
                  logP36F2  <- par[104];
                  logP37F2  <- par[105];
                  logP38F2  <- par[106];
                  logP39F2  <- par[107];
                  logP40F2  <- par[108];
                  logP41F2  <- par[109];
                  logP42F2  <- par[110];
                  logP43F2  <- par[111];
                  logP44F2  <- par[112];
                  logP45F2  <- par[113];
                  logP46F2  <- par[114];
                  logP47F2  <- par[115];
                  logP48F2  <- par[116];
                  logP49F2  <- par[117];
                  logP50F2  <- par[118];
                  logP51F2  <- par[119];
                  logP52F2  <- par[120];
                  logP53F2  <- par[121];
                  logP54F2  <- par[122];
                  logP55F2  <- par[123];
                  logP56F2  <- par[124];
                  logP57F2  <- par[125];
                  logP58F2  <- par[126];
                  logP59F2  <- par[127];
                  logP60F2  <- par[128];
                  logP61F2  <- par[129];
                  logP62F2  <- par[130];
                  logP63F2  <- par[131];
                  logscale2 <- par[132];
                  logalpha2 <- par[133];
                  logbeta2  <- par[134];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN64P64P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(64,64))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts2.P1    <- dates[66];
                  ts2.P2    <- dates[67];
                  ts2.P3    <- dates[68];
                  ts2.P4    <- dates[69];
                  ts2.P5    <- dates[70];
                  ts2.P6    <- dates[71];
                  ts2.P7    <- dates[72];
                  ts2.P8    <- dates[73];
                  ts2.P9    <- dates[74];
                  ts2.P10   <- dates[75];
                  ts2.P11   <- dates[76];
                  ts2.P12   <- dates[77];
                  ts2.P13   <- dates[78];
                  ts2.P14   <- dates[79];
                  ts2.P15   <- dates[80];
                  ts2.P16   <- dates[81];
                  ts2.P17   <- dates[82];
                  ts2.P18   <- dates[83];
                  ts2.P19   <- dates[84];
                  ts2.P20   <- dates[85];
                  ts2.P21   <- dates[86];
                  ts2.P22   <- dates[87];
                  ts2.P23   <- dates[88];
                  ts2.P24   <- dates[89];
                  ts2.P25   <- dates[90];
                  ts2.P26   <- dates[91];
                  ts2.P27   <- dates[92];
                  ts2.P28   <- dates[93];
                  ts2.P29   <- dates[94];
                  ts2.P30   <- dates[95];
                  ts2.P31   <- dates[96];
                  ts2.P32   <- dates[97];
                  ts2.P33   <- dates[98];
                  ts2.P34   <- dates[99];
                  ts2.P35   <- dates[100];
                  ts2.P36   <- dates[101];
                  ts2.P37   <- dates[102];
                  ts2.P38   <- dates[103];
                  ts2.P39   <- dates[104];
                  ts2.P40   <- dates[105];
                  ts2.P41   <- dates[106];
                  ts2.P42   <- dates[107];
                  ts2.P43   <- dates[108];
                  ts2.P44   <- dates[109];
                  ts2.P45   <- dates[110];
                  ts2.P46   <- dates[111];
                  ts2.P47   <- dates[112];
                  ts2.P48   <- dates[113];
                  ts2.P49   <- dates[114];
                  ts2.P50   <- dates[115];
                  ts2.P51   <- dates[116];
                  ts2.P52   <- dates[117];
                  ts2.P53   <- dates[118];
                  ts2.P54   <- dates[119];
                  ts2.P55   <- dates[120];
                  ts2.P56   <- dates[121];
                  ts2.P57   <- dates[122];
                  ts2.P58   <- dates[123];
                  ts2.P59   <- dates[124];
                  ts2.P60   <- dates[125];
                  ts2.P61   <- dates[126];
                  ts2.P62   <- dates[127];
                  ts2.P63   <- dates[128];
                  ts2.P64   <- dates[129];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logscale1 <- par[67];
                  logalpha1 <- par[68];
                  logbeta1  <- par[69];
                  logP1F2   <- par[70];
                  logP2F2   <- par[71];
                  logP3F2   <- par[72];
                  logP4F2   <- par[73];
                  logP5F2   <- par[74];
                  logP6F2   <- par[75];
                  logP7F2   <- par[76];
                  logP8F2   <- par[77];
                  logP9F2   <- par[78];
                  logP10F2  <- par[79];
                  logP11F2  <- par[80];
                  logP12F2  <- par[81];
                  logP13F2  <- par[82];
                  logP14F2  <- par[83];
                  logP15F2  <- par[84];
                  logP16F2  <- par[85];
                  logP17F2  <- par[86];
                  logP18F2  <- par[87];
                  logP19F2  <- par[88];
                  logP20F2  <- par[89];
                  logP21F2  <- par[90];
                  logP22F2  <- par[91];
                  logP23F2  <- par[92];
                  logP24F2  <- par[93];
                  logP25F2  <- par[94];
                  logP26F2  <- par[95];
                  logP27F2  <- par[96];
                  logP28F2  <- par[97];
                  logP29F2  <- par[98];
                  logP30F2  <- par[99];
                  logP31F2  <- par[100];
                  logP32F2  <- par[101];
                  logP33F2  <- par[102];
                  logP34F2  <- par[103];
                  logP35F2  <- par[104];
                  logP36F2  <- par[105];
                  logP37F2  <- par[106];
                  logP38F2  <- par[107];
                  logP39F2  <- par[108];
                  logP40F2  <- par[109];
                  logP41F2  <- par[110];
                  logP42F2  <- par[111];
                  logP43F2  <- par[112];
                  logP44F2  <- par[113];
                  logP45F2  <- par[114];
                  logP46F2  <- par[115];
                  logP47F2  <- par[116];
                  logP48F2  <- par[117];
                  logP49F2  <- par[118];
                  logP50F2  <- par[119];
                  logP51F2  <- par[120];
                  logP52F2  <- par[121];
                  logP53F2  <- par[122];
                  logP54F2  <- par[123];
                  logP55F2  <- par[124];
                  logP56F2  <- par[125];
                  logP57F2  <- par[126];
                  logP58F2  <- par[127];
                  logP59F2  <- par[128];
                  logP60F2  <- par[129];
                  logP61F2  <- par[130];
                  logP62F2  <- par[131];
                  logP63F2  <- par[132];
                  logP64F2  <- par[133];
                  logscale2 <- par[134];
                  logalpha2 <- par[135];
                  logbeta2  <- par[136];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN65P65P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(65,65))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts2.P1    <- dates[67];
                  ts2.P2    <- dates[68];
                  ts2.P3    <- dates[69];
                  ts2.P4    <- dates[70];
                  ts2.P5    <- dates[71];
                  ts2.P6    <- dates[72];
                  ts2.P7    <- dates[73];
                  ts2.P8    <- dates[74];
                  ts2.P9    <- dates[75];
                  ts2.P10   <- dates[76];
                  ts2.P11   <- dates[77];
                  ts2.P12   <- dates[78];
                  ts2.P13   <- dates[79];
                  ts2.P14   <- dates[80];
                  ts2.P15   <- dates[81];
                  ts2.P16   <- dates[82];
                  ts2.P17   <- dates[83];
                  ts2.P18   <- dates[84];
                  ts2.P19   <- dates[85];
                  ts2.P20   <- dates[86];
                  ts2.P21   <- dates[87];
                  ts2.P22   <- dates[88];
                  ts2.P23   <- dates[89];
                  ts2.P24   <- dates[90];
                  ts2.P25   <- dates[91];
                  ts2.P26   <- dates[92];
                  ts2.P27   <- dates[93];
                  ts2.P28   <- dates[94];
                  ts2.P29   <- dates[95];
                  ts2.P30   <- dates[96];
                  ts2.P31   <- dates[97];
                  ts2.P32   <- dates[98];
                  ts2.P33   <- dates[99];
                  ts2.P34   <- dates[100];
                  ts2.P35   <- dates[101];
                  ts2.P36   <- dates[102];
                  ts2.P37   <- dates[103];
                  ts2.P38   <- dates[104];
                  ts2.P39   <- dates[105];
                  ts2.P40   <- dates[106];
                  ts2.P41   <- dates[107];
                  ts2.P42   <- dates[108];
                  ts2.P43   <- dates[109];
                  ts2.P44   <- dates[110];
                  ts2.P45   <- dates[111];
                  ts2.P46   <- dates[112];
                  ts2.P47   <- dates[113];
                  ts2.P48   <- dates[114];
                  ts2.P49   <- dates[115];
                  ts2.P50   <- dates[116];
                  ts2.P51   <- dates[117];
                  ts2.P52   <- dates[118];
                  ts2.P53   <- dates[119];
                  ts2.P54   <- dates[120];
                  ts2.P55   <- dates[121];
                  ts2.P56   <- dates[122];
                  ts2.P57   <- dates[123];
                  ts2.P58   <- dates[124];
                  ts2.P59   <- dates[125];
                  ts2.P60   <- dates[126];
                  ts2.P61   <- dates[127];
                  ts2.P62   <- dates[128];
                  ts2.P63   <- dates[129];
                  ts2.P64   <- dates[130];
                  ts2.P65   <- dates[131];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logscale1 <- par[68];
                  logalpha1 <- par[69];
                  logbeta1  <- par[70];
                  logP1F2   <- par[71];
                  logP2F2   <- par[72];
                  logP3F2   <- par[73];
                  logP4F2   <- par[74];
                  logP5F2   <- par[75];
                  logP6F2   <- par[76];
                  logP7F2   <- par[77];
                  logP8F2   <- par[78];
                  logP9F2   <- par[79];
                  logP10F2  <- par[80];
                  logP11F2  <- par[81];
                  logP12F2  <- par[82];
                  logP13F2  <- par[83];
                  logP14F2  <- par[84];
                  logP15F2  <- par[85];
                  logP16F2  <- par[86];
                  logP17F2  <- par[87];
                  logP18F2  <- par[88];
                  logP19F2  <- par[89];
                  logP20F2  <- par[90];
                  logP21F2  <- par[91];
                  logP22F2  <- par[92];
                  logP23F2  <- par[93];
                  logP24F2  <- par[94];
                  logP25F2  <- par[95];
                  logP26F2  <- par[96];
                  logP27F2  <- par[97];
                  logP28F2  <- par[98];
                  logP29F2  <- par[99];
                  logP30F2  <- par[100];
                  logP31F2  <- par[101];
                  logP32F2  <- par[102];
                  logP33F2  <- par[103];
                  logP34F2  <- par[104];
                  logP35F2  <- par[105];
                  logP36F2  <- par[106];
                  logP37F2  <- par[107];
                  logP38F2  <- par[108];
                  logP39F2  <- par[109];
                  logP40F2  <- par[110];
                  logP41F2  <- par[111];
                  logP42F2  <- par[112];
                  logP43F2  <- par[113];
                  logP44F2  <- par[114];
                  logP45F2  <- par[115];
                  logP46F2  <- par[116];
                  logP47F2  <- par[117];
                  logP48F2  <- par[118];
                  logP49F2  <- par[119];
                  logP50F2  <- par[120];
                  logP51F2  <- par[121];
                  logP52F2  <- par[122];
                  logP53F2  <- par[123];
                  logP54F2  <- par[124];
                  logP55F2  <- par[125];
                  logP56F2  <- par[126];
                  logP57F2  <- par[127];
                  logP58F2  <- par[128];
                  logP59F2  <- par[129];
                  logP60F2  <- par[130];
                  logP61F2  <- par[131];
                  logP62F2  <- par[132];
                  logP63F2  <- par[133];
                  logP64F2  <- par[134];
                  logP65F2  <- par[135];
                  logscale2 <- par[136];
                  logalpha2 <- par[137];
                  logbeta2  <- par[138];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN66P66P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(66,66))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts2.P1    <- dates[68];
                  ts2.P2    <- dates[69];
                  ts2.P3    <- dates[70];
                  ts2.P4    <- dates[71];
                  ts2.P5    <- dates[72];
                  ts2.P6    <- dates[73];
                  ts2.P7    <- dates[74];
                  ts2.P8    <- dates[75];
                  ts2.P9    <- dates[76];
                  ts2.P10   <- dates[77];
                  ts2.P11   <- dates[78];
                  ts2.P12   <- dates[79];
                  ts2.P13   <- dates[80];
                  ts2.P14   <- dates[81];
                  ts2.P15   <- dates[82];
                  ts2.P16   <- dates[83];
                  ts2.P17   <- dates[84];
                  ts2.P18   <- dates[85];
                  ts2.P19   <- dates[86];
                  ts2.P20   <- dates[87];
                  ts2.P21   <- dates[88];
                  ts2.P22   <- dates[89];
                  ts2.P23   <- dates[90];
                  ts2.P24   <- dates[91];
                  ts2.P25   <- dates[92];
                  ts2.P26   <- dates[93];
                  ts2.P27   <- dates[94];
                  ts2.P28   <- dates[95];
                  ts2.P29   <- dates[96];
                  ts2.P30   <- dates[97];
                  ts2.P31   <- dates[98];
                  ts2.P32   <- dates[99];
                  ts2.P33   <- dates[100];
                  ts2.P34   <- dates[101];
                  ts2.P35   <- dates[102];
                  ts2.P36   <- dates[103];
                  ts2.P37   <- dates[104];
                  ts2.P38   <- dates[105];
                  ts2.P39   <- dates[106];
                  ts2.P40   <- dates[107];
                  ts2.P41   <- dates[108];
                  ts2.P42   <- dates[109];
                  ts2.P43   <- dates[110];
                  ts2.P44   <- dates[111];
                  ts2.P45   <- dates[112];
                  ts2.P46   <- dates[113];
                  ts2.P47   <- dates[114];
                  ts2.P48   <- dates[115];
                  ts2.P49   <- dates[116];
                  ts2.P50   <- dates[117];
                  ts2.P51   <- dates[118];
                  ts2.P52   <- dates[119];
                  ts2.P53   <- dates[120];
                  ts2.P54   <- dates[121];
                  ts2.P55   <- dates[122];
                  ts2.P56   <- dates[123];
                  ts2.P57   <- dates[124];
                  ts2.P58   <- dates[125];
                  ts2.P59   <- dates[126];
                  ts2.P60   <- dates[127];
                  ts2.P61   <- dates[128];
                  ts2.P62   <- dates[129];
                  ts2.P63   <- dates[130];
                  ts2.P64   <- dates[131];
                  ts2.P65   <- dates[132];
                  ts2.P66   <- dates[133];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logscale1 <- par[69];
                  logalpha1 <- par[70];
                  logbeta1  <- par[71];
                  logP1F2   <- par[72];
                  logP2F2   <- par[73];
                  logP3F2   <- par[74];
                  logP4F2   <- par[75];
                  logP5F2   <- par[76];
                  logP6F2   <- par[77];
                  logP7F2   <- par[78];
                  logP8F2   <- par[79];
                  logP9F2   <- par[80];
                  logP10F2  <- par[81];
                  logP11F2  <- par[82];
                  logP12F2  <- par[83];
                  logP13F2  <- par[84];
                  logP14F2  <- par[85];
                  logP15F2  <- par[86];
                  logP16F2  <- par[87];
                  logP17F2  <- par[88];
                  logP18F2  <- par[89];
                  logP19F2  <- par[90];
                  logP20F2  <- par[91];
                  logP21F2  <- par[92];
                  logP22F2  <- par[93];
                  logP23F2  <- par[94];
                  logP24F2  <- par[95];
                  logP25F2  <- par[96];
                  logP26F2  <- par[97];
                  logP27F2  <- par[98];
                  logP28F2  <- par[99];
                  logP29F2  <- par[100];
                  logP30F2  <- par[101];
                  logP31F2  <- par[102];
                  logP32F2  <- par[103];
                  logP33F2  <- par[104];
                  logP34F2  <- par[105];
                  logP35F2  <- par[106];
                  logP36F2  <- par[107];
                  logP37F2  <- par[108];
                  logP38F2  <- par[109];
                  logP39F2  <- par[110];
                  logP40F2  <- par[111];
                  logP41F2  <- par[112];
                  logP42F2  <- par[113];
                  logP43F2  <- par[114];
                  logP44F2  <- par[115];
                  logP45F2  <- par[116];
                  logP46F2  <- par[117];
                  logP47F2  <- par[118];
                  logP48F2  <- par[119];
                  logP49F2  <- par[120];
                  logP50F2  <- par[121];
                  logP51F2  <- par[122];
                  logP52F2  <- par[123];
                  logP53F2  <- par[124];
                  logP54F2  <- par[125];
                  logP55F2  <- par[126];
                  logP56F2  <- par[127];
                  logP57F2  <- par[128];
                  logP58F2  <- par[129];
                  logP59F2  <- par[130];
                  logP60F2  <- par[131];
                  logP61F2  <- par[132];
                  logP62F2  <- par[133];
                  logP63F2  <- par[134];
                  logP64F2  <- par[135];
                  logP65F2  <- par[136];
                  logP66F2  <- par[137];
                  logscale2 <- par[138];
                  logalpha2 <- par[139];
                  logbeta2  <- par[140];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN67P67P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(67,67))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts2.P1    <- dates[69];
                  ts2.P2    <- dates[70];
                  ts2.P3    <- dates[71];
                  ts2.P4    <- dates[72];
                  ts2.P5    <- dates[73];
                  ts2.P6    <- dates[74];
                  ts2.P7    <- dates[75];
                  ts2.P8    <- dates[76];
                  ts2.P9    <- dates[77];
                  ts2.P10   <- dates[78];
                  ts2.P11   <- dates[79];
                  ts2.P12   <- dates[80];
                  ts2.P13   <- dates[81];
                  ts2.P14   <- dates[82];
                  ts2.P15   <- dates[83];
                  ts2.P16   <- dates[84];
                  ts2.P17   <- dates[85];
                  ts2.P18   <- dates[86];
                  ts2.P19   <- dates[87];
                  ts2.P20   <- dates[88];
                  ts2.P21   <- dates[89];
                  ts2.P22   <- dates[90];
                  ts2.P23   <- dates[91];
                  ts2.P24   <- dates[92];
                  ts2.P25   <- dates[93];
                  ts2.P26   <- dates[94];
                  ts2.P27   <- dates[95];
                  ts2.P28   <- dates[96];
                  ts2.P29   <- dates[97];
                  ts2.P30   <- dates[98];
                  ts2.P31   <- dates[99];
                  ts2.P32   <- dates[100];
                  ts2.P33   <- dates[101];
                  ts2.P34   <- dates[102];
                  ts2.P35   <- dates[103];
                  ts2.P36   <- dates[104];
                  ts2.P37   <- dates[105];
                  ts2.P38   <- dates[106];
                  ts2.P39   <- dates[107];
                  ts2.P40   <- dates[108];
                  ts2.P41   <- dates[109];
                  ts2.P42   <- dates[110];
                  ts2.P43   <- dates[111];
                  ts2.P44   <- dates[112];
                  ts2.P45   <- dates[113];
                  ts2.P46   <- dates[114];
                  ts2.P47   <- dates[115];
                  ts2.P48   <- dates[116];
                  ts2.P49   <- dates[117];
                  ts2.P50   <- dates[118];
                  ts2.P51   <- dates[119];
                  ts2.P52   <- dates[120];
                  ts2.P53   <- dates[121];
                  ts2.P54   <- dates[122];
                  ts2.P55   <- dates[123];
                  ts2.P56   <- dates[124];
                  ts2.P57   <- dates[125];
                  ts2.P58   <- dates[126];
                  ts2.P59   <- dates[127];
                  ts2.P60   <- dates[128];
                  ts2.P61   <- dates[129];
                  ts2.P62   <- dates[130];
                  ts2.P63   <- dates[131];
                  ts2.P64   <- dates[132];
                  ts2.P65   <- dates[133];
                  ts2.P66   <- dates[134];
                  ts2.P67   <- dates[135];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logscale1 <- par[70];
                  logalpha1 <- par[71];
                  logbeta1  <- par[72];
                  logP1F2   <- par[73];
                  logP2F2   <- par[74];
                  logP3F2   <- par[75];
                  logP4F2   <- par[76];
                  logP5F2   <- par[77];
                  logP6F2   <- par[78];
                  logP7F2   <- par[79];
                  logP8F2   <- par[80];
                  logP9F2   <- par[81];
                  logP10F2  <- par[82];
                  logP11F2  <- par[83];
                  logP12F2  <- par[84];
                  logP13F2  <- par[85];
                  logP14F2  <- par[86];
                  logP15F2  <- par[87];
                  logP16F2  <- par[88];
                  logP17F2  <- par[89];
                  logP18F2  <- par[90];
                  logP19F2  <- par[91];
                  logP20F2  <- par[92];
                  logP21F2  <- par[93];
                  logP22F2  <- par[94];
                  logP23F2  <- par[95];
                  logP24F2  <- par[96];
                  logP25F2  <- par[97];
                  logP26F2  <- par[98];
                  logP27F2  <- par[99];
                  logP28F2  <- par[100];
                  logP29F2  <- par[101];
                  logP30F2  <- par[102];
                  logP31F2  <- par[103];
                  logP32F2  <- par[104];
                  logP33F2  <- par[105];
                  logP34F2  <- par[106];
                  logP35F2  <- par[107];
                  logP36F2  <- par[108];
                  logP37F2  <- par[109];
                  logP38F2  <- par[110];
                  logP39F2  <- par[111];
                  logP40F2  <- par[112];
                  logP41F2  <- par[113];
                  logP42F2  <- par[114];
                  logP43F2  <- par[115];
                  logP44F2  <- par[116];
                  logP45F2  <- par[117];
                  logP46F2  <- par[118];
                  logP47F2  <- par[119];
                  logP48F2  <- par[120];
                  logP49F2  <- par[121];
                  logP50F2  <- par[122];
                  logP51F2  <- par[123];
                  logP52F2  <- par[124];
                  logP53F2  <- par[125];
                  logP54F2  <- par[126];
                  logP55F2  <- par[127];
                  logP56F2  <- par[128];
                  logP57F2  <- par[129];
                  logP58F2  <- par[130];
                  logP59F2  <- par[131];
                  logP60F2  <- par[132];
                  logP61F2  <- par[133];
                  logP62F2  <- par[134];
                  logP63F2  <- par[135];
                  logP64F2  <- par[136];
                  logP65F2  <- par[137];
                  logP66F2  <- par[138];
                  logP67F2  <- par[139];
                  logscale2 <- par[140];
                  logalpha2 <- par[141];
                  logbeta2  <- par[142];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN68P68P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(68,68))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts2.P1    <- dates[70];
                  ts2.P2    <- dates[71];
                  ts2.P3    <- dates[72];
                  ts2.P4    <- dates[73];
                  ts2.P5    <- dates[74];
                  ts2.P6    <- dates[75];
                  ts2.P7    <- dates[76];
                  ts2.P8    <- dates[77];
                  ts2.P9    <- dates[78];
                  ts2.P10   <- dates[79];
                  ts2.P11   <- dates[80];
                  ts2.P12   <- dates[81];
                  ts2.P13   <- dates[82];
                  ts2.P14   <- dates[83];
                  ts2.P15   <- dates[84];
                  ts2.P16   <- dates[85];
                  ts2.P17   <- dates[86];
                  ts2.P18   <- dates[87];
                  ts2.P19   <- dates[88];
                  ts2.P20   <- dates[89];
                  ts2.P21   <- dates[90];
                  ts2.P22   <- dates[91];
                  ts2.P23   <- dates[92];
                  ts2.P24   <- dates[93];
                  ts2.P25   <- dates[94];
                  ts2.P26   <- dates[95];
                  ts2.P27   <- dates[96];
                  ts2.P28   <- dates[97];
                  ts2.P29   <- dates[98];
                  ts2.P30   <- dates[99];
                  ts2.P31   <- dates[100];
                  ts2.P32   <- dates[101];
                  ts2.P33   <- dates[102];
                  ts2.P34   <- dates[103];
                  ts2.P35   <- dates[104];
                  ts2.P36   <- dates[105];
                  ts2.P37   <- dates[106];
                  ts2.P38   <- dates[107];
                  ts2.P39   <- dates[108];
                  ts2.P40   <- dates[109];
                  ts2.P41   <- dates[110];
                  ts2.P42   <- dates[111];
                  ts2.P43   <- dates[112];
                  ts2.P44   <- dates[113];
                  ts2.P45   <- dates[114];
                  ts2.P46   <- dates[115];
                  ts2.P47   <- dates[116];
                  ts2.P48   <- dates[117];
                  ts2.P49   <- dates[118];
                  ts2.P50   <- dates[119];
                  ts2.P51   <- dates[120];
                  ts2.P52   <- dates[121];
                  ts2.P53   <- dates[122];
                  ts2.P54   <- dates[123];
                  ts2.P55   <- dates[124];
                  ts2.P56   <- dates[125];
                  ts2.P57   <- dates[126];
                  ts2.P58   <- dates[127];
                  ts2.P59   <- dates[128];
                  ts2.P60   <- dates[129];
                  ts2.P61   <- dates[130];
                  ts2.P62   <- dates[131];
                  ts2.P63   <- dates[132];
                  ts2.P64   <- dates[133];
                  ts2.P65   <- dates[134];
                  ts2.P66   <- dates[135];
                  ts2.P67   <- dates[136];
                  ts2.P68   <- dates[137];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logscale1 <- par[71];
                  logalpha1 <- par[72];
                  logbeta1  <- par[73];
                  logP1F2   <- par[74];
                  logP2F2   <- par[75];
                  logP3F2   <- par[76];
                  logP4F2   <- par[77];
                  logP5F2   <- par[78];
                  logP6F2   <- par[79];
                  logP7F2   <- par[80];
                  logP8F2   <- par[81];
                  logP9F2   <- par[82];
                  logP10F2  <- par[83];
                  logP11F2  <- par[84];
                  logP12F2  <- par[85];
                  logP13F2  <- par[86];
                  logP14F2  <- par[87];
                  logP15F2  <- par[88];
                  logP16F2  <- par[89];
                  logP17F2  <- par[90];
                  logP18F2  <- par[91];
                  logP19F2  <- par[92];
                  logP20F2  <- par[93];
                  logP21F2  <- par[94];
                  logP22F2  <- par[95];
                  logP23F2  <- par[96];
                  logP24F2  <- par[97];
                  logP25F2  <- par[98];
                  logP26F2  <- par[99];
                  logP27F2  <- par[100];
                  logP28F2  <- par[101];
                  logP29F2  <- par[102];
                  logP30F2  <- par[103];
                  logP31F2  <- par[104];
                  logP32F2  <- par[105];
                  logP33F2  <- par[106];
                  logP34F2  <- par[107];
                  logP35F2  <- par[108];
                  logP36F2  <- par[109];
                  logP37F2  <- par[110];
                  logP38F2  <- par[111];
                  logP39F2  <- par[112];
                  logP40F2  <- par[113];
                  logP41F2  <- par[114];
                  logP42F2  <- par[115];
                  logP43F2  <- par[116];
                  logP44F2  <- par[117];
                  logP45F2  <- par[118];
                  logP46F2  <- par[119];
                  logP47F2  <- par[120];
                  logP48F2  <- par[121];
                  logP49F2  <- par[122];
                  logP50F2  <- par[123];
                  logP51F2  <- par[124];
                  logP52F2  <- par[125];
                  logP53F2  <- par[126];
                  logP54F2  <- par[127];
                  logP55F2  <- par[128];
                  logP56F2  <- par[129];
                  logP57F2  <- par[130];
                  logP58F2  <- par[131];
                  logP59F2  <- par[132];
                  logP60F2  <- par[133];
                  logP61F2  <- par[134];
                  logP62F2  <- par[135];
                  logP63F2  <- par[136];
                  logP64F2  <- par[137];
                  logP65F2  <- par[138];
                  logP66F2  <- par[139];
                  logP67F2  <- par[140];
                  logP68F2  <- par[141];
                  logscale2 <- par[142];
                  logalpha2 <- par[143];
                  logbeta2  <- par[144];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN69P69P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(69,69))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts2.P1    <- dates[71];
                  ts2.P2    <- dates[72];
                  ts2.P3    <- dates[73];
                  ts2.P4    <- dates[74];
                  ts2.P5    <- dates[75];
                  ts2.P6    <- dates[76];
                  ts2.P7    <- dates[77];
                  ts2.P8    <- dates[78];
                  ts2.P9    <- dates[79];
                  ts2.P10   <- dates[80];
                  ts2.P11   <- dates[81];
                  ts2.P12   <- dates[82];
                  ts2.P13   <- dates[83];
                  ts2.P14   <- dates[84];
                  ts2.P15   <- dates[85];
                  ts2.P16   <- dates[86];
                  ts2.P17   <- dates[87];
                  ts2.P18   <- dates[88];
                  ts2.P19   <- dates[89];
                  ts2.P20   <- dates[90];
                  ts2.P21   <- dates[91];
                  ts2.P22   <- dates[92];
                  ts2.P23   <- dates[93];
                  ts2.P24   <- dates[94];
                  ts2.P25   <- dates[95];
                  ts2.P26   <- dates[96];
                  ts2.P27   <- dates[97];
                  ts2.P28   <- dates[98];
                  ts2.P29   <- dates[99];
                  ts2.P30   <- dates[100];
                  ts2.P31   <- dates[101];
                  ts2.P32   <- dates[102];
                  ts2.P33   <- dates[103];
                  ts2.P34   <- dates[104];
                  ts2.P35   <- dates[105];
                  ts2.P36   <- dates[106];
                  ts2.P37   <- dates[107];
                  ts2.P38   <- dates[108];
                  ts2.P39   <- dates[109];
                  ts2.P40   <- dates[110];
                  ts2.P41   <- dates[111];
                  ts2.P42   <- dates[112];
                  ts2.P43   <- dates[113];
                  ts2.P44   <- dates[114];
                  ts2.P45   <- dates[115];
                  ts2.P46   <- dates[116];
                  ts2.P47   <- dates[117];
                  ts2.P48   <- dates[118];
                  ts2.P49   <- dates[119];
                  ts2.P50   <- dates[120];
                  ts2.P51   <- dates[121];
                  ts2.P52   <- dates[122];
                  ts2.P53   <- dates[123];
                  ts2.P54   <- dates[124];
                  ts2.P55   <- dates[125];
                  ts2.P56   <- dates[126];
                  ts2.P57   <- dates[127];
                  ts2.P58   <- dates[128];
                  ts2.P59   <- dates[129];
                  ts2.P60   <- dates[130];
                  ts2.P61   <- dates[131];
                  ts2.P62   <- dates[132];
                  ts2.P63   <- dates[133];
                  ts2.P64   <- dates[134];
                  ts2.P65   <- dates[135];
                  ts2.P66   <- dates[136];
                  ts2.P67   <- dates[137];
                  ts2.P68   <- dates[138];
                  ts2.P69   <- dates[139];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logscale1 <- par[72];
                  logalpha1 <- par[73];
                  logbeta1  <- par[74];
                  logP1F2   <- par[75];
                  logP2F2   <- par[76];
                  logP3F2   <- par[77];
                  logP4F2   <- par[78];
                  logP5F2   <- par[79];
                  logP6F2   <- par[80];
                  logP7F2   <- par[81];
                  logP8F2   <- par[82];
                  logP9F2   <- par[83];
                  logP10F2  <- par[84];
                  logP11F2  <- par[85];
                  logP12F2  <- par[86];
                  logP13F2  <- par[87];
                  logP14F2  <- par[88];
                  logP15F2  <- par[89];
                  logP16F2  <- par[90];
                  logP17F2  <- par[91];
                  logP18F2  <- par[92];
                  logP19F2  <- par[93];
                  logP20F2  <- par[94];
                  logP21F2  <- par[95];
                  logP22F2  <- par[96];
                  logP23F2  <- par[97];
                  logP24F2  <- par[98];
                  logP25F2  <- par[99];
                  logP26F2  <- par[100];
                  logP27F2  <- par[101];
                  logP28F2  <- par[102];
                  logP29F2  <- par[103];
                  logP30F2  <- par[104];
                  logP31F2  <- par[105];
                  logP32F2  <- par[106];
                  logP33F2  <- par[107];
                  logP34F2  <- par[108];
                  logP35F2  <- par[109];
                  logP36F2  <- par[110];
                  logP37F2  <- par[111];
                  logP38F2  <- par[112];
                  logP39F2  <- par[113];
                  logP40F2  <- par[114];
                  logP41F2  <- par[115];
                  logP42F2  <- par[116];
                  logP43F2  <- par[117];
                  logP44F2  <- par[118];
                  logP45F2  <- par[119];
                  logP46F2  <- par[120];
                  logP47F2  <- par[121];
                  logP48F2  <- par[122];
                  logP49F2  <- par[123];
                  logP50F2  <- par[124];
                  logP51F2  <- par[125];
                  logP52F2  <- par[126];
                  logP53F2  <- par[127];
                  logP54F2  <- par[128];
                  logP55F2  <- par[129];
                  logP56F2  <- par[130];
                  logP57F2  <- par[131];
                  logP58F2  <- par[132];
                  logP59F2  <- par[133];
                  logP60F2  <- par[134];
                  logP61F2  <- par[135];
                  logP62F2  <- par[136];
                  logP63F2  <- par[137];
                  logP64F2  <- par[138];
                  logP65F2  <- par[139];
                  logP66F2  <- par[140];
                  logP67F2  <- par[141];
                  logP68F2  <- par[142];
                  logP69F2  <- par[143];
                  logscale2 <- par[144];
                  logalpha2 <- par[145];
                  logbeta2  <- par[146];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN70P70P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(70,70))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts2.P1    <- dates[72];
                  ts2.P2    <- dates[73];
                  ts2.P3    <- dates[74];
                  ts2.P4    <- dates[75];
                  ts2.P5    <- dates[76];
                  ts2.P6    <- dates[77];
                  ts2.P7    <- dates[78];
                  ts2.P8    <- dates[79];
                  ts2.P9    <- dates[80];
                  ts2.P10   <- dates[81];
                  ts2.P11   <- dates[82];
                  ts2.P12   <- dates[83];
                  ts2.P13   <- dates[84];
                  ts2.P14   <- dates[85];
                  ts2.P15   <- dates[86];
                  ts2.P16   <- dates[87];
                  ts2.P17   <- dates[88];
                  ts2.P18   <- dates[89];
                  ts2.P19   <- dates[90];
                  ts2.P20   <- dates[91];
                  ts2.P21   <- dates[92];
                  ts2.P22   <- dates[93];
                  ts2.P23   <- dates[94];
                  ts2.P24   <- dates[95];
                  ts2.P25   <- dates[96];
                  ts2.P26   <- dates[97];
                  ts2.P27   <- dates[98];
                  ts2.P28   <- dates[99];
                  ts2.P29   <- dates[100];
                  ts2.P30   <- dates[101];
                  ts2.P31   <- dates[102];
                  ts2.P32   <- dates[103];
                  ts2.P33   <- dates[104];
                  ts2.P34   <- dates[105];
                  ts2.P35   <- dates[106];
                  ts2.P36   <- dates[107];
                  ts2.P37   <- dates[108];
                  ts2.P38   <- dates[109];
                  ts2.P39   <- dates[110];
                  ts2.P40   <- dates[111];
                  ts2.P41   <- dates[112];
                  ts2.P42   <- dates[113];
                  ts2.P43   <- dates[114];
                  ts2.P44   <- dates[115];
                  ts2.P45   <- dates[116];
                  ts2.P46   <- dates[117];
                  ts2.P47   <- dates[118];
                  ts2.P48   <- dates[119];
                  ts2.P49   <- dates[120];
                  ts2.P50   <- dates[121];
                  ts2.P51   <- dates[122];
                  ts2.P52   <- dates[123];
                  ts2.P53   <- dates[124];
                  ts2.P54   <- dates[125];
                  ts2.P55   <- dates[126];
                  ts2.P56   <- dates[127];
                  ts2.P57   <- dates[128];
                  ts2.P58   <- dates[129];
                  ts2.P59   <- dates[130];
                  ts2.P60   <- dates[131];
                  ts2.P61   <- dates[132];
                  ts2.P62   <- dates[133];
                  ts2.P63   <- dates[134];
                  ts2.P64   <- dates[135];
                  ts2.P65   <- dates[136];
                  ts2.P66   <- dates[137];
                  ts2.P67   <- dates[138];
                  ts2.P68   <- dates[139];
                  ts2.P69   <- dates[140];
                  ts2.P70   <- dates[141];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logscale1 <- par[73];
                  logalpha1 <- par[74];
                  logbeta1  <- par[75];
                  logP1F2   <- par[76];
                  logP2F2   <- par[77];
                  logP3F2   <- par[78];
                  logP4F2   <- par[79];
                  logP5F2   <- par[80];
                  logP6F2   <- par[81];
                  logP7F2   <- par[82];
                  logP8F2   <- par[83];
                  logP9F2   <- par[84];
                  logP10F2  <- par[85];
                  logP11F2  <- par[86];
                  logP12F2  <- par[87];
                  logP13F2  <- par[88];
                  logP14F2  <- par[89];
                  logP15F2  <- par[90];
                  logP16F2  <- par[91];
                  logP17F2  <- par[92];
                  logP18F2  <- par[93];
                  logP19F2  <- par[94];
                  logP20F2  <- par[95];
                  logP21F2  <- par[96];
                  logP22F2  <- par[97];
                  logP23F2  <- par[98];
                  logP24F2  <- par[99];
                  logP25F2  <- par[100];
                  logP26F2  <- par[101];
                  logP27F2  <- par[102];
                  logP28F2  <- par[103];
                  logP29F2  <- par[104];
                  logP30F2  <- par[105];
                  logP31F2  <- par[106];
                  logP32F2  <- par[107];
                  logP33F2  <- par[108];
                  logP34F2  <- par[109];
                  logP35F2  <- par[110];
                  logP36F2  <- par[111];
                  logP37F2  <- par[112];
                  logP38F2  <- par[113];
                  logP39F2  <- par[114];
                  logP40F2  <- par[115];
                  logP41F2  <- par[116];
                  logP42F2  <- par[117];
                  logP43F2  <- par[118];
                  logP44F2  <- par[119];
                  logP45F2  <- par[120];
                  logP46F2  <- par[121];
                  logP47F2  <- par[122];
                  logP48F2  <- par[123];
                  logP49F2  <- par[124];
                  logP50F2  <- par[125];
                  logP51F2  <- par[126];
                  logP52F2  <- par[127];
                  logP53F2  <- par[128];
                  logP54F2  <- par[129];
                  logP55F2  <- par[130];
                  logP56F2  <- par[131];
                  logP57F2  <- par[132];
                  logP58F2  <- par[133];
                  logP59F2  <- par[134];
                  logP60F2  <- par[135];
                  logP61F2  <- par[136];
                  logP62F2  <- par[137];
                  logP63F2  <- par[138];
                  logP64F2  <- par[139];
                  logP65F2  <- par[140];
                  logP66F2  <- par[141];
                  logP67F2  <- par[142];
                  logP68F2  <- par[143];
                  logP69F2  <- par[144];
                  logP70F2  <- par[145];
                  logscale2 <- par[146];
                  logalpha2 <- par[147];
                  logbeta2  <- par[148];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN71P71P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(71,71))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts2.P1    <- dates[73];
                  ts2.P2    <- dates[74];
                  ts2.P3    <- dates[75];
                  ts2.P4    <- dates[76];
                  ts2.P5    <- dates[77];
                  ts2.P6    <- dates[78];
                  ts2.P7    <- dates[79];
                  ts2.P8    <- dates[80];
                  ts2.P9    <- dates[81];
                  ts2.P10   <- dates[82];
                  ts2.P11   <- dates[83];
                  ts2.P12   <- dates[84];
                  ts2.P13   <- dates[85];
                  ts2.P14   <- dates[86];
                  ts2.P15   <- dates[87];
                  ts2.P16   <- dates[88];
                  ts2.P17   <- dates[89];
                  ts2.P18   <- dates[90];
                  ts2.P19   <- dates[91];
                  ts2.P20   <- dates[92];
                  ts2.P21   <- dates[93];
                  ts2.P22   <- dates[94];
                  ts2.P23   <- dates[95];
                  ts2.P24   <- dates[96];
                  ts2.P25   <- dates[97];
                  ts2.P26   <- dates[98];
                  ts2.P27   <- dates[99];
                  ts2.P28   <- dates[100];
                  ts2.P29   <- dates[101];
                  ts2.P30   <- dates[102];
                  ts2.P31   <- dates[103];
                  ts2.P32   <- dates[104];
                  ts2.P33   <- dates[105];
                  ts2.P34   <- dates[106];
                  ts2.P35   <- dates[107];
                  ts2.P36   <- dates[108];
                  ts2.P37   <- dates[109];
                  ts2.P38   <- dates[110];
                  ts2.P39   <- dates[111];
                  ts2.P40   <- dates[112];
                  ts2.P41   <- dates[113];
                  ts2.P42   <- dates[114];
                  ts2.P43   <- dates[115];
                  ts2.P44   <- dates[116];
                  ts2.P45   <- dates[117];
                  ts2.P46   <- dates[118];
                  ts2.P47   <- dates[119];
                  ts2.P48   <- dates[120];
                  ts2.P49   <- dates[121];
                  ts2.P50   <- dates[122];
                  ts2.P51   <- dates[123];
                  ts2.P52   <- dates[124];
                  ts2.P53   <- dates[125];
                  ts2.P54   <- dates[126];
                  ts2.P55   <- dates[127];
                  ts2.P56   <- dates[128];
                  ts2.P57   <- dates[129];
                  ts2.P58   <- dates[130];
                  ts2.P59   <- dates[131];
                  ts2.P60   <- dates[132];
                  ts2.P61   <- dates[133];
                  ts2.P62   <- dates[134];
                  ts2.P63   <- dates[135];
                  ts2.P64   <- dates[136];
                  ts2.P65   <- dates[137];
                  ts2.P66   <- dates[138];
                  ts2.P67   <- dates[139];
                  ts2.P68   <- dates[140];
                  ts2.P69   <- dates[141];
                  ts2.P70   <- dates[142];
                  ts2.P71   <- dates[143];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logscale1 <- par[74];
                  logalpha1 <- par[75];
                  logbeta1  <- par[76];
                  logP1F2   <- par[77];
                  logP2F2   <- par[78];
                  logP3F2   <- par[79];
                  logP4F2   <- par[80];
                  logP5F2   <- par[81];
                  logP6F2   <- par[82];
                  logP7F2   <- par[83];
                  logP8F2   <- par[84];
                  logP9F2   <- par[85];
                  logP10F2  <- par[86];
                  logP11F2  <- par[87];
                  logP12F2  <- par[88];
                  logP13F2  <- par[89];
                  logP14F2  <- par[90];
                  logP15F2  <- par[91];
                  logP16F2  <- par[92];
                  logP17F2  <- par[93];
                  logP18F2  <- par[94];
                  logP19F2  <- par[95];
                  logP20F2  <- par[96];
                  logP21F2  <- par[97];
                  logP22F2  <- par[98];
                  logP23F2  <- par[99];
                  logP24F2  <- par[100];
                  logP25F2  <- par[101];
                  logP26F2  <- par[102];
                  logP27F2  <- par[103];
                  logP28F2  <- par[104];
                  logP29F2  <- par[105];
                  logP30F2  <- par[106];
                  logP31F2  <- par[107];
                  logP32F2  <- par[108];
                  logP33F2  <- par[109];
                  logP34F2  <- par[110];
                  logP35F2  <- par[111];
                  logP36F2  <- par[112];
                  logP37F2  <- par[113];
                  logP38F2  <- par[114];
                  logP39F2  <- par[115];
                  logP40F2  <- par[116];
                  logP41F2  <- par[117];
                  logP42F2  <- par[118];
                  logP43F2  <- par[119];
                  logP44F2  <- par[120];
                  logP45F2  <- par[121];
                  logP46F2  <- par[122];
                  logP47F2  <- par[123];
                  logP48F2  <- par[124];
                  logP49F2  <- par[125];
                  logP50F2  <- par[126];
                  logP51F2  <- par[127];
                  logP52F2  <- par[128];
                  logP53F2  <- par[129];
                  logP54F2  <- par[130];
                  logP55F2  <- par[131];
                  logP56F2  <- par[132];
                  logP57F2  <- par[133];
                  logP58F2  <- par[134];
                  logP59F2  <- par[135];
                  logP60F2  <- par[136];
                  logP61F2  <- par[137];
                  logP62F2  <- par[138];
                  logP63F2  <- par[139];
                  logP64F2  <- par[140];
                  logP65F2  <- par[141];
                  logP66F2  <- par[142];
                  logP67F2  <- par[143];
                  logP68F2  <- par[144];
                  logP69F2  <- par[145];
                  logP70F2  <- par[146];
                  logP71F2  <- par[147];
                  logscale2 <- par[148];
                  logalpha2 <- par[149];
                  logbeta2  <- par[150];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN72P72P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(72,72))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts2.P1    <- dates[74];
                  ts2.P2    <- dates[75];
                  ts2.P3    <- dates[76];
                  ts2.P4    <- dates[77];
                  ts2.P5    <- dates[78];
                  ts2.P6    <- dates[79];
                  ts2.P7    <- dates[80];
                  ts2.P8    <- dates[81];
                  ts2.P9    <- dates[82];
                  ts2.P10   <- dates[83];
                  ts2.P11   <- dates[84];
                  ts2.P12   <- dates[85];
                  ts2.P13   <- dates[86];
                  ts2.P14   <- dates[87];
                  ts2.P15   <- dates[88];
                  ts2.P16   <- dates[89];
                  ts2.P17   <- dates[90];
                  ts2.P18   <- dates[91];
                  ts2.P19   <- dates[92];
                  ts2.P20   <- dates[93];
                  ts2.P21   <- dates[94];
                  ts2.P22   <- dates[95];
                  ts2.P23   <- dates[96];
                  ts2.P24   <- dates[97];
                  ts2.P25   <- dates[98];
                  ts2.P26   <- dates[99];
                  ts2.P27   <- dates[100];
                  ts2.P28   <- dates[101];
                  ts2.P29   <- dates[102];
                  ts2.P30   <- dates[103];
                  ts2.P31   <- dates[104];
                  ts2.P32   <- dates[105];
                  ts2.P33   <- dates[106];
                  ts2.P34   <- dates[107];
                  ts2.P35   <- dates[108];
                  ts2.P36   <- dates[109];
                  ts2.P37   <- dates[110];
                  ts2.P38   <- dates[111];
                  ts2.P39   <- dates[112];
                  ts2.P40   <- dates[113];
                  ts2.P41   <- dates[114];
                  ts2.P42   <- dates[115];
                  ts2.P43   <- dates[116];
                  ts2.P44   <- dates[117];
                  ts2.P45   <- dates[118];
                  ts2.P46   <- dates[119];
                  ts2.P47   <- dates[120];
                  ts2.P48   <- dates[121];
                  ts2.P49   <- dates[122];
                  ts2.P50   <- dates[123];
                  ts2.P51   <- dates[124];
                  ts2.P52   <- dates[125];
                  ts2.P53   <- dates[126];
                  ts2.P54   <- dates[127];
                  ts2.P55   <- dates[128];
                  ts2.P56   <- dates[129];
                  ts2.P57   <- dates[130];
                  ts2.P58   <- dates[131];
                  ts2.P59   <- dates[132];
                  ts2.P60   <- dates[133];
                  ts2.P61   <- dates[134];
                  ts2.P62   <- dates[135];
                  ts2.P63   <- dates[136];
                  ts2.P64   <- dates[137];
                  ts2.P65   <- dates[138];
                  ts2.P66   <- dates[139];
                  ts2.P67   <- dates[140];
                  ts2.P68   <- dates[141];
                  ts2.P69   <- dates[142];
                  ts2.P70   <- dates[143];
                  ts2.P71   <- dates[144];
                  ts2.P72   <- dates[145];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logscale1 <- par[75];
                  logalpha1 <- par[76];
                  logbeta1  <- par[77];
                  logP1F2   <- par[78];
                  logP2F2   <- par[79];
                  logP3F2   <- par[80];
                  logP4F2   <- par[81];
                  logP5F2   <- par[82];
                  logP6F2   <- par[83];
                  logP7F2   <- par[84];
                  logP8F2   <- par[85];
                  logP9F2   <- par[86];
                  logP10F2  <- par[87];
                  logP11F2  <- par[88];
                  logP12F2  <- par[89];
                  logP13F2  <- par[90];
                  logP14F2  <- par[91];
                  logP15F2  <- par[92];
                  logP16F2  <- par[93];
                  logP17F2  <- par[94];
                  logP18F2  <- par[95];
                  logP19F2  <- par[96];
                  logP20F2  <- par[97];
                  logP21F2  <- par[98];
                  logP22F2  <- par[99];
                  logP23F2  <- par[100];
                  logP24F2  <- par[101];
                  logP25F2  <- par[102];
                  logP26F2  <- par[103];
                  logP27F2  <- par[104];
                  logP28F2  <- par[105];
                  logP29F2  <- par[106];
                  logP30F2  <- par[107];
                  logP31F2  <- par[108];
                  logP32F2  <- par[109];
                  logP33F2  <- par[110];
                  logP34F2  <- par[111];
                  logP35F2  <- par[112];
                  logP36F2  <- par[113];
                  logP37F2  <- par[114];
                  logP38F2  <- par[115];
                  logP39F2  <- par[116];
                  logP40F2  <- par[117];
                  logP41F2  <- par[118];
                  logP42F2  <- par[119];
                  logP43F2  <- par[120];
                  logP44F2  <- par[121];
                  logP45F2  <- par[122];
                  logP46F2  <- par[123];
                  logP47F2  <- par[124];
                  logP48F2  <- par[125];
                  logP49F2  <- par[126];
                  logP50F2  <- par[127];
                  logP51F2  <- par[128];
                  logP52F2  <- par[129];
                  logP53F2  <- par[130];
                  logP54F2  <- par[131];
                  logP55F2  <- par[132];
                  logP56F2  <- par[133];
                  logP57F2  <- par[134];
                  logP58F2  <- par[135];
                  logP59F2  <- par[136];
                  logP60F2  <- par[137];
                  logP61F2  <- par[138];
                  logP62F2  <- par[139];
                  logP63F2  <- par[140];
                  logP64F2  <- par[141];
                  logP65F2  <- par[142];
                  logP66F2  <- par[143];
                  logP67F2  <- par[144];
                  logP68F2  <- par[145];
                  logP69F2  <- par[146];
                  logP70F2  <- par[147];
                  logP71F2  <- par[148];
                  logP72F2  <- par[149];
                  logscale2 <- par[150];
                  logalpha2 <- par[151];
                  logbeta2  <- par[152];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN73P73P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(73,73))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts2.P1    <- dates[75];
                  ts2.P2    <- dates[76];
                  ts2.P3    <- dates[77];
                  ts2.P4    <- dates[78];
                  ts2.P5    <- dates[79];
                  ts2.P6    <- dates[80];
                  ts2.P7    <- dates[81];
                  ts2.P8    <- dates[82];
                  ts2.P9    <- dates[83];
                  ts2.P10   <- dates[84];
                  ts2.P11   <- dates[85];
                  ts2.P12   <- dates[86];
                  ts2.P13   <- dates[87];
                  ts2.P14   <- dates[88];
                  ts2.P15   <- dates[89];
                  ts2.P16   <- dates[90];
                  ts2.P17   <- dates[91];
                  ts2.P18   <- dates[92];
                  ts2.P19   <- dates[93];
                  ts2.P20   <- dates[94];
                  ts2.P21   <- dates[95];
                  ts2.P22   <- dates[96];
                  ts2.P23   <- dates[97];
                  ts2.P24   <- dates[98];
                  ts2.P25   <- dates[99];
                  ts2.P26   <- dates[100];
                  ts2.P27   <- dates[101];
                  ts2.P28   <- dates[102];
                  ts2.P29   <- dates[103];
                  ts2.P30   <- dates[104];
                  ts2.P31   <- dates[105];
                  ts2.P32   <- dates[106];
                  ts2.P33   <- dates[107];
                  ts2.P34   <- dates[108];
                  ts2.P35   <- dates[109];
                  ts2.P36   <- dates[110];
                  ts2.P37   <- dates[111];
                  ts2.P38   <- dates[112];
                  ts2.P39   <- dates[113];
                  ts2.P40   <- dates[114];
                  ts2.P41   <- dates[115];
                  ts2.P42   <- dates[116];
                  ts2.P43   <- dates[117];
                  ts2.P44   <- dates[118];
                  ts2.P45   <- dates[119];
                  ts2.P46   <- dates[120];
                  ts2.P47   <- dates[121];
                  ts2.P48   <- dates[122];
                  ts2.P49   <- dates[123];
                  ts2.P50   <- dates[124];
                  ts2.P51   <- dates[125];
                  ts2.P52   <- dates[126];
                  ts2.P53   <- dates[127];
                  ts2.P54   <- dates[128];
                  ts2.P55   <- dates[129];
                  ts2.P56   <- dates[130];
                  ts2.P57   <- dates[131];
                  ts2.P58   <- dates[132];
                  ts2.P59   <- dates[133];
                  ts2.P60   <- dates[134];
                  ts2.P61   <- dates[135];
                  ts2.P62   <- dates[136];
                  ts2.P63   <- dates[137];
                  ts2.P64   <- dates[138];
                  ts2.P65   <- dates[139];
                  ts2.P66   <- dates[140];
                  ts2.P67   <- dates[141];
                  ts2.P68   <- dates[142];
                  ts2.P69   <- dates[143];
                  ts2.P70   <- dates[144];
                  ts2.P71   <- dates[145];
                  ts2.P72   <- dates[146];
                  ts2.P73   <- dates[147];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logscale1 <- par[76];
                  logalpha1 <- par[77];
                  logbeta1  <- par[78];
                  logP1F2   <- par[79];
                  logP2F2   <- par[80];
                  logP3F2   <- par[81];
                  logP4F2   <- par[82];
                  logP5F2   <- par[83];
                  logP6F2   <- par[84];
                  logP7F2   <- par[85];
                  logP8F2   <- par[86];
                  logP9F2   <- par[87];
                  logP10F2  <- par[88];
                  logP11F2  <- par[89];
                  logP12F2  <- par[90];
                  logP13F2  <- par[91];
                  logP14F2  <- par[92];
                  logP15F2  <- par[93];
                  logP16F2  <- par[94];
                  logP17F2  <- par[95];
                  logP18F2  <- par[96];
                  logP19F2  <- par[97];
                  logP20F2  <- par[98];
                  logP21F2  <- par[99];
                  logP22F2  <- par[100];
                  logP23F2  <- par[101];
                  logP24F2  <- par[102];
                  logP25F2  <- par[103];
                  logP26F2  <- par[104];
                  logP27F2  <- par[105];
                  logP28F2  <- par[106];
                  logP29F2  <- par[107];
                  logP30F2  <- par[108];
                  logP31F2  <- par[109];
                  logP32F2  <- par[110];
                  logP33F2  <- par[111];
                  logP34F2  <- par[112];
                  logP35F2  <- par[113];
                  logP36F2  <- par[114];
                  logP37F2  <- par[115];
                  logP38F2  <- par[116];
                  logP39F2  <- par[117];
                  logP40F2  <- par[118];
                  logP41F2  <- par[119];
                  logP42F2  <- par[120];
                  logP43F2  <- par[121];
                  logP44F2  <- par[122];
                  logP45F2  <- par[123];
                  logP46F2  <- par[124];
                  logP47F2  <- par[125];
                  logP48F2  <- par[126];
                  logP49F2  <- par[127];
                  logP50F2  <- par[128];
                  logP51F2  <- par[129];
                  logP52F2  <- par[130];
                  logP53F2  <- par[131];
                  logP54F2  <- par[132];
                  logP55F2  <- par[133];
                  logP56F2  <- par[134];
                  logP57F2  <- par[135];
                  logP58F2  <- par[136];
                  logP59F2  <- par[137];
                  logP60F2  <- par[138];
                  logP61F2  <- par[139];
                  logP62F2  <- par[140];
                  logP63F2  <- par[141];
                  logP64F2  <- par[142];
                  logP65F2  <- par[143];
                  logP66F2  <- par[144];
                  logP67F2  <- par[145];
                  logP68F2  <- par[146];
                  logP69F2  <- par[147];
                  logP70F2  <- par[148];
                  logP71F2  <- par[149];
                  logP72F2  <- par[150];
                  logP73F2  <- par[151];
                  logscale2 <- par[152];
                  logalpha2 <- par[153];
                  logbeta2  <- par[154];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN74P74P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(74,74))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts2.P1    <- dates[76];
                  ts2.P2    <- dates[77];
                  ts2.P3    <- dates[78];
                  ts2.P4    <- dates[79];
                  ts2.P5    <- dates[80];
                  ts2.P6    <- dates[81];
                  ts2.P7    <- dates[82];
                  ts2.P8    <- dates[83];
                  ts2.P9    <- dates[84];
                  ts2.P10   <- dates[85];
                  ts2.P11   <- dates[86];
                  ts2.P12   <- dates[87];
                  ts2.P13   <- dates[88];
                  ts2.P14   <- dates[89];
                  ts2.P15   <- dates[90];
                  ts2.P16   <- dates[91];
                  ts2.P17   <- dates[92];
                  ts2.P18   <- dates[93];
                  ts2.P19   <- dates[94];
                  ts2.P20   <- dates[95];
                  ts2.P21   <- dates[96];
                  ts2.P22   <- dates[97];
                  ts2.P23   <- dates[98];
                  ts2.P24   <- dates[99];
                  ts2.P25   <- dates[100];
                  ts2.P26   <- dates[101];
                  ts2.P27   <- dates[102];
                  ts2.P28   <- dates[103];
                  ts2.P29   <- dates[104];
                  ts2.P30   <- dates[105];
                  ts2.P31   <- dates[106];
                  ts2.P32   <- dates[107];
                  ts2.P33   <- dates[108];
                  ts2.P34   <- dates[109];
                  ts2.P35   <- dates[110];
                  ts2.P36   <- dates[111];
                  ts2.P37   <- dates[112];
                  ts2.P38   <- dates[113];
                  ts2.P39   <- dates[114];
                  ts2.P40   <- dates[115];
                  ts2.P41   <- dates[116];
                  ts2.P42   <- dates[117];
                  ts2.P43   <- dates[118];
                  ts2.P44   <- dates[119];
                  ts2.P45   <- dates[120];
                  ts2.P46   <- dates[121];
                  ts2.P47   <- dates[122];
                  ts2.P48   <- dates[123];
                  ts2.P49   <- dates[124];
                  ts2.P50   <- dates[125];
                  ts2.P51   <- dates[126];
                  ts2.P52   <- dates[127];
                  ts2.P53   <- dates[128];
                  ts2.P54   <- dates[129];
                  ts2.P55   <- dates[130];
                  ts2.P56   <- dates[131];
                  ts2.P57   <- dates[132];
                  ts2.P58   <- dates[133];
                  ts2.P59   <- dates[134];
                  ts2.P60   <- dates[135];
                  ts2.P61   <- dates[136];
                  ts2.P62   <- dates[137];
                  ts2.P63   <- dates[138];
                  ts2.P64   <- dates[139];
                  ts2.P65   <- dates[140];
                  ts2.P66   <- dates[141];
                  ts2.P67   <- dates[142];
                  ts2.P68   <- dates[143];
                  ts2.P69   <- dates[144];
                  ts2.P70   <- dates[145];
                  ts2.P71   <- dates[146];
                  ts2.P72   <- dates[147];
                  ts2.P73   <- dates[148];
                  ts2.P74   <- dates[149];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logscale1 <- par[77];
                  logalpha1 <- par[78];
                  logbeta1  <- par[79];
                  logP1F2   <- par[80];
                  logP2F2   <- par[81];
                  logP3F2   <- par[82];
                  logP4F2   <- par[83];
                  logP5F2   <- par[84];
                  logP6F2   <- par[85];
                  logP7F2   <- par[86];
                  logP8F2   <- par[87];
                  logP9F2   <- par[88];
                  logP10F2  <- par[89];
                  logP11F2  <- par[90];
                  logP12F2  <- par[91];
                  logP13F2  <- par[92];
                  logP14F2  <- par[93];
                  logP15F2  <- par[94];
                  logP16F2  <- par[95];
                  logP17F2  <- par[96];
                  logP18F2  <- par[97];
                  logP19F2  <- par[98];
                  logP20F2  <- par[99];
                  logP21F2  <- par[100];
                  logP22F2  <- par[101];
                  logP23F2  <- par[102];
                  logP24F2  <- par[103];
                  logP25F2  <- par[104];
                  logP26F2  <- par[105];
                  logP27F2  <- par[106];
                  logP28F2  <- par[107];
                  logP29F2  <- par[108];
                  logP30F2  <- par[109];
                  logP31F2  <- par[110];
                  logP32F2  <- par[111];
                  logP33F2  <- par[112];
                  logP34F2  <- par[113];
                  logP35F2  <- par[114];
                  logP36F2  <- par[115];
                  logP37F2  <- par[116];
                  logP38F2  <- par[117];
                  logP39F2  <- par[118];
                  logP40F2  <- par[119];
                  logP41F2  <- par[120];
                  logP42F2  <- par[121];
                  logP43F2  <- par[122];
                  logP44F2  <- par[123];
                  logP45F2  <- par[124];
                  logP46F2  <- par[125];
                  logP47F2  <- par[126];
                  logP48F2  <- par[127];
                  logP49F2  <- par[128];
                  logP50F2  <- par[129];
                  logP51F2  <- par[130];
                  logP52F2  <- par[131];
                  logP53F2  <- par[132];
                  logP54F2  <- par[133];
                  logP55F2  <- par[134];
                  logP56F2  <- par[135];
                  logP57F2  <- par[136];
                  logP58F2  <- par[137];
                  logP59F2  <- par[138];
                  logP60F2  <- par[139];
                  logP61F2  <- par[140];
                  logP62F2  <- par[141];
                  logP63F2  <- par[142];
                  logP64F2  <- par[143];
                  logP65F2  <- par[144];
                  logP66F2  <- par[145];
                  logP67F2  <- par[146];
                  logP68F2  <- par[147];
                  logP69F2  <- par[148];
                  logP70F2  <- par[149];
                  logP71F2  <- par[150];
                  logP72F2  <- par[151];
                  logP73F2  <- par[152];
                  logP74F2  <- par[153];
                  logscale2 <- par[154];
                  logalpha2 <- par[155];
                  logbeta2  <- par[156];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN75P75P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(75,75))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts2.P1    <- dates[77];
                  ts2.P2    <- dates[78];
                  ts2.P3    <- dates[79];
                  ts2.P4    <- dates[80];
                  ts2.P5    <- dates[81];
                  ts2.P6    <- dates[82];
                  ts2.P7    <- dates[83];
                  ts2.P8    <- dates[84];
                  ts2.P9    <- dates[85];
                  ts2.P10   <- dates[86];
                  ts2.P11   <- dates[87];
                  ts2.P12   <- dates[88];
                  ts2.P13   <- dates[89];
                  ts2.P14   <- dates[90];
                  ts2.P15   <- dates[91];
                  ts2.P16   <- dates[92];
                  ts2.P17   <- dates[93];
                  ts2.P18   <- dates[94];
                  ts2.P19   <- dates[95];
                  ts2.P20   <- dates[96];
                  ts2.P21   <- dates[97];
                  ts2.P22   <- dates[98];
                  ts2.P23   <- dates[99];
                  ts2.P24   <- dates[100];
                  ts2.P25   <- dates[101];
                  ts2.P26   <- dates[102];
                  ts2.P27   <- dates[103];
                  ts2.P28   <- dates[104];
                  ts2.P29   <- dates[105];
                  ts2.P30   <- dates[106];
                  ts2.P31   <- dates[107];
                  ts2.P32   <- dates[108];
                  ts2.P33   <- dates[109];
                  ts2.P34   <- dates[110];
                  ts2.P35   <- dates[111];
                  ts2.P36   <- dates[112];
                  ts2.P37   <- dates[113];
                  ts2.P38   <- dates[114];
                  ts2.P39   <- dates[115];
                  ts2.P40   <- dates[116];
                  ts2.P41   <- dates[117];
                  ts2.P42   <- dates[118];
                  ts2.P43   <- dates[119];
                  ts2.P44   <- dates[120];
                  ts2.P45   <- dates[121];
                  ts2.P46   <- dates[122];
                  ts2.P47   <- dates[123];
                  ts2.P48   <- dates[124];
                  ts2.P49   <- dates[125];
                  ts2.P50   <- dates[126];
                  ts2.P51   <- dates[127];
                  ts2.P52   <- dates[128];
                  ts2.P53   <- dates[129];
                  ts2.P54   <- dates[130];
                  ts2.P55   <- dates[131];
                  ts2.P56   <- dates[132];
                  ts2.P57   <- dates[133];
                  ts2.P58   <- dates[134];
                  ts2.P59   <- dates[135];
                  ts2.P60   <- dates[136];
                  ts2.P61   <- dates[137];
                  ts2.P62   <- dates[138];
                  ts2.P63   <- dates[139];
                  ts2.P64   <- dates[140];
                  ts2.P65   <- dates[141];
                  ts2.P66   <- dates[142];
                  ts2.P67   <- dates[143];
                  ts2.P68   <- dates[144];
                  ts2.P69   <- dates[145];
                  ts2.P70   <- dates[146];
                  ts2.P71   <- dates[147];
                  ts2.P72   <- dates[148];
                  ts2.P73   <- dates[149];
                  ts2.P74   <- dates[150];
                  ts2.P75   <- dates[151];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logscale1 <- par[78];
                  logalpha1 <- par[79];
                  logbeta1  <- par[80];
                  logP1F2   <- par[81];
                  logP2F2   <- par[82];
                  logP3F2   <- par[83];
                  logP4F2   <- par[84];
                  logP5F2   <- par[85];
                  logP6F2   <- par[86];
                  logP7F2   <- par[87];
                  logP8F2   <- par[88];
                  logP9F2   <- par[89];
                  logP10F2  <- par[90];
                  logP11F2  <- par[91];
                  logP12F2  <- par[92];
                  logP13F2  <- par[93];
                  logP14F2  <- par[94];
                  logP15F2  <- par[95];
                  logP16F2  <- par[96];
                  logP17F2  <- par[97];
                  logP18F2  <- par[98];
                  logP19F2  <- par[99];
                  logP20F2  <- par[100];
                  logP21F2  <- par[101];
                  logP22F2  <- par[102];
                  logP23F2  <- par[103];
                  logP24F2  <- par[104];
                  logP25F2  <- par[105];
                  logP26F2  <- par[106];
                  logP27F2  <- par[107];
                  logP28F2  <- par[108];
                  logP29F2  <- par[109];
                  logP30F2  <- par[110];
                  logP31F2  <- par[111];
                  logP32F2  <- par[112];
                  logP33F2  <- par[113];
                  logP34F2  <- par[114];
                  logP35F2  <- par[115];
                  logP36F2  <- par[116];
                  logP37F2  <- par[117];
                  logP38F2  <- par[118];
                  logP39F2  <- par[119];
                  logP40F2  <- par[120];
                  logP41F2  <- par[121];
                  logP42F2  <- par[122];
                  logP43F2  <- par[123];
                  logP44F2  <- par[124];
                  logP45F2  <- par[125];
                  logP46F2  <- par[126];
                  logP47F2  <- par[127];
                  logP48F2  <- par[128];
                  logP49F2  <- par[129];
                  logP50F2  <- par[130];
                  logP51F2  <- par[131];
                  logP52F2  <- par[132];
                  logP53F2  <- par[133];
                  logP54F2  <- par[134];
                  logP55F2  <- par[135];
                  logP56F2  <- par[136];
                  logP57F2  <- par[137];
                  logP58F2  <- par[138];
                  logP59F2  <- par[139];
                  logP60F2  <- par[140];
                  logP61F2  <- par[141];
                  logP62F2  <- par[142];
                  logP63F2  <- par[143];
                  logP64F2  <- par[144];
                  logP65F2  <- par[145];
                  logP66F2  <- par[146];
                  logP67F2  <- par[147];
                  logP68F2  <- par[148];
                  logP69F2  <- par[149];
                  logP70F2  <- par[150];
                  logP71F2  <- par[151];
                  logP72F2  <- par[152];
                  logP73F2  <- par[153];
                  logP74F2  <- par[154];
                  logP75F2  <- par[155];
                  logscale2 <- par[156];
                  logalpha2 <- par[157];
                  logbeta2  <- par[158];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN76P76P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(76,76))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts2.P1    <- dates[78];
                  ts2.P2    <- dates[79];
                  ts2.P3    <- dates[80];
                  ts2.P4    <- dates[81];
                  ts2.P5    <- dates[82];
                  ts2.P6    <- dates[83];
                  ts2.P7    <- dates[84];
                  ts2.P8    <- dates[85];
                  ts2.P9    <- dates[86];
                  ts2.P10   <- dates[87];
                  ts2.P11   <- dates[88];
                  ts2.P12   <- dates[89];
                  ts2.P13   <- dates[90];
                  ts2.P14   <- dates[91];
                  ts2.P15   <- dates[92];
                  ts2.P16   <- dates[93];
                  ts2.P17   <- dates[94];
                  ts2.P18   <- dates[95];
                  ts2.P19   <- dates[96];
                  ts2.P20   <- dates[97];
                  ts2.P21   <- dates[98];
                  ts2.P22   <- dates[99];
                  ts2.P23   <- dates[100];
                  ts2.P24   <- dates[101];
                  ts2.P25   <- dates[102];
                  ts2.P26   <- dates[103];
                  ts2.P27   <- dates[104];
                  ts2.P28   <- dates[105];
                  ts2.P29   <- dates[106];
                  ts2.P30   <- dates[107];
                  ts2.P31   <- dates[108];
                  ts2.P32   <- dates[109];
                  ts2.P33   <- dates[110];
                  ts2.P34   <- dates[111];
                  ts2.P35   <- dates[112];
                  ts2.P36   <- dates[113];
                  ts2.P37   <- dates[114];
                  ts2.P38   <- dates[115];
                  ts2.P39   <- dates[116];
                  ts2.P40   <- dates[117];
                  ts2.P41   <- dates[118];
                  ts2.P42   <- dates[119];
                  ts2.P43   <- dates[120];
                  ts2.P44   <- dates[121];
                  ts2.P45   <- dates[122];
                  ts2.P46   <- dates[123];
                  ts2.P47   <- dates[124];
                  ts2.P48   <- dates[125];
                  ts2.P49   <- dates[126];
                  ts2.P50   <- dates[127];
                  ts2.P51   <- dates[128];
                  ts2.P52   <- dates[129];
                  ts2.P53   <- dates[130];
                  ts2.P54   <- dates[131];
                  ts2.P55   <- dates[132];
                  ts2.P56   <- dates[133];
                  ts2.P57   <- dates[134];
                  ts2.P58   <- dates[135];
                  ts2.P59   <- dates[136];
                  ts2.P60   <- dates[137];
                  ts2.P61   <- dates[138];
                  ts2.P62   <- dates[139];
                  ts2.P63   <- dates[140];
                  ts2.P64   <- dates[141];
                  ts2.P65   <- dates[142];
                  ts2.P66   <- dates[143];
                  ts2.P67   <- dates[144];
                  ts2.P68   <- dates[145];
                  ts2.P69   <- dates[146];
                  ts2.P70   <- dates[147];
                  ts2.P71   <- dates[148];
                  ts2.P72   <- dates[149];
                  ts2.P73   <- dates[150];
                  ts2.P74   <- dates[151];
                  ts2.P75   <- dates[152];
                  ts2.P76   <- dates[153];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logscale1 <- par[79];
                  logalpha1 <- par[80];
                  logbeta1  <- par[81];
                  logP1F2   <- par[82];
                  logP2F2   <- par[83];
                  logP3F2   <- par[84];
                  logP4F2   <- par[85];
                  logP5F2   <- par[86];
                  logP6F2   <- par[87];
                  logP7F2   <- par[88];
                  logP8F2   <- par[89];
                  logP9F2   <- par[90];
                  logP10F2  <- par[91];
                  logP11F2  <- par[92];
                  logP12F2  <- par[93];
                  logP13F2  <- par[94];
                  logP14F2  <- par[95];
                  logP15F2  <- par[96];
                  logP16F2  <- par[97];
                  logP17F2  <- par[98];
                  logP18F2  <- par[99];
                  logP19F2  <- par[100];
                  logP20F2  <- par[101];
                  logP21F2  <- par[102];
                  logP22F2  <- par[103];
                  logP23F2  <- par[104];
                  logP24F2  <- par[105];
                  logP25F2  <- par[106];
                  logP26F2  <- par[107];
                  logP27F2  <- par[108];
                  logP28F2  <- par[109];
                  logP29F2  <- par[110];
                  logP30F2  <- par[111];
                  logP31F2  <- par[112];
                  logP32F2  <- par[113];
                  logP33F2  <- par[114];
                  logP34F2  <- par[115];
                  logP35F2  <- par[116];
                  logP36F2  <- par[117];
                  logP37F2  <- par[118];
                  logP38F2  <- par[119];
                  logP39F2  <- par[120];
                  logP40F2  <- par[121];
                  logP41F2  <- par[122];
                  logP42F2  <- par[123];
                  logP43F2  <- par[124];
                  logP44F2  <- par[125];
                  logP45F2  <- par[126];
                  logP46F2  <- par[127];
                  logP47F2  <- par[128];
                  logP48F2  <- par[129];
                  logP49F2  <- par[130];
                  logP50F2  <- par[131];
                  logP51F2  <- par[132];
                  logP52F2  <- par[133];
                  logP53F2  <- par[134];
                  logP54F2  <- par[135];
                  logP55F2  <- par[136];
                  logP56F2  <- par[137];
                  logP57F2  <- par[138];
                  logP58F2  <- par[139];
                  logP59F2  <- par[140];
                  logP60F2  <- par[141];
                  logP61F2  <- par[142];
                  logP62F2  <- par[143];
                  logP63F2  <- par[144];
                  logP64F2  <- par[145];
                  logP65F2  <- par[146];
                  logP66F2  <- par[147];
                  logP67F2  <- par[148];
                  logP68F2  <- par[149];
                  logP69F2  <- par[150];
                  logP70F2  <- par[151];
                  logP71F2  <- par[152];
                  logP72F2  <- par[153];
                  logP73F2  <- par[154];
                  logP74F2  <- par[155];
                  logP75F2  <- par[156];
                  logP76F2  <- par[157];
                  logscale2 <- par[158];
                  logalpha2 <- par[159];
                  logbeta2  <- par[160];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN77P77P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(77,77))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts2.P1    <- dates[79];
                  ts2.P2    <- dates[80];
                  ts2.P3    <- dates[81];
                  ts2.P4    <- dates[82];
                  ts2.P5    <- dates[83];
                  ts2.P6    <- dates[84];
                  ts2.P7    <- dates[85];
                  ts2.P8    <- dates[86];
                  ts2.P9    <- dates[87];
                  ts2.P10   <- dates[88];
                  ts2.P11   <- dates[89];
                  ts2.P12   <- dates[90];
                  ts2.P13   <- dates[91];
                  ts2.P14   <- dates[92];
                  ts2.P15   <- dates[93];
                  ts2.P16   <- dates[94];
                  ts2.P17   <- dates[95];
                  ts2.P18   <- dates[96];
                  ts2.P19   <- dates[97];
                  ts2.P20   <- dates[98];
                  ts2.P21   <- dates[99];
                  ts2.P22   <- dates[100];
                  ts2.P23   <- dates[101];
                  ts2.P24   <- dates[102];
                  ts2.P25   <- dates[103];
                  ts2.P26   <- dates[104];
                  ts2.P27   <- dates[105];
                  ts2.P28   <- dates[106];
                  ts2.P29   <- dates[107];
                  ts2.P30   <- dates[108];
                  ts2.P31   <- dates[109];
                  ts2.P32   <- dates[110];
                  ts2.P33   <- dates[111];
                  ts2.P34   <- dates[112];
                  ts2.P35   <- dates[113];
                  ts2.P36   <- dates[114];
                  ts2.P37   <- dates[115];
                  ts2.P38   <- dates[116];
                  ts2.P39   <- dates[117];
                  ts2.P40   <- dates[118];
                  ts2.P41   <- dates[119];
                  ts2.P42   <- dates[120];
                  ts2.P43   <- dates[121];
                  ts2.P44   <- dates[122];
                  ts2.P45   <- dates[123];
                  ts2.P46   <- dates[124];
                  ts2.P47   <- dates[125];
                  ts2.P48   <- dates[126];
                  ts2.P49   <- dates[127];
                  ts2.P50   <- dates[128];
                  ts2.P51   <- dates[129];
                  ts2.P52   <- dates[130];
                  ts2.P53   <- dates[131];
                  ts2.P54   <- dates[132];
                  ts2.P55   <- dates[133];
                  ts2.P56   <- dates[134];
                  ts2.P57   <- dates[135];
                  ts2.P58   <- dates[136];
                  ts2.P59   <- dates[137];
                  ts2.P60   <- dates[138];
                  ts2.P61   <- dates[139];
                  ts2.P62   <- dates[140];
                  ts2.P63   <- dates[141];
                  ts2.P64   <- dates[142];
                  ts2.P65   <- dates[143];
                  ts2.P66   <- dates[144];
                  ts2.P67   <- dates[145];
                  ts2.P68   <- dates[146];
                  ts2.P69   <- dates[147];
                  ts2.P70   <- dates[148];
                  ts2.P71   <- dates[149];
                  ts2.P72   <- dates[150];
                  ts2.P73   <- dates[151];
                  ts2.P74   <- dates[152];
                  ts2.P75   <- dates[153];
                  ts2.P76   <- dates[154];
                  ts2.P77   <- dates[155];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logscale1 <- par[80];
                  logalpha1 <- par[81];
                  logbeta1  <- par[82];
                  logP1F2   <- par[83];
                  logP2F2   <- par[84];
                  logP3F2   <- par[85];
                  logP4F2   <- par[86];
                  logP5F2   <- par[87];
                  logP6F2   <- par[88];
                  logP7F2   <- par[89];
                  logP8F2   <- par[90];
                  logP9F2   <- par[91];
                  logP10F2  <- par[92];
                  logP11F2  <- par[93];
                  logP12F2  <- par[94];
                  logP13F2  <- par[95];
                  logP14F2  <- par[96];
                  logP15F2  <- par[97];
                  logP16F2  <- par[98];
                  logP17F2  <- par[99];
                  logP18F2  <- par[100];
                  logP19F2  <- par[101];
                  logP20F2  <- par[102];
                  logP21F2  <- par[103];
                  logP22F2  <- par[104];
                  logP23F2  <- par[105];
                  logP24F2  <- par[106];
                  logP25F2  <- par[107];
                  logP26F2  <- par[108];
                  logP27F2  <- par[109];
                  logP28F2  <- par[110];
                  logP29F2  <- par[111];
                  logP30F2  <- par[112];
                  logP31F2  <- par[113];
                  logP32F2  <- par[114];
                  logP33F2  <- par[115];
                  logP34F2  <- par[116];
                  logP35F2  <- par[117];
                  logP36F2  <- par[118];
                  logP37F2  <- par[119];
                  logP38F2  <- par[120];
                  logP39F2  <- par[121];
                  logP40F2  <- par[122];
                  logP41F2  <- par[123];
                  logP42F2  <- par[124];
                  logP43F2  <- par[125];
                  logP44F2  <- par[126];
                  logP45F2  <- par[127];
                  logP46F2  <- par[128];
                  logP47F2  <- par[129];
                  logP48F2  <- par[130];
                  logP49F2  <- par[131];
                  logP50F2  <- par[132];
                  logP51F2  <- par[133];
                  logP52F2  <- par[134];
                  logP53F2  <- par[135];
                  logP54F2  <- par[136];
                  logP55F2  <- par[137];
                  logP56F2  <- par[138];
                  logP57F2  <- par[139];
                  logP58F2  <- par[140];
                  logP59F2  <- par[141];
                  logP60F2  <- par[142];
                  logP61F2  <- par[143];
                  logP62F2  <- par[144];
                  logP63F2  <- par[145];
                  logP64F2  <- par[146];
                  logP65F2  <- par[147];
                  logP66F2  <- par[148];
                  logP67F2  <- par[149];
                  logP68F2  <- par[150];
                  logP69F2  <- par[151];
                  logP70F2  <- par[152];
                  logP71F2  <- par[153];
                  logP72F2  <- par[154];
                  logP73F2  <- par[155];
                  logP74F2  <- par[156];
                  logP75F2  <- par[157];
                  logP76F2  <- par[158];
                  logP77F2  <- par[159];
                  logscale2 <- par[160];
                  logalpha2 <- par[161];
                  logbeta2  <- par[162];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN78P78P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(78,78))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts2.P1    <- dates[80];
                  ts2.P2    <- dates[81];
                  ts2.P3    <- dates[82];
                  ts2.P4    <- dates[83];
                  ts2.P5    <- dates[84];
                  ts2.P6    <- dates[85];
                  ts2.P7    <- dates[86];
                  ts2.P8    <- dates[87];
                  ts2.P9    <- dates[88];
                  ts2.P10   <- dates[89];
                  ts2.P11   <- dates[90];
                  ts2.P12   <- dates[91];
                  ts2.P13   <- dates[92];
                  ts2.P14   <- dates[93];
                  ts2.P15   <- dates[94];
                  ts2.P16   <- dates[95];
                  ts2.P17   <- dates[96];
                  ts2.P18   <- dates[97];
                  ts2.P19   <- dates[98];
                  ts2.P20   <- dates[99];
                  ts2.P21   <- dates[100];
                  ts2.P22   <- dates[101];
                  ts2.P23   <- dates[102];
                  ts2.P24   <- dates[103];
                  ts2.P25   <- dates[104];
                  ts2.P26   <- dates[105];
                  ts2.P27   <- dates[106];
                  ts2.P28   <- dates[107];
                  ts2.P29   <- dates[108];
                  ts2.P30   <- dates[109];
                  ts2.P31   <- dates[110];
                  ts2.P32   <- dates[111];
                  ts2.P33   <- dates[112];
                  ts2.P34   <- dates[113];
                  ts2.P35   <- dates[114];
                  ts2.P36   <- dates[115];
                  ts2.P37   <- dates[116];
                  ts2.P38   <- dates[117];
                  ts2.P39   <- dates[118];
                  ts2.P40   <- dates[119];
                  ts2.P41   <- dates[120];
                  ts2.P42   <- dates[121];
                  ts2.P43   <- dates[122];
                  ts2.P44   <- dates[123];
                  ts2.P45   <- dates[124];
                  ts2.P46   <- dates[125];
                  ts2.P47   <- dates[126];
                  ts2.P48   <- dates[127];
                  ts2.P49   <- dates[128];
                  ts2.P50   <- dates[129];
                  ts2.P51   <- dates[130];
                  ts2.P52   <- dates[131];
                  ts2.P53   <- dates[132];
                  ts2.P54   <- dates[133];
                  ts2.P55   <- dates[134];
                  ts2.P56   <- dates[135];
                  ts2.P57   <- dates[136];
                  ts2.P58   <- dates[137];
                  ts2.P59   <- dates[138];
                  ts2.P60   <- dates[139];
                  ts2.P61   <- dates[140];
                  ts2.P62   <- dates[141];
                  ts2.P63   <- dates[142];
                  ts2.P64   <- dates[143];
                  ts2.P65   <- dates[144];
                  ts2.P66   <- dates[145];
                  ts2.P67   <- dates[146];
                  ts2.P68   <- dates[147];
                  ts2.P69   <- dates[148];
                  ts2.P70   <- dates[149];
                  ts2.P71   <- dates[150];
                  ts2.P72   <- dates[151];
                  ts2.P73   <- dates[152];
                  ts2.P74   <- dates[153];
                  ts2.P75   <- dates[154];
                  ts2.P76   <- dates[155];
                  ts2.P77   <- dates[156];
                  ts2.P78   <- dates[157];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logscale1 <- par[81];
                  logalpha1 <- par[82];
                  logbeta1  <- par[83];
                  logP1F2   <- par[84];
                  logP2F2   <- par[85];
                  logP3F2   <- par[86];
                  logP4F2   <- par[87];
                  logP5F2   <- par[88];
                  logP6F2   <- par[89];
                  logP7F2   <- par[90];
                  logP8F2   <- par[91];
                  logP9F2   <- par[92];
                  logP10F2  <- par[93];
                  logP11F2  <- par[94];
                  logP12F2  <- par[95];
                  logP13F2  <- par[96];
                  logP14F2  <- par[97];
                  logP15F2  <- par[98];
                  logP16F2  <- par[99];
                  logP17F2  <- par[100];
                  logP18F2  <- par[101];
                  logP19F2  <- par[102];
                  logP20F2  <- par[103];
                  logP21F2  <- par[104];
                  logP22F2  <- par[105];
                  logP23F2  <- par[106];
                  logP24F2  <- par[107];
                  logP25F2  <- par[108];
                  logP26F2  <- par[109];
                  logP27F2  <- par[110];
                  logP28F2  <- par[111];
                  logP29F2  <- par[112];
                  logP30F2  <- par[113];
                  logP31F2  <- par[114];
                  logP32F2  <- par[115];
                  logP33F2  <- par[116];
                  logP34F2  <- par[117];
                  logP35F2  <- par[118];
                  logP36F2  <- par[119];
                  logP37F2  <- par[120];
                  logP38F2  <- par[121];
                  logP39F2  <- par[122];
                  logP40F2  <- par[123];
                  logP41F2  <- par[124];
                  logP42F2  <- par[125];
                  logP43F2  <- par[126];
                  logP44F2  <- par[127];
                  logP45F2  <- par[128];
                  logP46F2  <- par[129];
                  logP47F2  <- par[130];
                  logP48F2  <- par[131];
                  logP49F2  <- par[132];
                  logP50F2  <- par[133];
                  logP51F2  <- par[134];
                  logP52F2  <- par[135];
                  logP53F2  <- par[136];
                  logP54F2  <- par[137];
                  logP55F2  <- par[138];
                  logP56F2  <- par[139];
                  logP57F2  <- par[140];
                  logP58F2  <- par[141];
                  logP59F2  <- par[142];
                  logP60F2  <- par[143];
                  logP61F2  <- par[144];
                  logP62F2  <- par[145];
                  logP63F2  <- par[146];
                  logP64F2  <- par[147];
                  logP65F2  <- par[148];
                  logP66F2  <- par[149];
                  logP67F2  <- par[150];
                  logP68F2  <- par[151];
                  logP69F2  <- par[152];
                  logP70F2  <- par[153];
                  logP71F2  <- par[154];
                  logP72F2  <- par[155];
                  logP73F2  <- par[156];
                  logP74F2  <- par[157];
                  logP75F2  <- par[158];
                  logP76F2  <- par[159];
                  logP77F2  <- par[160];
                  logP78F2  <- par[161];
                  logscale2 <- par[162];
                  logalpha2 <- par[163];
                  logbeta2  <- par[164];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN79P79P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(79,79))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts2.P1    <- dates[81];
                  ts2.P2    <- dates[82];
                  ts2.P3    <- dates[83];
                  ts2.P4    <- dates[84];
                  ts2.P5    <- dates[85];
                  ts2.P6    <- dates[86];
                  ts2.P7    <- dates[87];
                  ts2.P8    <- dates[88];
                  ts2.P9    <- dates[89];
                  ts2.P10   <- dates[90];
                  ts2.P11   <- dates[91];
                  ts2.P12   <- dates[92];
                  ts2.P13   <- dates[93];
                  ts2.P14   <- dates[94];
                  ts2.P15   <- dates[95];
                  ts2.P16   <- dates[96];
                  ts2.P17   <- dates[97];
                  ts2.P18   <- dates[98];
                  ts2.P19   <- dates[99];
                  ts2.P20   <- dates[100];
                  ts2.P21   <- dates[101];
                  ts2.P22   <- dates[102];
                  ts2.P23   <- dates[103];
                  ts2.P24   <- dates[104];
                  ts2.P25   <- dates[105];
                  ts2.P26   <- dates[106];
                  ts2.P27   <- dates[107];
                  ts2.P28   <- dates[108];
                  ts2.P29   <- dates[109];
                  ts2.P30   <- dates[110];
                  ts2.P31   <- dates[111];
                  ts2.P32   <- dates[112];
                  ts2.P33   <- dates[113];
                  ts2.P34   <- dates[114];
                  ts2.P35   <- dates[115];
                  ts2.P36   <- dates[116];
                  ts2.P37   <- dates[117];
                  ts2.P38   <- dates[118];
                  ts2.P39   <- dates[119];
                  ts2.P40   <- dates[120];
                  ts2.P41   <- dates[121];
                  ts2.P42   <- dates[122];
                  ts2.P43   <- dates[123];
                  ts2.P44   <- dates[124];
                  ts2.P45   <- dates[125];
                  ts2.P46   <- dates[126];
                  ts2.P47   <- dates[127];
                  ts2.P48   <- dates[128];
                  ts2.P49   <- dates[129];
                  ts2.P50   <- dates[130];
                  ts2.P51   <- dates[131];
                  ts2.P52   <- dates[132];
                  ts2.P53   <- dates[133];
                  ts2.P54   <- dates[134];
                  ts2.P55   <- dates[135];
                  ts2.P56   <- dates[136];
                  ts2.P57   <- dates[137];
                  ts2.P58   <- dates[138];
                  ts2.P59   <- dates[139];
                  ts2.P60   <- dates[140];
                  ts2.P61   <- dates[141];
                  ts2.P62   <- dates[142];
                  ts2.P63   <- dates[143];
                  ts2.P64   <- dates[144];
                  ts2.P65   <- dates[145];
                  ts2.P66   <- dates[146];
                  ts2.P67   <- dates[147];
                  ts2.P68   <- dates[148];
                  ts2.P69   <- dates[149];
                  ts2.P70   <- dates[150];
                  ts2.P71   <- dates[151];
                  ts2.P72   <- dates[152];
                  ts2.P73   <- dates[153];
                  ts2.P74   <- dates[154];
                  ts2.P75   <- dates[155];
                  ts2.P76   <- dates[156];
                  ts2.P77   <- dates[157];
                  ts2.P78   <- dates[158];
                  ts2.P79   <- dates[159];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logscale1 <- par[82];
                  logalpha1 <- par[83];
                  logbeta1  <- par[84];
                  logP1F2   <- par[85];
                  logP2F2   <- par[86];
                  logP3F2   <- par[87];
                  logP4F2   <- par[88];
                  logP5F2   <- par[89];
                  logP6F2   <- par[90];
                  logP7F2   <- par[91];
                  logP8F2   <- par[92];
                  logP9F2   <- par[93];
                  logP10F2  <- par[94];
                  logP11F2  <- par[95];
                  logP12F2  <- par[96];
                  logP13F2  <- par[97];
                  logP14F2  <- par[98];
                  logP15F2  <- par[99];
                  logP16F2  <- par[100];
                  logP17F2  <- par[101];
                  logP18F2  <- par[102];
                  logP19F2  <- par[103];
                  logP20F2  <- par[104];
                  logP21F2  <- par[105];
                  logP22F2  <- par[106];
                  logP23F2  <- par[107];
                  logP24F2  <- par[108];
                  logP25F2  <- par[109];
                  logP26F2  <- par[110];
                  logP27F2  <- par[111];
                  logP28F2  <- par[112];
                  logP29F2  <- par[113];
                  logP30F2  <- par[114];
                  logP31F2  <- par[115];
                  logP32F2  <- par[116];
                  logP33F2  <- par[117];
                  logP34F2  <- par[118];
                  logP35F2  <- par[119];
                  logP36F2  <- par[120];
                  logP37F2  <- par[121];
                  logP38F2  <- par[122];
                  logP39F2  <- par[123];
                  logP40F2  <- par[124];
                  logP41F2  <- par[125];
                  logP42F2  <- par[126];
                  logP43F2  <- par[127];
                  logP44F2  <- par[128];
                  logP45F2  <- par[129];
                  logP46F2  <- par[130];
                  logP47F2  <- par[131];
                  logP48F2  <- par[132];
                  logP49F2  <- par[133];
                  logP50F2  <- par[134];
                  logP51F2  <- par[135];
                  logP52F2  <- par[136];
                  logP53F2  <- par[137];
                  logP54F2  <- par[138];
                  logP55F2  <- par[139];
                  logP56F2  <- par[140];
                  logP57F2  <- par[141];
                  logP58F2  <- par[142];
                  logP59F2  <- par[143];
                  logP60F2  <- par[144];
                  logP61F2  <- par[145];
                  logP62F2  <- par[146];
                  logP63F2  <- par[147];
                  logP64F2  <- par[148];
                  logP65F2  <- par[149];
                  logP66F2  <- par[150];
                  logP67F2  <- par[151];
                  logP68F2  <- par[152];
                  logP69F2  <- par[153];
                  logP70F2  <- par[154];
                  logP71F2  <- par[155];
                  logP72F2  <- par[156];
                  logP73F2  <- par[157];
                  logP74F2  <- par[158];
                  logP75F2  <- par[159];
                  logP76F2  <- par[160];
                  logP77F2  <- par[161];
                  logP78F2  <- par[162];
                  logP79F2  <- par[163];
                  logscale2 <- par[164];
                  logalpha2 <- par[165];
                  logbeta2  <- par[166];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN80P80P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(80,80))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts2.P1    <- dates[82];
                  ts2.P2    <- dates[83];
                  ts2.P3    <- dates[84];
                  ts2.P4    <- dates[85];
                  ts2.P5    <- dates[86];
                  ts2.P6    <- dates[87];
                  ts2.P7    <- dates[88];
                  ts2.P8    <- dates[89];
                  ts2.P9    <- dates[90];
                  ts2.P10   <- dates[91];
                  ts2.P11   <- dates[92];
                  ts2.P12   <- dates[93];
                  ts2.P13   <- dates[94];
                  ts2.P14   <- dates[95];
                  ts2.P15   <- dates[96];
                  ts2.P16   <- dates[97];
                  ts2.P17   <- dates[98];
                  ts2.P18   <- dates[99];
                  ts2.P19   <- dates[100];
                  ts2.P20   <- dates[101];
                  ts2.P21   <- dates[102];
                  ts2.P22   <- dates[103];
                  ts2.P23   <- dates[104];
                  ts2.P24   <- dates[105];
                  ts2.P25   <- dates[106];
                  ts2.P26   <- dates[107];
                  ts2.P27   <- dates[108];
                  ts2.P28   <- dates[109];
                  ts2.P29   <- dates[110];
                  ts2.P30   <- dates[111];
                  ts2.P31   <- dates[112];
                  ts2.P32   <- dates[113];
                  ts2.P33   <- dates[114];
                  ts2.P34   <- dates[115];
                  ts2.P35   <- dates[116];
                  ts2.P36   <- dates[117];
                  ts2.P37   <- dates[118];
                  ts2.P38   <- dates[119];
                  ts2.P39   <- dates[120];
                  ts2.P40   <- dates[121];
                  ts2.P41   <- dates[122];
                  ts2.P42   <- dates[123];
                  ts2.P43   <- dates[124];
                  ts2.P44   <- dates[125];
                  ts2.P45   <- dates[126];
                  ts2.P46   <- dates[127];
                  ts2.P47   <- dates[128];
                  ts2.P48   <- dates[129];
                  ts2.P49   <- dates[130];
                  ts2.P50   <- dates[131];
                  ts2.P51   <- dates[132];
                  ts2.P52   <- dates[133];
                  ts2.P53   <- dates[134];
                  ts2.P54   <- dates[135];
                  ts2.P55   <- dates[136];
                  ts2.P56   <- dates[137];
                  ts2.P57   <- dates[138];
                  ts2.P58   <- dates[139];
                  ts2.P59   <- dates[140];
                  ts2.P60   <- dates[141];
                  ts2.P61   <- dates[142];
                  ts2.P62   <- dates[143];
                  ts2.P63   <- dates[144];
                  ts2.P64   <- dates[145];
                  ts2.P65   <- dates[146];
                  ts2.P66   <- dates[147];
                  ts2.P67   <- dates[148];
                  ts2.P68   <- dates[149];
                  ts2.P69   <- dates[150];
                  ts2.P70   <- dates[151];
                  ts2.P71   <- dates[152];
                  ts2.P72   <- dates[153];
                  ts2.P73   <- dates[154];
                  ts2.P74   <- dates[155];
                  ts2.P75   <- dates[156];
                  ts2.P76   <- dates[157];
                  ts2.P77   <- dates[158];
                  ts2.P78   <- dates[159];
                  ts2.P79   <- dates[160];
                  ts2.P80   <- dates[161];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logscale1 <- par[83];
                  logalpha1 <- par[84];
                  logbeta1  <- par[85];
                  logP1F2   <- par[86];
                  logP2F2   <- par[87];
                  logP3F2   <- par[88];
                  logP4F2   <- par[89];
                  logP5F2   <- par[90];
                  logP6F2   <- par[91];
                  logP7F2   <- par[92];
                  logP8F2   <- par[93];
                  logP9F2   <- par[94];
                  logP10F2  <- par[95];
                  logP11F2  <- par[96];
                  logP12F2  <- par[97];
                  logP13F2  <- par[98];
                  logP14F2  <- par[99];
                  logP15F2  <- par[100];
                  logP16F2  <- par[101];
                  logP17F2  <- par[102];
                  logP18F2  <- par[103];
                  logP19F2  <- par[104];
                  logP20F2  <- par[105];
                  logP21F2  <- par[106];
                  logP22F2  <- par[107];
                  logP23F2  <- par[108];
                  logP24F2  <- par[109];
                  logP25F2  <- par[110];
                  logP26F2  <- par[111];
                  logP27F2  <- par[112];
                  logP28F2  <- par[113];
                  logP29F2  <- par[114];
                  logP30F2  <- par[115];
                  logP31F2  <- par[116];
                  logP32F2  <- par[117];
                  logP33F2  <- par[118];
                  logP34F2  <- par[119];
                  logP35F2  <- par[120];
                  logP36F2  <- par[121];
                  logP37F2  <- par[122];
                  logP38F2  <- par[123];
                  logP39F2  <- par[124];
                  logP40F2  <- par[125];
                  logP41F2  <- par[126];
                  logP42F2  <- par[127];
                  logP43F2  <- par[128];
                  logP44F2  <- par[129];
                  logP45F2  <- par[130];
                  logP46F2  <- par[131];
                  logP47F2  <- par[132];
                  logP48F2  <- par[133];
                  logP49F2  <- par[134];
                  logP50F2  <- par[135];
                  logP51F2  <- par[136];
                  logP52F2  <- par[137];
                  logP53F2  <- par[138];
                  logP54F2  <- par[139];
                  logP55F2  <- par[140];
                  logP56F2  <- par[141];
                  logP57F2  <- par[142];
                  logP58F2  <- par[143];
                  logP59F2  <- par[144];
                  logP60F2  <- par[145];
                  logP61F2  <- par[146];
                  logP62F2  <- par[147];
                  logP63F2  <- par[148];
                  logP64F2  <- par[149];
                  logP65F2  <- par[150];
                  logP66F2  <- par[151];
                  logP67F2  <- par[152];
                  logP68F2  <- par[153];
                  logP69F2  <- par[154];
                  logP70F2  <- par[155];
                  logP71F2  <- par[156];
                  logP72F2  <- par[157];
                  logP73F2  <- par[158];
                  logP74F2  <- par[159];
                  logP75F2  <- par[160];
                  logP76F2  <- par[161];
                  logP77F2  <- par[162];
                  logP78F2  <- par[163];
                  logP79F2  <- par[164];
                  logP80F2  <- par[165];
                  logscale2 <- par[166];
                  logalpha2 <- par[167];
                  logbeta2  <- par[168];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN81P81P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(81,81))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts2.P1    <- dates[83];
                  ts2.P2    <- dates[84];
                  ts2.P3    <- dates[85];
                  ts2.P4    <- dates[86];
                  ts2.P5    <- dates[87];
                  ts2.P6    <- dates[88];
                  ts2.P7    <- dates[89];
                  ts2.P8    <- dates[90];
                  ts2.P9    <- dates[91];
                  ts2.P10   <- dates[92];
                  ts2.P11   <- dates[93];
                  ts2.P12   <- dates[94];
                  ts2.P13   <- dates[95];
                  ts2.P14   <- dates[96];
                  ts2.P15   <- dates[97];
                  ts2.P16   <- dates[98];
                  ts2.P17   <- dates[99];
                  ts2.P18   <- dates[100];
                  ts2.P19   <- dates[101];
                  ts2.P20   <- dates[102];
                  ts2.P21   <- dates[103];
                  ts2.P22   <- dates[104];
                  ts2.P23   <- dates[105];
                  ts2.P24   <- dates[106];
                  ts2.P25   <- dates[107];
                  ts2.P26   <- dates[108];
                  ts2.P27   <- dates[109];
                  ts2.P28   <- dates[110];
                  ts2.P29   <- dates[111];
                  ts2.P30   <- dates[112];
                  ts2.P31   <- dates[113];
                  ts2.P32   <- dates[114];
                  ts2.P33   <- dates[115];
                  ts2.P34   <- dates[116];
                  ts2.P35   <- dates[117];
                  ts2.P36   <- dates[118];
                  ts2.P37   <- dates[119];
                  ts2.P38   <- dates[120];
                  ts2.P39   <- dates[121];
                  ts2.P40   <- dates[122];
                  ts2.P41   <- dates[123];
                  ts2.P42   <- dates[124];
                  ts2.P43   <- dates[125];
                  ts2.P44   <- dates[126];
                  ts2.P45   <- dates[127];
                  ts2.P46   <- dates[128];
                  ts2.P47   <- dates[129];
                  ts2.P48   <- dates[130];
                  ts2.P49   <- dates[131];
                  ts2.P50   <- dates[132];
                  ts2.P51   <- dates[133];
                  ts2.P52   <- dates[134];
                  ts2.P53   <- dates[135];
                  ts2.P54   <- dates[136];
                  ts2.P55   <- dates[137];
                  ts2.P56   <- dates[138];
                  ts2.P57   <- dates[139];
                  ts2.P58   <- dates[140];
                  ts2.P59   <- dates[141];
                  ts2.P60   <- dates[142];
                  ts2.P61   <- dates[143];
                  ts2.P62   <- dates[144];
                  ts2.P63   <- dates[145];
                  ts2.P64   <- dates[146];
                  ts2.P65   <- dates[147];
                  ts2.P66   <- dates[148];
                  ts2.P67   <- dates[149];
                  ts2.P68   <- dates[150];
                  ts2.P69   <- dates[151];
                  ts2.P70   <- dates[152];
                  ts2.P71   <- dates[153];
                  ts2.P72   <- dates[154];
                  ts2.P73   <- dates[155];
                  ts2.P74   <- dates[156];
                  ts2.P75   <- dates[157];
                  ts2.P76   <- dates[158];
                  ts2.P77   <- dates[159];
                  ts2.P78   <- dates[160];
                  ts2.P79   <- dates[161];
                  ts2.P80   <- dates[162];
                  ts2.P81   <- dates[163];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logscale1 <- par[84];
                  logalpha1 <- par[85];
                  logbeta1  <- par[86];
                  logP1F2   <- par[87];
                  logP2F2   <- par[88];
                  logP3F2   <- par[89];
                  logP4F2   <- par[90];
                  logP5F2   <- par[91];
                  logP6F2   <- par[92];
                  logP7F2   <- par[93];
                  logP8F2   <- par[94];
                  logP9F2   <- par[95];
                  logP10F2  <- par[96];
                  logP11F2  <- par[97];
                  logP12F2  <- par[98];
                  logP13F2  <- par[99];
                  logP14F2  <- par[100];
                  logP15F2  <- par[101];
                  logP16F2  <- par[102];
                  logP17F2  <- par[103];
                  logP18F2  <- par[104];
                  logP19F2  <- par[105];
                  logP20F2  <- par[106];
                  logP21F2  <- par[107];
                  logP22F2  <- par[108];
                  logP23F2  <- par[109];
                  logP24F2  <- par[110];
                  logP25F2  <- par[111];
                  logP26F2  <- par[112];
                  logP27F2  <- par[113];
                  logP28F2  <- par[114];
                  logP29F2  <- par[115];
                  logP30F2  <- par[116];
                  logP31F2  <- par[117];
                  logP32F2  <- par[118];
                  logP33F2  <- par[119];
                  logP34F2  <- par[120];
                  logP35F2  <- par[121];
                  logP36F2  <- par[122];
                  logP37F2  <- par[123];
                  logP38F2  <- par[124];
                  logP39F2  <- par[125];
                  logP40F2  <- par[126];
                  logP41F2  <- par[127];
                  logP42F2  <- par[128];
                  logP43F2  <- par[129];
                  logP44F2  <- par[130];
                  logP45F2  <- par[131];
                  logP46F2  <- par[132];
                  logP47F2  <- par[133];
                  logP48F2  <- par[134];
                  logP49F2  <- par[135];
                  logP50F2  <- par[136];
                  logP51F2  <- par[137];
                  logP52F2  <- par[138];
                  logP53F2  <- par[139];
                  logP54F2  <- par[140];
                  logP55F2  <- par[141];
                  logP56F2  <- par[142];
                  logP57F2  <- par[143];
                  logP58F2  <- par[144];
                  logP59F2  <- par[145];
                  logP60F2  <- par[146];
                  logP61F2  <- par[147];
                  logP62F2  <- par[148];
                  logP63F2  <- par[149];
                  logP64F2  <- par[150];
                  logP65F2  <- par[151];
                  logP66F2  <- par[152];
                  logP67F2  <- par[153];
                  logP68F2  <- par[154];
                  logP69F2  <- par[155];
                  logP70F2  <- par[156];
                  logP71F2  <- par[157];
                  logP72F2  <- par[158];
                  logP73F2  <- par[159];
                  logP74F2  <- par[160];
                  logP75F2  <- par[161];
                  logP76F2  <- par[162];
                  logP77F2  <- par[163];
                  logP78F2  <- par[164];
                  logP79F2  <- par[165];
                  logP80F2  <- par[166];
                  logP81F2  <- par[167];
                  logscale2 <- par[168];
                  logalpha2 <- par[169];
                  logbeta2  <- par[170];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN82P82P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(82,82))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts2.P1    <- dates[84];
                  ts2.P2    <- dates[85];
                  ts2.P3    <- dates[86];
                  ts2.P4    <- dates[87];
                  ts2.P5    <- dates[88];
                  ts2.P6    <- dates[89];
                  ts2.P7    <- dates[90];
                  ts2.P8    <- dates[91];
                  ts2.P9    <- dates[92];
                  ts2.P10   <- dates[93];
                  ts2.P11   <- dates[94];
                  ts2.P12   <- dates[95];
                  ts2.P13   <- dates[96];
                  ts2.P14   <- dates[97];
                  ts2.P15   <- dates[98];
                  ts2.P16   <- dates[99];
                  ts2.P17   <- dates[100];
                  ts2.P18   <- dates[101];
                  ts2.P19   <- dates[102];
                  ts2.P20   <- dates[103];
                  ts2.P21   <- dates[104];
                  ts2.P22   <- dates[105];
                  ts2.P23   <- dates[106];
                  ts2.P24   <- dates[107];
                  ts2.P25   <- dates[108];
                  ts2.P26   <- dates[109];
                  ts2.P27   <- dates[110];
                  ts2.P28   <- dates[111];
                  ts2.P29   <- dates[112];
                  ts2.P30   <- dates[113];
                  ts2.P31   <- dates[114];
                  ts2.P32   <- dates[115];
                  ts2.P33   <- dates[116];
                  ts2.P34   <- dates[117];
                  ts2.P35   <- dates[118];
                  ts2.P36   <- dates[119];
                  ts2.P37   <- dates[120];
                  ts2.P38   <- dates[121];
                  ts2.P39   <- dates[122];
                  ts2.P40   <- dates[123];
                  ts2.P41   <- dates[124];
                  ts2.P42   <- dates[125];
                  ts2.P43   <- dates[126];
                  ts2.P44   <- dates[127];
                  ts2.P45   <- dates[128];
                  ts2.P46   <- dates[129];
                  ts2.P47   <- dates[130];
                  ts2.P48   <- dates[131];
                  ts2.P49   <- dates[132];
                  ts2.P50   <- dates[133];
                  ts2.P51   <- dates[134];
                  ts2.P52   <- dates[135];
                  ts2.P53   <- dates[136];
                  ts2.P54   <- dates[137];
                  ts2.P55   <- dates[138];
                  ts2.P56   <- dates[139];
                  ts2.P57   <- dates[140];
                  ts2.P58   <- dates[141];
                  ts2.P59   <- dates[142];
                  ts2.P60   <- dates[143];
                  ts2.P61   <- dates[144];
                  ts2.P62   <- dates[145];
                  ts2.P63   <- dates[146];
                  ts2.P64   <- dates[147];
                  ts2.P65   <- dates[148];
                  ts2.P66   <- dates[149];
                  ts2.P67   <- dates[150];
                  ts2.P68   <- dates[151];
                  ts2.P69   <- dates[152];
                  ts2.P70   <- dates[153];
                  ts2.P71   <- dates[154];
                  ts2.P72   <- dates[155];
                  ts2.P73   <- dates[156];
                  ts2.P74   <- dates[157];
                  ts2.P75   <- dates[158];
                  ts2.P76   <- dates[159];
                  ts2.P77   <- dates[160];
                  ts2.P78   <- dates[161];
                  ts2.P79   <- dates[162];
                  ts2.P80   <- dates[163];
                  ts2.P81   <- dates[164];
                  ts2.P82   <- dates[165];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logscale1 <- par[85];
                  logalpha1 <- par[86];
                  logbeta1  <- par[87];
                  logP1F2   <- par[88];
                  logP2F2   <- par[89];
                  logP3F2   <- par[90];
                  logP4F2   <- par[91];
                  logP5F2   <- par[92];
                  logP6F2   <- par[93];
                  logP7F2   <- par[94];
                  logP8F2   <- par[95];
                  logP9F2   <- par[96];
                  logP10F2  <- par[97];
                  logP11F2  <- par[98];
                  logP12F2  <- par[99];
                  logP13F2  <- par[100];
                  logP14F2  <- par[101];
                  logP15F2  <- par[102];
                  logP16F2  <- par[103];
                  logP17F2  <- par[104];
                  logP18F2  <- par[105];
                  logP19F2  <- par[106];
                  logP20F2  <- par[107];
                  logP21F2  <- par[108];
                  logP22F2  <- par[109];
                  logP23F2  <- par[110];
                  logP24F2  <- par[111];
                  logP25F2  <- par[112];
                  logP26F2  <- par[113];
                  logP27F2  <- par[114];
                  logP28F2  <- par[115];
                  logP29F2  <- par[116];
                  logP30F2  <- par[117];
                  logP31F2  <- par[118];
                  logP32F2  <- par[119];
                  logP33F2  <- par[120];
                  logP34F2  <- par[121];
                  logP35F2  <- par[122];
                  logP36F2  <- par[123];
                  logP37F2  <- par[124];
                  logP38F2  <- par[125];
                  logP39F2  <- par[126];
                  logP40F2  <- par[127];
                  logP41F2  <- par[128];
                  logP42F2  <- par[129];
                  logP43F2  <- par[130];
                  logP44F2  <- par[131];
                  logP45F2  <- par[132];
                  logP46F2  <- par[133];
                  logP47F2  <- par[134];
                  logP48F2  <- par[135];
                  logP49F2  <- par[136];
                  logP50F2  <- par[137];
                  logP51F2  <- par[138];
                  logP52F2  <- par[139];
                  logP53F2  <- par[140];
                  logP54F2  <- par[141];
                  logP55F2  <- par[142];
                  logP56F2  <- par[143];
                  logP57F2  <- par[144];
                  logP58F2  <- par[145];
                  logP59F2  <- par[146];
                  logP60F2  <- par[147];
                  logP61F2  <- par[148];
                  logP62F2  <- par[149];
                  logP63F2  <- par[150];
                  logP64F2  <- par[151];
                  logP65F2  <- par[152];
                  logP66F2  <- par[153];
                  logP67F2  <- par[154];
                  logP68F2  <- par[155];
                  logP69F2  <- par[156];
                  logP70F2  <- par[157];
                  logP71F2  <- par[158];
                  logP72F2  <- par[159];
                  logP73F2  <- par[160];
                  logP74F2  <- par[161];
                  logP75F2  <- par[162];
                  logP76F2  <- par[163];
                  logP77F2  <- par[164];
                  logP78F2  <- par[165];
                  logP79F2  <- par[166];
                  logP80F2  <- par[167];
                  logP81F2  <- par[168];
                  logP82F2  <- par[169];
                  logscale2 <- par[170];
                  logalpha2 <- par[171];
                  logbeta2  <- par[172];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN83P83P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(83,83))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts2.P1    <- dates[85];
                  ts2.P2    <- dates[86];
                  ts2.P3    <- dates[87];
                  ts2.P4    <- dates[88];
                  ts2.P5    <- dates[89];
                  ts2.P6    <- dates[90];
                  ts2.P7    <- dates[91];
                  ts2.P8    <- dates[92];
                  ts2.P9    <- dates[93];
                  ts2.P10   <- dates[94];
                  ts2.P11   <- dates[95];
                  ts2.P12   <- dates[96];
                  ts2.P13   <- dates[97];
                  ts2.P14   <- dates[98];
                  ts2.P15   <- dates[99];
                  ts2.P16   <- dates[100];
                  ts2.P17   <- dates[101];
                  ts2.P18   <- dates[102];
                  ts2.P19   <- dates[103];
                  ts2.P20   <- dates[104];
                  ts2.P21   <- dates[105];
                  ts2.P22   <- dates[106];
                  ts2.P23   <- dates[107];
                  ts2.P24   <- dates[108];
                  ts2.P25   <- dates[109];
                  ts2.P26   <- dates[110];
                  ts2.P27   <- dates[111];
                  ts2.P28   <- dates[112];
                  ts2.P29   <- dates[113];
                  ts2.P30   <- dates[114];
                  ts2.P31   <- dates[115];
                  ts2.P32   <- dates[116];
                  ts2.P33   <- dates[117];
                  ts2.P34   <- dates[118];
                  ts2.P35   <- dates[119];
                  ts2.P36   <- dates[120];
                  ts2.P37   <- dates[121];
                  ts2.P38   <- dates[122];
                  ts2.P39   <- dates[123];
                  ts2.P40   <- dates[124];
                  ts2.P41   <- dates[125];
                  ts2.P42   <- dates[126];
                  ts2.P43   <- dates[127];
                  ts2.P44   <- dates[128];
                  ts2.P45   <- dates[129];
                  ts2.P46   <- dates[130];
                  ts2.P47   <- dates[131];
                  ts2.P48   <- dates[132];
                  ts2.P49   <- dates[133];
                  ts2.P50   <- dates[134];
                  ts2.P51   <- dates[135];
                  ts2.P52   <- dates[136];
                  ts2.P53   <- dates[137];
                  ts2.P54   <- dates[138];
                  ts2.P55   <- dates[139];
                  ts2.P56   <- dates[140];
                  ts2.P57   <- dates[141];
                  ts2.P58   <- dates[142];
                  ts2.P59   <- dates[143];
                  ts2.P60   <- dates[144];
                  ts2.P61   <- dates[145];
                  ts2.P62   <- dates[146];
                  ts2.P63   <- dates[147];
                  ts2.P64   <- dates[148];
                  ts2.P65   <- dates[149];
                  ts2.P66   <- dates[150];
                  ts2.P67   <- dates[151];
                  ts2.P68   <- dates[152];
                  ts2.P69   <- dates[153];
                  ts2.P70   <- dates[154];
                  ts2.P71   <- dates[155];
                  ts2.P72   <- dates[156];
                  ts2.P73   <- dates[157];
                  ts2.P74   <- dates[158];
                  ts2.P75   <- dates[159];
                  ts2.P76   <- dates[160];
                  ts2.P77   <- dates[161];
                  ts2.P78   <- dates[162];
                  ts2.P79   <- dates[163];
                  ts2.P80   <- dates[164];
                  ts2.P81   <- dates[165];
                  ts2.P82   <- dates[166];
                  ts2.P83   <- dates[167];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logscale1 <- par[86];
                  logalpha1 <- par[87];
                  logbeta1  <- par[88];
                  logP1F2   <- par[89];
                  logP2F2   <- par[90];
                  logP3F2   <- par[91];
                  logP4F2   <- par[92];
                  logP5F2   <- par[93];
                  logP6F2   <- par[94];
                  logP7F2   <- par[95];
                  logP8F2   <- par[96];
                  logP9F2   <- par[97];
                  logP10F2  <- par[98];
                  logP11F2  <- par[99];
                  logP12F2  <- par[100];
                  logP13F2  <- par[101];
                  logP14F2  <- par[102];
                  logP15F2  <- par[103];
                  logP16F2  <- par[104];
                  logP17F2  <- par[105];
                  logP18F2  <- par[106];
                  logP19F2  <- par[107];
                  logP20F2  <- par[108];
                  logP21F2  <- par[109];
                  logP22F2  <- par[110];
                  logP23F2  <- par[111];
                  logP24F2  <- par[112];
                  logP25F2  <- par[113];
                  logP26F2  <- par[114];
                  logP27F2  <- par[115];
                  logP28F2  <- par[116];
                  logP29F2  <- par[117];
                  logP30F2  <- par[118];
                  logP31F2  <- par[119];
                  logP32F2  <- par[120];
                  logP33F2  <- par[121];
                  logP34F2  <- par[122];
                  logP35F2  <- par[123];
                  logP36F2  <- par[124];
                  logP37F2  <- par[125];
                  logP38F2  <- par[126];
                  logP39F2  <- par[127];
                  logP40F2  <- par[128];
                  logP41F2  <- par[129];
                  logP42F2  <- par[130];
                  logP43F2  <- par[131];
                  logP44F2  <- par[132];
                  logP45F2  <- par[133];
                  logP46F2  <- par[134];
                  logP47F2  <- par[135];
                  logP48F2  <- par[136];
                  logP49F2  <- par[137];
                  logP50F2  <- par[138];
                  logP51F2  <- par[139];
                  logP52F2  <- par[140];
                  logP53F2  <- par[141];
                  logP54F2  <- par[142];
                  logP55F2  <- par[143];
                  logP56F2  <- par[144];
                  logP57F2  <- par[145];
                  logP58F2  <- par[146];
                  logP59F2  <- par[147];
                  logP60F2  <- par[148];
                  logP61F2  <- par[149];
                  logP62F2  <- par[150];
                  logP63F2  <- par[151];
                  logP64F2  <- par[152];
                  logP65F2  <- par[153];
                  logP66F2  <- par[154];
                  logP67F2  <- par[155];
                  logP68F2  <- par[156];
                  logP69F2  <- par[157];
                  logP70F2  <- par[158];
                  logP71F2  <- par[159];
                  logP72F2  <- par[160];
                  logP73F2  <- par[161];
                  logP74F2  <- par[162];
                  logP75F2  <- par[163];
                  logP76F2  <- par[164];
                  logP77F2  <- par[165];
                  logP78F2  <- par[166];
                  logP79F2  <- par[167];
                  logP80F2  <- par[168];
                  logP81F2  <- par[169];
                  logP82F2  <- par[170];
                  logP83F2  <- par[171];
                  logscale2 <- par[172];
                  logalpha2 <- par[173];
                  logbeta2  <- par[174];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN84P84P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(84,84))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts2.P1    <- dates[86];
                  ts2.P2    <- dates[87];
                  ts2.P3    <- dates[88];
                  ts2.P4    <- dates[89];
                  ts2.P5    <- dates[90];
                  ts2.P6    <- dates[91];
                  ts2.P7    <- dates[92];
                  ts2.P8    <- dates[93];
                  ts2.P9    <- dates[94];
                  ts2.P10   <- dates[95];
                  ts2.P11   <- dates[96];
                  ts2.P12   <- dates[97];
                  ts2.P13   <- dates[98];
                  ts2.P14   <- dates[99];
                  ts2.P15   <- dates[100];
                  ts2.P16   <- dates[101];
                  ts2.P17   <- dates[102];
                  ts2.P18   <- dates[103];
                  ts2.P19   <- dates[104];
                  ts2.P20   <- dates[105];
                  ts2.P21   <- dates[106];
                  ts2.P22   <- dates[107];
                  ts2.P23   <- dates[108];
                  ts2.P24   <- dates[109];
                  ts2.P25   <- dates[110];
                  ts2.P26   <- dates[111];
                  ts2.P27   <- dates[112];
                  ts2.P28   <- dates[113];
                  ts2.P29   <- dates[114];
                  ts2.P30   <- dates[115];
                  ts2.P31   <- dates[116];
                  ts2.P32   <- dates[117];
                  ts2.P33   <- dates[118];
                  ts2.P34   <- dates[119];
                  ts2.P35   <- dates[120];
                  ts2.P36   <- dates[121];
                  ts2.P37   <- dates[122];
                  ts2.P38   <- dates[123];
                  ts2.P39   <- dates[124];
                  ts2.P40   <- dates[125];
                  ts2.P41   <- dates[126];
                  ts2.P42   <- dates[127];
                  ts2.P43   <- dates[128];
                  ts2.P44   <- dates[129];
                  ts2.P45   <- dates[130];
                  ts2.P46   <- dates[131];
                  ts2.P47   <- dates[132];
                  ts2.P48   <- dates[133];
                  ts2.P49   <- dates[134];
                  ts2.P50   <- dates[135];
                  ts2.P51   <- dates[136];
                  ts2.P52   <- dates[137];
                  ts2.P53   <- dates[138];
                  ts2.P54   <- dates[139];
                  ts2.P55   <- dates[140];
                  ts2.P56   <- dates[141];
                  ts2.P57   <- dates[142];
                  ts2.P58   <- dates[143];
                  ts2.P59   <- dates[144];
                  ts2.P60   <- dates[145];
                  ts2.P61   <- dates[146];
                  ts2.P62   <- dates[147];
                  ts2.P63   <- dates[148];
                  ts2.P64   <- dates[149];
                  ts2.P65   <- dates[150];
                  ts2.P66   <- dates[151];
                  ts2.P67   <- dates[152];
                  ts2.P68   <- dates[153];
                  ts2.P69   <- dates[154];
                  ts2.P70   <- dates[155];
                  ts2.P71   <- dates[156];
                  ts2.P72   <- dates[157];
                  ts2.P73   <- dates[158];
                  ts2.P74   <- dates[159];
                  ts2.P75   <- dates[160];
                  ts2.P76   <- dates[161];
                  ts2.P77   <- dates[162];
                  ts2.P78   <- dates[163];
                  ts2.P79   <- dates[164];
                  ts2.P80   <- dates[165];
                  ts2.P81   <- dates[166];
                  ts2.P82   <- dates[167];
                  ts2.P83   <- dates[168];
                  ts2.P84   <- dates[169];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logscale1 <- par[87];
                  logalpha1 <- par[88];
                  logbeta1  <- par[89];
                  logP1F2   <- par[90];
                  logP2F2   <- par[91];
                  logP3F2   <- par[92];
                  logP4F2   <- par[93];
                  logP5F2   <- par[94];
                  logP6F2   <- par[95];
                  logP7F2   <- par[96];
                  logP8F2   <- par[97];
                  logP9F2   <- par[98];
                  logP10F2  <- par[99];
                  logP11F2  <- par[100];
                  logP12F2  <- par[101];
                  logP13F2  <- par[102];
                  logP14F2  <- par[103];
                  logP15F2  <- par[104];
                  logP16F2  <- par[105];
                  logP17F2  <- par[106];
                  logP18F2  <- par[107];
                  logP19F2  <- par[108];
                  logP20F2  <- par[109];
                  logP21F2  <- par[110];
                  logP22F2  <- par[111];
                  logP23F2  <- par[112];
                  logP24F2  <- par[113];
                  logP25F2  <- par[114];
                  logP26F2  <- par[115];
                  logP27F2  <- par[116];
                  logP28F2  <- par[117];
                  logP29F2  <- par[118];
                  logP30F2  <- par[119];
                  logP31F2  <- par[120];
                  logP32F2  <- par[121];
                  logP33F2  <- par[122];
                  logP34F2  <- par[123];
                  logP35F2  <- par[124];
                  logP36F2  <- par[125];
                  logP37F2  <- par[126];
                  logP38F2  <- par[127];
                  logP39F2  <- par[128];
                  logP40F2  <- par[129];
                  logP41F2  <- par[130];
                  logP42F2  <- par[131];
                  logP43F2  <- par[132];
                  logP44F2  <- par[133];
                  logP45F2  <- par[134];
                  logP46F2  <- par[135];
                  logP47F2  <- par[136];
                  logP48F2  <- par[137];
                  logP49F2  <- par[138];
                  logP50F2  <- par[139];
                  logP51F2  <- par[140];
                  logP52F2  <- par[141];
                  logP53F2  <- par[142];
                  logP54F2  <- par[143];
                  logP55F2  <- par[144];
                  logP56F2  <- par[145];
                  logP57F2  <- par[146];
                  logP58F2  <- par[147];
                  logP59F2  <- par[148];
                  logP60F2  <- par[149];
                  logP61F2  <- par[150];
                  logP62F2  <- par[151];
                  logP63F2  <- par[152];
                  logP64F2  <- par[153];
                  logP65F2  <- par[154];
                  logP66F2  <- par[155];
                  logP67F2  <- par[156];
                  logP68F2  <- par[157];
                  logP69F2  <- par[158];
                  logP70F2  <- par[159];
                  logP71F2  <- par[160];
                  logP72F2  <- par[161];
                  logP73F2  <- par[162];
                  logP74F2  <- par[163];
                  logP75F2  <- par[164];
                  logP76F2  <- par[165];
                  logP77F2  <- par[166];
                  logP78F2  <- par[167];
                  logP79F2  <- par[168];
                  logP80F2  <- par[169];
                  logP81F2  <- par[170];
                  logP82F2  <- par[171];
                  logP83F2  <- par[172];
                  logP84F2  <- par[173];
                  logscale2 <- par[174];
                  logalpha2 <- par[175];
                  logbeta2  <- par[176];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN85P85P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(85,85))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts2.P1    <- dates[87];
                  ts2.P2    <- dates[88];
                  ts2.P3    <- dates[89];
                  ts2.P4    <- dates[90];
                  ts2.P5    <- dates[91];
                  ts2.P6    <- dates[92];
                  ts2.P7    <- dates[93];
                  ts2.P8    <- dates[94];
                  ts2.P9    <- dates[95];
                  ts2.P10   <- dates[96];
                  ts2.P11   <- dates[97];
                  ts2.P12   <- dates[98];
                  ts2.P13   <- dates[99];
                  ts2.P14   <- dates[100];
                  ts2.P15   <- dates[101];
                  ts2.P16   <- dates[102];
                  ts2.P17   <- dates[103];
                  ts2.P18   <- dates[104];
                  ts2.P19   <- dates[105];
                  ts2.P20   <- dates[106];
                  ts2.P21   <- dates[107];
                  ts2.P22   <- dates[108];
                  ts2.P23   <- dates[109];
                  ts2.P24   <- dates[110];
                  ts2.P25   <- dates[111];
                  ts2.P26   <- dates[112];
                  ts2.P27   <- dates[113];
                  ts2.P28   <- dates[114];
                  ts2.P29   <- dates[115];
                  ts2.P30   <- dates[116];
                  ts2.P31   <- dates[117];
                  ts2.P32   <- dates[118];
                  ts2.P33   <- dates[119];
                  ts2.P34   <- dates[120];
                  ts2.P35   <- dates[121];
                  ts2.P36   <- dates[122];
                  ts2.P37   <- dates[123];
                  ts2.P38   <- dates[124];
                  ts2.P39   <- dates[125];
                  ts2.P40   <- dates[126];
                  ts2.P41   <- dates[127];
                  ts2.P42   <- dates[128];
                  ts2.P43   <- dates[129];
                  ts2.P44   <- dates[130];
                  ts2.P45   <- dates[131];
                  ts2.P46   <- dates[132];
                  ts2.P47   <- dates[133];
                  ts2.P48   <- dates[134];
                  ts2.P49   <- dates[135];
                  ts2.P50   <- dates[136];
                  ts2.P51   <- dates[137];
                  ts2.P52   <- dates[138];
                  ts2.P53   <- dates[139];
                  ts2.P54   <- dates[140];
                  ts2.P55   <- dates[141];
                  ts2.P56   <- dates[142];
                  ts2.P57   <- dates[143];
                  ts2.P58   <- dates[144];
                  ts2.P59   <- dates[145];
                  ts2.P60   <- dates[146];
                  ts2.P61   <- dates[147];
                  ts2.P62   <- dates[148];
                  ts2.P63   <- dates[149];
                  ts2.P64   <- dates[150];
                  ts2.P65   <- dates[151];
                  ts2.P66   <- dates[152];
                  ts2.P67   <- dates[153];
                  ts2.P68   <- dates[154];
                  ts2.P69   <- dates[155];
                  ts2.P70   <- dates[156];
                  ts2.P71   <- dates[157];
                  ts2.P72   <- dates[158];
                  ts2.P73   <- dates[159];
                  ts2.P74   <- dates[160];
                  ts2.P75   <- dates[161];
                  ts2.P76   <- dates[162];
                  ts2.P77   <- dates[163];
                  ts2.P78   <- dates[164];
                  ts2.P79   <- dates[165];
                  ts2.P80   <- dates[166];
                  ts2.P81   <- dates[167];
                  ts2.P82   <- dates[168];
                  ts2.P83   <- dates[169];
                  ts2.P84   <- dates[170];
                  ts2.P85   <- dates[171];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logscale1 <- par[88];
                  logalpha1 <- par[89];
                  logbeta1  <- par[90];
                  logP1F2   <- par[91];
                  logP2F2   <- par[92];
                  logP3F2   <- par[93];
                  logP4F2   <- par[94];
                  logP5F2   <- par[95];
                  logP6F2   <- par[96];
                  logP7F2   <- par[97];
                  logP8F2   <- par[98];
                  logP9F2   <- par[99];
                  logP10F2  <- par[100];
                  logP11F2  <- par[101];
                  logP12F2  <- par[102];
                  logP13F2  <- par[103];
                  logP14F2  <- par[104];
                  logP15F2  <- par[105];
                  logP16F2  <- par[106];
                  logP17F2  <- par[107];
                  logP18F2  <- par[108];
                  logP19F2  <- par[109];
                  logP20F2  <- par[110];
                  logP21F2  <- par[111];
                  logP22F2  <- par[112];
                  logP23F2  <- par[113];
                  logP24F2  <- par[114];
                  logP25F2  <- par[115];
                  logP26F2  <- par[116];
                  logP27F2  <- par[117];
                  logP28F2  <- par[118];
                  logP29F2  <- par[119];
                  logP30F2  <- par[120];
                  logP31F2  <- par[121];
                  logP32F2  <- par[122];
                  logP33F2  <- par[123];
                  logP34F2  <- par[124];
                  logP35F2  <- par[125];
                  logP36F2  <- par[126];
                  logP37F2  <- par[127];
                  logP38F2  <- par[128];
                  logP39F2  <- par[129];
                  logP40F2  <- par[130];
                  logP41F2  <- par[131];
                  logP42F2  <- par[132];
                  logP43F2  <- par[133];
                  logP44F2  <- par[134];
                  logP45F2  <- par[135];
                  logP46F2  <- par[136];
                  logP47F2  <- par[137];
                  logP48F2  <- par[138];
                  logP49F2  <- par[139];
                  logP50F2  <- par[140];
                  logP51F2  <- par[141];
                  logP52F2  <- par[142];
                  logP53F2  <- par[143];
                  logP54F2  <- par[144];
                  logP55F2  <- par[145];
                  logP56F2  <- par[146];
                  logP57F2  <- par[147];
                  logP58F2  <- par[148];
                  logP59F2  <- par[149];
                  logP60F2  <- par[150];
                  logP61F2  <- par[151];
                  logP62F2  <- par[152];
                  logP63F2  <- par[153];
                  logP64F2  <- par[154];
                  logP65F2  <- par[155];
                  logP66F2  <- par[156];
                  logP67F2  <- par[157];
                  logP68F2  <- par[158];
                  logP69F2  <- par[159];
                  logP70F2  <- par[160];
                  logP71F2  <- par[161];
                  logP72F2  <- par[162];
                  logP73F2  <- par[163];
                  logP74F2  <- par[164];
                  logP75F2  <- par[165];
                  logP76F2  <- par[166];
                  logP77F2  <- par[167];
                  logP78F2  <- par[168];
                  logP79F2  <- par[169];
                  logP80F2  <- par[170];
                  logP81F2  <- par[171];
                  logP82F2  <- par[172];
                  logP83F2  <- par[173];
                  logP84F2  <- par[174];
                  logP85F2  <- par[175];
                  logscale2 <- par[176];
                  logalpha2 <- par[177];
                  logbeta2  <- par[178];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN86P86P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(86,86))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts2.P1    <- dates[88];
                  ts2.P2    <- dates[89];
                  ts2.P3    <- dates[90];
                  ts2.P4    <- dates[91];
                  ts2.P5    <- dates[92];
                  ts2.P6    <- dates[93];
                  ts2.P7    <- dates[94];
                  ts2.P8    <- dates[95];
                  ts2.P9    <- dates[96];
                  ts2.P10   <- dates[97];
                  ts2.P11   <- dates[98];
                  ts2.P12   <- dates[99];
                  ts2.P13   <- dates[100];
                  ts2.P14   <- dates[101];
                  ts2.P15   <- dates[102];
                  ts2.P16   <- dates[103];
                  ts2.P17   <- dates[104];
                  ts2.P18   <- dates[105];
                  ts2.P19   <- dates[106];
                  ts2.P20   <- dates[107];
                  ts2.P21   <- dates[108];
                  ts2.P22   <- dates[109];
                  ts2.P23   <- dates[110];
                  ts2.P24   <- dates[111];
                  ts2.P25   <- dates[112];
                  ts2.P26   <- dates[113];
                  ts2.P27   <- dates[114];
                  ts2.P28   <- dates[115];
                  ts2.P29   <- dates[116];
                  ts2.P30   <- dates[117];
                  ts2.P31   <- dates[118];
                  ts2.P32   <- dates[119];
                  ts2.P33   <- dates[120];
                  ts2.P34   <- dates[121];
                  ts2.P35   <- dates[122];
                  ts2.P36   <- dates[123];
                  ts2.P37   <- dates[124];
                  ts2.P38   <- dates[125];
                  ts2.P39   <- dates[126];
                  ts2.P40   <- dates[127];
                  ts2.P41   <- dates[128];
                  ts2.P42   <- dates[129];
                  ts2.P43   <- dates[130];
                  ts2.P44   <- dates[131];
                  ts2.P45   <- dates[132];
                  ts2.P46   <- dates[133];
                  ts2.P47   <- dates[134];
                  ts2.P48   <- dates[135];
                  ts2.P49   <- dates[136];
                  ts2.P50   <- dates[137];
                  ts2.P51   <- dates[138];
                  ts2.P52   <- dates[139];
                  ts2.P53   <- dates[140];
                  ts2.P54   <- dates[141];
                  ts2.P55   <- dates[142];
                  ts2.P56   <- dates[143];
                  ts2.P57   <- dates[144];
                  ts2.P58   <- dates[145];
                  ts2.P59   <- dates[146];
                  ts2.P60   <- dates[147];
                  ts2.P61   <- dates[148];
                  ts2.P62   <- dates[149];
                  ts2.P63   <- dates[150];
                  ts2.P64   <- dates[151];
                  ts2.P65   <- dates[152];
                  ts2.P66   <- dates[153];
                  ts2.P67   <- dates[154];
                  ts2.P68   <- dates[155];
                  ts2.P69   <- dates[156];
                  ts2.P70   <- dates[157];
                  ts2.P71   <- dates[158];
                  ts2.P72   <- dates[159];
                  ts2.P73   <- dates[160];
                  ts2.P74   <- dates[161];
                  ts2.P75   <- dates[162];
                  ts2.P76   <- dates[163];
                  ts2.P77   <- dates[164];
                  ts2.P78   <- dates[165];
                  ts2.P79   <- dates[166];
                  ts2.P80   <- dates[167];
                  ts2.P81   <- dates[168];
                  ts2.P82   <- dates[169];
                  ts2.P83   <- dates[170];
                  ts2.P84   <- dates[171];
                  ts2.P85   <- dates[172];
                  ts2.P86   <- dates[173];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logscale1 <- par[89];
                  logalpha1 <- par[90];
                  logbeta1  <- par[91];
                  logP1F2   <- par[92];
                  logP2F2   <- par[93];
                  logP3F2   <- par[94];
                  logP4F2   <- par[95];
                  logP5F2   <- par[96];
                  logP6F2   <- par[97];
                  logP7F2   <- par[98];
                  logP8F2   <- par[99];
                  logP9F2   <- par[100];
                  logP10F2  <- par[101];
                  logP11F2  <- par[102];
                  logP12F2  <- par[103];
                  logP13F2  <- par[104];
                  logP14F2  <- par[105];
                  logP15F2  <- par[106];
                  logP16F2  <- par[107];
                  logP17F2  <- par[108];
                  logP18F2  <- par[109];
                  logP19F2  <- par[110];
                  logP20F2  <- par[111];
                  logP21F2  <- par[112];
                  logP22F2  <- par[113];
                  logP23F2  <- par[114];
                  logP24F2  <- par[115];
                  logP25F2  <- par[116];
                  logP26F2  <- par[117];
                  logP27F2  <- par[118];
                  logP28F2  <- par[119];
                  logP29F2  <- par[120];
                  logP30F2  <- par[121];
                  logP31F2  <- par[122];
                  logP32F2  <- par[123];
                  logP33F2  <- par[124];
                  logP34F2  <- par[125];
                  logP35F2  <- par[126];
                  logP36F2  <- par[127];
                  logP37F2  <- par[128];
                  logP38F2  <- par[129];
                  logP39F2  <- par[130];
                  logP40F2  <- par[131];
                  logP41F2  <- par[132];
                  logP42F2  <- par[133];
                  logP43F2  <- par[134];
                  logP44F2  <- par[135];
                  logP45F2  <- par[136];
                  logP46F2  <- par[137];
                  logP47F2  <- par[138];
                  logP48F2  <- par[139];
                  logP49F2  <- par[140];
                  logP50F2  <- par[141];
                  logP51F2  <- par[142];
                  logP52F2  <- par[143];
                  logP53F2  <- par[144];
                  logP54F2  <- par[145];
                  logP55F2  <- par[146];
                  logP56F2  <- par[147];
                  logP57F2  <- par[148];
                  logP58F2  <- par[149];
                  logP59F2  <- par[150];
                  logP60F2  <- par[151];
                  logP61F2  <- par[152];
                  logP62F2  <- par[153];
                  logP63F2  <- par[154];
                  logP64F2  <- par[155];
                  logP65F2  <- par[156];
                  logP66F2  <- par[157];
                  logP67F2  <- par[158];
                  logP68F2  <- par[159];
                  logP69F2  <- par[160];
                  logP70F2  <- par[161];
                  logP71F2  <- par[162];
                  logP72F2  <- par[163];
                  logP73F2  <- par[164];
                  logP74F2  <- par[165];
                  logP75F2  <- par[166];
                  logP76F2  <- par[167];
                  logP77F2  <- par[168];
                  logP78F2  <- par[169];
                  logP79F2  <- par[170];
                  logP80F2  <- par[171];
                  logP81F2  <- par[172];
                  logP82F2  <- par[173];
                  logP83F2  <- par[174];
                  logP84F2  <- par[175];
                  logP85F2  <- par[176];
                  logP86F2  <- par[177];
                  logscale2 <- par[178];
                  logalpha2 <- par[179];
                  logbeta2  <- par[180];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN87P87P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(87,87))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts2.P1    <- dates[89];
                  ts2.P2    <- dates[90];
                  ts2.P3    <- dates[91];
                  ts2.P4    <- dates[92];
                  ts2.P5    <- dates[93];
                  ts2.P6    <- dates[94];
                  ts2.P7    <- dates[95];
                  ts2.P8    <- dates[96];
                  ts2.P9    <- dates[97];
                  ts2.P10   <- dates[98];
                  ts2.P11   <- dates[99];
                  ts2.P12   <- dates[100];
                  ts2.P13   <- dates[101];
                  ts2.P14   <- dates[102];
                  ts2.P15   <- dates[103];
                  ts2.P16   <- dates[104];
                  ts2.P17   <- dates[105];
                  ts2.P18   <- dates[106];
                  ts2.P19   <- dates[107];
                  ts2.P20   <- dates[108];
                  ts2.P21   <- dates[109];
                  ts2.P22   <- dates[110];
                  ts2.P23   <- dates[111];
                  ts2.P24   <- dates[112];
                  ts2.P25   <- dates[113];
                  ts2.P26   <- dates[114];
                  ts2.P27   <- dates[115];
                  ts2.P28   <- dates[116];
                  ts2.P29   <- dates[117];
                  ts2.P30   <- dates[118];
                  ts2.P31   <- dates[119];
                  ts2.P32   <- dates[120];
                  ts2.P33   <- dates[121];
                  ts2.P34   <- dates[122];
                  ts2.P35   <- dates[123];
                  ts2.P36   <- dates[124];
                  ts2.P37   <- dates[125];
                  ts2.P38   <- dates[126];
                  ts2.P39   <- dates[127];
                  ts2.P40   <- dates[128];
                  ts2.P41   <- dates[129];
                  ts2.P42   <- dates[130];
                  ts2.P43   <- dates[131];
                  ts2.P44   <- dates[132];
                  ts2.P45   <- dates[133];
                  ts2.P46   <- dates[134];
                  ts2.P47   <- dates[135];
                  ts2.P48   <- dates[136];
                  ts2.P49   <- dates[137];
                  ts2.P50   <- dates[138];
                  ts2.P51   <- dates[139];
                  ts2.P52   <- dates[140];
                  ts2.P53   <- dates[141];
                  ts2.P54   <- dates[142];
                  ts2.P55   <- dates[143];
                  ts2.P56   <- dates[144];
                  ts2.P57   <- dates[145];
                  ts2.P58   <- dates[146];
                  ts2.P59   <- dates[147];
                  ts2.P60   <- dates[148];
                  ts2.P61   <- dates[149];
                  ts2.P62   <- dates[150];
                  ts2.P63   <- dates[151];
                  ts2.P64   <- dates[152];
                  ts2.P65   <- dates[153];
                  ts2.P66   <- dates[154];
                  ts2.P67   <- dates[155];
                  ts2.P68   <- dates[156];
                  ts2.P69   <- dates[157];
                  ts2.P70   <- dates[158];
                  ts2.P71   <- dates[159];
                  ts2.P72   <- dates[160];
                  ts2.P73   <- dates[161];
                  ts2.P74   <- dates[162];
                  ts2.P75   <- dates[163];
                  ts2.P76   <- dates[164];
                  ts2.P77   <- dates[165];
                  ts2.P78   <- dates[166];
                  ts2.P79   <- dates[167];
                  ts2.P80   <- dates[168];
                  ts2.P81   <- dates[169];
                  ts2.P82   <- dates[170];
                  ts2.P83   <- dates[171];
                  ts2.P84   <- dates[172];
                  ts2.P85   <- dates[173];
                  ts2.P86   <- dates[174];
                  ts2.P87   <- dates[175];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logscale1 <- par[90];
                  logalpha1 <- par[91];
                  logbeta1  <- par[92];
                  logP1F2   <- par[93];
                  logP2F2   <- par[94];
                  logP3F2   <- par[95];
                  logP4F2   <- par[96];
                  logP5F2   <- par[97];
                  logP6F2   <- par[98];
                  logP7F2   <- par[99];
                  logP8F2   <- par[100];
                  logP9F2   <- par[101];
                  logP10F2  <- par[102];
                  logP11F2  <- par[103];
                  logP12F2  <- par[104];
                  logP13F2  <- par[105];
                  logP14F2  <- par[106];
                  logP15F2  <- par[107];
                  logP16F2  <- par[108];
                  logP17F2  <- par[109];
                  logP18F2  <- par[110];
                  logP19F2  <- par[111];
                  logP20F2  <- par[112];
                  logP21F2  <- par[113];
                  logP22F2  <- par[114];
                  logP23F2  <- par[115];
                  logP24F2  <- par[116];
                  logP25F2  <- par[117];
                  logP26F2  <- par[118];
                  logP27F2  <- par[119];
                  logP28F2  <- par[120];
                  logP29F2  <- par[121];
                  logP30F2  <- par[122];
                  logP31F2  <- par[123];
                  logP32F2  <- par[124];
                  logP33F2  <- par[125];
                  logP34F2  <- par[126];
                  logP35F2  <- par[127];
                  logP36F2  <- par[128];
                  logP37F2  <- par[129];
                  logP38F2  <- par[130];
                  logP39F2  <- par[131];
                  logP40F2  <- par[132];
                  logP41F2  <- par[133];
                  logP42F2  <- par[134];
                  logP43F2  <- par[135];
                  logP44F2  <- par[136];
                  logP45F2  <- par[137];
                  logP46F2  <- par[138];
                  logP47F2  <- par[139];
                  logP48F2  <- par[140];
                  logP49F2  <- par[141];
                  logP50F2  <- par[142];
                  logP51F2  <- par[143];
                  logP52F2  <- par[144];
                  logP53F2  <- par[145];
                  logP54F2  <- par[146];
                  logP55F2  <- par[147];
                  logP56F2  <- par[148];
                  logP57F2  <- par[149];
                  logP58F2  <- par[150];
                  logP59F2  <- par[151];
                  logP60F2  <- par[152];
                  logP61F2  <- par[153];
                  logP62F2  <- par[154];
                  logP63F2  <- par[155];
                  logP64F2  <- par[156];
                  logP65F2  <- par[157];
                  logP66F2  <- par[158];
                  logP67F2  <- par[159];
                  logP68F2  <- par[160];
                  logP69F2  <- par[161];
                  logP70F2  <- par[162];
                  logP71F2  <- par[163];
                  logP72F2  <- par[164];
                  logP73F2  <- par[165];
                  logP74F2  <- par[166];
                  logP75F2  <- par[167];
                  logP76F2  <- par[168];
                  logP77F2  <- par[169];
                  logP78F2  <- par[170];
                  logP79F2  <- par[171];
                  logP80F2  <- par[172];
                  logP81F2  <- par[173];
                  logP82F2  <- par[174];
                  logP83F2  <- par[175];
                  logP84F2  <- par[176];
                  logP85F2  <- par[177];
                  logP86F2  <- par[178];
                  logP87F2  <- par[179];
                  logscale2 <- par[180];
                  logalpha2 <- par[181];
                  logbeta2  <- par[182];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN88P88P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(88,88))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts2.P1    <- dates[90];
                  ts2.P2    <- dates[91];
                  ts2.P3    <- dates[92];
                  ts2.P4    <- dates[93];
                  ts2.P5    <- dates[94];
                  ts2.P6    <- dates[95];
                  ts2.P7    <- dates[96];
                  ts2.P8    <- dates[97];
                  ts2.P9    <- dates[98];
                  ts2.P10   <- dates[99];
                  ts2.P11   <- dates[100];
                  ts2.P12   <- dates[101];
                  ts2.P13   <- dates[102];
                  ts2.P14   <- dates[103];
                  ts2.P15   <- dates[104];
                  ts2.P16   <- dates[105];
                  ts2.P17   <- dates[106];
                  ts2.P18   <- dates[107];
                  ts2.P19   <- dates[108];
                  ts2.P20   <- dates[109];
                  ts2.P21   <- dates[110];
                  ts2.P22   <- dates[111];
                  ts2.P23   <- dates[112];
                  ts2.P24   <- dates[113];
                  ts2.P25   <- dates[114];
                  ts2.P26   <- dates[115];
                  ts2.P27   <- dates[116];
                  ts2.P28   <- dates[117];
                  ts2.P29   <- dates[118];
                  ts2.P30   <- dates[119];
                  ts2.P31   <- dates[120];
                  ts2.P32   <- dates[121];
                  ts2.P33   <- dates[122];
                  ts2.P34   <- dates[123];
                  ts2.P35   <- dates[124];
                  ts2.P36   <- dates[125];
                  ts2.P37   <- dates[126];
                  ts2.P38   <- dates[127];
                  ts2.P39   <- dates[128];
                  ts2.P40   <- dates[129];
                  ts2.P41   <- dates[130];
                  ts2.P42   <- dates[131];
                  ts2.P43   <- dates[132];
                  ts2.P44   <- dates[133];
                  ts2.P45   <- dates[134];
                  ts2.P46   <- dates[135];
                  ts2.P47   <- dates[136];
                  ts2.P48   <- dates[137];
                  ts2.P49   <- dates[138];
                  ts2.P50   <- dates[139];
                  ts2.P51   <- dates[140];
                  ts2.P52   <- dates[141];
                  ts2.P53   <- dates[142];
                  ts2.P54   <- dates[143];
                  ts2.P55   <- dates[144];
                  ts2.P56   <- dates[145];
                  ts2.P57   <- dates[146];
                  ts2.P58   <- dates[147];
                  ts2.P59   <- dates[148];
                  ts2.P60   <- dates[149];
                  ts2.P61   <- dates[150];
                  ts2.P62   <- dates[151];
                  ts2.P63   <- dates[152];
                  ts2.P64   <- dates[153];
                  ts2.P65   <- dates[154];
                  ts2.P66   <- dates[155];
                  ts2.P67   <- dates[156];
                  ts2.P68   <- dates[157];
                  ts2.P69   <- dates[158];
                  ts2.P70   <- dates[159];
                  ts2.P71   <- dates[160];
                  ts2.P72   <- dates[161];
                  ts2.P73   <- dates[162];
                  ts2.P74   <- dates[163];
                  ts2.P75   <- dates[164];
                  ts2.P76   <- dates[165];
                  ts2.P77   <- dates[166];
                  ts2.P78   <- dates[167];
                  ts2.P79   <- dates[168];
                  ts2.P80   <- dates[169];
                  ts2.P81   <- dates[170];
                  ts2.P82   <- dates[171];
                  ts2.P83   <- dates[172];
                  ts2.P84   <- dates[173];
                  ts2.P85   <- dates[174];
                  ts2.P86   <- dates[175];
                  ts2.P87   <- dates[176];
                  ts2.P88   <- dates[177];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logscale1 <- par[91];
                  logalpha1 <- par[92];
                  logbeta1  <- par[93];
                  logP1F2   <- par[94];
                  logP2F2   <- par[95];
                  logP3F2   <- par[96];
                  logP4F2   <- par[97];
                  logP5F2   <- par[98];
                  logP6F2   <- par[99];
                  logP7F2   <- par[100];
                  logP8F2   <- par[101];
                  logP9F2   <- par[102];
                  logP10F2  <- par[103];
                  logP11F2  <- par[104];
                  logP12F2  <- par[105];
                  logP13F2  <- par[106];
                  logP14F2  <- par[107];
                  logP15F2  <- par[108];
                  logP16F2  <- par[109];
                  logP17F2  <- par[110];
                  logP18F2  <- par[111];
                  logP19F2  <- par[112];
                  logP20F2  <- par[113];
                  logP21F2  <- par[114];
                  logP22F2  <- par[115];
                  logP23F2  <- par[116];
                  logP24F2  <- par[117];
                  logP25F2  <- par[118];
                  logP26F2  <- par[119];
                  logP27F2  <- par[120];
                  logP28F2  <- par[121];
                  logP29F2  <- par[122];
                  logP30F2  <- par[123];
                  logP31F2  <- par[124];
                  logP32F2  <- par[125];
                  logP33F2  <- par[126];
                  logP34F2  <- par[127];
                  logP35F2  <- par[128];
                  logP36F2  <- par[129];
                  logP37F2  <- par[130];
                  logP38F2  <- par[131];
                  logP39F2  <- par[132];
                  logP40F2  <- par[133];
                  logP41F2  <- par[134];
                  logP42F2  <- par[135];
                  logP43F2  <- par[136];
                  logP44F2  <- par[137];
                  logP45F2  <- par[138];
                  logP46F2  <- par[139];
                  logP47F2  <- par[140];
                  logP48F2  <- par[141];
                  logP49F2  <- par[142];
                  logP50F2  <- par[143];
                  logP51F2  <- par[144];
                  logP52F2  <- par[145];
                  logP53F2  <- par[146];
                  logP54F2  <- par[147];
                  logP55F2  <- par[148];
                  logP56F2  <- par[149];
                  logP57F2  <- par[150];
                  logP58F2  <- par[151];
                  logP59F2  <- par[152];
                  logP60F2  <- par[153];
                  logP61F2  <- par[154];
                  logP62F2  <- par[155];
                  logP63F2  <- par[156];
                  logP64F2  <- par[157];
                  logP65F2  <- par[158];
                  logP66F2  <- par[159];
                  logP67F2  <- par[160];
                  logP68F2  <- par[161];
                  logP69F2  <- par[162];
                  logP70F2  <- par[163];
                  logP71F2  <- par[164];
                  logP72F2  <- par[165];
                  logP73F2  <- par[166];
                  logP74F2  <- par[167];
                  logP75F2  <- par[168];
                  logP76F2  <- par[169];
                  logP77F2  <- par[170];
                  logP78F2  <- par[171];
                  logP79F2  <- par[172];
                  logP80F2  <- par[173];
                  logP81F2  <- par[174];
                  logP82F2  <- par[175];
                  logP83F2  <- par[176];
                  logP84F2  <- par[177];
                  logP85F2  <- par[178];
                  logP86F2  <- par[179];
                  logP87F2  <- par[180];
                  logP88F2  <- par[181];
                  logscale2 <- par[182];
                  logalpha2 <- par[183];
                  logbeta2  <- par[184];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN89P89P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(89,89))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts2.P1    <- dates[91];
                  ts2.P2    <- dates[92];
                  ts2.P3    <- dates[93];
                  ts2.P4    <- dates[94];
                  ts2.P5    <- dates[95];
                  ts2.P6    <- dates[96];
                  ts2.P7    <- dates[97];
                  ts2.P8    <- dates[98];
                  ts2.P9    <- dates[99];
                  ts2.P10   <- dates[100];
                  ts2.P11   <- dates[101];
                  ts2.P12   <- dates[102];
                  ts2.P13   <- dates[103];
                  ts2.P14   <- dates[104];
                  ts2.P15   <- dates[105];
                  ts2.P16   <- dates[106];
                  ts2.P17   <- dates[107];
                  ts2.P18   <- dates[108];
                  ts2.P19   <- dates[109];
                  ts2.P20   <- dates[110];
                  ts2.P21   <- dates[111];
                  ts2.P22   <- dates[112];
                  ts2.P23   <- dates[113];
                  ts2.P24   <- dates[114];
                  ts2.P25   <- dates[115];
                  ts2.P26   <- dates[116];
                  ts2.P27   <- dates[117];
                  ts2.P28   <- dates[118];
                  ts2.P29   <- dates[119];
                  ts2.P30   <- dates[120];
                  ts2.P31   <- dates[121];
                  ts2.P32   <- dates[122];
                  ts2.P33   <- dates[123];
                  ts2.P34   <- dates[124];
                  ts2.P35   <- dates[125];
                  ts2.P36   <- dates[126];
                  ts2.P37   <- dates[127];
                  ts2.P38   <- dates[128];
                  ts2.P39   <- dates[129];
                  ts2.P40   <- dates[130];
                  ts2.P41   <- dates[131];
                  ts2.P42   <- dates[132];
                  ts2.P43   <- dates[133];
                  ts2.P44   <- dates[134];
                  ts2.P45   <- dates[135];
                  ts2.P46   <- dates[136];
                  ts2.P47   <- dates[137];
                  ts2.P48   <- dates[138];
                  ts2.P49   <- dates[139];
                  ts2.P50   <- dates[140];
                  ts2.P51   <- dates[141];
                  ts2.P52   <- dates[142];
                  ts2.P53   <- dates[143];
                  ts2.P54   <- dates[144];
                  ts2.P55   <- dates[145];
                  ts2.P56   <- dates[146];
                  ts2.P57   <- dates[147];
                  ts2.P58   <- dates[148];
                  ts2.P59   <- dates[149];
                  ts2.P60   <- dates[150];
                  ts2.P61   <- dates[151];
                  ts2.P62   <- dates[152];
                  ts2.P63   <- dates[153];
                  ts2.P64   <- dates[154];
                  ts2.P65   <- dates[155];
                  ts2.P66   <- dates[156];
                  ts2.P67   <- dates[157];
                  ts2.P68   <- dates[158];
                  ts2.P69   <- dates[159];
                  ts2.P70   <- dates[160];
                  ts2.P71   <- dates[161];
                  ts2.P72   <- dates[162];
                  ts2.P73   <- dates[163];
                  ts2.P74   <- dates[164];
                  ts2.P75   <- dates[165];
                  ts2.P76   <- dates[166];
                  ts2.P77   <- dates[167];
                  ts2.P78   <- dates[168];
                  ts2.P79   <- dates[169];
                  ts2.P80   <- dates[170];
                  ts2.P81   <- dates[171];
                  ts2.P82   <- dates[172];
                  ts2.P83   <- dates[173];
                  ts2.P84   <- dates[174];
                  ts2.P85   <- dates[175];
                  ts2.P86   <- dates[176];
                  ts2.P87   <- dates[177];
                  ts2.P88   <- dates[178];
                  ts2.P89   <- dates[179];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logscale1 <- par[92];
                  logalpha1 <- par[93];
                  logbeta1  <- par[94];
                  logP1F2   <- par[95];
                  logP2F2   <- par[96];
                  logP3F2   <- par[97];
                  logP4F2   <- par[98];
                  logP5F2   <- par[99];
                  logP6F2   <- par[100];
                  logP7F2   <- par[101];
                  logP8F2   <- par[102];
                  logP9F2   <- par[103];
                  logP10F2  <- par[104];
                  logP11F2  <- par[105];
                  logP12F2  <- par[106];
                  logP13F2  <- par[107];
                  logP14F2  <- par[108];
                  logP15F2  <- par[109];
                  logP16F2  <- par[110];
                  logP17F2  <- par[111];
                  logP18F2  <- par[112];
                  logP19F2  <- par[113];
                  logP20F2  <- par[114];
                  logP21F2  <- par[115];
                  logP22F2  <- par[116];
                  logP23F2  <- par[117];
                  logP24F2  <- par[118];
                  logP25F2  <- par[119];
                  logP26F2  <- par[120];
                  logP27F2  <- par[121];
                  logP28F2  <- par[122];
                  logP29F2  <- par[123];
                  logP30F2  <- par[124];
                  logP31F2  <- par[125];
                  logP32F2  <- par[126];
                  logP33F2  <- par[127];
                  logP34F2  <- par[128];
                  logP35F2  <- par[129];
                  logP36F2  <- par[130];
                  logP37F2  <- par[131];
                  logP38F2  <- par[132];
                  logP39F2  <- par[133];
                  logP40F2  <- par[134];
                  logP41F2  <- par[135];
                  logP42F2  <- par[136];
                  logP43F2  <- par[137];
                  logP44F2  <- par[138];
                  logP45F2  <- par[139];
                  logP46F2  <- par[140];
                  logP47F2  <- par[141];
                  logP48F2  <- par[142];
                  logP49F2  <- par[143];
                  logP50F2  <- par[144];
                  logP51F2  <- par[145];
                  logP52F2  <- par[146];
                  logP53F2  <- par[147];
                  logP54F2  <- par[148];
                  logP55F2  <- par[149];
                  logP56F2  <- par[150];
                  logP57F2  <- par[151];
                  logP58F2  <- par[152];
                  logP59F2  <- par[153];
                  logP60F2  <- par[154];
                  logP61F2  <- par[155];
                  logP62F2  <- par[156];
                  logP63F2  <- par[157];
                  logP64F2  <- par[158];
                  logP65F2  <- par[159];
                  logP66F2  <- par[160];
                  logP67F2  <- par[161];
                  logP68F2  <- par[162];
                  logP69F2  <- par[163];
                  logP70F2  <- par[164];
                  logP71F2  <- par[165];
                  logP72F2  <- par[166];
                  logP73F2  <- par[167];
                  logP74F2  <- par[168];
                  logP75F2  <- par[169];
                  logP76F2  <- par[170];
                  logP77F2  <- par[171];
                  logP78F2  <- par[172];
                  logP79F2  <- par[173];
                  logP80F2  <- par[174];
                  logP81F2  <- par[175];
                  logP82F2  <- par[176];
                  logP83F2  <- par[177];
                  logP84F2  <- par[178];
                  logP85F2  <- par[179];
                  logP86F2  <- par[180];
                  logP87F2  <- par[181];
                  logP88F2  <- par[182];
                  logP89F2  <- par[183];
                  logscale2 <- par[184];
                  logalpha2 <- par[185];
                  logbeta2  <- par[186];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN90P90P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(90,90))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts2.P1    <- dates[92];
                  ts2.P2    <- dates[93];
                  ts2.P3    <- dates[94];
                  ts2.P4    <- dates[95];
                  ts2.P5    <- dates[96];
                  ts2.P6    <- dates[97];
                  ts2.P7    <- dates[98];
                  ts2.P8    <- dates[99];
                  ts2.P9    <- dates[100];
                  ts2.P10   <- dates[101];
                  ts2.P11   <- dates[102];
                  ts2.P12   <- dates[103];
                  ts2.P13   <- dates[104];
                  ts2.P14   <- dates[105];
                  ts2.P15   <- dates[106];
                  ts2.P16   <- dates[107];
                  ts2.P17   <- dates[108];
                  ts2.P18   <- dates[109];
                  ts2.P19   <- dates[110];
                  ts2.P20   <- dates[111];
                  ts2.P21   <- dates[112];
                  ts2.P22   <- dates[113];
                  ts2.P23   <- dates[114];
                  ts2.P24   <- dates[115];
                  ts2.P25   <- dates[116];
                  ts2.P26   <- dates[117];
                  ts2.P27   <- dates[118];
                  ts2.P28   <- dates[119];
                  ts2.P29   <- dates[120];
                  ts2.P30   <- dates[121];
                  ts2.P31   <- dates[122];
                  ts2.P32   <- dates[123];
                  ts2.P33   <- dates[124];
                  ts2.P34   <- dates[125];
                  ts2.P35   <- dates[126];
                  ts2.P36   <- dates[127];
                  ts2.P37   <- dates[128];
                  ts2.P38   <- dates[129];
                  ts2.P39   <- dates[130];
                  ts2.P40   <- dates[131];
                  ts2.P41   <- dates[132];
                  ts2.P42   <- dates[133];
                  ts2.P43   <- dates[134];
                  ts2.P44   <- dates[135];
                  ts2.P45   <- dates[136];
                  ts2.P46   <- dates[137];
                  ts2.P47   <- dates[138];
                  ts2.P48   <- dates[139];
                  ts2.P49   <- dates[140];
                  ts2.P50   <- dates[141];
                  ts2.P51   <- dates[142];
                  ts2.P52   <- dates[143];
                  ts2.P53   <- dates[144];
                  ts2.P54   <- dates[145];
                  ts2.P55   <- dates[146];
                  ts2.P56   <- dates[147];
                  ts2.P57   <- dates[148];
                  ts2.P58   <- dates[149];
                  ts2.P59   <- dates[150];
                  ts2.P60   <- dates[151];
                  ts2.P61   <- dates[152];
                  ts2.P62   <- dates[153];
                  ts2.P63   <- dates[154];
                  ts2.P64   <- dates[155];
                  ts2.P65   <- dates[156];
                  ts2.P66   <- dates[157];
                  ts2.P67   <- dates[158];
                  ts2.P68   <- dates[159];
                  ts2.P69   <- dates[160];
                  ts2.P70   <- dates[161];
                  ts2.P71   <- dates[162];
                  ts2.P72   <- dates[163];
                  ts2.P73   <- dates[164];
                  ts2.P74   <- dates[165];
                  ts2.P75   <- dates[166];
                  ts2.P76   <- dates[167];
                  ts2.P77   <- dates[168];
                  ts2.P78   <- dates[169];
                  ts2.P79   <- dates[170];
                  ts2.P80   <- dates[171];
                  ts2.P81   <- dates[172];
                  ts2.P82   <- dates[173];
                  ts2.P83   <- dates[174];
                  ts2.P84   <- dates[175];
                  ts2.P85   <- dates[176];
                  ts2.P86   <- dates[177];
                  ts2.P87   <- dates[178];
                  ts2.P88   <- dates[179];
                  ts2.P89   <- dates[180];
                  ts2.P90   <- dates[181];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logscale1 <- par[93];
                  logalpha1 <- par[94];
                  logbeta1  <- par[95];
                  logP1F2   <- par[96];
                  logP2F2   <- par[97];
                  logP3F2   <- par[98];
                  logP4F2   <- par[99];
                  logP5F2   <- par[100];
                  logP6F2   <- par[101];
                  logP7F2   <- par[102];
                  logP8F2   <- par[103];
                  logP9F2   <- par[104];
                  logP10F2  <- par[105];
                  logP11F2  <- par[106];
                  logP12F2  <- par[107];
                  logP13F2  <- par[108];
                  logP14F2  <- par[109];
                  logP15F2  <- par[110];
                  logP16F2  <- par[111];
                  logP17F2  <- par[112];
                  logP18F2  <- par[113];
                  logP19F2  <- par[114];
                  logP20F2  <- par[115];
                  logP21F2  <- par[116];
                  logP22F2  <- par[117];
                  logP23F2  <- par[118];
                  logP24F2  <- par[119];
                  logP25F2  <- par[120];
                  logP26F2  <- par[121];
                  logP27F2  <- par[122];
                  logP28F2  <- par[123];
                  logP29F2  <- par[124];
                  logP30F2  <- par[125];
                  logP31F2  <- par[126];
                  logP32F2  <- par[127];
                  logP33F2  <- par[128];
                  logP34F2  <- par[129];
                  logP35F2  <- par[130];
                  logP36F2  <- par[131];
                  logP37F2  <- par[132];
                  logP38F2  <- par[133];
                  logP39F2  <- par[134];
                  logP40F2  <- par[135];
                  logP41F2  <- par[136];
                  logP42F2  <- par[137];
                  logP43F2  <- par[138];
                  logP44F2  <- par[139];
                  logP45F2  <- par[140];
                  logP46F2  <- par[141];
                  logP47F2  <- par[142];
                  logP48F2  <- par[143];
                  logP49F2  <- par[144];
                  logP50F2  <- par[145];
                  logP51F2  <- par[146];
                  logP52F2  <- par[147];
                  logP53F2  <- par[148];
                  logP54F2  <- par[149];
                  logP55F2  <- par[150];
                  logP56F2  <- par[151];
                  logP57F2  <- par[152];
                  logP58F2  <- par[153];
                  logP59F2  <- par[154];
                  logP60F2  <- par[155];
                  logP61F2  <- par[156];
                  logP62F2  <- par[157];
                  logP63F2  <- par[158];
                  logP64F2  <- par[159];
                  logP65F2  <- par[160];
                  logP66F2  <- par[161];
                  logP67F2  <- par[162];
                  logP68F2  <- par[163];
                  logP69F2  <- par[164];
                  logP70F2  <- par[165];
                  logP71F2  <- par[166];
                  logP72F2  <- par[167];
                  logP73F2  <- par[168];
                  logP74F2  <- par[169];
                  logP75F2  <- par[170];
                  logP76F2  <- par[171];
                  logP77F2  <- par[172];
                  logP78F2  <- par[173];
                  logP79F2  <- par[174];
                  logP80F2  <- par[175];
                  logP81F2  <- par[176];
                  logP82F2  <- par[177];
                  logP83F2  <- par[178];
                  logP84F2  <- par[179];
                  logP85F2  <- par[180];
                  logP86F2  <- par[181];
                  logP87F2  <- par[182];
                  logP88F2  <- par[183];
                  logP89F2  <- par[184];
                  logP90F2  <- par[185];
                  logscale2 <- par[186];
                  logalpha2 <- par[187];
                  logbeta2  <- par[188];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN91P91P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(91,91))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts2.P1    <- dates[93];
                  ts2.P2    <- dates[94];
                  ts2.P3    <- dates[95];
                  ts2.P4    <- dates[96];
                  ts2.P5    <- dates[97];
                  ts2.P6    <- dates[98];
                  ts2.P7    <- dates[99];
                  ts2.P8    <- dates[100];
                  ts2.P9    <- dates[101];
                  ts2.P10   <- dates[102];
                  ts2.P11   <- dates[103];
                  ts2.P12   <- dates[104];
                  ts2.P13   <- dates[105];
                  ts2.P14   <- dates[106];
                  ts2.P15   <- dates[107];
                  ts2.P16   <- dates[108];
                  ts2.P17   <- dates[109];
                  ts2.P18   <- dates[110];
                  ts2.P19   <- dates[111];
                  ts2.P20   <- dates[112];
                  ts2.P21   <- dates[113];
                  ts2.P22   <- dates[114];
                  ts2.P23   <- dates[115];
                  ts2.P24   <- dates[116];
                  ts2.P25   <- dates[117];
                  ts2.P26   <- dates[118];
                  ts2.P27   <- dates[119];
                  ts2.P28   <- dates[120];
                  ts2.P29   <- dates[121];
                  ts2.P30   <- dates[122];
                  ts2.P31   <- dates[123];
                  ts2.P32   <- dates[124];
                  ts2.P33   <- dates[125];
                  ts2.P34   <- dates[126];
                  ts2.P35   <- dates[127];
                  ts2.P36   <- dates[128];
                  ts2.P37   <- dates[129];
                  ts2.P38   <- dates[130];
                  ts2.P39   <- dates[131];
                  ts2.P40   <- dates[132];
                  ts2.P41   <- dates[133];
                  ts2.P42   <- dates[134];
                  ts2.P43   <- dates[135];
                  ts2.P44   <- dates[136];
                  ts2.P45   <- dates[137];
                  ts2.P46   <- dates[138];
                  ts2.P47   <- dates[139];
                  ts2.P48   <- dates[140];
                  ts2.P49   <- dates[141];
                  ts2.P50   <- dates[142];
                  ts2.P51   <- dates[143];
                  ts2.P52   <- dates[144];
                  ts2.P53   <- dates[145];
                  ts2.P54   <- dates[146];
                  ts2.P55   <- dates[147];
                  ts2.P56   <- dates[148];
                  ts2.P57   <- dates[149];
                  ts2.P58   <- dates[150];
                  ts2.P59   <- dates[151];
                  ts2.P60   <- dates[152];
                  ts2.P61   <- dates[153];
                  ts2.P62   <- dates[154];
                  ts2.P63   <- dates[155];
                  ts2.P64   <- dates[156];
                  ts2.P65   <- dates[157];
                  ts2.P66   <- dates[158];
                  ts2.P67   <- dates[159];
                  ts2.P68   <- dates[160];
                  ts2.P69   <- dates[161];
                  ts2.P70   <- dates[162];
                  ts2.P71   <- dates[163];
                  ts2.P72   <- dates[164];
                  ts2.P73   <- dates[165];
                  ts2.P74   <- dates[166];
                  ts2.P75   <- dates[167];
                  ts2.P76   <- dates[168];
                  ts2.P77   <- dates[169];
                  ts2.P78   <- dates[170];
                  ts2.P79   <- dates[171];
                  ts2.P80   <- dates[172];
                  ts2.P81   <- dates[173];
                  ts2.P82   <- dates[174];
                  ts2.P83   <- dates[175];
                  ts2.P84   <- dates[176];
                  ts2.P85   <- dates[177];
                  ts2.P86   <- dates[178];
                  ts2.P87   <- dates[179];
                  ts2.P88   <- dates[180];
                  ts2.P89   <- dates[181];
                  ts2.P90   <- dates[182];
                  ts2.P91   <- dates[183];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logscale1 <- par[94];
                  logalpha1 <- par[95];
                  logbeta1  <- par[96];
                  logP1F2   <- par[97];
                  logP2F2   <- par[98];
                  logP3F2   <- par[99];
                  logP4F2   <- par[100];
                  logP5F2   <- par[101];
                  logP6F2   <- par[102];
                  logP7F2   <- par[103];
                  logP8F2   <- par[104];
                  logP9F2   <- par[105];
                  logP10F2  <- par[106];
                  logP11F2  <- par[107];
                  logP12F2  <- par[108];
                  logP13F2  <- par[109];
                  logP14F2  <- par[110];
                  logP15F2  <- par[111];
                  logP16F2  <- par[112];
                  logP17F2  <- par[113];
                  logP18F2  <- par[114];
                  logP19F2  <- par[115];
                  logP20F2  <- par[116];
                  logP21F2  <- par[117];
                  logP22F2  <- par[118];
                  logP23F2  <- par[119];
                  logP24F2  <- par[120];
                  logP25F2  <- par[121];
                  logP26F2  <- par[122];
                  logP27F2  <- par[123];
                  logP28F2  <- par[124];
                  logP29F2  <- par[125];
                  logP30F2  <- par[126];
                  logP31F2  <- par[127];
                  logP32F2  <- par[128];
                  logP33F2  <- par[129];
                  logP34F2  <- par[130];
                  logP35F2  <- par[131];
                  logP36F2  <- par[132];
                  logP37F2  <- par[133];
                  logP38F2  <- par[134];
                  logP39F2  <- par[135];
                  logP40F2  <- par[136];
                  logP41F2  <- par[137];
                  logP42F2  <- par[138];
                  logP43F2  <- par[139];
                  logP44F2  <- par[140];
                  logP45F2  <- par[141];
                  logP46F2  <- par[142];
                  logP47F2  <- par[143];
                  logP48F2  <- par[144];
                  logP49F2  <- par[145];
                  logP50F2  <- par[146];
                  logP51F2  <- par[147];
                  logP52F2  <- par[148];
                  logP53F2  <- par[149];
                  logP54F2  <- par[150];
                  logP55F2  <- par[151];
                  logP56F2  <- par[152];
                  logP57F2  <- par[153];
                  logP58F2  <- par[154];
                  logP59F2  <- par[155];
                  logP60F2  <- par[156];
                  logP61F2  <- par[157];
                  logP62F2  <- par[158];
                  logP63F2  <- par[159];
                  logP64F2  <- par[160];
                  logP65F2  <- par[161];
                  logP66F2  <- par[162];
                  logP67F2  <- par[163];
                  logP68F2  <- par[164];
                  logP69F2  <- par[165];
                  logP70F2  <- par[166];
                  logP71F2  <- par[167];
                  logP72F2  <- par[168];
                  logP73F2  <- par[169];
                  logP74F2  <- par[170];
                  logP75F2  <- par[171];
                  logP76F2  <- par[172];
                  logP77F2  <- par[173];
                  logP78F2  <- par[174];
                  logP79F2  <- par[175];
                  logP80F2  <- par[176];
                  logP81F2  <- par[177];
                  logP82F2  <- par[178];
                  logP83F2  <- par[179];
                  logP84F2  <- par[180];
                  logP85F2  <- par[181];
                  logP86F2  <- par[182];
                  logP87F2  <- par[183];
                  logP88F2  <- par[184];
                  logP89F2  <- par[185];
                  logP90F2  <- par[186];
                  logP91F2  <- par[187];
                  logscale2 <- par[188];
                  logalpha2 <- par[189];
                  logbeta2  <- par[190];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN92P92P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(92,92))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts2.P1    <- dates[94];
                  ts2.P2    <- dates[95];
                  ts2.P3    <- dates[96];
                  ts2.P4    <- dates[97];
                  ts2.P5    <- dates[98];
                  ts2.P6    <- dates[99];
                  ts2.P7    <- dates[100];
                  ts2.P8    <- dates[101];
                  ts2.P9    <- dates[102];
                  ts2.P10   <- dates[103];
                  ts2.P11   <- dates[104];
                  ts2.P12   <- dates[105];
                  ts2.P13   <- dates[106];
                  ts2.P14   <- dates[107];
                  ts2.P15   <- dates[108];
                  ts2.P16   <- dates[109];
                  ts2.P17   <- dates[110];
                  ts2.P18   <- dates[111];
                  ts2.P19   <- dates[112];
                  ts2.P20   <- dates[113];
                  ts2.P21   <- dates[114];
                  ts2.P22   <- dates[115];
                  ts2.P23   <- dates[116];
                  ts2.P24   <- dates[117];
                  ts2.P25   <- dates[118];
                  ts2.P26   <- dates[119];
                  ts2.P27   <- dates[120];
                  ts2.P28   <- dates[121];
                  ts2.P29   <- dates[122];
                  ts2.P30   <- dates[123];
                  ts2.P31   <- dates[124];
                  ts2.P32   <- dates[125];
                  ts2.P33   <- dates[126];
                  ts2.P34   <- dates[127];
                  ts2.P35   <- dates[128];
                  ts2.P36   <- dates[129];
                  ts2.P37   <- dates[130];
                  ts2.P38   <- dates[131];
                  ts2.P39   <- dates[132];
                  ts2.P40   <- dates[133];
                  ts2.P41   <- dates[134];
                  ts2.P42   <- dates[135];
                  ts2.P43   <- dates[136];
                  ts2.P44   <- dates[137];
                  ts2.P45   <- dates[138];
                  ts2.P46   <- dates[139];
                  ts2.P47   <- dates[140];
                  ts2.P48   <- dates[141];
                  ts2.P49   <- dates[142];
                  ts2.P50   <- dates[143];
                  ts2.P51   <- dates[144];
                  ts2.P52   <- dates[145];
                  ts2.P53   <- dates[146];
                  ts2.P54   <- dates[147];
                  ts2.P55   <- dates[148];
                  ts2.P56   <- dates[149];
                  ts2.P57   <- dates[150];
                  ts2.P58   <- dates[151];
                  ts2.P59   <- dates[152];
                  ts2.P60   <- dates[153];
                  ts2.P61   <- dates[154];
                  ts2.P62   <- dates[155];
                  ts2.P63   <- dates[156];
                  ts2.P64   <- dates[157];
                  ts2.P65   <- dates[158];
                  ts2.P66   <- dates[159];
                  ts2.P67   <- dates[160];
                  ts2.P68   <- dates[161];
                  ts2.P69   <- dates[162];
                  ts2.P70   <- dates[163];
                  ts2.P71   <- dates[164];
                  ts2.P72   <- dates[165];
                  ts2.P73   <- dates[166];
                  ts2.P74   <- dates[167];
                  ts2.P75   <- dates[168];
                  ts2.P76   <- dates[169];
                  ts2.P77   <- dates[170];
                  ts2.P78   <- dates[171];
                  ts2.P79   <- dates[172];
                  ts2.P80   <- dates[173];
                  ts2.P81   <- dates[174];
                  ts2.P82   <- dates[175];
                  ts2.P83   <- dates[176];
                  ts2.P84   <- dates[177];
                  ts2.P85   <- dates[178];
                  ts2.P86   <- dates[179];
                  ts2.P87   <- dates[180];
                  ts2.P88   <- dates[181];
                  ts2.P89   <- dates[182];
                  ts2.P90   <- dates[183];
                  ts2.P91   <- dates[184];
                  ts2.P92   <- dates[185];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logscale1 <- par[95];
                  logalpha1 <- par[96];
                  logbeta1  <- par[97];
                  logP1F2   <- par[98];
                  logP2F2   <- par[99];
                  logP3F2   <- par[100];
                  logP4F2   <- par[101];
                  logP5F2   <- par[102];
                  logP6F2   <- par[103];
                  logP7F2   <- par[104];
                  logP8F2   <- par[105];
                  logP9F2   <- par[106];
                  logP10F2  <- par[107];
                  logP11F2  <- par[108];
                  logP12F2  <- par[109];
                  logP13F2  <- par[110];
                  logP14F2  <- par[111];
                  logP15F2  <- par[112];
                  logP16F2  <- par[113];
                  logP17F2  <- par[114];
                  logP18F2  <- par[115];
                  logP19F2  <- par[116];
                  logP20F2  <- par[117];
                  logP21F2  <- par[118];
                  logP22F2  <- par[119];
                  logP23F2  <- par[120];
                  logP24F2  <- par[121];
                  logP25F2  <- par[122];
                  logP26F2  <- par[123];
                  logP27F2  <- par[124];
                  logP28F2  <- par[125];
                  logP29F2  <- par[126];
                  logP30F2  <- par[127];
                  logP31F2  <- par[128];
                  logP32F2  <- par[129];
                  logP33F2  <- par[130];
                  logP34F2  <- par[131];
                  logP35F2  <- par[132];
                  logP36F2  <- par[133];
                  logP37F2  <- par[134];
                  logP38F2  <- par[135];
                  logP39F2  <- par[136];
                  logP40F2  <- par[137];
                  logP41F2  <- par[138];
                  logP42F2  <- par[139];
                  logP43F2  <- par[140];
                  logP44F2  <- par[141];
                  logP45F2  <- par[142];
                  logP46F2  <- par[143];
                  logP47F2  <- par[144];
                  logP48F2  <- par[145];
                  logP49F2  <- par[146];
                  logP50F2  <- par[147];
                  logP51F2  <- par[148];
                  logP52F2  <- par[149];
                  logP53F2  <- par[150];
                  logP54F2  <- par[151];
                  logP55F2  <- par[152];
                  logP56F2  <- par[153];
                  logP57F2  <- par[154];
                  logP58F2  <- par[155];
                  logP59F2  <- par[156];
                  logP60F2  <- par[157];
                  logP61F2  <- par[158];
                  logP62F2  <- par[159];
                  logP63F2  <- par[160];
                  logP64F2  <- par[161];
                  logP65F2  <- par[162];
                  logP66F2  <- par[163];
                  logP67F2  <- par[164];
                  logP68F2  <- par[165];
                  logP69F2  <- par[166];
                  logP70F2  <- par[167];
                  logP71F2  <- par[168];
                  logP72F2  <- par[169];
                  logP73F2  <- par[170];
                  logP74F2  <- par[171];
                  logP75F2  <- par[172];
                  logP76F2  <- par[173];
                  logP77F2  <- par[174];
                  logP78F2  <- par[175];
                  logP79F2  <- par[176];
                  logP80F2  <- par[177];
                  logP81F2  <- par[178];
                  logP82F2  <- par[179];
                  logP83F2  <- par[180];
                  logP84F2  <- par[181];
                  logP85F2  <- par[182];
                  logP86F2  <- par[183];
                  logP87F2  <- par[184];
                  logP88F2  <- par[185];
                  logP89F2  <- par[186];
                  logP90F2  <- par[187];
                  logP91F2  <- par[188];
                  logP92F2  <- par[189];
                  logscale2 <- par[190];
                  logalpha2 <- par[191];
                  logbeta2  <- par[192];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN93P93P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(93,93))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts2.P1    <- dates[95];
                  ts2.P2    <- dates[96];
                  ts2.P3    <- dates[97];
                  ts2.P4    <- dates[98];
                  ts2.P5    <- dates[99];
                  ts2.P6    <- dates[100];
                  ts2.P7    <- dates[101];
                  ts2.P8    <- dates[102];
                  ts2.P9    <- dates[103];
                  ts2.P10   <- dates[104];
                  ts2.P11   <- dates[105];
                  ts2.P12   <- dates[106];
                  ts2.P13   <- dates[107];
                  ts2.P14   <- dates[108];
                  ts2.P15   <- dates[109];
                  ts2.P16   <- dates[110];
                  ts2.P17   <- dates[111];
                  ts2.P18   <- dates[112];
                  ts2.P19   <- dates[113];
                  ts2.P20   <- dates[114];
                  ts2.P21   <- dates[115];
                  ts2.P22   <- dates[116];
                  ts2.P23   <- dates[117];
                  ts2.P24   <- dates[118];
                  ts2.P25   <- dates[119];
                  ts2.P26   <- dates[120];
                  ts2.P27   <- dates[121];
                  ts2.P28   <- dates[122];
                  ts2.P29   <- dates[123];
                  ts2.P30   <- dates[124];
                  ts2.P31   <- dates[125];
                  ts2.P32   <- dates[126];
                  ts2.P33   <- dates[127];
                  ts2.P34   <- dates[128];
                  ts2.P35   <- dates[129];
                  ts2.P36   <- dates[130];
                  ts2.P37   <- dates[131];
                  ts2.P38   <- dates[132];
                  ts2.P39   <- dates[133];
                  ts2.P40   <- dates[134];
                  ts2.P41   <- dates[135];
                  ts2.P42   <- dates[136];
                  ts2.P43   <- dates[137];
                  ts2.P44   <- dates[138];
                  ts2.P45   <- dates[139];
                  ts2.P46   <- dates[140];
                  ts2.P47   <- dates[141];
                  ts2.P48   <- dates[142];
                  ts2.P49   <- dates[143];
                  ts2.P50   <- dates[144];
                  ts2.P51   <- dates[145];
                  ts2.P52   <- dates[146];
                  ts2.P53   <- dates[147];
                  ts2.P54   <- dates[148];
                  ts2.P55   <- dates[149];
                  ts2.P56   <- dates[150];
                  ts2.P57   <- dates[151];
                  ts2.P58   <- dates[152];
                  ts2.P59   <- dates[153];
                  ts2.P60   <- dates[154];
                  ts2.P61   <- dates[155];
                  ts2.P62   <- dates[156];
                  ts2.P63   <- dates[157];
                  ts2.P64   <- dates[158];
                  ts2.P65   <- dates[159];
                  ts2.P66   <- dates[160];
                  ts2.P67   <- dates[161];
                  ts2.P68   <- dates[162];
                  ts2.P69   <- dates[163];
                  ts2.P70   <- dates[164];
                  ts2.P71   <- dates[165];
                  ts2.P72   <- dates[166];
                  ts2.P73   <- dates[167];
                  ts2.P74   <- dates[168];
                  ts2.P75   <- dates[169];
                  ts2.P76   <- dates[170];
                  ts2.P77   <- dates[171];
                  ts2.P78   <- dates[172];
                  ts2.P79   <- dates[173];
                  ts2.P80   <- dates[174];
                  ts2.P81   <- dates[175];
                  ts2.P82   <- dates[176];
                  ts2.P83   <- dates[177];
                  ts2.P84   <- dates[178];
                  ts2.P85   <- dates[179];
                  ts2.P86   <- dates[180];
                  ts2.P87   <- dates[181];
                  ts2.P88   <- dates[182];
                  ts2.P89   <- dates[183];
                  ts2.P90   <- dates[184];
                  ts2.P91   <- dates[185];
                  ts2.P92   <- dates[186];
                  ts2.P93   <- dates[187];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logscale1 <- par[96];
                  logalpha1 <- par[97];
                  logbeta1  <- par[98];
                  logP1F2   <- par[99];
                  logP2F2   <- par[100];
                  logP3F2   <- par[101];
                  logP4F2   <- par[102];
                  logP5F2   <- par[103];
                  logP6F2   <- par[104];
                  logP7F2   <- par[105];
                  logP8F2   <- par[106];
                  logP9F2   <- par[107];
                  logP10F2  <- par[108];
                  logP11F2  <- par[109];
                  logP12F2  <- par[110];
                  logP13F2  <- par[111];
                  logP14F2  <- par[112];
                  logP15F2  <- par[113];
                  logP16F2  <- par[114];
                  logP17F2  <- par[115];
                  logP18F2  <- par[116];
                  logP19F2  <- par[117];
                  logP20F2  <- par[118];
                  logP21F2  <- par[119];
                  logP22F2  <- par[120];
                  logP23F2  <- par[121];
                  logP24F2  <- par[122];
                  logP25F2  <- par[123];
                  logP26F2  <- par[124];
                  logP27F2  <- par[125];
                  logP28F2  <- par[126];
                  logP29F2  <- par[127];
                  logP30F2  <- par[128];
                  logP31F2  <- par[129];
                  logP32F2  <- par[130];
                  logP33F2  <- par[131];
                  logP34F2  <- par[132];
                  logP35F2  <- par[133];
                  logP36F2  <- par[134];
                  logP37F2  <- par[135];
                  logP38F2  <- par[136];
                  logP39F2  <- par[137];
                  logP40F2  <- par[138];
                  logP41F2  <- par[139];
                  logP42F2  <- par[140];
                  logP43F2  <- par[141];
                  logP44F2  <- par[142];
                  logP45F2  <- par[143];
                  logP46F2  <- par[144];
                  logP47F2  <- par[145];
                  logP48F2  <- par[146];
                  logP49F2  <- par[147];
                  logP50F2  <- par[148];
                  logP51F2  <- par[149];
                  logP52F2  <- par[150];
                  logP53F2  <- par[151];
                  logP54F2  <- par[152];
                  logP55F2  <- par[153];
                  logP56F2  <- par[154];
                  logP57F2  <- par[155];
                  logP58F2  <- par[156];
                  logP59F2  <- par[157];
                  logP60F2  <- par[158];
                  logP61F2  <- par[159];
                  logP62F2  <- par[160];
                  logP63F2  <- par[161];
                  logP64F2  <- par[162];
                  logP65F2  <- par[163];
                  logP66F2  <- par[164];
                  logP67F2  <- par[165];
                  logP68F2  <- par[166];
                  logP69F2  <- par[167];
                  logP70F2  <- par[168];
                  logP71F2  <- par[169];
                  logP72F2  <- par[170];
                  logP73F2  <- par[171];
                  logP74F2  <- par[172];
                  logP75F2  <- par[173];
                  logP76F2  <- par[174];
                  logP77F2  <- par[175];
                  logP78F2  <- par[176];
                  logP79F2  <- par[177];
                  logP80F2  <- par[178];
                  logP81F2  <- par[179];
                  logP82F2  <- par[180];
                  logP83F2  <- par[181];
                  logP84F2  <- par[182];
                  logP85F2  <- par[183];
                  logP86F2  <- par[184];
                  logP87F2  <- par[185];
                  logP88F2  <- par[186];
                  logP89F2  <- par[187];
                  logP90F2  <- par[188];
                  logP91F2  <- par[189];
                  logP92F2  <- par[190];
                  logP93F2  <- par[191];
                  logscale2 <- par[192];
                  logalpha2 <- par[193];
                  logbeta2  <- par[194];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN94P94P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(94,94))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts1.P94   <- dates[95];
                  ts2.P1    <- dates[96];
                  ts2.P2    <- dates[97];
                  ts2.P3    <- dates[98];
                  ts2.P4    <- dates[99];
                  ts2.P5    <- dates[100];
                  ts2.P6    <- dates[101];
                  ts2.P7    <- dates[102];
                  ts2.P8    <- dates[103];
                  ts2.P9    <- dates[104];
                  ts2.P10   <- dates[105];
                  ts2.P11   <- dates[106];
                  ts2.P12   <- dates[107];
                  ts2.P13   <- dates[108];
                  ts2.P14   <- dates[109];
                  ts2.P15   <- dates[110];
                  ts2.P16   <- dates[111];
                  ts2.P17   <- dates[112];
                  ts2.P18   <- dates[113];
                  ts2.P19   <- dates[114];
                  ts2.P20   <- dates[115];
                  ts2.P21   <- dates[116];
                  ts2.P22   <- dates[117];
                  ts2.P23   <- dates[118];
                  ts2.P24   <- dates[119];
                  ts2.P25   <- dates[120];
                  ts2.P26   <- dates[121];
                  ts2.P27   <- dates[122];
                  ts2.P28   <- dates[123];
                  ts2.P29   <- dates[124];
                  ts2.P30   <- dates[125];
                  ts2.P31   <- dates[126];
                  ts2.P32   <- dates[127];
                  ts2.P33   <- dates[128];
                  ts2.P34   <- dates[129];
                  ts2.P35   <- dates[130];
                  ts2.P36   <- dates[131];
                  ts2.P37   <- dates[132];
                  ts2.P38   <- dates[133];
                  ts2.P39   <- dates[134];
                  ts2.P40   <- dates[135];
                  ts2.P41   <- dates[136];
                  ts2.P42   <- dates[137];
                  ts2.P43   <- dates[138];
                  ts2.P44   <- dates[139];
                  ts2.P45   <- dates[140];
                  ts2.P46   <- dates[141];
                  ts2.P47   <- dates[142];
                  ts2.P48   <- dates[143];
                  ts2.P49   <- dates[144];
                  ts2.P50   <- dates[145];
                  ts2.P51   <- dates[146];
                  ts2.P52   <- dates[147];
                  ts2.P53   <- dates[148];
                  ts2.P54   <- dates[149];
                  ts2.P55   <- dates[150];
                  ts2.P56   <- dates[151];
                  ts2.P57   <- dates[152];
                  ts2.P58   <- dates[153];
                  ts2.P59   <- dates[154];
                  ts2.P60   <- dates[155];
                  ts2.P61   <- dates[156];
                  ts2.P62   <- dates[157];
                  ts2.P63   <- dates[158];
                  ts2.P64   <- dates[159];
                  ts2.P65   <- dates[160];
                  ts2.P66   <- dates[161];
                  ts2.P67   <- dates[162];
                  ts2.P68   <- dates[163];
                  ts2.P69   <- dates[164];
                  ts2.P70   <- dates[165];
                  ts2.P71   <- dates[166];
                  ts2.P72   <- dates[167];
                  ts2.P73   <- dates[168];
                  ts2.P74   <- dates[169];
                  ts2.P75   <- dates[170];
                  ts2.P76   <- dates[171];
                  ts2.P77   <- dates[172];
                  ts2.P78   <- dates[173];
                  ts2.P79   <- dates[174];
                  ts2.P80   <- dates[175];
                  ts2.P81   <- dates[176];
                  ts2.P82   <- dates[177];
                  ts2.P83   <- dates[178];
                  ts2.P84   <- dates[179];
                  ts2.P85   <- dates[180];
                  ts2.P86   <- dates[181];
                  ts2.P87   <- dates[182];
                  ts2.P88   <- dates[183];
                  ts2.P89   <- dates[184];
                  ts2.P90   <- dates[185];
                  ts2.P91   <- dates[186];
                  ts2.P92   <- dates[187];
                  ts2.P93   <- dates[188];
                  ts2.P94   <- dates[189];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  ind1.P94  <- ifelse(1:sealen < (ts1.P94-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  ind2.P94  <- ifelse(1:sealen < (ts2.P94-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logP94F1  <- par[96];
                  logscale1 <- par[97];
                  logalpha1 <- par[98];
                  logbeta1  <- par[99];
                  logP1F2   <- par[100];
                  logP2F2   <- par[101];
                  logP3F2   <- par[102];
                  logP4F2   <- par[103];
                  logP5F2   <- par[104];
                  logP6F2   <- par[105];
                  logP7F2   <- par[106];
                  logP8F2   <- par[107];
                  logP9F2   <- par[108];
                  logP10F2  <- par[109];
                  logP11F2  <- par[110];
                  logP12F2  <- par[111];
                  logP13F2  <- par[112];
                  logP14F2  <- par[113];
                  logP15F2  <- par[114];
                  logP16F2  <- par[115];
                  logP17F2  <- par[116];
                  logP18F2  <- par[117];
                  logP19F2  <- par[118];
                  logP20F2  <- par[119];
                  logP21F2  <- par[120];
                  logP22F2  <- par[121];
                  logP23F2  <- par[122];
                  logP24F2  <- par[123];
                  logP25F2  <- par[124];
                  logP26F2  <- par[125];
                  logP27F2  <- par[126];
                  logP28F2  <- par[127];
                  logP29F2  <- par[128];
                  logP30F2  <- par[129];
                  logP31F2  <- par[130];
                  logP32F2  <- par[131];
                  logP33F2  <- par[132];
                  logP34F2  <- par[133];
                  logP35F2  <- par[134];
                  logP36F2  <- par[135];
                  logP37F2  <- par[136];
                  logP38F2  <- par[137];
                  logP39F2  <- par[138];
                  logP40F2  <- par[139];
                  logP41F2  <- par[140];
                  logP42F2  <- par[141];
                  logP43F2  <- par[142];
                  logP44F2  <- par[143];
                  logP45F2  <- par[144];
                  logP46F2  <- par[145];
                  logP47F2  <- par[146];
                  logP48F2  <- par[147];
                  logP49F2  <- par[148];
                  logP50F2  <- par[149];
                  logP51F2  <- par[150];
                  logP52F2  <- par[151];
                  logP53F2  <- par[152];
                  logP54F2  <- par[153];
                  logP55F2  <- par[154];
                  logP56F2  <- par[155];
                  logP57F2  <- par[156];
                  logP58F2  <- par[157];
                  logP59F2  <- par[158];
                  logP60F2  <- par[159];
                  logP61F2  <- par[160];
                  logP62F2  <- par[161];
                  logP63F2  <- par[162];
                  logP64F2  <- par[163];
                  logP65F2  <- par[164];
                  logP66F2  <- par[165];
                  logP67F2  <- par[166];
                  logP68F2  <- par[167];
                  logP69F2  <- par[168];
                  logP70F2  <- par[169];
                  logP71F2  <- par[170];
                  logP72F2  <- par[171];
                  logP73F2  <- par[172];
                  logP74F2  <- par[173];
                  logP75F2  <- par[174];
                  logP76F2  <- par[175];
                  logP77F2  <- par[176];
                  logP78F2  <- par[177];
                  logP79F2  <- par[178];
                  logP80F2  <- par[179];
                  logP81F2  <- par[180];
                  logP82F2  <- par[181];
                  logP83F2  <- par[182];
                  logP84F2  <- par[183];
                  logP85F2  <- par[184];
                  logP86F2  <- par[185];
                  logP87F2  <- par[186];
                  logP88F2  <- par[187];
                  logP89F2  <- par[188];
                  logP90F2  <- par[189];
                  logP91F2  <- par[190];
                  logP92F2  <- par[191];
                  logP93F2  <- par[192];
                  logP94F2  <- par[193];
                  logscale2 <- par[194];
                  logalpha2 <- par[195];
                  logbeta2  <- par[196];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind1.P94[i]*exp(logP94F1)*exp(-exp(logM)*(i-(ts1.P94-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) +
                                 ind2.P94[i]*exp(logP94F2)*exp(-exp(logM)*(i-(ts2.P94-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN95P95P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(95,95))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts1.P94   <- dates[95];
                  ts1.P95   <- dates[96];
                  ts2.P1    <- dates[97];
                  ts2.P2    <- dates[98];
                  ts2.P3    <- dates[99];
                  ts2.P4    <- dates[100];
                  ts2.P5    <- dates[101];
                  ts2.P6    <- dates[102];
                  ts2.P7    <- dates[103];
                  ts2.P8    <- dates[104];
                  ts2.P9    <- dates[105];
                  ts2.P10   <- dates[106];
                  ts2.P11   <- dates[107];
                  ts2.P12   <- dates[108];
                  ts2.P13   <- dates[109];
                  ts2.P14   <- dates[110];
                  ts2.P15   <- dates[111];
                  ts2.P16   <- dates[112];
                  ts2.P17   <- dates[113];
                  ts2.P18   <- dates[114];
                  ts2.P19   <- dates[115];
                  ts2.P20   <- dates[116];
                  ts2.P21   <- dates[117];
                  ts2.P22   <- dates[118];
                  ts2.P23   <- dates[119];
                  ts2.P24   <- dates[120];
                  ts2.P25   <- dates[121];
                  ts2.P26   <- dates[122];
                  ts2.P27   <- dates[123];
                  ts2.P28   <- dates[124];
                  ts2.P29   <- dates[125];
                  ts2.P30   <- dates[126];
                  ts2.P31   <- dates[127];
                  ts2.P32   <- dates[128];
                  ts2.P33   <- dates[129];
                  ts2.P34   <- dates[130];
                  ts2.P35   <- dates[131];
                  ts2.P36   <- dates[132];
                  ts2.P37   <- dates[133];
                  ts2.P38   <- dates[134];
                  ts2.P39   <- dates[135];
                  ts2.P40   <- dates[136];
                  ts2.P41   <- dates[137];
                  ts2.P42   <- dates[138];
                  ts2.P43   <- dates[139];
                  ts2.P44   <- dates[140];
                  ts2.P45   <- dates[141];
                  ts2.P46   <- dates[142];
                  ts2.P47   <- dates[143];
                  ts2.P48   <- dates[144];
                  ts2.P49   <- dates[145];
                  ts2.P50   <- dates[146];
                  ts2.P51   <- dates[147];
                  ts2.P52   <- dates[148];
                  ts2.P53   <- dates[149];
                  ts2.P54   <- dates[150];
                  ts2.P55   <- dates[151];
                  ts2.P56   <- dates[152];
                  ts2.P57   <- dates[153];
                  ts2.P58   <- dates[154];
                  ts2.P59   <- dates[155];
                  ts2.P60   <- dates[156];
                  ts2.P61   <- dates[157];
                  ts2.P62   <- dates[158];
                  ts2.P63   <- dates[159];
                  ts2.P64   <- dates[160];
                  ts2.P65   <- dates[161];
                  ts2.P66   <- dates[162];
                  ts2.P67   <- dates[163];
                  ts2.P68   <- dates[164];
                  ts2.P69   <- dates[165];
                  ts2.P70   <- dates[166];
                  ts2.P71   <- dates[167];
                  ts2.P72   <- dates[168];
                  ts2.P73   <- dates[169];
                  ts2.P74   <- dates[170];
                  ts2.P75   <- dates[171];
                  ts2.P76   <- dates[172];
                  ts2.P77   <- dates[173];
                  ts2.P78   <- dates[174];
                  ts2.P79   <- dates[175];
                  ts2.P80   <- dates[176];
                  ts2.P81   <- dates[177];
                  ts2.P82   <- dates[178];
                  ts2.P83   <- dates[179];
                  ts2.P84   <- dates[180];
                  ts2.P85   <- dates[181];
                  ts2.P86   <- dates[182];
                  ts2.P87   <- dates[183];
                  ts2.P88   <- dates[184];
                  ts2.P89   <- dates[185];
                  ts2.P90   <- dates[186];
                  ts2.P91   <- dates[187];
                  ts2.P92   <- dates[188];
                  ts2.P93   <- dates[189];
                  ts2.P94   <- dates[190];
                  ts2.P95   <- dates[191];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  ind1.P94  <- ifelse(1:sealen < (ts1.P94-ts.start), 0, 1);
                  ind1.P95  <- ifelse(1:sealen < (ts1.P95-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  ind2.P94  <- ifelse(1:sealen < (ts2.P94-ts.start), 0, 1);
                  ind2.P95  <- ifelse(1:sealen < (ts2.P95-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logP94F1  <- par[96];
                  logP95F1  <- par[97];
                  logscale1 <- par[98];
                  logalpha1 <- par[99];
                  logbeta1  <- par[100];
                  logP1F2   <- par[101];
                  logP2F2   <- par[102];
                  logP3F2   <- par[103];
                  logP4F2   <- par[104];
                  logP5F2   <- par[105];
                  logP6F2   <- par[106];
                  logP7F2   <- par[107];
                  logP8F2   <- par[108];
                  logP9F2   <- par[109];
                  logP10F2  <- par[110];
                  logP11F2  <- par[111];
                  logP12F2  <- par[112];
                  logP13F2  <- par[113];
                  logP14F2  <- par[114];
                  logP15F2  <- par[115];
                  logP16F2  <- par[116];
                  logP17F2  <- par[117];
                  logP18F2  <- par[118];
                  logP19F2  <- par[119];
                  logP20F2  <- par[120];
                  logP21F2  <- par[121];
                  logP22F2  <- par[122];
                  logP23F2  <- par[123];
                  logP24F2  <- par[124];
                  logP25F2  <- par[125];
                  logP26F2  <- par[126];
                  logP27F2  <- par[127];
                  logP28F2  <- par[128];
                  logP29F2  <- par[129];
                  logP30F2  <- par[130];
                  logP31F2  <- par[131];
                  logP32F2  <- par[132];
                  logP33F2  <- par[133];
                  logP34F2  <- par[134];
                  logP35F2  <- par[135];
                  logP36F2  <- par[136];
                  logP37F2  <- par[137];
                  logP38F2  <- par[138];
                  logP39F2  <- par[139];
                  logP40F2  <- par[140];
                  logP41F2  <- par[141];
                  logP42F2  <- par[142];
                  logP43F2  <- par[143];
                  logP44F2  <- par[144];
                  logP45F2  <- par[145];
                  logP46F2  <- par[146];
                  logP47F2  <- par[147];
                  logP48F2  <- par[148];
                  logP49F2  <- par[149];
                  logP50F2  <- par[150];
                  logP51F2  <- par[151];
                  logP52F2  <- par[152];
                  logP53F2  <- par[153];
                  logP54F2  <- par[154];
                  logP55F2  <- par[155];
                  logP56F2  <- par[156];
                  logP57F2  <- par[157];
                  logP58F2  <- par[158];
                  logP59F2  <- par[159];
                  logP60F2  <- par[160];
                  logP61F2  <- par[161];
                  logP62F2  <- par[162];
                  logP63F2  <- par[163];
                  logP64F2  <- par[164];
                  logP65F2  <- par[165];
                  logP66F2  <- par[166];
                  logP67F2  <- par[167];
                  logP68F2  <- par[168];
                  logP69F2  <- par[169];
                  logP70F2  <- par[170];
                  logP71F2  <- par[171];
                  logP72F2  <- par[172];
                  logP73F2  <- par[173];
                  logP74F2  <- par[174];
                  logP75F2  <- par[175];
                  logP76F2  <- par[176];
                  logP77F2  <- par[177];
                  logP78F2  <- par[178];
                  logP79F2  <- par[179];
                  logP80F2  <- par[180];
                  logP81F2  <- par[181];
                  logP82F2  <- par[182];
                  logP83F2  <- par[183];
                  logP84F2  <- par[184];
                  logP85F2  <- par[185];
                  logP86F2  <- par[186];
                  logP87F2  <- par[187];
                  logP88F2  <- par[188];
                  logP89F2  <- par[189];
                  logP90F2  <- par[190];
                  logP91F2  <- par[191];
                  logP92F2  <- par[192];
                  logP93F2  <- par[193];
                  logP94F2  <- par[194];
                  logP95F2  <- par[195];
                  logscale2 <- par[196];
                  logalpha2 <- par[197];
                  logbeta2  <- par[198];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind1.P94[i]*exp(logP94F1)*exp(-exp(logM)*(i-(ts1.P94-ts.start)+1)) +
                                 ind1.P95[i]*exp(logP95F1)*exp(-exp(logM)*(i-(ts1.P95-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) +
                                 ind2.P94[i]*exp(logP94F2)*exp(-exp(logM)*(i-(ts2.P94-ts.start)+1)) +
                                 ind2.P95[i]*exp(logP95F2)*exp(-exp(logM)*(i-(ts2.P95-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN96P96P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(96,96))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts1.P94   <- dates[95];
                  ts1.P95   <- dates[96];
                  ts1.P96   <- dates[97];
                  ts2.P1    <- dates[98];
                  ts2.P2    <- dates[99];
                  ts2.P3    <- dates[100];
                  ts2.P4    <- dates[101];
                  ts2.P5    <- dates[102];
                  ts2.P6    <- dates[103];
                  ts2.P7    <- dates[104];
                  ts2.P8    <- dates[105];
                  ts2.P9    <- dates[106];
                  ts2.P10   <- dates[107];
                  ts2.P11   <- dates[108];
                  ts2.P12   <- dates[109];
                  ts2.P13   <- dates[110];
                  ts2.P14   <- dates[111];
                  ts2.P15   <- dates[112];
                  ts2.P16   <- dates[113];
                  ts2.P17   <- dates[114];
                  ts2.P18   <- dates[115];
                  ts2.P19   <- dates[116];
                  ts2.P20   <- dates[117];
                  ts2.P21   <- dates[118];
                  ts2.P22   <- dates[119];
                  ts2.P23   <- dates[120];
                  ts2.P24   <- dates[121];
                  ts2.P25   <- dates[122];
                  ts2.P26   <- dates[123];
                  ts2.P27   <- dates[124];
                  ts2.P28   <- dates[125];
                  ts2.P29   <- dates[126];
                  ts2.P30   <- dates[127];
                  ts2.P31   <- dates[128];
                  ts2.P32   <- dates[129];
                  ts2.P33   <- dates[130];
                  ts2.P34   <- dates[131];
                  ts2.P35   <- dates[132];
                  ts2.P36   <- dates[133];
                  ts2.P37   <- dates[134];
                  ts2.P38   <- dates[135];
                  ts2.P39   <- dates[136];
                  ts2.P40   <- dates[137];
                  ts2.P41   <- dates[138];
                  ts2.P42   <- dates[139];
                  ts2.P43   <- dates[140];
                  ts2.P44   <- dates[141];
                  ts2.P45   <- dates[142];
                  ts2.P46   <- dates[143];
                  ts2.P47   <- dates[144];
                  ts2.P48   <- dates[145];
                  ts2.P49   <- dates[146];
                  ts2.P50   <- dates[147];
                  ts2.P51   <- dates[148];
                  ts2.P52   <- dates[149];
                  ts2.P53   <- dates[150];
                  ts2.P54   <- dates[151];
                  ts2.P55   <- dates[152];
                  ts2.P56   <- dates[153];
                  ts2.P57   <- dates[154];
                  ts2.P58   <- dates[155];
                  ts2.P59   <- dates[156];
                  ts2.P60   <- dates[157];
                  ts2.P61   <- dates[158];
                  ts2.P62   <- dates[159];
                  ts2.P63   <- dates[160];
                  ts2.P64   <- dates[161];
                  ts2.P65   <- dates[162];
                  ts2.P66   <- dates[163];
                  ts2.P67   <- dates[164];
                  ts2.P68   <- dates[165];
                  ts2.P69   <- dates[166];
                  ts2.P70   <- dates[167];
                  ts2.P71   <- dates[168];
                  ts2.P72   <- dates[169];
                  ts2.P73   <- dates[170];
                  ts2.P74   <- dates[171];
                  ts2.P75   <- dates[172];
                  ts2.P76   <- dates[173];
                  ts2.P77   <- dates[174];
                  ts2.P78   <- dates[175];
                  ts2.P79   <- dates[176];
                  ts2.P80   <- dates[177];
                  ts2.P81   <- dates[178];
                  ts2.P82   <- dates[179];
                  ts2.P83   <- dates[180];
                  ts2.P84   <- dates[181];
                  ts2.P85   <- dates[182];
                  ts2.P86   <- dates[183];
                  ts2.P87   <- dates[184];
                  ts2.P88   <- dates[185];
                  ts2.P89   <- dates[186];
                  ts2.P90   <- dates[187];
                  ts2.P91   <- dates[188];
                  ts2.P92   <- dates[189];
                  ts2.P93   <- dates[190];
                  ts2.P94   <- dates[191];
                  ts2.P95   <- dates[192];
                  ts2.P96   <- dates[193];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  ind1.P94  <- ifelse(1:sealen < (ts1.P94-ts.start), 0, 1);
                  ind1.P95  <- ifelse(1:sealen < (ts1.P95-ts.start), 0, 1);
                  ind1.P96  <- ifelse(1:sealen < (ts1.P96-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  ind2.P94  <- ifelse(1:sealen < (ts2.P94-ts.start), 0, 1);
                  ind2.P95  <- ifelse(1:sealen < (ts2.P95-ts.start), 0, 1);
                  ind2.P96  <- ifelse(1:sealen < (ts2.P96-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logP94F1  <- par[96];
                  logP95F1  <- par[97];
                  logP96F1  <- par[98];
                  logscale1 <- par[99];
                  logalpha1 <- par[100];
                  logbeta1  <- par[101];
                  logP1F2   <- par[102];
                  logP2F2   <- par[103];
                  logP3F2   <- par[104];
                  logP4F2   <- par[105];
                  logP5F2   <- par[106];
                  logP6F2   <- par[107];
                  logP7F2   <- par[108];
                  logP8F2   <- par[109];
                  logP9F2   <- par[110];
                  logP10F2  <- par[111];
                  logP11F2  <- par[112];
                  logP12F2  <- par[113];
                  logP13F2  <- par[114];
                  logP14F2  <- par[115];
                  logP15F2  <- par[116];
                  logP16F2  <- par[117];
                  logP17F2  <- par[118];
                  logP18F2  <- par[119];
                  logP19F2  <- par[120];
                  logP20F2  <- par[121];
                  logP21F2  <- par[122];
                  logP22F2  <- par[123];
                  logP23F2  <- par[124];
                  logP24F2  <- par[125];
                  logP25F2  <- par[126];
                  logP26F2  <- par[127];
                  logP27F2  <- par[128];
                  logP28F2  <- par[129];
                  logP29F2  <- par[130];
                  logP30F2  <- par[131];
                  logP31F2  <- par[132];
                  logP32F2  <- par[133];
                  logP33F2  <- par[134];
                  logP34F2  <- par[135];
                  logP35F2  <- par[136];
                  logP36F2  <- par[137];
                  logP37F2  <- par[138];
                  logP38F2  <- par[139];
                  logP39F2  <- par[140];
                  logP40F2  <- par[141];
                  logP41F2  <- par[142];
                  logP42F2  <- par[143];
                  logP43F2  <- par[144];
                  logP44F2  <- par[145];
                  logP45F2  <- par[146];
                  logP46F2  <- par[147];
                  logP47F2  <- par[148];
                  logP48F2  <- par[149];
                  logP49F2  <- par[150];
                  logP50F2  <- par[151];
                  logP51F2  <- par[152];
                  logP52F2  <- par[153];
                  logP53F2  <- par[154];
                  logP54F2  <- par[155];
                  logP55F2  <- par[156];
                  logP56F2  <- par[157];
                  logP57F2  <- par[158];
                  logP58F2  <- par[159];
                  logP59F2  <- par[160];
                  logP60F2  <- par[161];
                  logP61F2  <- par[162];
                  logP62F2  <- par[163];
                  logP63F2  <- par[164];
                  logP64F2  <- par[165];
                  logP65F2  <- par[166];
                  logP66F2  <- par[167];
                  logP67F2  <- par[168];
                  logP68F2  <- par[169];
                  logP69F2  <- par[170];
                  logP70F2  <- par[171];
                  logP71F2  <- par[172];
                  logP72F2  <- par[173];
                  logP73F2  <- par[174];
                  logP74F2  <- par[175];
                  logP75F2  <- par[176];
                  logP76F2  <- par[177];
                  logP77F2  <- par[178];
                  logP78F2  <- par[179];
                  logP79F2  <- par[180];
                  logP80F2  <- par[181];
                  logP81F2  <- par[182];
                  logP82F2  <- par[183];
                  logP83F2  <- par[184];
                  logP84F2  <- par[185];
                  logP85F2  <- par[186];
                  logP86F2  <- par[187];
                  logP87F2  <- par[188];
                  logP88F2  <- par[189];
                  logP89F2  <- par[190];
                  logP90F2  <- par[191];
                  logP91F2  <- par[192];
                  logP92F2  <- par[193];
                  logP93F2  <- par[194];
                  logP94F2  <- par[195];
                  logP95F2  <- par[196];
                  logP96F2  <- par[197];
                  logscale2 <- par[198];
                  logalpha2 <- par[199];
                  logbeta2  <- par[200];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind1.P94[i]*exp(logP94F1)*exp(-exp(logM)*(i-(ts1.P94-ts.start)+1)) +
                                 ind1.P95[i]*exp(logP95F1)*exp(-exp(logM)*(i-(ts1.P95-ts.start)+1)) +
                                 ind1.P96[i]*exp(logP96F1)*exp(-exp(logM)*(i-(ts1.P96-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) +
                                 ind2.P94[i]*exp(logP94F2)*exp(-exp(logM)*(i-(ts2.P94-ts.start)+1)) +
                                 ind2.P95[i]*exp(logP95F2)*exp(-exp(logM)*(i-(ts2.P95-ts.start)+1)) +
                                 ind2.P96[i]*exp(logP96F2)*exp(-exp(logM)*(i-(ts2.P96-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN97P97P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(97,97))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts1.P94   <- dates[95];
                  ts1.P95   <- dates[96];
                  ts1.P96   <- dates[97];
                  ts1.P97   <- dates[98];
                  ts2.P1    <- dates[99];
                  ts2.P2    <- dates[100];
                  ts2.P3    <- dates[101];
                  ts2.P4    <- dates[102];
                  ts2.P5    <- dates[103];
                  ts2.P6    <- dates[104];
                  ts2.P7    <- dates[105];
                  ts2.P8    <- dates[106];
                  ts2.P9    <- dates[107];
                  ts2.P10   <- dates[108];
                  ts2.P11   <- dates[109];
                  ts2.P12   <- dates[110];
                  ts2.P13   <- dates[111];
                  ts2.P14   <- dates[112];
                  ts2.P15   <- dates[113];
                  ts2.P16   <- dates[114];
                  ts2.P17   <- dates[115];
                  ts2.P18   <- dates[116];
                  ts2.P19   <- dates[117];
                  ts2.P20   <- dates[118];
                  ts2.P21   <- dates[119];
                  ts2.P22   <- dates[120];
                  ts2.P23   <- dates[121];
                  ts2.P24   <- dates[122];
                  ts2.P25   <- dates[123];
                  ts2.P26   <- dates[124];
                  ts2.P27   <- dates[125];
                  ts2.P28   <- dates[126];
                  ts2.P29   <- dates[127];
                  ts2.P30   <- dates[128];
                  ts2.P31   <- dates[129];
                  ts2.P32   <- dates[130];
                  ts2.P33   <- dates[131];
                  ts2.P34   <- dates[132];
                  ts2.P35   <- dates[133];
                  ts2.P36   <- dates[134];
                  ts2.P37   <- dates[135];
                  ts2.P38   <- dates[136];
                  ts2.P39   <- dates[137];
                  ts2.P40   <- dates[138];
                  ts2.P41   <- dates[139];
                  ts2.P42   <- dates[140];
                  ts2.P43   <- dates[141];
                  ts2.P44   <- dates[142];
                  ts2.P45   <- dates[143];
                  ts2.P46   <- dates[144];
                  ts2.P47   <- dates[145];
                  ts2.P48   <- dates[146];
                  ts2.P49   <- dates[147];
                  ts2.P50   <- dates[148];
                  ts2.P51   <- dates[149];
                  ts2.P52   <- dates[150];
                  ts2.P53   <- dates[151];
                  ts2.P54   <- dates[152];
                  ts2.P55   <- dates[153];
                  ts2.P56   <- dates[154];
                  ts2.P57   <- dates[155];
                  ts2.P58   <- dates[156];
                  ts2.P59   <- dates[157];
                  ts2.P60   <- dates[158];
                  ts2.P61   <- dates[159];
                  ts2.P62   <- dates[160];
                  ts2.P63   <- dates[161];
                  ts2.P64   <- dates[162];
                  ts2.P65   <- dates[163];
                  ts2.P66   <- dates[164];
                  ts2.P67   <- dates[165];
                  ts2.P68   <- dates[166];
                  ts2.P69   <- dates[167];
                  ts2.P70   <- dates[168];
                  ts2.P71   <- dates[169];
                  ts2.P72   <- dates[170];
                  ts2.P73   <- dates[171];
                  ts2.P74   <- dates[172];
                  ts2.P75   <- dates[173];
                  ts2.P76   <- dates[174];
                  ts2.P77   <- dates[175];
                  ts2.P78   <- dates[176];
                  ts2.P79   <- dates[177];
                  ts2.P80   <- dates[178];
                  ts2.P81   <- dates[179];
                  ts2.P82   <- dates[180];
                  ts2.P83   <- dates[181];
                  ts2.P84   <- dates[182];
                  ts2.P85   <- dates[183];
                  ts2.P86   <- dates[184];
                  ts2.P87   <- dates[185];
                  ts2.P88   <- dates[186];
                  ts2.P89   <- dates[187];
                  ts2.P90   <- dates[188];
                  ts2.P91   <- dates[189];
                  ts2.P92   <- dates[190];
                  ts2.P93   <- dates[191];
                  ts2.P94   <- dates[192];
                  ts2.P95   <- dates[193];
                  ts2.P96   <- dates[194];
                  ts2.P97   <- dates[195];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  ind1.P94  <- ifelse(1:sealen < (ts1.P94-ts.start), 0, 1);
                  ind1.P95  <- ifelse(1:sealen < (ts1.P95-ts.start), 0, 1);
                  ind1.P96  <- ifelse(1:sealen < (ts1.P96-ts.start), 0, 1);
                  ind1.P97  <- ifelse(1:sealen < (ts1.P97-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  ind2.P94  <- ifelse(1:sealen < (ts2.P94-ts.start), 0, 1);
                  ind2.P95  <- ifelse(1:sealen < (ts2.P95-ts.start), 0, 1);
                  ind2.P96  <- ifelse(1:sealen < (ts2.P96-ts.start), 0, 1);
                  ind2.P97  <- ifelse(1:sealen < (ts2.P97-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[92];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logP94F1  <- par[96];
                  logP95F1  <- par[97];
                  logP96F1  <- par[98];
                  logP97F1  <- par[99];
                  logscale1 <- par[100];
                  logalpha1 <- par[101];
                  logbeta1  <- par[102];
                  logP1F2   <- par[103];
                  logP2F2   <- par[104];
                  logP3F2   <- par[105];
                  logP4F2   <- par[106];
                  logP5F2   <- par[107];
                  logP6F2   <- par[108];
                  logP7F2   <- par[109];
                  logP8F2   <- par[110];
                  logP9F2   <- par[111];
                  logP10F2  <- par[112];
                  logP11F2  <- par[113];
                  logP12F2  <- par[114];
                  logP13F2  <- par[115];
                  logP14F2  <- par[116];
                  logP15F2  <- par[117];
                  logP16F2  <- par[118];
                  logP17F2  <- par[119];
                  logP18F2  <- par[120];
                  logP19F2  <- par[121];
                  logP20F2  <- par[122];
                  logP21F2  <- par[123];
                  logP22F2  <- par[124];
                  logP23F2  <- par[125];
                  logP24F2  <- par[126];
                  logP25F2  <- par[127];
                  logP26F2  <- par[128];
                  logP27F2  <- par[129];
                  logP28F2  <- par[130];
                  logP29F2  <- par[131];
                  logP30F2  <- par[132];
                  logP31F2  <- par[133];
                  logP32F2  <- par[134];
                  logP33F2  <- par[135];
                  logP34F2  <- par[136];
                  logP35F2  <- par[137];
                  logP36F2  <- par[138];
                  logP37F2  <- par[139];
                  logP38F2  <- par[140];
                  logP39F2  <- par[141];
                  logP40F2  <- par[142];
                  logP41F2  <- par[143];
                  logP42F2  <- par[144];
                  logP43F2  <- par[145];
                  logP44F2  <- par[146];
                  logP45F2  <- par[147];
                  logP46F2  <- par[148];
                  logP47F2  <- par[149];
                  logP48F2  <- par[150];
                  logP49F2  <- par[151];
                  logP50F2  <- par[152];
                  logP51F2  <- par[153];
                  logP52F2  <- par[154];
                  logP53F2  <- par[155];
                  logP54F2  <- par[156];
                  logP55F2  <- par[157];
                  logP56F2  <- par[158];
                  logP57F2  <- par[159];
                  logP58F2  <- par[160];
                  logP59F2  <- par[161];
                  logP60F2  <- par[162];
                  logP61F2  <- par[163];
                  logP62F2  <- par[164];
                  logP63F2  <- par[165];
                  logP64F2  <- par[166];
                  logP65F2  <- par[167];
                  logP66F2  <- par[168];
                  logP67F2  <- par[169];
                  logP68F2  <- par[170];
                  logP69F2  <- par[171];
                  logP70F2  <- par[172];
                  logP71F2  <- par[173];
                  logP72F2  <- par[174];
                  logP73F2  <- par[175];
                  logP74F2  <- par[176];
                  logP75F2  <- par[177];
                  logP76F2  <- par[178];
                  logP77F2  <- par[179];
                  logP78F2  <- par[180];
                  logP79F2  <- par[181];
                  logP80F2  <- par[182];
                  logP81F2  <- par[183];
                  logP82F2  <- par[184];
                  logP83F2  <- par[185];
                  logP84F2  <- par[186];
                  logP85F2  <- par[187];
                  logP86F2  <- par[188];
                  logP87F2  <- par[189];
                  logP88F2  <- par[190];
                  logP89F2  <- par[191];
                  logP90F2  <- par[192];
                  logP91F2  <- par[193];
                  logP92F2  <- par[194];
                  logP93F2  <- par[195];
                  logP94F2  <- par[196];
                  logP95F2  <- par[197];
                  logP96F2  <- par[198];
                  logP97F2  <- par[199];
                  logscale2 <- par[200];
                  logalpha2 <- par[201];
                  logbeta2  <- par[202];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind1.P94[i]*exp(logP94F1)*exp(-exp(logM)*(i-(ts1.P94-ts.start)+1)) +
                                 ind1.P95[i]*exp(logP95F1)*exp(-exp(logM)*(i-(ts1.P95-ts.start)+1)) +
                                 ind1.P96[i]*exp(logP96F1)*exp(-exp(logM)*(i-(ts1.P96-ts.start)+1)) +
                                 ind1.P97[i]*exp(logP97F1)*exp(-exp(logM)*(i-(ts1.P97-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) +
                                 ind2.P94[i]*exp(logP94F2)*exp(-exp(logM)*(i-(ts2.P94-ts.start)+1)) +
                                 ind2.P95[i]*exp(logP95F2)*exp(-exp(logM)*(i-(ts2.P95-ts.start)+1)) +
                                 ind2.P96[i]*exp(logP96F2)*exp(-exp(logM)*(i-(ts2.P96-ts.start)+1)) +
                                 ind2.P97[i]*exp(logP97F2)*exp(-exp(logM)*(i-(ts2.P97-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN98P98P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(98,98))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts1.P94   <- dates[95];
                  ts1.P95   <- dates[96];
                  ts1.P96   <- dates[97];
                  ts1.P97   <- dates[98];
                  ts1.P98   <- dates[99];
                  ts2.P1    <- dates[100];
                  ts2.P2    <- dates[101];
                  ts2.P3    <- dates[102];
                  ts2.P4    <- dates[103];
                  ts2.P5    <- dates[104];
                  ts2.P6    <- dates[105];
                  ts2.P7    <- dates[106];
                  ts2.P8    <- dates[107];
                  ts2.P9    <- dates[108];
                  ts2.P10   <- dates[109];
                  ts2.P11   <- dates[110];
                  ts2.P12   <- dates[111];
                  ts2.P13   <- dates[112];
                  ts2.P14   <- dates[113];
                  ts2.P15   <- dates[114];
                  ts2.P16   <- dates[115];
                  ts2.P17   <- dates[116];
                  ts2.P18   <- dates[117];
                  ts2.P19   <- dates[118];
                  ts2.P20   <- dates[119];
                  ts2.P21   <- dates[120];
                  ts2.P22   <- dates[121];
                  ts2.P23   <- dates[122];
                  ts2.P24   <- dates[123];
                  ts2.P25   <- dates[124];
                  ts2.P26   <- dates[125];
                  ts2.P27   <- dates[126];
                  ts2.P28   <- dates[127];
                  ts2.P29   <- dates[128];
                  ts2.P30   <- dates[129];
                  ts2.P31   <- dates[130];
                  ts2.P32   <- dates[131];
                  ts2.P33   <- dates[132];
                  ts2.P34   <- dates[133];
                  ts2.P35   <- dates[134];
                  ts2.P36   <- dates[135];
                  ts2.P37   <- dates[136];
                  ts2.P38   <- dates[137];
                  ts2.P39   <- dates[138];
                  ts2.P40   <- dates[139];
                  ts2.P41   <- dates[140];
                  ts2.P42   <- dates[141];
                  ts2.P43   <- dates[142];
                  ts2.P44   <- dates[143];
                  ts2.P45   <- dates[144];
                  ts2.P46   <- dates[145];
                  ts2.P47   <- dates[146];
                  ts2.P48   <- dates[147];
                  ts2.P49   <- dates[148];
                  ts2.P50   <- dates[149];
                  ts2.P51   <- dates[150];
                  ts2.P52   <- dates[151];
                  ts2.P53   <- dates[152];
                  ts2.P54   <- dates[153];
                  ts2.P55   <- dates[154];
                  ts2.P56   <- dates[155];
                  ts2.P57   <- dates[156];
                  ts2.P58   <- dates[157];
                  ts2.P59   <- dates[158];
                  ts2.P60   <- dates[159];
                  ts2.P61   <- dates[160];
                  ts2.P62   <- dates[161];
                  ts2.P63   <- dates[162];
                  ts2.P64   <- dates[163];
                  ts2.P65   <- dates[164];
                  ts2.P66   <- dates[165];
                  ts2.P67   <- dates[166];
                  ts2.P68   <- dates[167];
                  ts2.P69   <- dates[168];
                  ts2.P70   <- dates[169];
                  ts2.P71   <- dates[170];
                  ts2.P72   <- dates[171];
                  ts2.P73   <- dates[172];
                  ts2.P74   <- dates[173];
                  ts2.P75   <- dates[174];
                  ts2.P76   <- dates[175];
                  ts2.P77   <- dates[176];
                  ts2.P78   <- dates[177];
                  ts2.P79   <- dates[178];
                  ts2.P80   <- dates[179];
                  ts2.P81   <- dates[180];
                  ts2.P82   <- dates[181];
                  ts2.P83   <- dates[182];
                  ts2.P84   <- dates[183];
                  ts2.P85   <- dates[184];
                  ts2.P86   <- dates[185];
                  ts2.P87   <- dates[186];
                  ts2.P88   <- dates[187];
                  ts2.P89   <- dates[188];
                  ts2.P90   <- dates[189];
                  ts2.P91   <- dates[190];
                  ts2.P92   <- dates[191];
                  ts2.P93   <- dates[192];
                  ts2.P94   <- dates[193];
                  ts2.P95   <- dates[194];
                  ts2.P96   <- dates[195];
                  ts2.P97   <- dates[196];
                  ts2.P98   <- dates[197];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  ind1.P94  <- ifelse(1:sealen < (ts1.P94-ts.start), 0, 1);
                  ind1.P95  <- ifelse(1:sealen < (ts1.P95-ts.start), 0, 1);
                  ind1.P96  <- ifelse(1:sealen < (ts1.P96-ts.start), 0, 1);
                  ind1.P97  <- ifelse(1:sealen < (ts1.P97-ts.start), 0, 1);
                  ind1.P98  <- ifelse(1:sealen < (ts1.P98-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  ind2.P94  <- ifelse(1:sealen < (ts2.P94-ts.start), 0, 1);
                  ind2.P95  <- ifelse(1:sealen < (ts2.P95-ts.start), 0, 1);
                  ind2.P96  <- ifelse(1:sealen < (ts2.P96-ts.start), 0, 1);
                  ind2.P97  <- ifelse(1:sealen < (ts2.P97-ts.start), 0, 1);
                  ind2.P98  <- ifelse(1:sealen < (ts2.P98-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logP94F1  <- par[96];
                  logP95F1  <- par[97];
                  logP96F1  <- par[98];
                  logP97F1  <- par[99];
                  logP98F1  <- par[100];
                  logscale1 <- par[101];
                  logalpha1 <- par[102];
                  logbeta1  <- par[103];
                  logP1F2   <- par[104];
                  logP2F2   <- par[105];
                  logP3F2   <- par[106];
                  logP4F2   <- par[107];
                  logP5F2   <- par[108];
                  logP6F2   <- par[109];
                  logP7F2   <- par[110];
                  logP8F2   <- par[111];
                  logP9F2   <- par[112];
                  logP10F2  <- par[113];
                  logP11F2  <- par[114];
                  logP12F2  <- par[115];
                  logP13F2  <- par[116];
                  logP14F2  <- par[117];
                  logP15F2  <- par[118];
                  logP16F2  <- par[119];
                  logP17F2  <- par[120];
                  logP18F2  <- par[121];
                  logP19F2  <- par[122];
                  logP20F2  <- par[123];
                  logP21F2  <- par[124];
                  logP22F2  <- par[125];
                  logP23F2  <- par[126];
                  logP24F2  <- par[127];
                  logP25F2  <- par[128];
                  logP26F2  <- par[129];
                  logP27F2  <- par[130];
                  logP28F2  <- par[131];
                  logP29F2  <- par[132];
                  logP30F2  <- par[133];
                  logP31F2  <- par[134];
                  logP32F2  <- par[135];
                  logP33F2  <- par[136];
                  logP34F2  <- par[137];
                  logP35F2  <- par[138];
                  logP36F2  <- par[139];
                  logP37F2  <- par[140];
                  logP38F2  <- par[141];
                  logP39F2  <- par[142];
                  logP40F2  <- par[143];
                  logP41F2  <- par[144];
                  logP42F2  <- par[145];
                  logP43F2  <- par[146];
                  logP44F2  <- par[147];
                  logP45F2  <- par[148];
                  logP46F2  <- par[149];
                  logP47F2  <- par[150];
                  logP48F2  <- par[151];
                  logP49F2  <- par[152];
                  logP50F2  <- par[153];
                  logP51F2  <- par[154];
                  logP52F2  <- par[155];
                  logP53F2  <- par[156];
                  logP54F2  <- par[157];
                  logP55F2  <- par[158];
                  logP56F2  <- par[159];
                  logP57F2  <- par[160];
                  logP58F2  <- par[161];
                  logP59F2  <- par[162];
                  logP60F2  <- par[163];
                  logP61F2  <- par[164];
                  logP62F2  <- par[165];
                  logP63F2  <- par[166];
                  logP64F2  <- par[167];
                  logP65F2  <- par[168];
                  logP66F2  <- par[169];
                  logP67F2  <- par[170];
                  logP68F2  <- par[171];
                  logP69F2  <- par[172];
                  logP70F2  <- par[173];
                  logP71F2  <- par[174];
                  logP72F2  <- par[175];
                  logP73F2  <- par[176];
                  logP74F2  <- par[177];
                  logP75F2  <- par[178];
                  logP76F2  <- par[179];
                  logP77F2  <- par[180];
                  logP78F2  <- par[181];
                  logP79F2  <- par[182];
                  logP80F2  <- par[183];
                  logP81F2  <- par[184];
                  logP82F2  <- par[185];
                  logP83F2  <- par[186];
                  logP84F2  <- par[187];
                  logP85F2  <- par[188];
                  logP86F2  <- par[189];
                  logP87F2  <- par[190];
                  logP88F2  <- par[191];
                  logP89F2  <- par[192];
                  logP90F2  <- par[193];
                  logP91F2  <- par[194];
                  logP92F2  <- par[195];
                  logP93F2  <- par[196];
                  logP94F2  <- par[197];
                  logP95F2  <- par[198];
                  logP96F2  <- par[199];
                  logP97F2  <- par[200];
                  logP98F2  <- par[201];
                  logscale2 <- par[202];
                  logalpha2 <- par[203];
                  logbeta2  <- par[204];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind1.P94[i]*exp(logP94F1)*exp(-exp(logM)*(i-(ts1.P94-ts.start)+1)) +
                                 ind1.P95[i]*exp(logP95F1)*exp(-exp(logM)*(i-(ts1.P95-ts.start)+1)) +
                                 ind1.P96[i]*exp(logP96F1)*exp(-exp(logM)*(i-(ts1.P96-ts.start)+1)) +
                                 ind1.P97[i]*exp(logP97F1)*exp(-exp(logM)*(i-(ts1.P97-ts.start)+1)) +
                                 ind1.P98[i]*exp(logP98F1)*exp(-exp(logM)*(i-(ts1.P98-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) +
                                 ind2.P94[i]*exp(logP94F2)*exp(-exp(logM)*(i-(ts2.P94-ts.start)+1)) +
                                 ind2.P95[i]*exp(logP95F2)*exp(-exp(logM)*(i-(ts2.P95-ts.start)+1)) +
                                 ind2.P96[i]*exp(logP96F2)*exp(-exp(logM)*(i-(ts2.P96-ts.start)+1)) +
                                 ind2.P97[i]*exp(logP97F2)*exp(-exp(logM)*(i-(ts2.P97-ts.start)+1)) +
                                 ind2.P98[i]*exp(logP98F2)*exp(-exp(logM)*(i-(ts2.P98-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN99P99P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(99,99))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts1.P94   <- dates[95];
                  ts1.P95   <- dates[96];
                  ts1.P96   <- dates[97];
                  ts1.P97   <- dates[98];
                  ts1.P98   <- dates[99];
                  ts1.P99   <- dates[100];
                  ts2.P1    <- dates[101];
                  ts2.P2    <- dates[102];
                  ts2.P3    <- dates[103];
                  ts2.P4    <- dates[104];
                  ts2.P5    <- dates[105];
                  ts2.P6    <- dates[106];
                  ts2.P7    <- dates[107];
                  ts2.P8    <- dates[108];
                  ts2.P9    <- dates[109];
                  ts2.P10   <- dates[110];
                  ts2.P11   <- dates[111];
                  ts2.P12   <- dates[112];
                  ts2.P13   <- dates[113];
                  ts2.P14   <- dates[114];
                  ts2.P15   <- dates[115];
                  ts2.P16   <- dates[116];
                  ts2.P17   <- dates[117];
                  ts2.P18   <- dates[118];
                  ts2.P19   <- dates[119];
                  ts2.P20   <- dates[120];
                  ts2.P21   <- dates[121];
                  ts2.P22   <- dates[122];
                  ts2.P23   <- dates[123];
                  ts2.P24   <- dates[124];
                  ts2.P25   <- dates[125];
                  ts2.P26   <- dates[126];
                  ts2.P27   <- dates[127];
                  ts2.P28   <- dates[128];
                  ts2.P29   <- dates[129];
                  ts2.P30   <- dates[130];
                  ts2.P31   <- dates[131];
                  ts2.P32   <- dates[132];
                  ts2.P33   <- dates[133];
                  ts2.P34   <- dates[134];
                  ts2.P35   <- dates[135];
                  ts2.P36   <- dates[136];
                  ts2.P37   <- dates[137];
                  ts2.P38   <- dates[138];
                  ts2.P39   <- dates[139];
                  ts2.P40   <- dates[140];
                  ts2.P41   <- dates[141];
                  ts2.P42   <- dates[142];
                  ts2.P43   <- dates[143];
                  ts2.P44   <- dates[144];
                  ts2.P45   <- dates[145];
                  ts2.P46   <- dates[146];
                  ts2.P47   <- dates[147];
                  ts2.P48   <- dates[148];
                  ts2.P49   <- dates[149];
                  ts2.P50   <- dates[150];
                  ts2.P51   <- dates[151];
                  ts2.P52   <- dates[152];
                  ts2.P53   <- dates[153];
                  ts2.P54   <- dates[154];
                  ts2.P55   <- dates[155];
                  ts2.P56   <- dates[156];
                  ts2.P57   <- dates[157];
                  ts2.P58   <- dates[158];
                  ts2.P59   <- dates[159];
                  ts2.P60   <- dates[160];
                  ts2.P61   <- dates[161];
                  ts2.P62   <- dates[162];
                  ts2.P63   <- dates[163];
                  ts2.P64   <- dates[164];
                  ts2.P65   <- dates[165];
                  ts2.P66   <- dates[166];
                  ts2.P67   <- dates[167];
                  ts2.P68   <- dates[168];
                  ts2.P69   <- dates[169];
                  ts2.P70   <- dates[170];
                  ts2.P71   <- dates[171];
                  ts2.P72   <- dates[172];
                  ts2.P73   <- dates[173];
                  ts2.P74   <- dates[174];
                  ts2.P75   <- dates[175];
                  ts2.P76   <- dates[176];
                  ts2.P77   <- dates[177];
                  ts2.P78   <- dates[178];
                  ts2.P79   <- dates[179];
                  ts2.P80   <- dates[180];
                  ts2.P81   <- dates[181];
                  ts2.P82   <- dates[182];
                  ts2.P83   <- dates[183];
                  ts2.P84   <- dates[184];
                  ts2.P85   <- dates[185];
                  ts2.P86   <- dates[186];
                  ts2.P87   <- dates[187];
                  ts2.P88   <- dates[188];
                  ts2.P89   <- dates[189];
                  ts2.P90   <- dates[190];
                  ts2.P91   <- dates[191];
                  ts2.P92   <- dates[192];
                  ts2.P93   <- dates[193];
                  ts2.P94   <- dates[194];
                  ts2.P95   <- dates[195];
                  ts2.P96   <- dates[196];
                  ts2.P97   <- dates[197];
                  ts2.P98   <- dates[198];
                  ts2.P99   <- dates[199];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  ind1.P94  <- ifelse(1:sealen < (ts1.P94-ts.start), 0, 1);
                  ind1.P95  <- ifelse(1:sealen < (ts1.P95-ts.start), 0, 1);
                  ind1.P96  <- ifelse(1:sealen < (ts1.P96-ts.start), 0, 1);
                  ind1.P97  <- ifelse(1:sealen < (ts1.P97-ts.start), 0, 1);
                  ind1.P98  <- ifelse(1:sealen < (ts1.P98-ts.start), 0, 1);
                  ind1.P99  <- ifelse(1:sealen < (ts1.P99-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  ind2.P94  <- ifelse(1:sealen < (ts2.P94-ts.start), 0, 1);
                  ind2.P95  <- ifelse(1:sealen < (ts2.P95-ts.start), 0, 1);
                  ind2.P96  <- ifelse(1:sealen < (ts2.P96-ts.start), 0, 1);
                  ind2.P97  <- ifelse(1:sealen < (ts2.P97-ts.start), 0, 1);
                  ind2.P98  <- ifelse(1:sealen < (ts2.P98-ts.start), 0, 1);
                  ind2.P99  <- ifelse(1:sealen < (ts2.P99-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logP94F1  <- par[96];
                  logP95F1  <- par[97];
                  logP96F1  <- par[98];
                  logP97F1  <- par[99];
                  logP98F1  <- par[100];
                  logP99F1  <- par[101];
                  logscale1 <- par[102];
                  logalpha1 <- par[103];
                  logbeta1  <- par[104];
                  logP1F2   <- par[105];
                  logP2F2   <- par[106];
                  logP3F2   <- par[107];
                  logP4F2   <- par[108];
                  logP5F2   <- par[109];
                  logP6F2   <- par[110];
                  logP7F2   <- par[111];
                  logP8F2   <- par[112];
                  logP9F2   <- par[113];
                  logP10F2  <- par[114];
                  logP11F2  <- par[115];
                  logP12F2  <- par[116];
                  logP13F2  <- par[117];
                  logP14F2  <- par[118];
                  logP15F2  <- par[119];
                  logP16F2  <- par[120];
                  logP17F2  <- par[121];
                  logP18F2  <- par[122];
                  logP19F2  <- par[123];
                  logP20F2  <- par[124];
                  logP21F2  <- par[125];
                  logP22F2  <- par[126];
                  logP23F2  <- par[127];
                  logP24F2  <- par[128];
                  logP25F2  <- par[129];
                  logP26F2  <- par[130];
                  logP27F2  <- par[131];
                  logP28F2  <- par[132];
                  logP29F2  <- par[133];
                  logP30F2  <- par[134];
                  logP31F2  <- par[135];
                  logP32F2  <- par[136];
                  logP33F2  <- par[137];
                  logP34F2  <- par[138];
                  logP35F2  <- par[139];
                  logP36F2  <- par[140];
                  logP37F2  <- par[141];
                  logP38F2  <- par[142];
                  logP39F2  <- par[143];
                  logP40F2  <- par[144];
                  logP41F2  <- par[145];
                  logP42F2  <- par[146];
                  logP43F2  <- par[147];
                  logP44F2  <- par[148];
                  logP45F2  <- par[149];
                  logP46F2  <- par[150];
                  logP47F2  <- par[151];
                  logP48F2  <- par[152];
                  logP49F2  <- par[153];
                  logP50F2  <- par[154];
                  logP51F2  <- par[155];
                  logP52F2  <- par[156];
                  logP53F2  <- par[157];
                  logP54F2  <- par[158];
                  logP55F2  <- par[159];
                  logP56F2  <- par[160];
                  logP57F2  <- par[161];
                  logP58F2  <- par[162];
                  logP59F2  <- par[163];
                  logP60F2  <- par[164];
                  logP61F2  <- par[165];
                  logP62F2  <- par[166];
                  logP63F2  <- par[167];
                  logP64F2  <- par[168];
                  logP65F2  <- par[169];
                  logP66F2  <- par[170];
                  logP67F2  <- par[171];
                  logP68F2  <- par[172];
                  logP69F2  <- par[173];
                  logP70F2  <- par[174];
                  logP71F2  <- par[175];
                  logP72F2  <- par[176];
                  logP73F2  <- par[177];
                  logP74F2  <- par[178];
                  logP75F2  <- par[179];
                  logP76F2  <- par[180];
                  logP77F2  <- par[181];
                  logP78F2  <- par[182];
                  logP79F2  <- par[183];
                  logP80F2  <- par[184];
                  logP81F2  <- par[185];
                  logP82F2  <- par[186];
                  logP83F2  <- par[187];
                  logP84F2  <- par[188];
                  logP85F2  <- par[189];
                  logP86F2  <- par[190];
                  logP87F2  <- par[191];
                  logP88F2  <- par[192];
                  logP89F2  <- par[193];
                  logP90F2  <- par[194];
                  logP91F2  <- par[195];
                  logP92F2  <- par[196];
                  logP93F2  <- par[197];
                  logP94F2  <- par[198];
                  logP95F2  <- par[199];
                  logP96F2  <- par[200];
                  logP97F2  <- par[201];
                  logP98F2  <- par[202];
                  logP99F2  <- par[203];
                  logscale2 <- par[204];
                  logalpha2 <- par[205];
                  logbeta2  <- par[206];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind1.P94[i]*exp(logP94F1)*exp(-exp(logM)*(i-(ts1.P94-ts.start)+1)) +
                                 ind1.P95[i]*exp(logP95F1)*exp(-exp(logM)*(i-(ts1.P95-ts.start)+1)) +
                                 ind1.P96[i]*exp(logP96F1)*exp(-exp(logM)*(i-(ts1.P96-ts.start)+1)) +
                                 ind1.P97[i]*exp(logP97F1)*exp(-exp(logM)*(i-(ts1.P97-ts.start)+1)) +
                                 ind1.P98[i]*exp(logP98F1)*exp(-exp(logM)*(i-(ts1.P98-ts.start)+1)) +
                                 ind1.P99[i]*exp(logP99F1)*exp(-exp(logM)*(i-(ts1.P99-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) +
                                 ind2.P94[i]*exp(logP94F2)*exp(-exp(logM)*(i-(ts2.P94-ts.start)+1)) +
                                 ind2.P95[i]*exp(logP95F2)*exp(-exp(logM)*(i-(ts2.P95-ts.start)+1)) +
                                 ind2.P96[i]*exp(logP96F2)*exp(-exp(logM)*(i-(ts2.P96-ts.start)+1)) +
                                 ind2.P97[i]*exp(logP97F2)*exp(-exp(logM)*(i-(ts2.P97-ts.start)+1)) +
                                 ind2.P98[i]*exp(logP98F2)*exp(-exp(logM)*(i-(ts2.P98-ts.start)+1)) +
                                 ind2.P99[i]*exp(logP99F2)*exp(-exp(logM)*(i-(ts2.P99-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1     <- obseff1^(exp(logalpha1));
                  effn1       <- nstep^(exp(logbeta1));
                  predcat1    <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2     <- obseff2^(exp(logalpha2));
                  effn2       <- nstep^(exp(logbeta2));
                  predcat2    <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1      <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2      <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
.CDMN100P100P <-
function(par,dates,obscat1,obseff1,obsmbm1,obscat2,obseff2,obsmbm2,distr,properties,output,pp=c(100,100))
  {
                  ts.start  <- head(dates,1);
                  ts1.P1    <- dates[2];
                  ts1.P2    <- dates[3];
                  ts1.P3    <- dates[4];
                  ts1.P4    <- dates[5];
                  ts1.P5    <- dates[6];
                  ts1.P6    <- dates[7];
                  ts1.P7    <- dates[8];
                  ts1.P8    <- dates[9];
                  ts1.P9    <- dates[10];
                  ts1.P10   <- dates[11];
                  ts1.P11   <- dates[12];
                  ts1.P12   <- dates[13];
                  ts1.P13   <- dates[14];
                  ts1.P14   <- dates[15];
                  ts1.P15   <- dates[16];
                  ts1.P16   <- dates[17];
                  ts1.P17   <- dates[18];
                  ts1.P18   <- dates[19];
                  ts1.P19   <- dates[20];
                  ts1.P20   <- dates[21];
                  ts1.P21   <- dates[22];
                  ts1.P22   <- dates[23];
                  ts1.P23   <- dates[24];
                  ts1.P24   <- dates[25];
                  ts1.P25   <- dates[26];
                  ts1.P26   <- dates[27];
                  ts1.P27   <- dates[28];
                  ts1.P28   <- dates[29];
                  ts1.P29   <- dates[30];
                  ts1.P30   <- dates[31];
                  ts1.P31   <- dates[32];
                  ts1.P32   <- dates[33];
                  ts1.P33   <- dates[34];
                  ts1.P34   <- dates[35];
                  ts1.P35   <- dates[36];
                  ts1.P36   <- dates[37];
                  ts1.P37   <- dates[38];
                  ts1.P38   <- dates[39];
                  ts1.P39   <- dates[40];
                  ts1.P40   <- dates[41];
                  ts1.P41   <- dates[42];
                  ts1.P42   <- dates[43];
                  ts1.P43   <- dates[44];
                  ts1.P44   <- dates[45];
                  ts1.P45   <- dates[46];
                  ts1.P46   <- dates[47];
                  ts1.P47   <- dates[48];
                  ts1.P48   <- dates[49];
                  ts1.P49   <- dates[50];
                  ts1.P50   <- dates[51];
                  ts1.P51   <- dates[52];
                  ts1.P52   <- dates[53];
                  ts1.P53   <- dates[54];
                  ts1.P54   <- dates[55];
                  ts1.P55   <- dates[56];
                  ts1.P56   <- dates[57];
                  ts1.P57   <- dates[58];
                  ts1.P58   <- dates[59];
                  ts1.P59   <- dates[60];
                  ts1.P60   <- dates[61];
                  ts1.P61   <- dates[62];
                  ts1.P62   <- dates[63];
                  ts1.P63   <- dates[64];
                  ts1.P64   <- dates[65];
                  ts1.P65   <- dates[66];
                  ts1.P66   <- dates[67];
                  ts1.P67   <- dates[68];
                  ts1.P68   <- dates[69];
                  ts1.P69   <- dates[70];
                  ts1.P70   <- dates[71];
                  ts1.P71   <- dates[72];
                  ts1.P72   <- dates[73];
                  ts1.P73   <- dates[74];
                  ts1.P74   <- dates[75];
                  ts1.P75   <- dates[76];
                  ts1.P76   <- dates[77];
                  ts1.P77   <- dates[78];
                  ts1.P78   <- dates[79];
                  ts1.P79   <- dates[80];
                  ts1.P80   <- dates[81];
                  ts1.P81   <- dates[82];
                  ts1.P82   <- dates[83];
                  ts1.P83   <- dates[84];
                  ts1.P84   <- dates[85];
                  ts1.P85   <- dates[86];
                  ts1.P86   <- dates[87];
                  ts1.P87   <- dates[88];
                  ts1.P88   <- dates[89];
                  ts1.P89   <- dates[90];
                  ts1.P90   <- dates[91];
                  ts1.P91   <- dates[92];
                  ts1.P92   <- dates[93];
                  ts1.P93   <- dates[94];
                  ts1.P94   <- dates[95];
                  ts1.P95   <- dates[96];
                  ts1.P96   <- dates[97];
                  ts1.P97   <- dates[98];
                  ts1.P98   <- dates[99];
                  ts1.P99   <- dates[100];
                  ts1.P100  <- dates[101];
                  ts2.P1    <- dates[102];
                  ts2.P2    <- dates[103];
                  ts2.P3    <- dates[104];
                  ts2.P4    <- dates[105];
                  ts2.P5    <- dates[106];
                  ts2.P6    <- dates[107];
                  ts2.P7    <- dates[108];
                  ts2.P8    <- dates[109];
                  ts2.P9    <- dates[110];
                  ts2.P10   <- dates[111];
                  ts2.P11   <- dates[112];
                  ts2.P12   <- dates[113];
                  ts2.P13   <- dates[114];
                  ts2.P14   <- dates[115];
                  ts2.P15   <- dates[116];
                  ts2.P16   <- dates[117];
                  ts2.P17   <- dates[118];
                  ts2.P18   <- dates[119];
                  ts2.P19   <- dates[120];
                  ts2.P20   <- dates[121];
                  ts2.P21   <- dates[122];
                  ts2.P22   <- dates[123];
                  ts2.P23   <- dates[124];
                  ts2.P24   <- dates[125];
                  ts2.P25   <- dates[126];
                  ts2.P26   <- dates[127];
                  ts2.P27   <- dates[128];
                  ts2.P28   <- dates[129];
                  ts2.P29   <- dates[130];
                  ts2.P30   <- dates[131];
                  ts2.P31   <- dates[132];
                  ts2.P32   <- dates[133];
                  ts2.P33   <- dates[134];
                  ts2.P34   <- dates[135];
                  ts2.P35   <- dates[136];
                  ts2.P36   <- dates[137];
                  ts2.P37   <- dates[138];
                  ts2.P38   <- dates[139];
                  ts2.P39   <- dates[140];
                  ts2.P40   <- dates[141];
                  ts2.P41   <- dates[142];
                  ts2.P42   <- dates[143];
                  ts2.P43   <- dates[144];
                  ts2.P44   <- dates[145];
                  ts2.P45   <- dates[146];
                  ts2.P46   <- dates[147];
                  ts2.P47   <- dates[148];
                  ts2.P48   <- dates[149];
                  ts2.P49   <- dates[150];
                  ts2.P50   <- dates[151];
                  ts2.P51   <- dates[152];
                  ts2.P52   <- dates[153];
                  ts2.P53   <- dates[154];
                  ts2.P54   <- dates[155];
                  ts2.P55   <- dates[156];
                  ts2.P56   <- dates[157];
                  ts2.P57   <- dates[158];
                  ts2.P58   <- dates[159];
                  ts2.P59   <- dates[160];
                  ts2.P60   <- dates[161];
                  ts2.P61   <- dates[162];
                  ts2.P62   <- dates[163];
                  ts2.P63   <- dates[164];
                  ts2.P64   <- dates[165];
                  ts2.P65   <- dates[166];
                  ts2.P66   <- dates[167];
                  ts2.P67   <- dates[168];
                  ts2.P68   <- dates[169];
                  ts2.P69   <- dates[170];
                  ts2.P70   <- dates[171];
                  ts2.P71   <- dates[172];
                  ts2.P72   <- dates[173];
                  ts2.P73   <- dates[174];
                  ts2.P74   <- dates[175];
                  ts2.P75   <- dates[176];
                  ts2.P76   <- dates[177];
                  ts2.P77   <- dates[178];
                  ts2.P78   <- dates[179];
                  ts2.P79   <- dates[180];
                  ts2.P80   <- dates[181];
                  ts2.P81   <- dates[182];
                  ts2.P82   <- dates[183];
                  ts2.P83   <- dates[184];
                  ts2.P84   <- dates[185];
                  ts2.P85   <- dates[186];
                  ts2.P86   <- dates[187];
                  ts2.P87   <- dates[188];
                  ts2.P88   <- dates[189];
                  ts2.P89   <- dates[190];
                  ts2.P90   <- dates[191];
                  ts2.P91   <- dates[192];
                  ts2.P92   <- dates[193];
                  ts2.P93   <- dates[194];
                  ts2.P94   <- dates[195];
                  ts2.P95   <- dates[196];
                  ts2.P96   <- dates[197];
                  ts2.P97   <- dates[198];
                  ts2.P98   <- dates[199];
                  ts2.P99   <- dates[200];
                  ts2.P100  <- dates[201];
                  ts.end    <- tail(dates,1);
                  sealen    <- ts.end-ts.start+1;
                  nstep     <- vector("numeric",sealen);
                  mccum     <- vector("numeric",sealen);
                  effeff1   <- vector("numeric",sealen);
                  effn1     <- vector("numeric",sealen);
                  predcat1  <- vector("numeric",sealen);
                  ind1.P1   <- ifelse(1:sealen < (ts1.P1-ts.start), 0, 1);
                  ind1.P2   <- ifelse(1:sealen < (ts1.P2-ts.start), 0, 1);
                  ind1.P3   <- ifelse(1:sealen < (ts1.P3-ts.start), 0, 1);
                  ind1.P4   <- ifelse(1:sealen < (ts1.P4-ts.start), 0, 1);
                  ind1.P5   <- ifelse(1:sealen < (ts1.P5-ts.start), 0, 1);
                  ind1.P6   <- ifelse(1:sealen < (ts1.P6-ts.start), 0, 1);
                  ind1.P7   <- ifelse(1:sealen < (ts1.P7-ts.start), 0, 1);
                  ind1.P8   <- ifelse(1:sealen < (ts1.P8-ts.start), 0, 1);
                  ind1.P9   <- ifelse(1:sealen < (ts1.P9-ts.start), 0, 1);
                  ind1.P10  <- ifelse(1:sealen < (ts1.P10-ts.start), 0, 1);
                  ind1.P11  <- ifelse(1:sealen < (ts1.P11-ts.start), 0, 1);
                  ind1.P12  <- ifelse(1:sealen < (ts1.P12-ts.start), 0, 1);
                  ind1.P13  <- ifelse(1:sealen < (ts1.P13-ts.start), 0, 1);
                  ind1.P14  <- ifelse(1:sealen < (ts1.P14-ts.start), 0, 1);
                  ind1.P15  <- ifelse(1:sealen < (ts1.P15-ts.start), 0, 1);
                  ind1.P16  <- ifelse(1:sealen < (ts1.P16-ts.start), 0, 1);
                  ind1.P17  <- ifelse(1:sealen < (ts1.P17-ts.start), 0, 1);
                  ind1.P18  <- ifelse(1:sealen < (ts1.P18-ts.start), 0, 1);
                  ind1.P19  <- ifelse(1:sealen < (ts1.P19-ts.start), 0, 1);
                  ind1.P20  <- ifelse(1:sealen < (ts1.P20-ts.start), 0, 1);
                  ind1.P21  <- ifelse(1:sealen < (ts1.P21-ts.start), 0, 1);
                  ind1.P22  <- ifelse(1:sealen < (ts1.P22-ts.start), 0, 1);
                  ind1.P23  <- ifelse(1:sealen < (ts1.P23-ts.start), 0, 1);
                  ind1.P24  <- ifelse(1:sealen < (ts1.P24-ts.start), 0, 1);
                  ind1.P25  <- ifelse(1:sealen < (ts1.P25-ts.start), 0, 1);
                  ind1.P26  <- ifelse(1:sealen < (ts1.P26-ts.start), 0, 1);
                  ind1.P27  <- ifelse(1:sealen < (ts1.P27-ts.start), 0, 1);
                  ind1.P28  <- ifelse(1:sealen < (ts1.P28-ts.start), 0, 1);
                  ind1.P29  <- ifelse(1:sealen < (ts1.P29-ts.start), 0, 1);
                  ind1.P30  <- ifelse(1:sealen < (ts1.P30-ts.start), 0, 1);
                  ind1.P31  <- ifelse(1:sealen < (ts1.P31-ts.start), 0, 1);
                  ind1.P32  <- ifelse(1:sealen < (ts1.P32-ts.start), 0, 1);
                  ind1.P33  <- ifelse(1:sealen < (ts1.P33-ts.start), 0, 1);
                  ind1.P34  <- ifelse(1:sealen < (ts1.P34-ts.start), 0, 1);
                  ind1.P35  <- ifelse(1:sealen < (ts1.P35-ts.start), 0, 1);
                  ind1.P36  <- ifelse(1:sealen < (ts1.P36-ts.start), 0, 1);
                  ind1.P37  <- ifelse(1:sealen < (ts1.P37-ts.start), 0, 1);
                  ind1.P38  <- ifelse(1:sealen < (ts1.P38-ts.start), 0, 1);
                  ind1.P39  <- ifelse(1:sealen < (ts1.P39-ts.start), 0, 1);
                  ind1.P40  <- ifelse(1:sealen < (ts1.P40-ts.start), 0, 1);
                  ind1.P41  <- ifelse(1:sealen < (ts1.P41-ts.start), 0, 1);
                  ind1.P42  <- ifelse(1:sealen < (ts1.P42-ts.start), 0, 1);
                  ind1.P43  <- ifelse(1:sealen < (ts1.P43-ts.start), 0, 1);
                  ind1.P44  <- ifelse(1:sealen < (ts1.P44-ts.start), 0, 1);
                  ind1.P45  <- ifelse(1:sealen < (ts1.P45-ts.start), 0, 1);
                  ind1.P46  <- ifelse(1:sealen < (ts1.P46-ts.start), 0, 1);
                  ind1.P47  <- ifelse(1:sealen < (ts1.P47-ts.start), 0, 1);
                  ind1.P48  <- ifelse(1:sealen < (ts1.P48-ts.start), 0, 1);
                  ind1.P49  <- ifelse(1:sealen < (ts1.P49-ts.start), 0, 1);
                  ind1.P50  <- ifelse(1:sealen < (ts1.P50-ts.start), 0, 1);
                  ind1.P51  <- ifelse(1:sealen < (ts1.P51-ts.start), 0, 1);
                  ind1.P52  <- ifelse(1:sealen < (ts1.P52-ts.start), 0, 1);
                  ind1.P53  <- ifelse(1:sealen < (ts1.P53-ts.start), 0, 1);
                  ind1.P54  <- ifelse(1:sealen < (ts1.P54-ts.start), 0, 1);
                  ind1.P55  <- ifelse(1:sealen < (ts1.P55-ts.start), 0, 1);
                  ind1.P56  <- ifelse(1:sealen < (ts1.P56-ts.start), 0, 1);
                  ind1.P57  <- ifelse(1:sealen < (ts1.P57-ts.start), 0, 1);
                  ind1.P58  <- ifelse(1:sealen < (ts1.P58-ts.start), 0, 1);
                  ind1.P59  <- ifelse(1:sealen < (ts1.P59-ts.start), 0, 1);
                  ind1.P60  <- ifelse(1:sealen < (ts1.P60-ts.start), 0, 1);
                  ind1.P61  <- ifelse(1:sealen < (ts1.P61-ts.start), 0, 1);
                  ind1.P62  <- ifelse(1:sealen < (ts1.P62-ts.start), 0, 1);
                  ind1.P63  <- ifelse(1:sealen < (ts1.P63-ts.start), 0, 1);
                  ind1.P64  <- ifelse(1:sealen < (ts1.P64-ts.start), 0, 1);
                  ind1.P65  <- ifelse(1:sealen < (ts1.P65-ts.start), 0, 1);
                  ind1.P66  <- ifelse(1:sealen < (ts1.P66-ts.start), 0, 1);
                  ind1.P67  <- ifelse(1:sealen < (ts1.P67-ts.start), 0, 1);
                  ind1.P68  <- ifelse(1:sealen < (ts1.P68-ts.start), 0, 1);
                  ind1.P69  <- ifelse(1:sealen < (ts1.P69-ts.start), 0, 1);
                  ind1.P70  <- ifelse(1:sealen < (ts1.P70-ts.start), 0, 1);
                  ind1.P71  <- ifelse(1:sealen < (ts1.P71-ts.start), 0, 1);
                  ind1.P72  <- ifelse(1:sealen < (ts1.P72-ts.start), 0, 1);
                  ind1.P73  <- ifelse(1:sealen < (ts1.P73-ts.start), 0, 1);
                  ind1.P74  <- ifelse(1:sealen < (ts1.P74-ts.start), 0, 1);
                  ind1.P75  <- ifelse(1:sealen < (ts1.P75-ts.start), 0, 1);
                  ind1.P76  <- ifelse(1:sealen < (ts1.P76-ts.start), 0, 1);
                  ind1.P77  <- ifelse(1:sealen < (ts1.P77-ts.start), 0, 1);
                  ind1.P78  <- ifelse(1:sealen < (ts1.P78-ts.start), 0, 1);
                  ind1.P79  <- ifelse(1:sealen < (ts1.P79-ts.start), 0, 1);
                  ind1.P80  <- ifelse(1:sealen < (ts1.P80-ts.start), 0, 1);
                  ind1.P81  <- ifelse(1:sealen < (ts1.P81-ts.start), 0, 1);
                  ind1.P82  <- ifelse(1:sealen < (ts1.P82-ts.start), 0, 1);
                  ind1.P83  <- ifelse(1:sealen < (ts1.P83-ts.start), 0, 1);
                  ind1.P84  <- ifelse(1:sealen < (ts1.P84-ts.start), 0, 1);
                  ind1.P85  <- ifelse(1:sealen < (ts1.P85-ts.start), 0, 1);
                  ind1.P86  <- ifelse(1:sealen < (ts1.P86-ts.start), 0, 1);
                  ind1.P87  <- ifelse(1:sealen < (ts1.P87-ts.start), 0, 1);
                  ind1.P88  <- ifelse(1:sealen < (ts1.P88-ts.start), 0, 1);
                  ind1.P89  <- ifelse(1:sealen < (ts1.P89-ts.start), 0, 1);
                  ind1.P90  <- ifelse(1:sealen < (ts1.P90-ts.start), 0, 1);
                  ind1.P91  <- ifelse(1:sealen < (ts1.P91-ts.start), 0, 1);
                  ind1.P92  <- ifelse(1:sealen < (ts1.P92-ts.start), 0, 1);
                  ind1.P93  <- ifelse(1:sealen < (ts1.P93-ts.start), 0, 1);
                  ind1.P94  <- ifelse(1:sealen < (ts1.P94-ts.start), 0, 1);
                  ind1.P95  <- ifelse(1:sealen < (ts1.P95-ts.start), 0, 1);
                  ind1.P96  <- ifelse(1:sealen < (ts1.P96-ts.start), 0, 1);
                  ind1.P97  <- ifelse(1:sealen < (ts1.P97-ts.start), 0, 1);
                  ind1.P98  <- ifelse(1:sealen < (ts1.P98-ts.start), 0, 1);
                  ind1.P99  <- ifelse(1:sealen < (ts1.P99-ts.start), 0, 1);
                  ind1.P100 <- ifelse(1:sealen < (ts1.P100-ts.start), 0, 1);
                  effeff2   <- vector("numeric",sealen);
                  effn2     <- vector("numeric",sealen);
                  predcat2  <- vector("numeric",sealen);
                  ind2.P1   <- ifelse(1:sealen < (ts2.P1-ts.start), 0, 1);
                  ind2.P2   <- ifelse(1:sealen < (ts2.P2-ts.start), 0, 1);
                  ind2.P3   <- ifelse(1:sealen < (ts2.P3-ts.start), 0, 1);
                  ind2.P4   <- ifelse(1:sealen < (ts2.P4-ts.start), 0, 1);
                  ind2.P5   <- ifelse(1:sealen < (ts2.P5-ts.start), 0, 1);
                  ind2.P6   <- ifelse(1:sealen < (ts2.P6-ts.start), 0, 1);
                  ind2.P7   <- ifelse(1:sealen < (ts2.P7-ts.start), 0, 1);
                  ind2.P8   <- ifelse(1:sealen < (ts2.P8-ts.start), 0, 1);
                  ind2.P9   <- ifelse(1:sealen < (ts2.P9-ts.start), 0, 1);
                  ind2.P10  <- ifelse(1:sealen < (ts2.P10-ts.start), 0, 1);
                  ind2.P11  <- ifelse(1:sealen < (ts2.P11-ts.start), 0, 1);
                  ind2.P12  <- ifelse(1:sealen < (ts2.P12-ts.start), 0, 1);
                  ind2.P13  <- ifelse(1:sealen < (ts2.P13-ts.start), 0, 1);
                  ind2.P14  <- ifelse(1:sealen < (ts2.P14-ts.start), 0, 1);
                  ind2.P15  <- ifelse(1:sealen < (ts2.P15-ts.start), 0, 1);
                  ind2.P16  <- ifelse(1:sealen < (ts2.P16-ts.start), 0, 1);
                  ind2.P17  <- ifelse(1:sealen < (ts2.P17-ts.start), 0, 1);
                  ind2.P18  <- ifelse(1:sealen < (ts2.P18-ts.start), 0, 1);
                  ind2.P19  <- ifelse(1:sealen < (ts2.P19-ts.start), 0, 1);
                  ind2.P20  <- ifelse(1:sealen < (ts2.P20-ts.start), 0, 1);
                  ind2.P21  <- ifelse(1:sealen < (ts2.P21-ts.start), 0, 1);
                  ind2.P22  <- ifelse(1:sealen < (ts2.P22-ts.start), 0, 1);
                  ind2.P23  <- ifelse(1:sealen < (ts2.P23-ts.start), 0, 1);
                  ind2.P24  <- ifelse(1:sealen < (ts2.P24-ts.start), 0, 1);
                  ind2.P25  <- ifelse(1:sealen < (ts2.P25-ts.start), 0, 1);
                  ind2.P26  <- ifelse(1:sealen < (ts2.P26-ts.start), 0, 1);
                  ind2.P27  <- ifelse(1:sealen < (ts2.P27-ts.start), 0, 1);
                  ind2.P28  <- ifelse(1:sealen < (ts2.P28-ts.start), 0, 1);
                  ind2.P29  <- ifelse(1:sealen < (ts2.P29-ts.start), 0, 1);
                  ind2.P30  <- ifelse(1:sealen < (ts2.P30-ts.start), 0, 1);
                  ind2.P31  <- ifelse(1:sealen < (ts2.P31-ts.start), 0, 1);
                  ind2.P32  <- ifelse(1:sealen < (ts2.P32-ts.start), 0, 1);
                  ind2.P33  <- ifelse(1:sealen < (ts2.P33-ts.start), 0, 1);
                  ind2.P34  <- ifelse(1:sealen < (ts2.P34-ts.start), 0, 1);
                  ind2.P35  <- ifelse(1:sealen < (ts2.P35-ts.start), 0, 1);
                  ind2.P36  <- ifelse(1:sealen < (ts2.P36-ts.start), 0, 1);
                  ind2.P37  <- ifelse(1:sealen < (ts2.P37-ts.start), 0, 1);
                  ind2.P38  <- ifelse(1:sealen < (ts2.P38-ts.start), 0, 1);
                  ind2.P39  <- ifelse(1:sealen < (ts2.P39-ts.start), 0, 1);
                  ind2.P40  <- ifelse(1:sealen < (ts2.P40-ts.start), 0, 1);
                  ind2.P41  <- ifelse(1:sealen < (ts2.P41-ts.start), 0, 1);
                  ind2.P42  <- ifelse(1:sealen < (ts2.P42-ts.start), 0, 1);
                  ind2.P43  <- ifelse(1:sealen < (ts2.P43-ts.start), 0, 1);
                  ind2.P44  <- ifelse(1:sealen < (ts2.P44-ts.start), 0, 1);
                  ind2.P45  <- ifelse(1:sealen < (ts2.P45-ts.start), 0, 1);
                  ind2.P46  <- ifelse(1:sealen < (ts2.P46-ts.start), 0, 1);
                  ind2.P47  <- ifelse(1:sealen < (ts2.P47-ts.start), 0, 1);
                  ind2.P48  <- ifelse(1:sealen < (ts2.P48-ts.start), 0, 1);
                  ind2.P49  <- ifelse(1:sealen < (ts2.P49-ts.start), 0, 1);
                  ind2.P50  <- ifelse(1:sealen < (ts2.P50-ts.start), 0, 1);
                  ind2.P51  <- ifelse(1:sealen < (ts2.P51-ts.start), 0, 1);
                  ind2.P52  <- ifelse(1:sealen < (ts2.P52-ts.start), 0, 1);
                  ind2.P53  <- ifelse(1:sealen < (ts2.P53-ts.start), 0, 1);
                  ind2.P54  <- ifelse(1:sealen < (ts2.P54-ts.start), 0, 1);
                  ind2.P55  <- ifelse(1:sealen < (ts2.P55-ts.start), 0, 1);
                  ind2.P56  <- ifelse(1:sealen < (ts2.P56-ts.start), 0, 1);
                  ind2.P57  <- ifelse(1:sealen < (ts2.P57-ts.start), 0, 1);
                  ind2.P58  <- ifelse(1:sealen < (ts2.P58-ts.start), 0, 1);
                  ind2.P59  <- ifelse(1:sealen < (ts2.P59-ts.start), 0, 1);
                  ind2.P60  <- ifelse(1:sealen < (ts2.P60-ts.start), 0, 1);
                  ind2.P61  <- ifelse(1:sealen < (ts2.P61-ts.start), 0, 1);
                  ind2.P62  <- ifelse(1:sealen < (ts2.P62-ts.start), 0, 1);
                  ind2.P63  <- ifelse(1:sealen < (ts2.P63-ts.start), 0, 1);
                  ind2.P64  <- ifelse(1:sealen < (ts2.P64-ts.start), 0, 1);
                  ind2.P65  <- ifelse(1:sealen < (ts2.P65-ts.start), 0, 1);
                  ind2.P66  <- ifelse(1:sealen < (ts2.P66-ts.start), 0, 1);
                  ind2.P67  <- ifelse(1:sealen < (ts2.P67-ts.start), 0, 1);
                  ind2.P68  <- ifelse(1:sealen < (ts2.P68-ts.start), 0, 1);
                  ind2.P69  <- ifelse(1:sealen < (ts2.P69-ts.start), 0, 1);
                  ind2.P70  <- ifelse(1:sealen < (ts2.P70-ts.start), 0, 1);
                  ind2.P71  <- ifelse(1:sealen < (ts2.P71-ts.start), 0, 1);
                  ind2.P72  <- ifelse(1:sealen < (ts2.P72-ts.start), 0, 1);
                  ind2.P73  <- ifelse(1:sealen < (ts2.P73-ts.start), 0, 1);
                  ind2.P74  <- ifelse(1:sealen < (ts2.P74-ts.start), 0, 1);
                  ind2.P75  <- ifelse(1:sealen < (ts2.P75-ts.start), 0, 1);
                  ind2.P76  <- ifelse(1:sealen < (ts2.P76-ts.start), 0, 1);
                  ind2.P77  <- ifelse(1:sealen < (ts2.P77-ts.start), 0, 1);
                  ind2.P78  <- ifelse(1:sealen < (ts2.P78-ts.start), 0, 1);
                  ind2.P79  <- ifelse(1:sealen < (ts2.P79-ts.start), 0, 1);
                  ind2.P80  <- ifelse(1:sealen < (ts2.P80-ts.start), 0, 1);
                  ind2.P81  <- ifelse(1:sealen < (ts2.P81-ts.start), 0, 1);
                  ind2.P82  <- ifelse(1:sealen < (ts2.P82-ts.start), 0, 1);
                  ind2.P83  <- ifelse(1:sealen < (ts2.P83-ts.start), 0, 1);
                  ind2.P84  <- ifelse(1:sealen < (ts2.P84-ts.start), 0, 1);
                  ind2.P85  <- ifelse(1:sealen < (ts2.P85-ts.start), 0, 1);
                  ind2.P86  <- ifelse(1:sealen < (ts2.P86-ts.start), 0, 1);
                  ind2.P87  <- ifelse(1:sealen < (ts2.P87-ts.start), 0, 1);
                  ind2.P88  <- ifelse(1:sealen < (ts2.P88-ts.start), 0, 1);
                  ind2.P89  <- ifelse(1:sealen < (ts2.P89-ts.start), 0, 1);
                  ind2.P90  <- ifelse(1:sealen < (ts2.P90-ts.start), 0, 1);
                  ind2.P91  <- ifelse(1:sealen < (ts2.P91-ts.start), 0, 1);
                  ind2.P92  <- ifelse(1:sealen < (ts2.P92-ts.start), 0, 1);
                  ind2.P93  <- ifelse(1:sealen < (ts2.P93-ts.start), 0, 1);
                  ind2.P94  <- ifelse(1:sealen < (ts2.P94-ts.start), 0, 1);
                  ind2.P95  <- ifelse(1:sealen < (ts2.P95-ts.start), 0, 1);
                  ind2.P96  <- ifelse(1:sealen < (ts2.P96-ts.start), 0, 1);
                  ind2.P97  <- ifelse(1:sealen < (ts2.P97-ts.start), 0, 1);
                  ind2.P98  <- ifelse(1:sealen < (ts2.P98-ts.start), 0, 1);
                  ind2.P99  <- ifelse(1:sealen < (ts2.P99-ts.start), 0, 1);
                  ind2.P100 <- ifelse(1:sealen < (ts2.P100-ts.start), 0, 1);
                  logM      <- par[1];
                  logN0     <- par[2];
                  logP1F1   <- par[3];
                  logP2F1   <- par[4];
                  logP3F1   <- par[5];
                  logP4F1   <- par[6];
                  logP5F1   <- par[7];
                  logP6F1   <- par[8];
                  logP7F1   <- par[9];
                  logP8F1   <- par[10];
                  logP9F1   <- par[11];
                  logP10F1  <- par[12];
                  logP11F1  <- par[13];
                  logP12F1  <- par[14];
                  logP13F1  <- par[15];
                  logP14F1  <- par[16];
                  logP15F1  <- par[17];
                  logP16F1  <- par[18];
                  logP17F1  <- par[19];
                  logP18F1  <- par[20];
                  logP19F1  <- par[21];
                  logP20F1  <- par[22];
                  logP21F1  <- par[23];
                  logP22F1  <- par[24];
                  logP23F1  <- par[25];
                  logP24F1  <- par[26];
                  logP25F1  <- par[27];
                  logP26F1  <- par[28];
                  logP27F1  <- par[29];
                  logP28F1  <- par[30];
                  logP29F1  <- par[31];
                  logP30F1  <- par[32];
                  logP31F1  <- par[33];
                  logP32F1  <- par[34];
                  logP33F1  <- par[35];
                  logP34F1  <- par[36];
                  logP35F1  <- par[37];
                  logP36F1  <- par[38];
                  logP37F1  <- par[39];
                  logP38F1  <- par[40];
                  logP39F1  <- par[41];
                  logP40F1  <- par[42];
                  logP41F1  <- par[43];
                  logP42F1  <- par[44];
                  logP43F1  <- par[45];
                  logP44F1  <- par[46];
                  logP45F1  <- par[47];
                  logP46F1  <- par[48];
                  logP47F1  <- par[49];
                  logP48F1  <- par[50];
                  logP49F1  <- par[51];
                  logP50F1  <- par[52];
                  logP51F1  <- par[53];
                  logP52F1  <- par[54];
                  logP53F1  <- par[55];
                  logP54F1  <- par[56];
                  logP55F1  <- par[57];
                  logP56F1  <- par[58];
                  logP57F1  <- par[59];
                  logP58F1  <- par[60];
                  logP59F1  <- par[61];
                  logP60F1  <- par[62];
                  logP61F1  <- par[63];
                  logP62F1  <- par[64];
                  logP63F1  <- par[65];
                  logP64F1  <- par[66];
                  logP65F1  <- par[67];
                  logP66F1  <- par[68];
                  logP67F1  <- par[69];
                  logP68F1  <- par[70];
                  logP69F1  <- par[71];
                  logP70F1  <- par[72];
                  logP71F1  <- par[73];
                  logP72F1  <- par[74];
                  logP73F1  <- par[75];
                  logP74F1  <- par[76];
                  logP75F1  <- par[77];
                  logP76F1  <- par[78];
                  logP77F1  <- par[79];
                  logP78F1  <- par[80];
                  logP79F1  <- par[81];
                  logP80F1  <- par[82];
                  logP81F1  <- par[83];
                  logP82F1  <- par[84];
                  logP83F1  <- par[85];
                  logP84F1  <- par[86];
                  logP85F1  <- par[87];
                  logP86F1  <- par[88];
                  logP87F1  <- par[89];
                  logP88F1  <- par[90];
                  logP89F1  <- par[91];
                  logP90F1  <- par[92];
                  logP91F1  <- par[93];
                  logP92F1  <- par[94];
                  logP93F1  <- par[95];
                  logP94F1  <- par[96];
                  logP95F1  <- par[97];
                  logP96F1  <- par[98];
                  logP97F1  <- par[99];
                  logP98F1  <- par[100];
                  logP99F1  <- par[101];
                  logP100F1 <- par[102];
                  logscale1 <- par[103];
                  logalpha1 <- par[104];
                  logbeta1  <- par[105];
                  logP1F2   <- par[106];
                  logP2F2   <- par[107];
                  logP3F2   <- par[108];
                  logP4F2   <- par[109];
                  logP5F2   <- par[110];
                  logP6F2   <- par[111];
                  logP7F2   <- par[112];
                  logP8F2   <- par[113];
                  logP9F2   <- par[114];
                  logP10F2  <- par[115];
                  logP11F2  <- par[116];
                  logP12F2  <- par[117];
                  logP13F2  <- par[118];
                  logP14F2  <- par[119];
                  logP15F2  <- par[120];
                  logP16F2  <- par[121];
                  logP17F2  <- par[122];
                  logP18F2  <- par[123];
                  logP19F2  <- par[124];
                  logP20F2  <- par[125];
                  logP21F2  <- par[126];
                  logP22F2  <- par[127];
                  logP23F2  <- par[128];
                  logP24F2  <- par[129];
                  logP25F2  <- par[130];
                  logP26F2  <- par[131];
                  logP27F2  <- par[132];
                  logP28F2  <- par[133];
                  logP29F2  <- par[134];
                  logP30F2  <- par[135];
                  logP31F2  <- par[136];
                  logP32F2  <- par[137];
                  logP33F2  <- par[138];
                  logP34F2  <- par[139];
                  logP35F2  <- par[140];
                  logP36F2  <- par[141];
                  logP37F2  <- par[142];
                  logP38F2  <- par[143];
                  logP39F2  <- par[144];
                  logP40F2  <- par[145];
                  logP41F2  <- par[146];
                  logP42F2  <- par[147];
                  logP43F2  <- par[148];
                  logP44F2  <- par[149];
                  logP45F2  <- par[150];
                  logP46F2  <- par[151];
                  logP47F2  <- par[152];
                  logP48F2  <- par[153];
                  logP49F2  <- par[154];
                  logP50F2  <- par[155];
                  logP51F2  <- par[156];
                  logP52F2  <- par[157];
                  logP53F2  <- par[158];
                  logP54F2  <- par[159];
                  logP55F2  <- par[160];
                  logP56F2  <- par[161];
                  logP57F2  <- par[162];
                  logP58F2  <- par[163];
                  logP59F2  <- par[164];
                  logP60F2  <- par[165];
                  logP61F2  <- par[166];
                  logP62F2  <- par[167];
                  logP63F2  <- par[168];
                  logP64F2  <- par[169];
                  logP65F2  <- par[170];
                  logP66F2  <- par[171];
                  logP67F2  <- par[172];
                  logP68F2  <- par[173];
                  logP69F2  <- par[174];
                  logP70F2  <- par[175];
                  logP71F2  <- par[176];
                  logP72F2  <- par[177];
                  logP73F2  <- par[178];
                  logP74F2  <- par[179];
                  logP75F2  <- par[180];
                  logP76F2  <- par[181];
                  logP77F2  <- par[182];
                  logP78F2  <- par[183];
                  logP79F2  <- par[184];
                  logP80F2  <- par[185];
                  logP81F2  <- par[186];
                  logP82F2  <- par[187];
                  logP83F2  <- par[188];
                  logP84F2  <- par[189];
                  logP85F2  <- par[190];
                  logP86F2  <- par[191];
                  logP87F2  <- par[192];
                  logP88F2  <- par[193];
                  logP89F2  <- par[194];
                  logP90F2  <- par[195];
                  logP91F2  <- par[196];
                  logP92F2  <- par[197];
                  logP93F2  <- par[198];
                  logP94F2  <- par[199];
                  logP95F2  <- par[200];
                  logP96F2  <- par[201];
                  logP97F2  <- par[202];
                  logP98F2  <- par[203];
                  logP99F2  <- par[204];
                  logP100F2 <- par[205];
                  logscale2 <- par[206];
                  logalpha2 <- par[207];
                  logbeta2  <- par[208];
                  mccum[1]  <- 0;
                  nstep[1]  <- exp(logN0)*exp(-exp(logM));
                  for(i in 2:sealen)
                     {
                     mccum[i] <- obscat1[i-1] + obscat2[i-1] + mccum[i-1]*exp(-exp(logM));
                     nstep[i] <- exp(logN0)*exp(-exp(logM)*i) +
                                 ind1.P1[i]*exp(logP1F1)*exp(-exp(logM)*(i-(ts1.P1-ts.start)+1)) +
                                 ind1.P2[i]*exp(logP2F1)*exp(-exp(logM)*(i-(ts1.P2-ts.start)+1)) +
                                 ind1.P3[i]*exp(logP3F1)*exp(-exp(logM)*(i-(ts1.P3-ts.start)+1)) +
                                 ind1.P4[i]*exp(logP4F1)*exp(-exp(logM)*(i-(ts1.P4-ts.start)+1)) +
                                 ind1.P5[i]*exp(logP5F1)*exp(-exp(logM)*(i-(ts1.P5-ts.start)+1)) +
                                 ind1.P6[i]*exp(logP6F1)*exp(-exp(logM)*(i-(ts1.P6-ts.start)+1)) +
                                 ind1.P7[i]*exp(logP7F1)*exp(-exp(logM)*(i-(ts1.P7-ts.start)+1)) +
                                 ind1.P8[i]*exp(logP8F1)*exp(-exp(logM)*(i-(ts1.P8-ts.start)+1)) +
                                 ind1.P9[i]*exp(logP9F1)*exp(-exp(logM)*(i-(ts1.P9-ts.start)+1)) +
                                 ind1.P10[i]*exp(logP10F1)*exp(-exp(logM)*(i-(ts1.P10-ts.start)+1)) +
                                 ind1.P11[i]*exp(logP11F1)*exp(-exp(logM)*(i-(ts1.P11-ts.start)+1)) +
                                 ind1.P12[i]*exp(logP12F1)*exp(-exp(logM)*(i-(ts1.P12-ts.start)+1)) +
                                 ind1.P13[i]*exp(logP13F1)*exp(-exp(logM)*(i-(ts1.P13-ts.start)+1)) +
                                 ind1.P14[i]*exp(logP14F1)*exp(-exp(logM)*(i-(ts1.P14-ts.start)+1)) +
                                 ind1.P15[i]*exp(logP15F1)*exp(-exp(logM)*(i-(ts1.P15-ts.start)+1)) +
                                 ind1.P16[i]*exp(logP16F1)*exp(-exp(logM)*(i-(ts1.P16-ts.start)+1)) +
                                 ind1.P17[i]*exp(logP17F1)*exp(-exp(logM)*(i-(ts1.P17-ts.start)+1)) +
                                 ind1.P18[i]*exp(logP18F1)*exp(-exp(logM)*(i-(ts1.P18-ts.start)+1)) +
                                 ind1.P19[i]*exp(logP19F1)*exp(-exp(logM)*(i-(ts1.P19-ts.start)+1)) +
                                 ind1.P20[i]*exp(logP20F1)*exp(-exp(logM)*(i-(ts1.P20-ts.start)+1)) +
                                 ind1.P21[i]*exp(logP21F1)*exp(-exp(logM)*(i-(ts1.P21-ts.start)+1)) +
                                 ind1.P22[i]*exp(logP22F1)*exp(-exp(logM)*(i-(ts1.P22-ts.start)+1)) +
                                 ind1.P23[i]*exp(logP23F1)*exp(-exp(logM)*(i-(ts1.P23-ts.start)+1)) +
                                 ind1.P24[i]*exp(logP24F1)*exp(-exp(logM)*(i-(ts1.P24-ts.start)+1)) +
                                 ind1.P25[i]*exp(logP25F1)*exp(-exp(logM)*(i-(ts1.P25-ts.start)+1)) +
                                 ind1.P26[i]*exp(logP26F1)*exp(-exp(logM)*(i-(ts1.P26-ts.start)+1)) +
                                 ind1.P27[i]*exp(logP27F1)*exp(-exp(logM)*(i-(ts1.P27-ts.start)+1)) +
                                 ind1.P28[i]*exp(logP28F1)*exp(-exp(logM)*(i-(ts1.P28-ts.start)+1)) +
                                 ind1.P29[i]*exp(logP29F1)*exp(-exp(logM)*(i-(ts1.P29-ts.start)+1)) +
                                 ind1.P30[i]*exp(logP30F1)*exp(-exp(logM)*(i-(ts1.P30-ts.start)+1)) +
                                 ind1.P31[i]*exp(logP31F1)*exp(-exp(logM)*(i-(ts1.P31-ts.start)+1)) +
                                 ind1.P32[i]*exp(logP32F1)*exp(-exp(logM)*(i-(ts1.P32-ts.start)+1)) +
                                 ind1.P33[i]*exp(logP33F1)*exp(-exp(logM)*(i-(ts1.P33-ts.start)+1)) +
                                 ind1.P34[i]*exp(logP34F1)*exp(-exp(logM)*(i-(ts1.P34-ts.start)+1)) +
                                 ind1.P35[i]*exp(logP35F1)*exp(-exp(logM)*(i-(ts1.P35-ts.start)+1)) +
                                 ind1.P36[i]*exp(logP36F1)*exp(-exp(logM)*(i-(ts1.P36-ts.start)+1)) +
                                 ind1.P37[i]*exp(logP37F1)*exp(-exp(logM)*(i-(ts1.P37-ts.start)+1)) +
                                 ind1.P38[i]*exp(logP38F1)*exp(-exp(logM)*(i-(ts1.P38-ts.start)+1)) +
                                 ind1.P39[i]*exp(logP39F1)*exp(-exp(logM)*(i-(ts1.P39-ts.start)+1)) +
                                 ind1.P40[i]*exp(logP40F1)*exp(-exp(logM)*(i-(ts1.P40-ts.start)+1)) +
                                 ind1.P41[i]*exp(logP41F1)*exp(-exp(logM)*(i-(ts1.P41-ts.start)+1)) +
                                 ind1.P42[i]*exp(logP42F1)*exp(-exp(logM)*(i-(ts1.P42-ts.start)+1)) +
                                 ind1.P43[i]*exp(logP43F1)*exp(-exp(logM)*(i-(ts1.P43-ts.start)+1)) +
                                 ind1.P44[i]*exp(logP44F1)*exp(-exp(logM)*(i-(ts1.P44-ts.start)+1)) +
                                 ind1.P45[i]*exp(logP45F1)*exp(-exp(logM)*(i-(ts1.P45-ts.start)+1)) +
                                 ind1.P46[i]*exp(logP46F1)*exp(-exp(logM)*(i-(ts1.P46-ts.start)+1)) +
                                 ind1.P47[i]*exp(logP47F1)*exp(-exp(logM)*(i-(ts1.P47-ts.start)+1)) +
                                 ind1.P48[i]*exp(logP48F1)*exp(-exp(logM)*(i-(ts1.P48-ts.start)+1)) +
                                 ind1.P49[i]*exp(logP49F1)*exp(-exp(logM)*(i-(ts1.P49-ts.start)+1)) +
                                 ind1.P50[i]*exp(logP50F1)*exp(-exp(logM)*(i-(ts1.P50-ts.start)+1)) +
                                 ind1.P51[i]*exp(logP51F1)*exp(-exp(logM)*(i-(ts1.P51-ts.start)+1)) +
                                 ind1.P52[i]*exp(logP52F1)*exp(-exp(logM)*(i-(ts1.P52-ts.start)+1)) +
                                 ind1.P53[i]*exp(logP53F1)*exp(-exp(logM)*(i-(ts1.P53-ts.start)+1)) +
                                 ind1.P54[i]*exp(logP54F1)*exp(-exp(logM)*(i-(ts1.P54-ts.start)+1)) +
                                 ind1.P55[i]*exp(logP55F1)*exp(-exp(logM)*(i-(ts1.P55-ts.start)+1)) +
                                 ind1.P56[i]*exp(logP56F1)*exp(-exp(logM)*(i-(ts1.P56-ts.start)+1)) +
                                 ind1.P57[i]*exp(logP57F1)*exp(-exp(logM)*(i-(ts1.P57-ts.start)+1)) +
                                 ind1.P58[i]*exp(logP58F1)*exp(-exp(logM)*(i-(ts1.P58-ts.start)+1)) +
                                 ind1.P59[i]*exp(logP59F1)*exp(-exp(logM)*(i-(ts1.P59-ts.start)+1)) +
                                 ind1.P60[i]*exp(logP60F1)*exp(-exp(logM)*(i-(ts1.P60-ts.start)+1)) +
                                 ind1.P61[i]*exp(logP61F1)*exp(-exp(logM)*(i-(ts1.P61-ts.start)+1)) +
                                 ind1.P62[i]*exp(logP62F1)*exp(-exp(logM)*(i-(ts1.P62-ts.start)+1)) +
                                 ind1.P63[i]*exp(logP63F1)*exp(-exp(logM)*(i-(ts1.P63-ts.start)+1)) +
                                 ind1.P64[i]*exp(logP64F1)*exp(-exp(logM)*(i-(ts1.P64-ts.start)+1)) +
                                 ind1.P65[i]*exp(logP65F1)*exp(-exp(logM)*(i-(ts1.P65-ts.start)+1)) +
                                 ind1.P66[i]*exp(logP66F1)*exp(-exp(logM)*(i-(ts1.P66-ts.start)+1)) +
                                 ind1.P67[i]*exp(logP67F1)*exp(-exp(logM)*(i-(ts1.P67-ts.start)+1)) +
                                 ind1.P68[i]*exp(logP68F1)*exp(-exp(logM)*(i-(ts1.P68-ts.start)+1)) +
                                 ind1.P69[i]*exp(logP69F1)*exp(-exp(logM)*(i-(ts1.P69-ts.start)+1)) +
                                 ind1.P70[i]*exp(logP70F1)*exp(-exp(logM)*(i-(ts1.P70-ts.start)+1)) +
                                 ind1.P71[i]*exp(logP71F1)*exp(-exp(logM)*(i-(ts1.P71-ts.start)+1)) +
                                 ind1.P72[i]*exp(logP72F1)*exp(-exp(logM)*(i-(ts1.P72-ts.start)+1)) +
                                 ind1.P73[i]*exp(logP73F1)*exp(-exp(logM)*(i-(ts1.P73-ts.start)+1)) +
                                 ind1.P74[i]*exp(logP74F1)*exp(-exp(logM)*(i-(ts1.P74-ts.start)+1)) +
                                 ind1.P75[i]*exp(logP75F1)*exp(-exp(logM)*(i-(ts1.P75-ts.start)+1)) +
                                 ind1.P76[i]*exp(logP76F1)*exp(-exp(logM)*(i-(ts1.P76-ts.start)+1)) +
                                 ind1.P77[i]*exp(logP77F1)*exp(-exp(logM)*(i-(ts1.P77-ts.start)+1)) +
                                 ind1.P78[i]*exp(logP78F1)*exp(-exp(logM)*(i-(ts1.P78-ts.start)+1)) +
                                 ind1.P79[i]*exp(logP79F1)*exp(-exp(logM)*(i-(ts1.P79-ts.start)+1)) +
                                 ind1.P80[i]*exp(logP80F1)*exp(-exp(logM)*(i-(ts1.P80-ts.start)+1)) +
                                 ind1.P81[i]*exp(logP81F1)*exp(-exp(logM)*(i-(ts1.P81-ts.start)+1)) +
                                 ind1.P82[i]*exp(logP82F1)*exp(-exp(logM)*(i-(ts1.P82-ts.start)+1)) +
                                 ind1.P83[i]*exp(logP83F1)*exp(-exp(logM)*(i-(ts1.P83-ts.start)+1)) +
                                 ind1.P84[i]*exp(logP84F1)*exp(-exp(logM)*(i-(ts1.P84-ts.start)+1)) +
                                 ind1.P85[i]*exp(logP85F1)*exp(-exp(logM)*(i-(ts1.P85-ts.start)+1)) +
                                 ind1.P86[i]*exp(logP86F1)*exp(-exp(logM)*(i-(ts1.P86-ts.start)+1)) +
                                 ind1.P87[i]*exp(logP87F1)*exp(-exp(logM)*(i-(ts1.P87-ts.start)+1)) +
                                 ind1.P88[i]*exp(logP88F1)*exp(-exp(logM)*(i-(ts1.P88-ts.start)+1)) +
                                 ind1.P89[i]*exp(logP89F1)*exp(-exp(logM)*(i-(ts1.P89-ts.start)+1)) +
                                 ind1.P90[i]*exp(logP90F1)*exp(-exp(logM)*(i-(ts1.P90-ts.start)+1)) +
                                 ind1.P91[i]*exp(logP91F1)*exp(-exp(logM)*(i-(ts1.P91-ts.start)+1)) +
                                 ind1.P92[i]*exp(logP92F1)*exp(-exp(logM)*(i-(ts1.P92-ts.start)+1)) +
                                 ind1.P93[i]*exp(logP93F1)*exp(-exp(logM)*(i-(ts1.P93-ts.start)+1)) +
                                 ind1.P94[i]*exp(logP94F1)*exp(-exp(logM)*(i-(ts1.P94-ts.start)+1)) +
                                 ind1.P95[i]*exp(logP95F1)*exp(-exp(logM)*(i-(ts1.P95-ts.start)+1)) +
                                 ind1.P96[i]*exp(logP96F1)*exp(-exp(logM)*(i-(ts1.P96-ts.start)+1)) +
                                 ind1.P97[i]*exp(logP97F1)*exp(-exp(logM)*(i-(ts1.P97-ts.start)+1)) +
                                 ind1.P98[i]*exp(logP98F1)*exp(-exp(logM)*(i-(ts1.P98-ts.start)+1)) +
                                 ind1.P99[i]*exp(logP99F1)*exp(-exp(logM)*(i-(ts1.P99-ts.start)+1)) +
                                 ind1.P100[i]*exp(logP100F1)*exp(-exp(logM)*(i-(ts1.P100-ts.start)+1)) +
                                 ind2.P1[i]*exp(logP1F2)*exp(-exp(logM)*(i-(ts2.P1-ts.start)+1)) +
                                 ind2.P2[i]*exp(logP2F2)*exp(-exp(logM)*(i-(ts2.P2-ts.start)+1)) +
                                 ind2.P3[i]*exp(logP3F2)*exp(-exp(logM)*(i-(ts2.P3-ts.start)+1)) +
                                 ind2.P4[i]*exp(logP4F2)*exp(-exp(logM)*(i-(ts2.P4-ts.start)+1)) +
                                 ind2.P5[i]*exp(logP5F2)*exp(-exp(logM)*(i-(ts2.P5-ts.start)+1)) +
                                 ind2.P6[i]*exp(logP6F2)*exp(-exp(logM)*(i-(ts2.P6-ts.start)+1)) +
                                 ind2.P7[i]*exp(logP7F2)*exp(-exp(logM)*(i-(ts2.P7-ts.start)+1)) +
                                 ind2.P8[i]*exp(logP8F2)*exp(-exp(logM)*(i-(ts2.P8-ts.start)+1)) +
                                 ind2.P9[i]*exp(logP9F2)*exp(-exp(logM)*(i-(ts2.P9-ts.start)+1)) +
                                 ind2.P10[i]*exp(logP10F2)*exp(-exp(logM)*(i-(ts2.P10-ts.start)+1)) +
                                 ind2.P11[i]*exp(logP11F2)*exp(-exp(logM)*(i-(ts2.P11-ts.start)+1)) +
                                 ind2.P12[i]*exp(logP12F2)*exp(-exp(logM)*(i-(ts2.P12-ts.start)+1)) +
                                 ind2.P13[i]*exp(logP13F2)*exp(-exp(logM)*(i-(ts2.P13-ts.start)+1)) +
                                 ind2.P14[i]*exp(logP14F2)*exp(-exp(logM)*(i-(ts2.P14-ts.start)+1)) +
                                 ind2.P15[i]*exp(logP15F2)*exp(-exp(logM)*(i-(ts2.P15-ts.start)+1)) +
                                 ind2.P16[i]*exp(logP16F2)*exp(-exp(logM)*(i-(ts2.P16-ts.start)+1)) +
                                 ind2.P17[i]*exp(logP17F2)*exp(-exp(logM)*(i-(ts2.P17-ts.start)+1)) +
                                 ind2.P18[i]*exp(logP18F2)*exp(-exp(logM)*(i-(ts2.P18-ts.start)+1)) +
                                 ind2.P19[i]*exp(logP19F2)*exp(-exp(logM)*(i-(ts2.P19-ts.start)+1)) +
                                 ind2.P20[i]*exp(logP20F2)*exp(-exp(logM)*(i-(ts2.P20-ts.start)+1)) +
                                 ind2.P21[i]*exp(logP21F2)*exp(-exp(logM)*(i-(ts2.P21-ts.start)+1)) +
                                 ind2.P22[i]*exp(logP22F2)*exp(-exp(logM)*(i-(ts2.P22-ts.start)+1)) +
                                 ind2.P23[i]*exp(logP23F2)*exp(-exp(logM)*(i-(ts2.P23-ts.start)+1)) +
                                 ind2.P24[i]*exp(logP24F2)*exp(-exp(logM)*(i-(ts2.P24-ts.start)+1)) +
                                 ind2.P25[i]*exp(logP25F2)*exp(-exp(logM)*(i-(ts2.P25-ts.start)+1)) +
                                 ind2.P26[i]*exp(logP26F2)*exp(-exp(logM)*(i-(ts2.P26-ts.start)+1)) +
                                 ind2.P27[i]*exp(logP27F2)*exp(-exp(logM)*(i-(ts2.P27-ts.start)+1)) +
                                 ind2.P28[i]*exp(logP28F2)*exp(-exp(logM)*(i-(ts2.P28-ts.start)+1)) +
                                 ind2.P29[i]*exp(logP29F2)*exp(-exp(logM)*(i-(ts2.P29-ts.start)+1)) +
                                 ind2.P30[i]*exp(logP30F2)*exp(-exp(logM)*(i-(ts2.P30-ts.start)+1)) +
                                 ind2.P31[i]*exp(logP31F2)*exp(-exp(logM)*(i-(ts2.P31-ts.start)+1)) +
                                 ind2.P32[i]*exp(logP32F2)*exp(-exp(logM)*(i-(ts2.P32-ts.start)+1)) +
                                 ind2.P33[i]*exp(logP33F2)*exp(-exp(logM)*(i-(ts2.P33-ts.start)+1)) +
                                 ind2.P34[i]*exp(logP34F2)*exp(-exp(logM)*(i-(ts2.P34-ts.start)+1)) +
                                 ind2.P35[i]*exp(logP35F2)*exp(-exp(logM)*(i-(ts2.P35-ts.start)+1)) +
                                 ind2.P36[i]*exp(logP36F2)*exp(-exp(logM)*(i-(ts2.P36-ts.start)+1)) +
                                 ind2.P37[i]*exp(logP37F2)*exp(-exp(logM)*(i-(ts2.P37-ts.start)+1)) +
                                 ind2.P38[i]*exp(logP38F2)*exp(-exp(logM)*(i-(ts2.P38-ts.start)+1)) +
                                 ind2.P39[i]*exp(logP39F2)*exp(-exp(logM)*(i-(ts2.P39-ts.start)+1)) +
                                 ind2.P40[i]*exp(logP40F2)*exp(-exp(logM)*(i-(ts2.P40-ts.start)+1)) +
                                 ind2.P41[i]*exp(logP41F2)*exp(-exp(logM)*(i-(ts2.P41-ts.start)+1)) +
                                 ind2.P42[i]*exp(logP42F2)*exp(-exp(logM)*(i-(ts2.P42-ts.start)+1)) +
                                 ind2.P43[i]*exp(logP43F2)*exp(-exp(logM)*(i-(ts2.P43-ts.start)+1)) +
                                 ind2.P44[i]*exp(logP44F2)*exp(-exp(logM)*(i-(ts2.P44-ts.start)+1)) +
                                 ind2.P45[i]*exp(logP45F2)*exp(-exp(logM)*(i-(ts2.P45-ts.start)+1)) +
                                 ind2.P46[i]*exp(logP46F2)*exp(-exp(logM)*(i-(ts2.P46-ts.start)+1)) +
                                 ind2.P47[i]*exp(logP47F2)*exp(-exp(logM)*(i-(ts2.P47-ts.start)+1)) +
                                 ind2.P48[i]*exp(logP48F2)*exp(-exp(logM)*(i-(ts2.P48-ts.start)+1)) +
                                 ind2.P49[i]*exp(logP49F2)*exp(-exp(logM)*(i-(ts2.P49-ts.start)+1)) +
                                 ind2.P50[i]*exp(logP50F2)*exp(-exp(logM)*(i-(ts2.P50-ts.start)+1)) +
                                 ind2.P51[i]*exp(logP51F2)*exp(-exp(logM)*(i-(ts2.P51-ts.start)+1)) +
                                 ind2.P52[i]*exp(logP52F2)*exp(-exp(logM)*(i-(ts2.P52-ts.start)+1)) +
                                 ind2.P53[i]*exp(logP53F2)*exp(-exp(logM)*(i-(ts2.P53-ts.start)+1)) +
                                 ind2.P54[i]*exp(logP54F2)*exp(-exp(logM)*(i-(ts2.P54-ts.start)+1)) +
                                 ind2.P55[i]*exp(logP55F2)*exp(-exp(logM)*(i-(ts2.P55-ts.start)+1)) +
                                 ind2.P56[i]*exp(logP56F2)*exp(-exp(logM)*(i-(ts2.P56-ts.start)+1)) +
                                 ind2.P57[i]*exp(logP57F2)*exp(-exp(logM)*(i-(ts2.P57-ts.start)+1)) +
                                 ind2.P58[i]*exp(logP58F2)*exp(-exp(logM)*(i-(ts2.P58-ts.start)+1)) +
                                 ind2.P59[i]*exp(logP59F2)*exp(-exp(logM)*(i-(ts2.P59-ts.start)+1)) +
                                 ind2.P60[i]*exp(logP60F2)*exp(-exp(logM)*(i-(ts2.P60-ts.start)+1)) +
                                 ind2.P61[i]*exp(logP61F2)*exp(-exp(logM)*(i-(ts2.P61-ts.start)+1)) +
                                 ind2.P62[i]*exp(logP62F2)*exp(-exp(logM)*(i-(ts2.P62-ts.start)+1)) +
                                 ind2.P63[i]*exp(logP63F2)*exp(-exp(logM)*(i-(ts2.P63-ts.start)+1)) +
                                 ind2.P64[i]*exp(logP64F2)*exp(-exp(logM)*(i-(ts2.P64-ts.start)+1)) +
                                 ind2.P65[i]*exp(logP65F2)*exp(-exp(logM)*(i-(ts2.P65-ts.start)+1)) +
                                 ind2.P66[i]*exp(logP66F2)*exp(-exp(logM)*(i-(ts2.P66-ts.start)+1)) +
                                 ind2.P67[i]*exp(logP67F2)*exp(-exp(logM)*(i-(ts2.P67-ts.start)+1)) +
                                 ind2.P68[i]*exp(logP68F2)*exp(-exp(logM)*(i-(ts2.P68-ts.start)+1)) +
                                 ind2.P69[i]*exp(logP69F2)*exp(-exp(logM)*(i-(ts2.P69-ts.start)+1)) +
                                 ind2.P70[i]*exp(logP70F2)*exp(-exp(logM)*(i-(ts2.P70-ts.start)+1)) +
                                 ind2.P71[i]*exp(logP71F2)*exp(-exp(logM)*(i-(ts2.P71-ts.start)+1)) +
                                 ind2.P72[i]*exp(logP72F2)*exp(-exp(logM)*(i-(ts2.P72-ts.start)+1)) +
                                 ind2.P73[i]*exp(logP73F2)*exp(-exp(logM)*(i-(ts2.P73-ts.start)+1)) +
                                 ind2.P74[i]*exp(logP74F2)*exp(-exp(logM)*(i-(ts2.P74-ts.start)+1)) +
                                 ind2.P75[i]*exp(logP75F2)*exp(-exp(logM)*(i-(ts2.P75-ts.start)+1)) +
                                 ind2.P76[i]*exp(logP76F2)*exp(-exp(logM)*(i-(ts2.P76-ts.start)+1)) +
                                 ind2.P77[i]*exp(logP77F2)*exp(-exp(logM)*(i-(ts2.P77-ts.start)+1)) +
                                 ind2.P78[i]*exp(logP78F2)*exp(-exp(logM)*(i-(ts2.P78-ts.start)+1)) +
                                 ind2.P79[i]*exp(logP79F2)*exp(-exp(logM)*(i-(ts2.P79-ts.start)+1)) +
                                 ind2.P80[i]*exp(logP80F2)*exp(-exp(logM)*(i-(ts2.P80-ts.start)+1)) +
                                 ind2.P81[i]*exp(logP81F2)*exp(-exp(logM)*(i-(ts2.P81-ts.start)+1)) +
                                 ind2.P82[i]*exp(logP82F2)*exp(-exp(logM)*(i-(ts2.P82-ts.start)+1)) +
                                 ind2.P83[i]*exp(logP83F2)*exp(-exp(logM)*(i-(ts2.P83-ts.start)+1)) +
                                 ind2.P84[i]*exp(logP84F2)*exp(-exp(logM)*(i-(ts2.P84-ts.start)+1)) +
                                 ind2.P85[i]*exp(logP85F2)*exp(-exp(logM)*(i-(ts2.P85-ts.start)+1)) +
                                 ind2.P86[i]*exp(logP86F2)*exp(-exp(logM)*(i-(ts2.P86-ts.start)+1)) +
                                 ind2.P87[i]*exp(logP87F2)*exp(-exp(logM)*(i-(ts2.P87-ts.start)+1)) +
                                 ind2.P88[i]*exp(logP88F2)*exp(-exp(logM)*(i-(ts2.P88-ts.start)+1)) +
                                 ind2.P89[i]*exp(logP89F2)*exp(-exp(logM)*(i-(ts2.P89-ts.start)+1)) +
                                 ind2.P90[i]*exp(logP90F2)*exp(-exp(logM)*(i-(ts2.P90-ts.start)+1)) +
                                 ind2.P91[i]*exp(logP91F2)*exp(-exp(logM)*(i-(ts2.P91-ts.start)+1)) +
                                 ind2.P92[i]*exp(logP92F2)*exp(-exp(logM)*(i-(ts2.P92-ts.start)+1)) +
                                 ind2.P93[i]*exp(logP93F2)*exp(-exp(logM)*(i-(ts2.P93-ts.start)+1)) +
                                 ind2.P94[i]*exp(logP94F2)*exp(-exp(logM)*(i-(ts2.P94-ts.start)+1)) +
                                 ind2.P95[i]*exp(logP95F2)*exp(-exp(logM)*(i-(ts2.P95-ts.start)+1)) +
                                 ind2.P96[i]*exp(logP96F2)*exp(-exp(logM)*(i-(ts2.P96-ts.start)+1)) +
                                 ind2.P97[i]*exp(logP97F2)*exp(-exp(logM)*(i-(ts2.P97-ts.start)+1)) +
                                 ind2.P98[i]*exp(logP98F2)*exp(-exp(logM)*(i-(ts2.P98-ts.start)+1)) +
                                 ind1.P99[i]*exp(logP99F1)*exp(-exp(logM)*(i-(ts1.P99-ts.start)+1)) +
                                 ind1.P100[i]*exp(logP100F1)*exp(-exp(logM)*(i-(ts1.P100-ts.start)+1)) -
                                 mccum[i]*exp(-exp(logM)/2);
                     }
                  effeff1   <- obseff1^(exp(logalpha1));
                  effn1     <- nstep^(exp(logbeta1));
                  predcat1  <- exp(logscale1)*(effeff1*effn1)*exp(-exp(logM)/2);
                  effeff2   <- obseff2^(exp(logalpha2));
                  effn2     <- nstep^(exp(logbeta2));
                  predcat2  <- exp(logscale2)*(effeff2*effn2)*exp(-exp(logM)/2);
                  Likel1    <- .CatDynLik(obscat1,predcat1,distr[1],npar=length(par)/2+1)
                  Likel2    <- .CatDynLik(obscat2,predcat2,distr[2],npar=length(par)/2+1)
                  if(output == "predict")
                    {
                    catdynexp <- .CatDynExp2F.Res(properties,nstep,obsmbm1,obsmbm2,pp,dates,distr,par,Likel1,Likel2,ts.start,ts.end,obseff1,obscat1,predcat1,obseff2,obscat2,predcat2)
                    class(catdynexp) <- "CatDynExp";
                    return(catdynexp);
                    }
                  else
                    {
                     if(distr == "apnormal" | distr == "aplnormal")
                       {
                        negsup <- ((sealen-2)/2)*log(sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]));
                       }
                     else
                       {
                        negsup <- -sum(Likel1[["Likelihood"]] + Likel2[["Likelihood"]]);
                       }
                     return(negsup);
                    }
 }
